// Copyright (C) 2005-2007, ENPC - INRIA - EDF R&D
// Author(s): Ir�ne Korsakissok, Yelva Roustan
//
// This file is part of the air quality modeling system Polyphemus.
//
// Polyphemus is developed in the INRIA - ENPC joint project-team CLIME and in
// the ENPC - EDF R&D joint laboratory CEREA.
//
// Polyphemus is free software; you can redistribute it and/or modify it under
// the terms of the GNU General Public License as published by the Free
// Software Foundation; either version 2 of the License, or (at your option)
// any later version.
//
// Polyphemus is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
// more details.
//
// For more information, visit the Polyphemus web site:
//      http://cerea.enpc.fr/polyphemus/


#ifndef POLYPHEMUS_FILE_MODELS_BASEPOINTEMISSION_HXX



//////////////
// INCLUDES //
//////////////


#include "ContinuousEmission.cxx"
#include "PuffEmission.cxx"
#include "TemporalEmission.cxx"
#include "ContinuousLineEmission.cxx"

namespace Polyphemus
{
  using namespace std;
  using namespace AtmoData;

  /////////////////////
  // POINT EMISSIONS //
  /////////////////////


  //! This class manages a set of point emissions.
  template<class T>
  class BasePointEmission
  {

  protected:

    //! List of point emissions.
    vector<PointEmissionUnit<T>*> Emission;

  public:

    BasePointEmission();
    virtual ~BasePointEmission();

    void Init(string config_file, vector<string> species_list);
    int GetNumberEmission();
    void GetEmissionCoordinates(T& abscissa, T& ordinate, T& height,
				int emission) const;
    void GetEmissionCoordinates(list<Array<T, 1> >& coordinate_list,
				int emission);
    void SetEmissionCoordinates(T abscissa, T ordinate, T height,
				int emission);
    string GetEmissionType(int emission);
    Date GetDateBeg(int emission);
    bool HasBegun(Date date, int emission);
    bool HasEnded(Date date, int emission);
    vector<int> GetEmittedSpeciesIndex(int emission) const;
    T GetRate(int emission, int species) const;
    void GetEmission(Date date_beg, Date date_end, int species,
		     int emission, Array<T, 2>& point_emission);
    bool IsEmitting(Date current_date, Date next_date, int emission);
    bool HasPlumeRise(int emission);
    void GetPlumeRiseParam(T& velocity, T& temperature,
			   T& diameter, int emission);
    T GetEmissionTimespan(const Date& current_date,
			  const Date& next_date, int emission) const;
  };


} // namespace Polyphemus.


#define POLYPHEMUS_FILE_MODELS_BASEPOINTEMISSION_HXX
#endif
