C------------------------------------------------------------------------
C     Copyright (C) 2001-2008, ENPC - INRIA - EDF R&D
C     
C     This file is part of the air quality modeling system Polyphemus.
C    
C     Polyphemus is developed in the INRIA - ENPC joint project-team
C     CLIME and in the ENPC - EDF R&D joint laboratory CEREA.
C    
C     Polyphemus is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published
C     by the Free Software Foundation; either version 2 of the License,
C     or (at your option) any later version.
C     
C     Polyphemus is distributed in the hope that it will be useful, but
C     WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
C     General Public License for more details.
C     
C     For more information, visit the Polyphemus web site:
C     http://cerea.enpc.fr/polyphemus/
C
C------------------------------------------------------------------------

      SUBROUTINE LU_decompose (ns,M)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine computes an LU factorization of M.
C	  This routine is automatically generated by LU.cpp
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C
C	  nesp: matrix row number from the chemical species number
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     M: on entry, an invertible matrix. On exit, an LU factorization
C     of M.
C     
C     -- OUTPUT VARIABLES
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C------------------------------------------------------------------------

      IMPLICIT NONE


      INTEGER ns
      DOUBLE PRECISION M(ns,ns)
      DOUBLE PRECISION temp




C     Upper part.
      M(3, 62) = M(3, 62) / M(3, 3)

C     Upper part.
      M(4, 58) = M(4, 58) / M(4, 4)

C     Upper part.
      M(5, 58) = M(5, 58) / M(5, 5)

C     Upper part.
      M(6, 58) = M(6, 58) / M(6, 6)

C     Upper part.
      M(7, 58) = M(7, 58) / M(7, 7)

C     Upper part.
      M(8, 58) = M(8, 58) / M(8, 8)

C     Upper part.
      M(9, 58) = M(9, 58) / M(9, 9)

C     Upper part.
      temp = M(10, 9) * M(9, 58)
      M(10, 58) = ( M(10, 58) - temp ) / M(10, 10)

C     Upper part.
      M(11, 58) = M(11, 58) / M(11, 11)

C     Upper part.
      M(12, 64) = M(12, 64) / M(12, 12)
C     Upper part.
      M(12, 66) = M(12, 66) / M(12, 12)

C     Upper part.
      M(13, 56) = M(13, 56) / M(13, 13)
C     Upper part.
      M(13, 58) = M(13, 58) / M(13, 13)

C     Upper part.
      temp = M(14, 7) * M(7, 58)
      temp = temp + M(14, 8) * M(8, 58)
      M(14, 58) = ( M(14, 58) - temp ) / M(14, 14)
C     Upper part.
      M(14, 65) = M(14, 65) / M(14, 14)

C     Upper part.
      M(15, 59) = M(15, 59) / M(15, 15)
C     Upper part.
      M(15, 66) = M(15, 66) / M(15, 15)

C     Upper part.
      M(16, 42) = M(16, 42) / M(16, 16)
C     Upper part.
      M(16, 58) = M(16, 58) / M(16, 16)

C     Upper part.
      M(17, 42) = M(17, 42) / M(17, 17)
C     Upper part.
      M(17, 58) = M(17, 58) / M(17, 17)

C     Upper part.
      M(18, 58) = M(18, 58) / M(18, 18)
C     Upper part.
      M(18, 63) = M(18, 63) / M(18, 18)
C     Upper part.
      M(18, 66) = M(18, 66) / M(18, 18)

C     Upper part.
      M(19, 58) = M(19, 58) / M(19, 19)
C     Upper part.
      M(19, 66) = M(19, 66) / M(19, 19)
C     Upper part.
      M(19, 67) = M(19, 67) / M(19, 19)

C     Upper part.
      M(20, 45) = M(20, 45) / M(20, 20)
C     Upper part.
      M(20, 58) = M(20, 58) / M(20, 20)
C     Upper part.
      M(20, 66) = M(20, 66) / M(20, 20)

C     Upper part.
      M(21, 58) = M(21, 58) / M(21, 21)
C     Upper part.
      M(21, 60) = M(21, 60) / M(21, 21)
C     Upper part.
      M(21, 67) = M(21, 67) / M(21, 21)

C     Upper part.
      M(22, 57) = M(22, 57) / M(22, 22)
C     Upper part.
      M(22, 65) = M(22, 65) / M(22, 22)
C     Upper part.
      M(22, 67) = M(22, 67) / M(22, 22)

C     Upper part.
      M(23, 56) = M(23, 56) / M(23, 23)
C     Upper part.
      temp = M(23, 22) * M(22, 57)
      M(23, 57) = ( M(23, 57) - temp ) / M(23, 23)
C     Upper part.
      M(23, 58) = M(23, 58) / M(23, 23)
C     Upper part.
      temp = M(23, 22) * M(22, 65)
      M(23, 65) = ( M(23, 65) - temp ) / M(23, 23)
C     Upper part.
      temp = M(23, 22) * M(22, 67)
      M(23, 67) = ( M(23, 67) - temp ) / M(23, 23)

C     Upper part.
      M(24, 58) = M(24, 58) / M(24, 24)
C     Upper part.
      M(24, 65) = M(24, 65) / M(24, 24)
C     Upper part.
      M(24, 66) = M(24, 66) / M(24, 24)

C     Upper part.
      M(25, 58) = M(25, 58) / M(25, 25)
C     Upper part.
      M(25, 59) = M(25, 59) / M(25, 25)
C     Upper part.
      M(25, 62) = M(25, 62) / M(25, 25)

C     Upper part.
      M(26, 58) = M(26, 58) / M(26, 26)
C     Upper part.
      M(26, 59) = M(26, 59) / M(26, 26)
C     Upper part.
      M(26, 62) = M(26, 62) / M(26, 26)

C     Upper part.
      temp = M(27, 25) * M(25, 58)
      temp = temp + M(27, 26) * M(26, 58)
      M(27, 58) = ( M(27, 58) - temp ) / M(27, 27)
C     Upper part.
      temp = M(27, 25) * M(25, 59)
      temp = temp + M(27, 26) * M(26, 59)
      M(27, 59) = ( M(27, 59) - temp ) / M(27, 27)
C     Upper part.
      temp = M(27, 25) * M(25, 62)
      temp = temp + M(27, 26) * M(26, 62)
      M(27, 62) = ( M(27, 62) - temp ) / M(27, 27)

C     Upper part.
      temp = M(28, 25) * M(25, 58)
      temp = temp + M(28, 26) * M(26, 58)
      M(28, 58) = ( M(28, 58) - temp ) / M(28, 28)
C     Upper part.
      temp = M(28, 25) * M(25, 59)
      temp = temp + M(28, 26) * M(26, 59)
      M(28, 59) = ( M(28, 59) - temp ) / M(28, 28)
C     Upper part.
      temp = M(28, 25) * M(25, 62)
      temp = temp + M(28, 26) * M(26, 62)
      M(28, 62) = ( M(28, 62) - temp ) / M(28, 28)

C     Upper part.
      temp = M(29, 25) * M(25, 58)
      temp = temp + M(29, 26) * M(26, 58)
      M(29, 58) = ( M(29, 58) - temp ) / M(29, 29)
C     Upper part.
      temp = M(29, 25) * M(25, 59)
      temp = temp + M(29, 26) * M(26, 59)
      M(29, 59) = ( M(29, 59) - temp ) / M(29, 29)
C     Upper part.
      temp = M(29, 25) * M(25, 62)
      temp = temp + M(29, 26) * M(26, 62)
      M(29, 62) = ( M(29, 62) - temp ) / M(29, 29)

C     Upper part.
      temp = M(30, 25) * M(25, 58)
      temp = temp + M(30, 26) * M(26, 58)
      M(30, 58) = ( M(30, 58) - temp ) / M(30, 30)
C     Upper part.
      temp = M(30, 25) * M(25, 59)
      temp = temp + M(30, 26) * M(26, 59)
      M(30, 59) = ( M(30, 59) - temp ) / M(30, 30)
C     Upper part.
      temp = M(30, 25) * M(25, 62)
      temp = temp + M(30, 26) * M(26, 62)
      M(30, 62) = ( M(30, 62) - temp ) / M(30, 30)

C     Upper part.
      M(31, 55) = M(31, 55) / M(31, 31)
C     Upper part.
      M(31, 58) = M(31, 58) / M(31, 31)
C     Upper part.
      M(31, 67) = M(31, 67) / M(31, 31)
C     Upper part.
      M(31, 68) = M(31, 68) / M(31, 31)

C     Upper part.
      M(32, 58) = M(32, 58) / M(32, 32)
C     Upper part.
      M(32, 63) = M(32, 63) / M(32, 32)
C     Upper part.
      M(32, 64) = M(32, 64) / M(32, 32)
C     Upper part.
      M(32, 67) = M(32, 67) / M(32, 32)

C     Upper part.
      M(33, 58) = M(33, 58) / M(33, 33)
C     Upper part.
      M(33, 59) = M(33, 59) / M(33, 33)
C     Upper part.
      M(33, 60) = M(33, 60) / M(33, 33)
C     Upper part.
      M(33, 62) = M(33, 62) / M(33, 33)

C     Upper part.
      temp = M(34, 22) * M(22, 57)
      M(34, 57) = ( M(34, 57) - temp ) / M(34, 34)
C     Upper part.
      temp = M(34, 33) * M(33, 58)
      M(34, 58) = ( M(34, 58) - temp ) / M(34, 34)
C     Upper part.
      temp = M(34, 33) * M(33, 59)
      M(34, 59) = ( M(34, 59) - temp ) / M(34, 34)
C     Upper part.
      temp = M(34, 33) * M(33, 60)
      M(34, 60) = ( M(34, 60) - temp ) / M(34, 34)
C     Upper part.
      temp = M(34, 33) * M(33, 62)
      M(34, 62) = ( M(34, 62) - temp ) / M(34, 34)
C     Upper part.
      temp = M(34, 22) * M(22, 65)
      M(34, 65) = ( M(34, 65) - temp ) / M(34, 34)
C     Upper part.
      temp = M(34, 22) * M(22, 67)
      M(34, 67) = ( M(34, 67) - temp ) / M(34, 34)

C     Upper part.
      M(35, 58) = M(35, 58) / M(35, 35)
C     Upper part.
      M(35, 59) = M(35, 59) / M(35, 35)
C     Upper part.
      M(35, 60) = M(35, 60) / M(35, 35)
C     Upper part.
      M(35, 62) = M(35, 62) / M(35, 35)

C     Upper part.
      M(36, 58) = M(36, 58) / M(36, 36)
C     Upper part.
      M(36, 59) = M(36, 59) / M(36, 36)
C     Upper part.
      M(36, 60) = M(36, 60) / M(36, 36)
C     Upper part.
      M(36, 62) = M(36, 62) / M(36, 36)

C     Upper part.
      M(37, 58) = M(37, 58) / M(37, 37)
C     Upper part.
      M(37, 59) = M(37, 59) / M(37, 37)
C     Upper part.
      M(37, 60) = M(37, 60) / M(37, 37)
C     Upper part.
      M(37, 62) = M(37, 62) / M(37, 37)

C     Upper part.
      M(38, 41) = M(38, 41) / M(38, 38)
C     Upper part.
      temp = M(38, 7) * M(7, 58)
      temp = temp + M(38, 8) * M(8, 58)
      temp = temp + M(38, 14) * M(14, 58)
      M(38, 58) = ( M(38, 58) - temp ) / M(38, 38)
C     Upper part.
      M(38, 59) = M(38, 59) / M(38, 38)
C     Upper part.
      temp = M(38, 14) * M(14, 65)
      M(38, 65) = ( M(38, 65) - temp ) / M(38, 38)
C     Upper part.
      M(38, 67) = M(38, 67) / M(38, 38)

C     Upper part.
      temp = M(39, 38) * M(38, 41)
      M(39, 41) = ( M(39, 41) - temp ) / M(39, 39)
C     Upper part.
      temp = M(39, 14) * M(14, 58)
      temp = temp + M(39, 38) * M(38, 58)
      M(39, 58) = ( M(39, 58) - temp ) / M(39, 39)
C     Upper part.
      temp = M(39, 38) * M(38, 59)
      M(39, 59) = ( M(39, 59) - temp ) / M(39, 39)
C     Upper part.
      M(39, 62) = M(39, 62) / M(39, 39)
C     Upper part.
      temp = M(39, 14) * M(14, 65)
      temp = temp + M(39, 38) * M(38, 65)
      M(39, 65) = ( M(39, 65) - temp ) / M(39, 39)
C     Upper part.
      temp = M(39, 38) * M(38, 67)
      M(39, 67) = ( M(39, 67) - temp ) / M(39, 39)

C     Upper part.
      temp = M(40, 39) * M(39, 41)
      M(40, 41) = ( M(40, 41) - temp ) / M(40, 40)
C     Upper part.
      M(40, 43) = M(40, 43) / M(40, 40)
C     Upper part.
      temp = M(40, 8) * M(8, 58)
      temp = temp + M(40, 39) * M(39, 58)
      M(40, 58) = ( M(40, 58) - temp ) / M(40, 40)
C     Upper part.
      temp = M(40, 39) * M(39, 59)
      M(40, 59) = ( M(40, 59) - temp ) / M(40, 40)
C     Upper part.
      temp = M(40, 39) * M(39, 62)
      M(40, 62) = ( M(40, 62) - temp ) / M(40, 40)
C     Upper part.
      temp = M(40, 39) * M(39, 65)
      M(40, 65) = ( M(40, 65) - temp ) / M(40, 40)
C     Upper part.
      temp = M(40, 39) * M(39, 67)
      M(40, 67) = ( M(40, 67) - temp ) / M(40, 40)

C     Lower part.
      temp = M(41, 38) * M(38, 41)
      M(41, 41) = M(41, 41) - temp
C     Lower part.
      temp = M(47, 38) * M(38, 41)
      M(47, 41) = M(47, 41) - temp
C     Lower part.
      temp = M(48, 39) * M(39, 41)
      M(48, 41) = M(48, 41) - temp
C     Lower part.
      temp = M(50, 38) * M(38, 41)
      M(50, 41) = M(50, 41) - temp
C     Lower part.
      temp = M(51, 39) * M(39, 41)
      temp = temp + M(51, 40) * M(40, 41)
      M(51, 41) = M(51, 41) - temp
C     Lower part.
      temp = M(52, 38) * M(38, 41)
      M(52, 41) = M(52, 41) - temp
C     Lower part.
      temp = M(57, 39) * M(39, 41)
      M(57, 41) = M(57, 41) - temp
C     Lower part.
      temp = M(58, 38) * M(38, 41)
      temp = temp + M(58, 39) * M(39, 41)
      temp = temp + M(58, 40) * M(40, 41)
      M(58, 41) = M(58, 41) - temp
C     Lower part.
      temp = M(59, 38) * M(38, 41)
      M(59, 41) = M(59, 41) - temp
C     Lower part.
      temp = M(62, 39) * M(39, 41)
      M(62, 41) = M(62, 41) - temp
C     Lower part.
      temp = M(64, 39) * M(39, 41)
      temp = temp + M(64, 40) * M(40, 41)
      M(64, 41) = M(64, 41) - temp
C     Lower part.
      temp = M(67, 38) * M(38, 41)
      temp = temp + M(67, 39) * M(39, 41)
      temp = temp + M(67, 40) * M(40, 41)
      M(67, 41) = M(67, 41) - temp
C     Lower part.
      temp = M(68, 38) * M(38, 41)
      temp = temp + M(68, 39) * M(39, 41)
      temp = temp + M(68, 40) * M(40, 41)
      M(68, 41) = M(68, 41) - temp
C     Upper part.
      temp = M(41, 38) * M(38, 58)
      M(41, 58) = ( M(41, 58) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 38) * M(38, 59)
      M(41, 59) = ( M(41, 59) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 38) * M(38, 65)
      M(41, 65) = ( M(41, 65) - temp ) / M(41, 41)
C     Upper part.
      M(41, 66) = M(41, 66) / M(41, 41)
C     Upper part.
      temp = M(41, 38) * M(38, 67)
      M(41, 67) = ( M(41, 67) - temp ) / M(41, 41)

C     Upper part.
      M(42, 58) = M(42, 58) / M(42, 42)
C     Upper part.
      M(42, 59) = M(42, 59) / M(42, 42)
C     Upper part.
      M(42, 60) = M(42, 60) / M(42, 42)
C     Upper part.
      M(42, 62) = M(42, 62) / M(42, 42)
C     Upper part.
      M(42, 66) = M(42, 66) / M(42, 42)

C     Lower part.
      temp = M(51, 40) * M(40, 43)
      M(51, 43) = M(51, 43) - temp
C     Lower part.
      temp = M(58, 40) * M(40, 43)
      M(58, 43) = M(58, 43) - temp
C     Lower part.
      temp = M(64, 40) * M(40, 43)
      M(64, 43) = M(64, 43) - temp
C     Lower part.
      temp = M(67, 40) * M(40, 43)
      M(67, 43) = M(67, 43) - temp
C     Lower part.
      temp = M(68, 40) * M(40, 43)
      M(68, 43) = M(68, 43) - temp
C     Upper part.
      temp = M(43, 42) * M(42, 58)
      M(43, 58) = ( M(43, 58) - temp ) / M(43, 43)
C     Upper part.
      temp = M(43, 42) * M(42, 59)
      M(43, 59) = ( M(43, 59) - temp ) / M(43, 43)
C     Upper part.
      temp = M(43, 42) * M(42, 60)
      M(43, 60) = ( M(43, 60) - temp ) / M(43, 43)
C     Upper part.
      temp = M(43, 42) * M(42, 62)
      M(43, 62) = ( M(43, 62) - temp ) / M(43, 43)
C     Upper part.
      temp = M(43, 42) * M(42, 66)
      M(43, 66) = ( M(43, 66) - temp ) / M(43, 43)

C     Upper part.
      temp = M(44, 20) * M(20, 45)
      M(44, 45) = ( M(44, 45) - temp ) / M(44, 44)
C     Upper part.
      M(44, 55) = M(44, 55) / M(44, 44)
C     Upper part.
      temp = M(44, 14) * M(14, 58)
      temp = temp + M(44, 20) * M(20, 58)
      temp = temp + M(44, 37) * M(37, 58)
      temp = temp + M(44, 41) * M(41, 58)
      temp = temp + M(44, 42) * M(42, 58)
      temp = temp + M(44, 43) * M(43, 58)
      M(44, 58) = ( M(44, 58) - temp ) / M(44, 44)
C     Upper part.
      temp = M(44, 37) * M(37, 59)
      temp = temp + M(44, 41) * M(41, 59)
      temp = temp + M(44, 42) * M(42, 59)
      temp = temp + M(44, 43) * M(43, 59)
      M(44, 59) = ( M(44, 59) - temp ) / M(44, 44)
C     Upper part.
      temp = M(44, 37) * M(37, 60)
      temp = temp + M(44, 42) * M(42, 60)
      temp = temp + M(44, 43) * M(43, 60)
      M(44, 60) = ( M(44, 60) - temp ) / M(44, 44)
C     Upper part.
      temp = M(44, 37) * M(37, 62)
      temp = temp + M(44, 42) * M(42, 62)
      temp = temp + M(44, 43) * M(43, 62)
      M(44, 62) = ( M(44, 62) - temp ) / M(44, 44)
C     Upper part.
      temp = M(44, 14) * M(14, 65)
      temp = temp + M(44, 41) * M(41, 65)
      M(44, 65) = ( M(44, 65) - temp ) / M(44, 44)
C     Upper part.
      temp = M(44, 20) * M(20, 66)
      temp = temp + M(44, 41) * M(41, 66)
      temp = temp + M(44, 42) * M(42, 66)
      temp = temp + M(44, 43) * M(43, 66)
      M(44, 66) = ( M(44, 66) - temp ) / M(44, 44)
C     Upper part.
      temp = M(44, 41) * M(41, 67)
      M(44, 67) = ( M(44, 67) - temp ) / M(44, 44)

C     Lower part.
      temp = M(45, 20) * M(20, 45)
      temp = temp + M(45, 44) * M(44, 45)
      M(45, 45) = M(45, 45) - temp
C     Lower part.
      temp = M(48, 20) * M(20, 45)
      temp = temp + M(48, 44) * M(44, 45)
      M(48, 45) = M(48, 45) - temp
C     Lower part.
      temp = M(50, 44) * M(44, 45)
      M(50, 45) = M(50, 45) - temp
C     Lower part.
      temp = M(55, 20) * M(20, 45)
      M(55, 45) = M(55, 45) - temp
C     Lower part.
      temp = M(57, 44) * M(44, 45)
      M(57, 45) = M(57, 45) - temp
C     Lower part.
      temp = M(58, 44) * M(44, 45)
      M(58, 45) = M(58, 45) - temp
C     Lower part.
      temp = M(61, 20) * M(20, 45)
      temp = temp + M(61, 44) * M(44, 45)
      M(61, 45) = M(61, 45) - temp
C     Lower part.
      temp = M(66, 20) * M(20, 45)
      temp = temp + M(66, 44) * M(44, 45)
      M(66, 45) = M(66, 45) - temp
C     Lower part.
      temp = M(67, 20) * M(20, 45)
      temp = temp + M(67, 44) * M(44, 45)
      M(67, 45) = M(67, 45) - temp
C     Lower part.
      temp = M(68, 20) * M(20, 45)
      M(68, 45) = M(68, 45) - temp
C     Upper part.
      temp = M(45, 44) * M(44, 55)
      M(45, 55) = ( M(45, 55) - temp ) / M(45, 45)
C     Upper part.
      temp = M(45, 8) * M(8, 58)
      temp = temp + M(45, 20) * M(20, 58)
      temp = temp + M(45, 35) * M(35, 58)
      temp = temp + M(45, 36) * M(36, 58)
      temp = temp + M(45, 37) * M(37, 58)
      temp = temp + M(45, 42) * M(42, 58)
      temp = temp + M(45, 43) * M(43, 58)
      temp = temp + M(45, 44) * M(44, 58)
      M(45, 58) = ( M(45, 58) - temp ) / M(45, 45)
C     Upper part.
      temp = M(45, 35) * M(35, 59)
      temp = temp + M(45, 36) * M(36, 59)
      temp = temp + M(45, 37) * M(37, 59)
      temp = temp + M(45, 42) * M(42, 59)
      temp = temp + M(45, 43) * M(43, 59)
      temp = temp + M(45, 44) * M(44, 59)
      M(45, 59) = ( M(45, 59) - temp ) / M(45, 45)
C     Upper part.
      temp = M(45, 35) * M(35, 60)
      temp = temp + M(45, 36) * M(36, 60)
      temp = temp + M(45, 37) * M(37, 60)
      temp = temp + M(45, 42) * M(42, 60)
      temp = temp + M(45, 43) * M(43, 60)
      temp = temp + M(45, 44) * M(44, 60)
      M(45, 60) = ( M(45, 60) - temp ) / M(45, 45)
C     Upper part.
      temp = M(45, 35) * M(35, 62)
      temp = temp + M(45, 36) * M(36, 62)
      temp = temp + M(45, 37) * M(37, 62)
      temp = temp + M(45, 42) * M(42, 62)
      temp = temp + M(45, 43) * M(43, 62)
      temp = temp + M(45, 44) * M(44, 62)
      M(45, 62) = ( M(45, 62) - temp ) / M(45, 45)
C     Upper part.
      temp = M(45, 44) * M(44, 65)
      M(45, 65) = ( M(45, 65) - temp ) / M(45, 45)
C     Upper part.
      temp = M(45, 20) * M(20, 66)
      temp = temp + M(45, 42) * M(42, 66)
      temp = temp + M(45, 43) * M(43, 66)
      temp = temp + M(45, 44) * M(44, 66)
      M(45, 66) = ( M(45, 66) - temp ) / M(45, 45)
C     Upper part.
      temp = M(45, 44) * M(44, 67)
      M(45, 67) = ( M(45, 67) - temp ) / M(45, 45)

C     Upper part.
      M(46, 53) = M(46, 53) / M(46, 46)
C     Upper part.
      M(46, 54) = M(46, 54) / M(46, 46)
C     Upper part.
      M(46, 56) = M(46, 56) / M(46, 46)
C     Upper part.
      M(46, 64) = M(46, 64) / M(46, 46)
C     Upper part.
      M(46, 67) = M(46, 67) / M(46, 46)

C     Upper part.
      M(47, 53) = M(47, 53) / M(47, 47)
C     Upper part.
      M(47, 54) = M(47, 54) / M(47, 47)
C     Upper part.
      temp = M(47, 38) * M(38, 58)
      temp = temp + M(47, 41) * M(41, 58)
      M(47, 58) = ( M(47, 58) - temp ) / M(47, 47)
C     Upper part.
      temp = M(47, 38) * M(38, 59)
      temp = temp + M(47, 41) * M(41, 59)
      M(47, 59) = ( M(47, 59) - temp ) / M(47, 47)
C     Upper part.
      temp = M(47, 38) * M(38, 65)
      temp = temp + M(47, 41) * M(41, 65)
      M(47, 65) = ( M(47, 65) - temp ) / M(47, 47)
C     Upper part.
      temp = M(47, 41) * M(41, 66)
      M(47, 66) = ( M(47, 66) - temp ) / M(47, 47)
C     Upper part.
      temp = M(47, 38) * M(38, 67)
      temp = temp + M(47, 41) * M(41, 67)
      M(47, 67) = ( M(47, 67) - temp ) / M(47, 47)

C     Upper part.
      temp = M(48, 31) * M(31, 55)
      temp = temp + M(48, 44) * M(44, 55)
      temp = temp + M(48, 45) * M(45, 55)
      M(48, 55) = ( M(48, 55) - temp ) / M(48, 48)
C     Upper part.
      temp = M(48, 4) * M(4, 58)
      temp = temp + M(48, 20) * M(20, 58)
      temp = temp + M(48, 31) * M(31, 58)
      temp = temp + M(48, 33) * M(33, 58)
      temp = temp + M(48, 35) * M(35, 58)
      temp = temp + M(48, 36) * M(36, 58)
      temp = temp + M(48, 37) * M(37, 58)
      temp = temp + M(48, 39) * M(39, 58)
      temp = temp + M(48, 41) * M(41, 58)
      temp = temp + M(48, 42) * M(42, 58)
      temp = temp + M(48, 43) * M(43, 58)
      temp = temp + M(48, 44) * M(44, 58)
      temp = temp + M(48, 45) * M(45, 58)
      M(48, 58) = ( M(48, 58) - temp ) / M(48, 48)
C     Upper part.
      temp = M(48, 33) * M(33, 59)
      temp = temp + M(48, 35) * M(35, 59)
      temp = temp + M(48, 36) * M(36, 59)
      temp = temp + M(48, 37) * M(37, 59)
      temp = temp + M(48, 39) * M(39, 59)
      temp = temp + M(48, 41) * M(41, 59)
      temp = temp + M(48, 42) * M(42, 59)
      temp = temp + M(48, 43) * M(43, 59)
      temp = temp + M(48, 44) * M(44, 59)
      temp = temp + M(48, 45) * M(45, 59)
      M(48, 59) = ( M(48, 59) - temp ) / M(48, 48)
C     Upper part.
      temp = M(48, 33) * M(33, 60)
      temp = temp + M(48, 35) * M(35, 60)
      temp = temp + M(48, 36) * M(36, 60)
      temp = temp + M(48, 37) * M(37, 60)
      temp = temp + M(48, 42) * M(42, 60)
      temp = temp + M(48, 43) * M(43, 60)
      temp = temp + M(48, 44) * M(44, 60)
      temp = temp + M(48, 45) * M(45, 60)
      M(48, 60) = ( M(48, 60) - temp ) / M(48, 48)
C     Upper part.
      temp = M(48, 33) * M(33, 62)
      temp = temp + M(48, 35) * M(35, 62)
      temp = temp + M(48, 36) * M(36, 62)
      temp = temp + M(48, 37) * M(37, 62)
      temp = temp + M(48, 39) * M(39, 62)
      temp = temp + M(48, 42) * M(42, 62)
      temp = temp + M(48, 43) * M(43, 62)
      temp = temp + M(48, 44) * M(44, 62)
      temp = temp + M(48, 45) * M(45, 62)
      M(48, 62) = ( M(48, 62) - temp ) / M(48, 48)
C     Upper part.
      temp = M(48, 39) * M(39, 65)
      temp = temp + M(48, 41) * M(41, 65)
      temp = temp + M(48, 44) * M(44, 65)
      temp = temp + M(48, 45) * M(45, 65)
      M(48, 65) = ( M(48, 65) - temp ) / M(48, 48)
C     Upper part.
      temp = M(48, 20) * M(20, 66)
      temp = temp + M(48, 41) * M(41, 66)
      temp = temp + M(48, 42) * M(42, 66)
      temp = temp + M(48, 43) * M(43, 66)
      temp = temp + M(48, 44) * M(44, 66)
      temp = temp + M(48, 45) * M(45, 66)
      M(48, 66) = ( M(48, 66) - temp ) / M(48, 48)
C     Upper part.
      temp = M(48, 31) * M(31, 67)
      temp = temp + M(48, 39) * M(39, 67)
      temp = temp + M(48, 41) * M(41, 67)
      temp = temp + M(48, 44) * M(44, 67)
      temp = temp + M(48, 45) * M(45, 67)
      M(48, 67) = ( M(48, 67) - temp ) / M(48, 48)
C     Upper part.
      temp = M(48, 31) * M(31, 68)
      M(48, 68) = ( M(48, 68) - temp ) / M(48, 48)

C     Upper part.
      M(49, 56) = M(49, 56) / M(49, 49)
C     Upper part.
      M(49, 58) = M(49, 58) / M(49, 49)
C     Upper part.
      M(49, 63) = M(49, 63) / M(49, 49)
C     Upper part.
      M(49, 64) = M(49, 64) / M(49, 49)
C     Upper part.
      M(49, 67) = M(49, 67) / M(49, 49)
C     Upper part.
      M(49, 68) = M(49, 68) / M(49, 49)

C     Upper part.
      temp = M(50, 44) * M(44, 55)
      temp = temp + M(50, 45) * M(45, 55)
      temp = temp + M(50, 48) * M(48, 55)
      M(50, 55) = ( M(50, 55) - temp ) / M(50, 50)
C     Upper part.
      M(50, 57) = M(50, 57) / M(50, 50)
C     Upper part.
      temp = M(50, 38) * M(38, 58)
      temp = temp + M(50, 41) * M(41, 58)
      temp = temp + M(50, 43) * M(43, 58)
      temp = temp + M(50, 44) * M(44, 58)
      temp = temp + M(50, 45) * M(45, 58)
      temp = temp + M(50, 48) * M(48, 58)
      M(50, 58) = ( M(50, 58) - temp ) / M(50, 50)
C     Upper part.
      temp = M(50, 15) * M(15, 59)
      temp = temp + M(50, 38) * M(38, 59)
      temp = temp + M(50, 41) * M(41, 59)
      temp = temp + M(50, 43) * M(43, 59)
      temp = temp + M(50, 44) * M(44, 59)
      temp = temp + M(50, 45) * M(45, 59)
      temp = temp + M(50, 48) * M(48, 59)
      M(50, 59) = ( M(50, 59) - temp ) / M(50, 50)
C     Upper part.
      temp = M(50, 43) * M(43, 60)
      temp = temp + M(50, 44) * M(44, 60)
      temp = temp + M(50, 45) * M(45, 60)
      temp = temp + M(50, 48) * M(48, 60)
      M(50, 60) = ( M(50, 60) - temp ) / M(50, 50)
C     Upper part.
      M(50, 61) = M(50, 61) / M(50, 50)
C     Upper part.
      temp = M(50, 43) * M(43, 62)
      temp = temp + M(50, 44) * M(44, 62)
      temp = temp + M(50, 45) * M(45, 62)
      temp = temp + M(50, 48) * M(48, 62)
      M(50, 62) = ( M(50, 62) - temp ) / M(50, 50)
C     Upper part.
      temp = M(50, 38) * M(38, 65)
      temp = temp + M(50, 41) * M(41, 65)
      temp = temp + M(50, 44) * M(44, 65)
      temp = temp + M(50, 45) * M(45, 65)
      temp = temp + M(50, 48) * M(48, 65)
      M(50, 65) = ( M(50, 65) - temp ) / M(50, 50)
C     Upper part.
      temp = M(50, 15) * M(15, 66)
      temp = temp + M(50, 41) * M(41, 66)
      temp = temp + M(50, 43) * M(43, 66)
      temp = temp + M(50, 44) * M(44, 66)
      temp = temp + M(50, 45) * M(45, 66)
      temp = temp + M(50, 48) * M(48, 66)
      M(50, 66) = ( M(50, 66) - temp ) / M(50, 50)
C     Upper part.
      temp = M(50, 38) * M(38, 67)
      temp = temp + M(50, 41) * M(41, 67)
      temp = temp + M(50, 44) * M(44, 67)
      temp = temp + M(50, 45) * M(45, 67)
      temp = temp + M(50, 48) * M(48, 67)
      M(50, 67) = ( M(50, 67) - temp ) / M(50, 50)
C     Upper part.
      temp = M(50, 48) * M(48, 68)
      M(50, 68) = ( M(50, 68) - temp ) / M(50, 50)

C     Upper part.
      temp = M(51, 48) * M(48, 55)
      M(51, 55) = ( M(51, 55) - temp ) / M(51, 51)
C     Upper part.
      M(51, 57) = M(51, 57) / M(51, 51)
C     Upper part.
      temp = M(51, 33) * M(33, 58)
      temp = temp + M(51, 35) * M(35, 58)
      temp = temp + M(51, 36) * M(36, 58)
      temp = temp + M(51, 37) * M(37, 58)
      temp = temp + M(51, 39) * M(39, 58)
      temp = temp + M(51, 40) * M(40, 58)
      temp = temp + M(51, 41) * M(41, 58)
      temp = temp + M(51, 42) * M(42, 58)
      temp = temp + M(51, 43) * M(43, 58)
      temp = temp + M(51, 48) * M(48, 58)
      M(51, 58) = ( M(51, 58) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 33) * M(33, 59)
      temp = temp + M(51, 35) * M(35, 59)
      temp = temp + M(51, 36) * M(36, 59)
      temp = temp + M(51, 37) * M(37, 59)
      temp = temp + M(51, 39) * M(39, 59)
      temp = temp + M(51, 40) * M(40, 59)
      temp = temp + M(51, 41) * M(41, 59)
      temp = temp + M(51, 42) * M(42, 59)
      temp = temp + M(51, 43) * M(43, 59)
      temp = temp + M(51, 48) * M(48, 59)
      M(51, 59) = ( M(51, 59) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 33) * M(33, 60)
      temp = temp + M(51, 35) * M(35, 60)
      temp = temp + M(51, 36) * M(36, 60)
      temp = temp + M(51, 37) * M(37, 60)
      temp = temp + M(51, 42) * M(42, 60)
      temp = temp + M(51, 43) * M(43, 60)
      temp = temp + M(51, 48) * M(48, 60)
      M(51, 60) = ( M(51, 60) - temp ) / M(51, 51)
C     Upper part.
      M(51, 61) = M(51, 61) / M(51, 51)
C     Upper part.
      temp = M(51, 33) * M(33, 62)
      temp = temp + M(51, 35) * M(35, 62)
      temp = temp + M(51, 36) * M(36, 62)
      temp = temp + M(51, 37) * M(37, 62)
      temp = temp + M(51, 39) * M(39, 62)
      temp = temp + M(51, 40) * M(40, 62)
      temp = temp + M(51, 42) * M(42, 62)
      temp = temp + M(51, 43) * M(43, 62)
      temp = temp + M(51, 48) * M(48, 62)
      M(51, 62) = ( M(51, 62) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 39) * M(39, 65)
      temp = temp + M(51, 40) * M(40, 65)
      temp = temp + M(51, 41) * M(41, 65)
      temp = temp + M(51, 48) * M(48, 65)
      M(51, 65) = ( M(51, 65) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 41) * M(41, 66)
      temp = temp + M(51, 42) * M(42, 66)
      temp = temp + M(51, 43) * M(43, 66)
      temp = temp + M(51, 48) * M(48, 66)
      M(51, 66) = ( M(51, 66) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 39) * M(39, 67)
      temp = temp + M(51, 40) * M(40, 67)
      temp = temp + M(51, 41) * M(41, 67)
      temp = temp + M(51, 48) * M(48, 67)
      M(51, 67) = ( M(51, 67) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 48) * M(48, 68)
      M(51, 68) = ( M(51, 68) - temp ) / M(51, 51)

C     Upper part.
      M(52, 53) = M(52, 53) / M(52, 52)
C     Upper part.
      M(52, 54) = M(52, 54) / M(52, 52)
C     Upper part.
      temp = M(52, 11) * M(11, 58)
      temp = temp + M(52, 35) * M(35, 58)
      temp = temp + M(52, 36) * M(36, 58)
      temp = temp + M(52, 38) * M(38, 58)
      temp = temp + M(52, 41) * M(41, 58)
      M(52, 58) = ( M(52, 58) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 35) * M(35, 59)
      temp = temp + M(52, 36) * M(36, 59)
      temp = temp + M(52, 38) * M(38, 59)
      temp = temp + M(52, 41) * M(41, 59)
      M(52, 59) = ( M(52, 59) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 35) * M(35, 60)
      temp = temp + M(52, 36) * M(36, 60)
      M(52, 60) = ( M(52, 60) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 35) * M(35, 62)
      temp = temp + M(52, 36) * M(36, 62)
      M(52, 62) = ( M(52, 62) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 38) * M(38, 65)
      temp = temp + M(52, 41) * M(41, 65)
      M(52, 65) = ( M(52, 65) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 41) * M(41, 66)
      M(52, 66) = ( M(52, 66) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 38) * M(38, 67)
      temp = temp + M(52, 41) * M(41, 67)
      M(52, 67) = ( M(52, 67) - temp ) / M(52, 52)

C     Upper part.
      M(53, 56) = M(53, 56) / M(53, 53)
C     Upper part.
      temp = M(53, 7) * M(7, 58)
      M(53, 58) = ( M(53, 58) - temp ) / M(53, 53)
C     Upper part.
      M(53, 59) = M(53, 59) / M(53, 53)
C     Upper part.
      M(53, 64) = M(53, 64) / M(53, 53)
C     Upper part.
      M(53, 65) = M(53, 65) / M(53, 53)
C     Upper part.
      M(53, 67) = M(53, 67) / M(53, 53)

C     Upper part.
      M(54, 56) = M(54, 56) / M(54, 54)
C     Upper part.
      temp = M(54, 8) * M(8, 58)
      M(54, 58) = ( M(54, 58) - temp ) / M(54, 54)
C     Upper part.
      M(54, 59) = M(54, 59) / M(54, 54)
C     Upper part.
      M(54, 64) = M(54, 64) / M(54, 54)
C     Upper part.
      M(54, 65) = M(54, 65) / M(54, 54)
C     Upper part.
      M(54, 67) = M(54, 67) / M(54, 54)

C     Lower part.
      temp = M(55, 45) * M(45, 55)
      M(55, 55) = M(55, 55) - temp
C     Lower part.
      temp = M(56, 48) * M(48, 55)
      M(56, 55) = M(56, 55) - temp
C     Lower part.
      temp = M(57, 44) * M(44, 55)
      temp = temp + M(57, 45) * M(45, 55)
      M(57, 55) = M(57, 55) - temp
C     Lower part.
      temp = M(58, 31) * M(31, 55)
      temp = temp + M(58, 44) * M(44, 55)
      temp = temp + M(58, 45) * M(45, 55)
      temp = temp + M(58, 48) * M(48, 55)
      temp = temp + M(58, 50) * M(50, 55)
      temp = temp + M(58, 51) * M(51, 55)
      M(58, 55) = M(58, 55) - temp
C     Lower part.
      temp = M(59, 48) * M(48, 55)
      temp = temp + M(59, 50) * M(50, 55)
      M(59, 55) = M(59, 55) - temp
C     Lower part.
      temp = M(60, 48) * M(48, 55)
      M(60, 55) = M(60, 55) - temp
C     Lower part.
      temp = M(61, 31) * M(31, 55)
      temp = temp + M(61, 44) * M(44, 55)
      temp = temp + M(61, 45) * M(45, 55)
      M(61, 55) = M(61, 55) - temp
C     Lower part.
      temp = M(63, 48) * M(48, 55)
      M(63, 55) = M(63, 55) - temp
C     Lower part.
      temp = M(66, 44) * M(44, 55)
      temp = temp + M(66, 45) * M(45, 55)
      temp = temp + M(66, 50) * M(50, 55)
      M(66, 55) = M(66, 55) - temp
C     Lower part.
      temp = M(67, 31) * M(31, 55)
      temp = temp + M(67, 44) * M(44, 55)
      temp = temp + M(67, 45) * M(45, 55)
      temp = temp + M(67, 48) * M(48, 55)
      temp = temp + M(67, 51) * M(51, 55)
      M(67, 55) = M(67, 55) - temp
C     Lower part.
      temp = M(68, 31) * M(31, 55)
      temp = temp + M(68, 45) * M(45, 55)
      M(68, 55) = M(68, 55) - temp
C     Upper part.
      temp = M(55, 6) * M(6, 58)
      temp = temp + M(55, 20) * M(20, 58)
      temp = temp + M(55, 35) * M(35, 58)
      temp = temp + M(55, 37) * M(37, 58)
      temp = temp + M(55, 42) * M(42, 58)
      temp = temp + M(55, 45) * M(45, 58)
      M(55, 58) = ( M(55, 58) - temp ) / M(55, 55)
C     Upper part.
      temp = M(55, 35) * M(35, 59)
      temp = temp + M(55, 37) * M(37, 59)
      temp = temp + M(55, 42) * M(42, 59)
      temp = temp + M(55, 45) * M(45, 59)
      M(55, 59) = ( M(55, 59) - temp ) / M(55, 55)
C     Upper part.
      temp = M(55, 35) * M(35, 60)
      temp = temp + M(55, 37) * M(37, 60)
      temp = temp + M(55, 42) * M(42, 60)
      temp = temp + M(55, 45) * M(45, 60)
      M(55, 60) = ( M(55, 60) - temp ) / M(55, 55)
C     Upper part.
      temp = M(55, 35) * M(35, 62)
      temp = temp + M(55, 37) * M(37, 62)
      temp = temp + M(55, 42) * M(42, 62)
      temp = temp + M(55, 45) * M(45, 62)
      M(55, 62) = ( M(55, 62) - temp ) / M(55, 55)
C     Upper part.
      temp = M(55, 45) * M(45, 65)
      M(55, 65) = ( M(55, 65) - temp ) / M(55, 55)
C     Upper part.
      temp = M(55, 20) * M(20, 66)
      temp = temp + M(55, 42) * M(42, 66)
      temp = temp + M(55, 45) * M(45, 66)
      M(55, 66) = ( M(55, 66) - temp ) / M(55, 55)
C     Upper part.
      temp = M(55, 45) * M(45, 67)
      M(55, 67) = ( M(55, 67) - temp ) / M(55, 55)
C     Upper part.
      M(55, 68) = M(55, 68) / M(55, 55)

C     Lower part.
      temp = M(56, 23) * M(23, 56)
      temp = temp + M(56, 49) * M(49, 56)
      M(56, 56) = M(56, 56) - temp
C     Lower part.
      temp = M(57, 13) * M(13, 56)
      temp = temp + M(57, 23) * M(23, 56)
      M(57, 56) = M(57, 56) - temp
C     Lower part.
      temp = M(58, 13) * M(13, 56)
      temp = temp + M(58, 23) * M(23, 56)
      temp = temp + M(58, 49) * M(49, 56)
      M(58, 56) = M(58, 56) - temp
C     Lower part.
      temp = M(67, 13) * M(13, 56)
      temp = temp + M(67, 23) * M(23, 56)
      M(67, 56) = M(67, 56) - temp
C     Lower part.
      temp = M(68, 23) * M(23, 56)
      M(68, 56) = M(68, 56) - temp
C     Upper part.
      temp = M(56, 23) * M(23, 57)
      M(56, 57) = ( M(56, 57) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 5) * M(5, 58)
      temp = temp + M(56, 23) * M(23, 58)
      temp = temp + M(56, 32) * M(32, 58)
      temp = temp + M(56, 48) * M(48, 58)
      temp = temp + M(56, 49) * M(49, 58)
      temp = temp + M(56, 55) * M(55, 58)
      M(56, 58) = ( M(56, 58) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 48) * M(48, 59)
      temp = temp + M(56, 55) * M(55, 59)
      M(56, 59) = ( M(56, 59) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 48) * M(48, 60)
      temp = temp + M(56, 55) * M(55, 60)
      M(56, 60) = ( M(56, 60) - temp ) / M(56, 56)
C     Upper part.
      M(56, 61) = M(56, 61) / M(56, 56)
C     Upper part.
      temp = M(56, 48) * M(48, 62)
      temp = temp + M(56, 55) * M(55, 62)
      M(56, 62) = ( M(56, 62) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 32) * M(32, 63)
      temp = temp + M(56, 49) * M(49, 63)
      M(56, 63) = ( M(56, 63) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 32) * M(32, 64)
      temp = temp + M(56, 49) * M(49, 64)
      M(56, 64) = ( M(56, 64) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 23) * M(23, 65)
      temp = temp + M(56, 48) * M(48, 65)
      temp = temp + M(56, 55) * M(55, 65)
      M(56, 65) = ( M(56, 65) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 48) * M(48, 66)
      temp = temp + M(56, 55) * M(55, 66)
      M(56, 66) = ( M(56, 66) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 23) * M(23, 67)
      temp = temp + M(56, 32) * M(32, 67)
      temp = temp + M(56, 48) * M(48, 67)
      temp = temp + M(56, 49) * M(49, 67)
      temp = temp + M(56, 55) * M(55, 67)
      M(56, 67) = ( M(56, 67) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 48) * M(48, 68)
      temp = temp + M(56, 49) * M(49, 68)
      temp = temp + M(56, 55) * M(55, 68)
      M(56, 68) = ( M(56, 68) - temp ) / M(56, 56)

C     Lower part.
      temp = M(57, 22) * M(22, 57)
      temp = temp + M(57, 23) * M(23, 57)
      temp = temp + M(57, 56) * M(56, 57)
      M(57, 57) = M(57, 57) - temp
C     Lower part.
      temp = M(58, 23) * M(23, 57)
      temp = temp + M(58, 34) * M(34, 57)
      temp = temp + M(58, 50) * M(50, 57)
      temp = temp + M(58, 51) * M(51, 57)
      temp = temp + M(58, 56) * M(56, 57)
      M(58, 57) = M(58, 57) - temp
C     Lower part.
      temp = M(59, 50) * M(50, 57)
      M(59, 57) = M(59, 57) - temp
C     Lower part.
      temp = M(61, 56) * M(56, 57)
      M(61, 57) = M(61, 57) - temp
C     Lower part.
      temp = M(64, 56) * M(56, 57)
      M(64, 57) = M(64, 57) - temp
C     Lower part.
      temp = M(65, 22) * M(22, 57)
      temp = temp + M(65, 56) * M(56, 57)
      M(65, 57) = M(65, 57) - temp
C     Lower part.
      temp = M(66, 22) * M(22, 57)
      temp = temp + M(66, 50) * M(50, 57)
      temp = temp + M(66, 56) * M(56, 57)
      M(66, 57) = M(66, 57) - temp
C     Lower part.
      temp = M(67, 22) * M(22, 57)
      temp = temp + M(67, 23) * M(23, 57)
      temp = temp + M(67, 34) * M(34, 57)
      temp = temp + M(67, 51) * M(51, 57)
      temp = temp + M(67, 56) * M(56, 57)
      M(67, 57) = M(67, 57) - temp
C     Lower part.
      temp = M(68, 23) * M(23, 57)
      temp = temp + M(68, 56) * M(56, 57)
      M(68, 57) = M(68, 57) - temp
C     Upper part.
      temp = M(57, 4) * M(4, 58)
      temp = temp + M(57, 13) * M(13, 58)
      temp = temp + M(57, 23) * M(23, 58)
      temp = temp + M(57, 33) * M(33, 58)
      temp = temp + M(57, 35) * M(35, 58)
      temp = temp + M(57, 36) * M(36, 58)
      temp = temp + M(57, 37) * M(37, 58)
      temp = temp + M(57, 39) * M(39, 58)
      temp = temp + M(57, 41) * M(41, 58)
      temp = temp + M(57, 42) * M(42, 58)
      temp = temp + M(57, 43) * M(43, 58)
      temp = temp + M(57, 44) * M(44, 58)
      temp = temp + M(57, 45) * M(45, 58)
      temp = temp + M(57, 55) * M(55, 58)
      temp = temp + M(57, 56) * M(56, 58)
      M(57, 58) = ( M(57, 58) - temp ) / M(57, 57)
C     Upper part.
      temp = M(57, 33) * M(33, 59)
      temp = temp + M(57, 35) * M(35, 59)
      temp = temp + M(57, 36) * M(36, 59)
      temp = temp + M(57, 37) * M(37, 59)
      temp = temp + M(57, 39) * M(39, 59)
      temp = temp + M(57, 41) * M(41, 59)
      temp = temp + M(57, 42) * M(42, 59)
      temp = temp + M(57, 43) * M(43, 59)
      temp = temp + M(57, 44) * M(44, 59)
      temp = temp + M(57, 45) * M(45, 59)
      temp = temp + M(57, 55) * M(55, 59)
      temp = temp + M(57, 56) * M(56, 59)
      M(57, 59) = ( M(57, 59) - temp ) / M(57, 57)
C     Upper part.
      temp = M(57, 33) * M(33, 60)
      temp = temp + M(57, 35) * M(35, 60)
      temp = temp + M(57, 36) * M(36, 60)
      temp = temp + M(57, 37) * M(37, 60)
      temp = temp + M(57, 42) * M(42, 60)
      temp = temp + M(57, 43) * M(43, 60)
      temp = temp + M(57, 44) * M(44, 60)
      temp = temp + M(57, 45) * M(45, 60)
      temp = temp + M(57, 55) * M(55, 60)
      temp = temp + M(57, 56) * M(56, 60)
      M(57, 60) = ( M(57, 60) - temp ) / M(57, 57)
C     Upper part.
      temp = M(57, 56) * M(56, 61)
      M(57, 61) = ( M(57, 61) - temp ) / M(57, 57)
C     Upper part.
      temp = M(57, 33) * M(33, 62)
      temp = temp + M(57, 35) * M(35, 62)
      temp = temp + M(57, 36) * M(36, 62)
      temp = temp + M(57, 37) * M(37, 62)
      temp = temp + M(57, 39) * M(39, 62)
      temp = temp + M(57, 42) * M(42, 62)
      temp = temp + M(57, 43) * M(43, 62)
      temp = temp + M(57, 44) * M(44, 62)
      temp = temp + M(57, 45) * M(45, 62)
      temp = temp + M(57, 55) * M(55, 62)
      temp = temp + M(57, 56) * M(56, 62)
      M(57, 62) = ( M(57, 62) - temp ) / M(57, 57)
C     Upper part.
      temp = M(57, 56) * M(56, 63)
      M(57, 63) = ( M(57, 63) - temp ) / M(57, 57)
C     Upper part.
      temp = M(57, 56) * M(56, 64)
      M(57, 64) = ( M(57, 64) - temp ) / M(57, 57)
C     Upper part.
      temp = M(57, 22) * M(22, 65)
      temp = temp + M(57, 23) * M(23, 65)
      temp = temp + M(57, 39) * M(39, 65)
      temp = temp + M(57, 41) * M(41, 65)
      temp = temp + M(57, 44) * M(44, 65)
      temp = temp + M(57, 45) * M(45, 65)
      temp = temp + M(57, 55) * M(55, 65)
      temp = temp + M(57, 56) * M(56, 65)
      M(57, 65) = ( M(57, 65) - temp ) / M(57, 57)
C     Upper part.
      temp = M(57, 41) * M(41, 66)
      temp = temp + M(57, 42) * M(42, 66)
      temp = temp + M(57, 43) * M(43, 66)
      temp = temp + M(57, 44) * M(44, 66)
      temp = temp + M(57, 45) * M(45, 66)
      temp = temp + M(57, 55) * M(55, 66)
      temp = temp + M(57, 56) * M(56, 66)
      M(57, 66) = ( M(57, 66) - temp ) / M(57, 57)
C     Upper part.
      temp = M(57, 22) * M(22, 67)
      temp = temp + M(57, 23) * M(23, 67)
      temp = temp + M(57, 39) * M(39, 67)
      temp = temp + M(57, 41) * M(41, 67)
      temp = temp + M(57, 44) * M(44, 67)
      temp = temp + M(57, 45) * M(45, 67)
      temp = temp + M(57, 55) * M(55, 67)
      temp = temp + M(57, 56) * M(56, 67)
      M(57, 67) = ( M(57, 67) - temp ) / M(57, 57)
C     Upper part.
      temp = M(57, 55) * M(55, 68)
      temp = temp + M(57, 56) * M(56, 68)
      M(57, 68) = ( M(57, 68) - temp ) / M(57, 57)

C     Lower part.
      temp = M(58, 4) * M(4, 58)
      temp = temp + M(58, 5) * M(5, 58)
      temp = temp + M(58, 6) * M(6, 58)
      temp = temp + M(58, 7) * M(7, 58)
      temp = temp + M(58, 8) * M(8, 58)
      temp = temp + M(58, 9) * M(9, 58)
      temp = temp + M(58, 13) * M(13, 58)
      temp = temp + M(58, 18) * M(18, 58)
      temp = temp + M(58, 19) * M(19, 58)
      temp = temp + M(58, 21) * M(21, 58)
      temp = temp + M(58, 23) * M(23, 58)
      temp = temp + M(58, 24) * M(24, 58)
      temp = temp + M(58, 31) * M(31, 58)
      temp = temp + M(58, 32) * M(32, 58)
      temp = temp + M(58, 33) * M(33, 58)
      temp = temp + M(58, 34) * M(34, 58)
      temp = temp + M(58, 35) * M(35, 58)
      temp = temp + M(58, 36) * M(36, 58)
      temp = temp + M(58, 37) * M(37, 58)
      temp = temp + M(58, 38) * M(38, 58)
      temp = temp + M(58, 39) * M(39, 58)
      temp = temp + M(58, 40) * M(40, 58)
      temp = temp + M(58, 41) * M(41, 58)
      temp = temp + M(58, 42) * M(42, 58)
      temp = temp + M(58, 43) * M(43, 58)
      temp = temp + M(58, 44) * M(44, 58)
      temp = temp + M(58, 45) * M(45, 58)
      temp = temp + M(58, 48) * M(48, 58)
      temp = temp + M(58, 49) * M(49, 58)
      temp = temp + M(58, 50) * M(50, 58)
      temp = temp + M(58, 51) * M(51, 58)
      temp = temp + M(58, 55) * M(55, 58)
      temp = temp + M(58, 56) * M(56, 58)
      temp = temp + M(58, 57) * M(57, 58)
      M(58, 58) = M(58, 58) - temp
C     Lower part.
      temp = M(59, 19) * M(19, 58)
      temp = temp + M(59, 33) * M(33, 58)
      temp = temp + M(59, 35) * M(35, 58)
      temp = temp + M(59, 36) * M(36, 58)
      temp = temp + M(59, 37) * M(37, 58)
      temp = temp + M(59, 38) * M(38, 58)
      temp = temp + M(59, 41) * M(41, 58)
      temp = temp + M(59, 42) * M(42, 58)
      temp = temp + M(59, 43) * M(43, 58)
      temp = temp + M(59, 48) * M(48, 58)
      temp = temp + M(59, 50) * M(50, 58)
      temp = temp + M(59, 55) * M(55, 58)
      temp = temp + M(59, 57) * M(57, 58)
      M(59, 58) = M(59, 58) - temp
C     Lower part.
      temp = M(60, 21) * M(21, 58)
      temp = temp + M(60, 33) * M(33, 58)
      temp = temp + M(60, 35) * M(35, 58)
      temp = temp + M(60, 36) * M(36, 58)
      temp = temp + M(60, 37) * M(37, 58)
      temp = temp + M(60, 42) * M(42, 58)
      temp = temp + M(60, 48) * M(48, 58)
      temp = temp + M(60, 55) * M(55, 58)
      temp = temp + M(60, 57) * M(57, 58)
      M(60, 58) = M(60, 58) - temp
C     Lower part.
      temp = M(61, 4) * M(4, 58)
      temp = temp + M(61, 6) * M(6, 58)
      temp = temp + M(61, 18) * M(18, 58)
      temp = temp + M(61, 20) * M(20, 58)
      temp = temp + M(61, 31) * M(31, 58)
      temp = temp + M(61, 35) * M(35, 58)
      temp = temp + M(61, 36) * M(36, 58)
      temp = temp + M(61, 43) * M(43, 58)
      temp = temp + M(61, 44) * M(44, 58)
      temp = temp + M(61, 45) * M(45, 58)
      temp = temp + M(61, 55) * M(55, 58)
      temp = temp + M(61, 56) * M(56, 58)
      temp = temp + M(61, 57) * M(57, 58)
      M(61, 58) = M(61, 58) - temp
C     Lower part.
      temp = M(62, 33) * M(33, 58)
      temp = temp + M(62, 35) * M(35, 58)
      temp = temp + M(62, 36) * M(36, 58)
      temp = temp + M(62, 37) * M(37, 58)
      temp = temp + M(62, 39) * M(39, 58)
      temp = temp + M(62, 41) * M(41, 58)
      temp = temp + M(62, 42) * M(42, 58)
      temp = temp + M(62, 43) * M(43, 58)
      M(62, 58) = M(62, 58) - temp
C     Lower part.
      temp = M(63, 18) * M(18, 58)
      temp = temp + M(63, 37) * M(37, 58)
      temp = temp + M(63, 42) * M(42, 58)
      temp = temp + M(63, 43) * M(43, 58)
      temp = temp + M(63, 48) * M(48, 58)
      temp = temp + M(63, 55) * M(55, 58)
      M(63, 58) = M(63, 58) - temp
C     Lower part.
      temp = M(64, 32) * M(32, 58)
      temp = temp + M(64, 39) * M(39, 58)
      temp = temp + M(64, 40) * M(40, 58)
      temp = temp + M(64, 41) * M(41, 58)
      temp = temp + M(64, 43) * M(43, 58)
      temp = temp + M(64, 56) * M(56, 58)
      temp = temp + M(64, 57) * M(57, 58)
      M(64, 58) = M(64, 58) - temp
C     Lower part.
      temp = M(65, 14) * M(14, 58)
      temp = temp + M(65, 24) * M(24, 58)
      temp = temp + M(65, 42) * M(42, 58)
      temp = temp + M(65, 55) * M(55, 58)
      temp = temp + M(65, 56) * M(56, 58)
      temp = temp + M(65, 57) * M(57, 58)
      M(65, 58) = M(65, 58) - temp
C     Lower part.
      temp = M(66, 14) * M(14, 58)
      temp = temp + M(66, 18) * M(18, 58)
      temp = temp + M(66, 19) * M(19, 58)
      temp = temp + M(66, 20) * M(20, 58)
      temp = temp + M(66, 24) * M(24, 58)
      temp = temp + M(66, 33) * M(33, 58)
      temp = temp + M(66, 35) * M(35, 58)
      temp = temp + M(66, 36) * M(36, 58)
      temp = temp + M(66, 37) * M(37, 58)
      temp = temp + M(66, 41) * M(41, 58)
      temp = temp + M(66, 42) * M(42, 58)
      temp = temp + M(66, 44) * M(44, 58)
      temp = temp + M(66, 45) * M(45, 58)
      temp = temp + M(66, 50) * M(50, 58)
      temp = temp + M(66, 55) * M(55, 58)
      temp = temp + M(66, 56) * M(56, 58)
      temp = temp + M(66, 57) * M(57, 58)
      M(66, 58) = M(66, 58) - temp
C     Lower part.
      temp = M(67, 4) * M(4, 58)
      temp = temp + M(67, 6) * M(6, 58)
      temp = temp + M(67, 7) * M(7, 58)
      temp = temp + M(67, 8) * M(8, 58)
      temp = temp + M(67, 9) * M(9, 58)
      temp = temp + M(67, 13) * M(13, 58)
      temp = temp + M(67, 14) * M(14, 58)
      temp = temp + M(67, 19) * M(19, 58)
      temp = temp + M(67, 20) * M(20, 58)
      temp = temp + M(67, 21) * M(21, 58)
      temp = temp + M(67, 23) * M(23, 58)
      temp = temp + M(67, 31) * M(31, 58)
      temp = temp + M(67, 33) * M(33, 58)
      temp = temp + M(67, 34) * M(34, 58)
      temp = temp + M(67, 35) * M(35, 58)
      temp = temp + M(67, 36) * M(36, 58)
      temp = temp + M(67, 37) * M(37, 58)
      temp = temp + M(67, 38) * M(38, 58)
      temp = temp + M(67, 39) * M(39, 58)
      temp = temp + M(67, 40) * M(40, 58)
      temp = temp + M(67, 41) * M(41, 58)
      temp = temp + M(67, 42) * M(42, 58)
      temp = temp + M(67, 43) * M(43, 58)
      temp = temp + M(67, 44) * M(44, 58)
      temp = temp + M(67, 45) * M(45, 58)
      temp = temp + M(67, 48) * M(48, 58)
      temp = temp + M(67, 51) * M(51, 58)
      temp = temp + M(67, 55) * M(55, 58)
      temp = temp + M(67, 56) * M(56, 58)
      temp = temp + M(67, 57) * M(57, 58)
      M(67, 58) = M(67, 58) - temp
C     Lower part.
      temp = M(68, 4) * M(4, 58)
      temp = temp + M(68, 6) * M(6, 58)
      temp = temp + M(68, 7) * M(7, 58)
      temp = temp + M(68, 8) * M(8, 58)
      temp = temp + M(68, 20) * M(20, 58)
      temp = temp + M(68, 23) * M(23, 58)
      temp = temp + M(68, 31) * M(31, 58)
      temp = temp + M(68, 33) * M(33, 58)
      temp = temp + M(68, 35) * M(35, 58)
      temp = temp + M(68, 36) * M(36, 58)
      temp = temp + M(68, 37) * M(37, 58)
      temp = temp + M(68, 38) * M(38, 58)
      temp = temp + M(68, 39) * M(39, 58)
      temp = temp + M(68, 40) * M(40, 58)
      temp = temp + M(68, 41) * M(41, 58)
      temp = temp + M(68, 42) * M(42, 58)
      temp = temp + M(68, 43) * M(43, 58)
      temp = temp + M(68, 45) * M(45, 58)
      temp = temp + M(68, 55) * M(55, 58)
      temp = temp + M(68, 56) * M(56, 58)
      temp = temp + M(68, 57) * M(57, 58)
      M(68, 58) = M(68, 58) - temp
C     Upper part.
      temp = M(58, 33) * M(33, 59)
      temp = temp + M(58, 34) * M(34, 59)
      temp = temp + M(58, 35) * M(35, 59)
      temp = temp + M(58, 36) * M(36, 59)
      temp = temp + M(58, 37) * M(37, 59)
      temp = temp + M(58, 38) * M(38, 59)
      temp = temp + M(58, 39) * M(39, 59)
      temp = temp + M(58, 40) * M(40, 59)
      temp = temp + M(58, 41) * M(41, 59)
      temp = temp + M(58, 42) * M(42, 59)
      temp = temp + M(58, 43) * M(43, 59)
      temp = temp + M(58, 44) * M(44, 59)
      temp = temp + M(58, 45) * M(45, 59)
      temp = temp + M(58, 48) * M(48, 59)
      temp = temp + M(58, 50) * M(50, 59)
      temp = temp + M(58, 51) * M(51, 59)
      temp = temp + M(58, 55) * M(55, 59)
      temp = temp + M(58, 56) * M(56, 59)
      temp = temp + M(58, 57) * M(57, 59)
      M(58, 59) = ( M(58, 59) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 21) * M(21, 60)
      temp = temp + M(58, 33) * M(33, 60)
      temp = temp + M(58, 34) * M(34, 60)
      temp = temp + M(58, 35) * M(35, 60)
      temp = temp + M(58, 36) * M(36, 60)
      temp = temp + M(58, 37) * M(37, 60)
      temp = temp + M(58, 42) * M(42, 60)
      temp = temp + M(58, 43) * M(43, 60)
      temp = temp + M(58, 44) * M(44, 60)
      temp = temp + M(58, 45) * M(45, 60)
      temp = temp + M(58, 48) * M(48, 60)
      temp = temp + M(58, 50) * M(50, 60)
      temp = temp + M(58, 51) * M(51, 60)
      temp = temp + M(58, 55) * M(55, 60)
      temp = temp + M(58, 56) * M(56, 60)
      temp = temp + M(58, 57) * M(57, 60)
      M(58, 60) = ( M(58, 60) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 50) * M(50, 61)
      temp = temp + M(58, 51) * M(51, 61)
      temp = temp + M(58, 56) * M(56, 61)
      temp = temp + M(58, 57) * M(57, 61)
      M(58, 61) = ( M(58, 61) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 3) * M(3, 62)
      temp = temp + M(58, 33) * M(33, 62)
      temp = temp + M(58, 34) * M(34, 62)
      temp = temp + M(58, 35) * M(35, 62)
      temp = temp + M(58, 36) * M(36, 62)
      temp = temp + M(58, 37) * M(37, 62)
      temp = temp + M(58, 39) * M(39, 62)
      temp = temp + M(58, 40) * M(40, 62)
      temp = temp + M(58, 42) * M(42, 62)
      temp = temp + M(58, 43) * M(43, 62)
      temp = temp + M(58, 44) * M(44, 62)
      temp = temp + M(58, 45) * M(45, 62)
      temp = temp + M(58, 48) * M(48, 62)
      temp = temp + M(58, 50) * M(50, 62)
      temp = temp + M(58, 51) * M(51, 62)
      temp = temp + M(58, 55) * M(55, 62)
      temp = temp + M(58, 56) * M(56, 62)
      temp = temp + M(58, 57) * M(57, 62)
      M(58, 62) = ( M(58, 62) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 18) * M(18, 63)
      temp = temp + M(58, 32) * M(32, 63)
      temp = temp + M(58, 49) * M(49, 63)
      temp = temp + M(58, 56) * M(56, 63)
      temp = temp + M(58, 57) * M(57, 63)
      M(58, 63) = ( M(58, 63) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 32) * M(32, 64)
      temp = temp + M(58, 49) * M(49, 64)
      temp = temp + M(58, 56) * M(56, 64)
      temp = temp + M(58, 57) * M(57, 64)
      M(58, 64) = ( M(58, 64) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 23) * M(23, 65)
      temp = temp + M(58, 24) * M(24, 65)
      temp = temp + M(58, 34) * M(34, 65)
      temp = temp + M(58, 38) * M(38, 65)
      temp = temp + M(58, 39) * M(39, 65)
      temp = temp + M(58, 40) * M(40, 65)
      temp = temp + M(58, 41) * M(41, 65)
      temp = temp + M(58, 44) * M(44, 65)
      temp = temp + M(58, 45) * M(45, 65)
      temp = temp + M(58, 48) * M(48, 65)
      temp = temp + M(58, 50) * M(50, 65)
      temp = temp + M(58, 51) * M(51, 65)
      temp = temp + M(58, 55) * M(55, 65)
      temp = temp + M(58, 56) * M(56, 65)
      temp = temp + M(58, 57) * M(57, 65)
      M(58, 65) = ( M(58, 65) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 18) * M(18, 66)
      temp = temp + M(58, 19) * M(19, 66)
      temp = temp + M(58, 24) * M(24, 66)
      temp = temp + M(58, 41) * M(41, 66)
      temp = temp + M(58, 42) * M(42, 66)
      temp = temp + M(58, 43) * M(43, 66)
      temp = temp + M(58, 44) * M(44, 66)
      temp = temp + M(58, 45) * M(45, 66)
      temp = temp + M(58, 48) * M(48, 66)
      temp = temp + M(58, 50) * M(50, 66)
      temp = temp + M(58, 51) * M(51, 66)
      temp = temp + M(58, 55) * M(55, 66)
      temp = temp + M(58, 56) * M(56, 66)
      temp = temp + M(58, 57) * M(57, 66)
      M(58, 66) = ( M(58, 66) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 19) * M(19, 67)
      temp = temp + M(58, 21) * M(21, 67)
      temp = temp + M(58, 23) * M(23, 67)
      temp = temp + M(58, 31) * M(31, 67)
      temp = temp + M(58, 32) * M(32, 67)
      temp = temp + M(58, 34) * M(34, 67)
      temp = temp + M(58, 38) * M(38, 67)
      temp = temp + M(58, 39) * M(39, 67)
      temp = temp + M(58, 40) * M(40, 67)
      temp = temp + M(58, 41) * M(41, 67)
      temp = temp + M(58, 44) * M(44, 67)
      temp = temp + M(58, 45) * M(45, 67)
      temp = temp + M(58, 48) * M(48, 67)
      temp = temp + M(58, 49) * M(49, 67)
      temp = temp + M(58, 50) * M(50, 67)
      temp = temp + M(58, 51) * M(51, 67)
      temp = temp + M(58, 55) * M(55, 67)
      temp = temp + M(58, 56) * M(56, 67)
      temp = temp + M(58, 57) * M(57, 67)
      M(58, 67) = ( M(58, 67) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 31) * M(31, 68)
      temp = temp + M(58, 48) * M(48, 68)
      temp = temp + M(58, 49) * M(49, 68)
      temp = temp + M(58, 50) * M(50, 68)
      temp = temp + M(58, 51) * M(51, 68)
      temp = temp + M(58, 55) * M(55, 68)
      temp = temp + M(58, 56) * M(56, 68)
      temp = temp + M(58, 57) * M(57, 68)
      M(58, 68) = ( M(58, 68) - temp ) / M(58, 58)

C     Lower part.
      temp = M(59, 15) * M(15, 59)
      temp = temp + M(59, 33) * M(33, 59)
      temp = temp + M(59, 35) * M(35, 59)
      temp = temp + M(59, 36) * M(36, 59)
      temp = temp + M(59, 37) * M(37, 59)
      temp = temp + M(59, 38) * M(38, 59)
      temp = temp + M(59, 41) * M(41, 59)
      temp = temp + M(59, 42) * M(42, 59)
      temp = temp + M(59, 43) * M(43, 59)
      temp = temp + M(59, 48) * M(48, 59)
      temp = temp + M(59, 50) * M(50, 59)
      temp = temp + M(59, 55) * M(55, 59)
      temp = temp + M(59, 57) * M(57, 59)
      temp = temp + M(59, 58) * M(58, 59)
      M(59, 59) = M(59, 59) - temp
C     Lower part.
      temp = M(60, 33) * M(33, 59)
      temp = temp + M(60, 35) * M(35, 59)
      temp = temp + M(60, 36) * M(36, 59)
      temp = temp + M(60, 37) * M(37, 59)
      temp = temp + M(60, 42) * M(42, 59)
      temp = temp + M(60, 48) * M(48, 59)
      temp = temp + M(60, 55) * M(55, 59)
      temp = temp + M(60, 57) * M(57, 59)
      temp = temp + M(60, 58) * M(58, 59)
      M(60, 59) = M(60, 59) - temp
C     Lower part.
      temp = M(61, 35) * M(35, 59)
      temp = temp + M(61, 36) * M(36, 59)
      temp = temp + M(61, 43) * M(43, 59)
      temp = temp + M(61, 44) * M(44, 59)
      temp = temp + M(61, 45) * M(45, 59)
      temp = temp + M(61, 55) * M(55, 59)
      temp = temp + M(61, 56) * M(56, 59)
      temp = temp + M(61, 57) * M(57, 59)
      temp = temp + M(61, 58) * M(58, 59)
      M(61, 59) = M(61, 59) - temp
C     Lower part.
      temp = M(62, 33) * M(33, 59)
      temp = temp + M(62, 35) * M(35, 59)
      temp = temp + M(62, 36) * M(36, 59)
      temp = temp + M(62, 37) * M(37, 59)
      temp = temp + M(62, 39) * M(39, 59)
      temp = temp + M(62, 41) * M(41, 59)
      temp = temp + M(62, 42) * M(42, 59)
      temp = temp + M(62, 43) * M(43, 59)
      temp = temp + M(62, 58) * M(58, 59)
      M(62, 59) = M(62, 59) - temp
C     Lower part.
      temp = M(63, 37) * M(37, 59)
      temp = temp + M(63, 42) * M(42, 59)
      temp = temp + M(63, 43) * M(43, 59)
      temp = temp + M(63, 48) * M(48, 59)
      temp = temp + M(63, 55) * M(55, 59)
      temp = temp + M(63, 58) * M(58, 59)
      M(63, 59) = M(63, 59) - temp
C     Lower part.
      temp = M(64, 39) * M(39, 59)
      temp = temp + M(64, 40) * M(40, 59)
      temp = temp + M(64, 41) * M(41, 59)
      temp = temp + M(64, 43) * M(43, 59)
      temp = temp + M(64, 56) * M(56, 59)
      temp = temp + M(64, 57) * M(57, 59)
      temp = temp + M(64, 58) * M(58, 59)
      M(64, 59) = M(64, 59) - temp
C     Lower part.
      temp = M(65, 42) * M(42, 59)
      temp = temp + M(65, 55) * M(55, 59)
      temp = temp + M(65, 56) * M(56, 59)
      temp = temp + M(65, 57) * M(57, 59)
      temp = temp + M(65, 58) * M(58, 59)
      M(65, 59) = M(65, 59) - temp
C     Lower part.
      temp = M(66, 15) * M(15, 59)
      temp = temp + M(66, 33) * M(33, 59)
      temp = temp + M(66, 35) * M(35, 59)
      temp = temp + M(66, 36) * M(36, 59)
      temp = temp + M(66, 37) * M(37, 59)
      temp = temp + M(66, 41) * M(41, 59)
      temp = temp + M(66, 42) * M(42, 59)
      temp = temp + M(66, 44) * M(44, 59)
      temp = temp + M(66, 45) * M(45, 59)
      temp = temp + M(66, 50) * M(50, 59)
      temp = temp + M(66, 55) * M(55, 59)
      temp = temp + M(66, 56) * M(56, 59)
      temp = temp + M(66, 57) * M(57, 59)
      temp = temp + M(66, 58) * M(58, 59)
      M(66, 59) = M(66, 59) - temp
C     Lower part.
      temp = M(67, 33) * M(33, 59)
      temp = temp + M(67, 34) * M(34, 59)
      temp = temp + M(67, 35) * M(35, 59)
      temp = temp + M(67, 36) * M(36, 59)
      temp = temp + M(67, 37) * M(37, 59)
      temp = temp + M(67, 38) * M(38, 59)
      temp = temp + M(67, 39) * M(39, 59)
      temp = temp + M(67, 40) * M(40, 59)
      temp = temp + M(67, 41) * M(41, 59)
      temp = temp + M(67, 42) * M(42, 59)
      temp = temp + M(67, 43) * M(43, 59)
      temp = temp + M(67, 44) * M(44, 59)
      temp = temp + M(67, 45) * M(45, 59)
      temp = temp + M(67, 48) * M(48, 59)
      temp = temp + M(67, 51) * M(51, 59)
      temp = temp + M(67, 55) * M(55, 59)
      temp = temp + M(67, 56) * M(56, 59)
      temp = temp + M(67, 57) * M(57, 59)
      temp = temp + M(67, 58) * M(58, 59)
      M(67, 59) = M(67, 59) - temp
C     Lower part.
      temp = M(68, 33) * M(33, 59)
      temp = temp + M(68, 35) * M(35, 59)
      temp = temp + M(68, 36) * M(36, 59)
      temp = temp + M(68, 37) * M(37, 59)
      temp = temp + M(68, 38) * M(38, 59)
      temp = temp + M(68, 39) * M(39, 59)
      temp = temp + M(68, 40) * M(40, 59)
      temp = temp + M(68, 41) * M(41, 59)
      temp = temp + M(68, 42) * M(42, 59)
      temp = temp + M(68, 43) * M(43, 59)
      temp = temp + M(68, 45) * M(45, 59)
      temp = temp + M(68, 55) * M(55, 59)
      temp = temp + M(68, 56) * M(56, 59)
      temp = temp + M(68, 57) * M(57, 59)
      temp = temp + M(68, 58) * M(58, 59)
      M(68, 59) = M(68, 59) - temp
C     Upper part.
      temp = M(59, 33) * M(33, 60)
      temp = temp + M(59, 35) * M(35, 60)
      temp = temp + M(59, 36) * M(36, 60)
      temp = temp + M(59, 37) * M(37, 60)
      temp = temp + M(59, 42) * M(42, 60)
      temp = temp + M(59, 43) * M(43, 60)
      temp = temp + M(59, 48) * M(48, 60)
      temp = temp + M(59, 50) * M(50, 60)
      temp = temp + M(59, 55) * M(55, 60)
      temp = temp + M(59, 57) * M(57, 60)
      temp = temp + M(59, 58) * M(58, 60)
      M(59, 60) = ( M(59, 60) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 50) * M(50, 61)
      temp = temp + M(59, 57) * M(57, 61)
      temp = temp + M(59, 58) * M(58, 61)
      M(59, 61) = ( M(59, 61) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 33) * M(33, 62)
      temp = temp + M(59, 35) * M(35, 62)
      temp = temp + M(59, 36) * M(36, 62)
      temp = temp + M(59, 37) * M(37, 62)
      temp = temp + M(59, 42) * M(42, 62)
      temp = temp + M(59, 43) * M(43, 62)
      temp = temp + M(59, 48) * M(48, 62)
      temp = temp + M(59, 50) * M(50, 62)
      temp = temp + M(59, 55) * M(55, 62)
      temp = temp + M(59, 57) * M(57, 62)
      temp = temp + M(59, 58) * M(58, 62)
      M(59, 62) = ( M(59, 62) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 57) * M(57, 63)
      temp = temp + M(59, 58) * M(58, 63)
      M(59, 63) = ( M(59, 63) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 57) * M(57, 64)
      temp = temp + M(59, 58) * M(58, 64)
      M(59, 64) = ( M(59, 64) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 38) * M(38, 65)
      temp = temp + M(59, 41) * M(41, 65)
      temp = temp + M(59, 48) * M(48, 65)
      temp = temp + M(59, 50) * M(50, 65)
      temp = temp + M(59, 55) * M(55, 65)
      temp = temp + M(59, 57) * M(57, 65)
      temp = temp + M(59, 58) * M(58, 65)
      M(59, 65) = ( M(59, 65) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 15) * M(15, 66)
      temp = temp + M(59, 19) * M(19, 66)
      temp = temp + M(59, 41) * M(41, 66)
      temp = temp + M(59, 42) * M(42, 66)
      temp = temp + M(59, 43) * M(43, 66)
      temp = temp + M(59, 48) * M(48, 66)
      temp = temp + M(59, 50) * M(50, 66)
      temp = temp + M(59, 55) * M(55, 66)
      temp = temp + M(59, 57) * M(57, 66)
      temp = temp + M(59, 58) * M(58, 66)
      M(59, 66) = ( M(59, 66) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 19) * M(19, 67)
      temp = temp + M(59, 38) * M(38, 67)
      temp = temp + M(59, 41) * M(41, 67)
      temp = temp + M(59, 48) * M(48, 67)
      temp = temp + M(59, 50) * M(50, 67)
      temp = temp + M(59, 55) * M(55, 67)
      temp = temp + M(59, 57) * M(57, 67)
      temp = temp + M(59, 58) * M(58, 67)
      M(59, 67) = ( M(59, 67) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 48) * M(48, 68)
      temp = temp + M(59, 50) * M(50, 68)
      temp = temp + M(59, 55) * M(55, 68)
      temp = temp + M(59, 57) * M(57, 68)
      temp = temp + M(59, 58) * M(58, 68)
      M(59, 68) = ( M(59, 68) - temp ) / M(59, 59)

C     Lower part.
      temp = M(60, 21) * M(21, 60)
      temp = temp + M(60, 33) * M(33, 60)
      temp = temp + M(60, 35) * M(35, 60)
      temp = temp + M(60, 36) * M(36, 60)
      temp = temp + M(60, 37) * M(37, 60)
      temp = temp + M(60, 42) * M(42, 60)
      temp = temp + M(60, 48) * M(48, 60)
      temp = temp + M(60, 55) * M(55, 60)
      temp = temp + M(60, 57) * M(57, 60)
      temp = temp + M(60, 58) * M(58, 60)
      temp = temp + M(60, 59) * M(59, 60)
      M(60, 60) = M(60, 60) - temp
C     Lower part.
      temp = M(61, 35) * M(35, 60)
      temp = temp + M(61, 36) * M(36, 60)
      temp = temp + M(61, 43) * M(43, 60)
      temp = temp + M(61, 44) * M(44, 60)
      temp = temp + M(61, 45) * M(45, 60)
      temp = temp + M(61, 55) * M(55, 60)
      temp = temp + M(61, 56) * M(56, 60)
      temp = temp + M(61, 57) * M(57, 60)
      temp = temp + M(61, 58) * M(58, 60)
      temp = temp + M(61, 59) * M(59, 60)
      M(61, 60) = M(61, 60) - temp
C     Lower part.
      temp = M(62, 33) * M(33, 60)
      temp = temp + M(62, 35) * M(35, 60)
      temp = temp + M(62, 36) * M(36, 60)
      temp = temp + M(62, 37) * M(37, 60)
      temp = temp + M(62, 42) * M(42, 60)
      temp = temp + M(62, 43) * M(43, 60)
      temp = temp + M(62, 58) * M(58, 60)
      temp = temp + M(62, 59) * M(59, 60)
      M(62, 60) = M(62, 60) - temp
C     Lower part.
      temp = M(63, 37) * M(37, 60)
      temp = temp + M(63, 42) * M(42, 60)
      temp = temp + M(63, 43) * M(43, 60)
      temp = temp + M(63, 48) * M(48, 60)
      temp = temp + M(63, 55) * M(55, 60)
      temp = temp + M(63, 58) * M(58, 60)
      temp = temp + M(63, 59) * M(59, 60)
      M(63, 60) = M(63, 60) - temp
C     Lower part.
      temp = M(64, 43) * M(43, 60)
      temp = temp + M(64, 56) * M(56, 60)
      temp = temp + M(64, 57) * M(57, 60)
      temp = temp + M(64, 58) * M(58, 60)
      temp = temp + M(64, 59) * M(59, 60)
      M(64, 60) = M(64, 60) - temp
C     Lower part.
      temp = M(65, 42) * M(42, 60)
      temp = temp + M(65, 55) * M(55, 60)
      temp = temp + M(65, 56) * M(56, 60)
      temp = temp + M(65, 57) * M(57, 60)
      temp = temp + M(65, 58) * M(58, 60)
      temp = temp + M(65, 59) * M(59, 60)
      M(65, 60) = M(65, 60) - temp
C     Lower part.
      temp = M(66, 33) * M(33, 60)
      temp = temp + M(66, 35) * M(35, 60)
      temp = temp + M(66, 36) * M(36, 60)
      temp = temp + M(66, 37) * M(37, 60)
      temp = temp + M(66, 42) * M(42, 60)
      temp = temp + M(66, 44) * M(44, 60)
      temp = temp + M(66, 45) * M(45, 60)
      temp = temp + M(66, 50) * M(50, 60)
      temp = temp + M(66, 55) * M(55, 60)
      temp = temp + M(66, 56) * M(56, 60)
      temp = temp + M(66, 57) * M(57, 60)
      temp = temp + M(66, 58) * M(58, 60)
      temp = temp + M(66, 59) * M(59, 60)
      M(66, 60) = M(66, 60) - temp
C     Lower part.
      temp = M(67, 21) * M(21, 60)
      temp = temp + M(67, 33) * M(33, 60)
      temp = temp + M(67, 34) * M(34, 60)
      temp = temp + M(67, 35) * M(35, 60)
      temp = temp + M(67, 36) * M(36, 60)
      temp = temp + M(67, 37) * M(37, 60)
      temp = temp + M(67, 42) * M(42, 60)
      temp = temp + M(67, 43) * M(43, 60)
      temp = temp + M(67, 44) * M(44, 60)
      temp = temp + M(67, 45) * M(45, 60)
      temp = temp + M(67, 48) * M(48, 60)
      temp = temp + M(67, 51) * M(51, 60)
      temp = temp + M(67, 55) * M(55, 60)
      temp = temp + M(67, 56) * M(56, 60)
      temp = temp + M(67, 57) * M(57, 60)
      temp = temp + M(67, 58) * M(58, 60)
      temp = temp + M(67, 59) * M(59, 60)
      M(67, 60) = M(67, 60) - temp
C     Lower part.
      temp = M(68, 33) * M(33, 60)
      temp = temp + M(68, 35) * M(35, 60)
      temp = temp + M(68, 36) * M(36, 60)
      temp = temp + M(68, 37) * M(37, 60)
      temp = temp + M(68, 42) * M(42, 60)
      temp = temp + M(68, 43) * M(43, 60)
      temp = temp + M(68, 45) * M(45, 60)
      temp = temp + M(68, 55) * M(55, 60)
      temp = temp + M(68, 56) * M(56, 60)
      temp = temp + M(68, 57) * M(57, 60)
      temp = temp + M(68, 58) * M(58, 60)
      temp = temp + M(68, 59) * M(59, 60)
      M(68, 60) = M(68, 60) - temp
C     Upper part.
      temp = M(60, 57) * M(57, 61)
      temp = temp + M(60, 58) * M(58, 61)
      temp = temp + M(60, 59) * M(59, 61)
      M(60, 61) = ( M(60, 61) - temp ) / M(60, 60)
C     Upper part.
      temp = M(60, 3) * M(3, 62)
      temp = temp + M(60, 33) * M(33, 62)
      temp = temp + M(60, 35) * M(35, 62)
      temp = temp + M(60, 36) * M(36, 62)
      temp = temp + M(60, 37) * M(37, 62)
      temp = temp + M(60, 42) * M(42, 62)
      temp = temp + M(60, 48) * M(48, 62)
      temp = temp + M(60, 55) * M(55, 62)
      temp = temp + M(60, 57) * M(57, 62)
      temp = temp + M(60, 58) * M(58, 62)
      temp = temp + M(60, 59) * M(59, 62)
      M(60, 62) = ( M(60, 62) - temp ) / M(60, 60)
C     Upper part.
      temp = M(60, 57) * M(57, 63)
      temp = temp + M(60, 58) * M(58, 63)
      temp = temp + M(60, 59) * M(59, 63)
      M(60, 63) = ( M(60, 63) - temp ) / M(60, 60)
C     Upper part.
      temp = M(60, 57) * M(57, 64)
      temp = temp + M(60, 58) * M(58, 64)
      temp = temp + M(60, 59) * M(59, 64)
      M(60, 64) = ( M(60, 64) - temp ) / M(60, 60)
C     Upper part.
      temp = M(60, 48) * M(48, 65)
      temp = temp + M(60, 55) * M(55, 65)
      temp = temp + M(60, 57) * M(57, 65)
      temp = temp + M(60, 58) * M(58, 65)
      temp = temp + M(60, 59) * M(59, 65)
      M(60, 65) = ( M(60, 65) - temp ) / M(60, 60)
C     Upper part.
      temp = M(60, 42) * M(42, 66)
      temp = temp + M(60, 48) * M(48, 66)
      temp = temp + M(60, 55) * M(55, 66)
      temp = temp + M(60, 57) * M(57, 66)
      temp = temp + M(60, 58) * M(58, 66)
      temp = temp + M(60, 59) * M(59, 66)
      M(60, 66) = ( M(60, 66) - temp ) / M(60, 60)
C     Upper part.
      temp = M(60, 21) * M(21, 67)
      temp = temp + M(60, 48) * M(48, 67)
      temp = temp + M(60, 55) * M(55, 67)
      temp = temp + M(60, 57) * M(57, 67)
      temp = temp + M(60, 58) * M(58, 67)
      temp = temp + M(60, 59) * M(59, 67)
      M(60, 67) = ( M(60, 67) - temp ) / M(60, 60)
C     Upper part.
      temp = M(60, 48) * M(48, 68)
      temp = temp + M(60, 55) * M(55, 68)
      temp = temp + M(60, 57) * M(57, 68)
      temp = temp + M(60, 58) * M(58, 68)
      temp = temp + M(60, 59) * M(59, 68)
      M(60, 68) = ( M(60, 68) - temp ) / M(60, 60)

C     Lower part.
      temp = M(61, 56) * M(56, 61)
      temp = temp + M(61, 57) * M(57, 61)
      temp = temp + M(61, 58) * M(58, 61)
      temp = temp + M(61, 59) * M(59, 61)
      temp = temp + M(61, 60) * M(60, 61)
      M(61, 61) = M(61, 61) - temp
C     Lower part.
      temp = M(62, 58) * M(58, 61)
      temp = temp + M(62, 59) * M(59, 61)
      temp = temp + M(62, 60) * M(60, 61)
      M(62, 61) = M(62, 61) - temp
C     Lower part.
      temp = M(63, 58) * M(58, 61)
      temp = temp + M(63, 59) * M(59, 61)
      temp = temp + M(63, 60) * M(60, 61)
      M(63, 61) = M(63, 61) - temp
C     Lower part.
      temp = M(64, 56) * M(56, 61)
      temp = temp + M(64, 57) * M(57, 61)
      temp = temp + M(64, 58) * M(58, 61)
      temp = temp + M(64, 59) * M(59, 61)
      temp = temp + M(64, 60) * M(60, 61)
      M(64, 61) = M(64, 61) - temp
C     Lower part.
      temp = M(65, 56) * M(56, 61)
      temp = temp + M(65, 57) * M(57, 61)
      temp = temp + M(65, 58) * M(58, 61)
      temp = temp + M(65, 59) * M(59, 61)
      temp = temp + M(65, 60) * M(60, 61)
      M(65, 61) = M(65, 61) - temp
C     Lower part.
      temp = M(66, 50) * M(50, 61)
      temp = temp + M(66, 56) * M(56, 61)
      temp = temp + M(66, 57) * M(57, 61)
      temp = temp + M(66, 58) * M(58, 61)
      temp = temp + M(66, 59) * M(59, 61)
      temp = temp + M(66, 60) * M(60, 61)
      M(66, 61) = M(66, 61) - temp
C     Lower part.
      temp = M(67, 51) * M(51, 61)
      temp = temp + M(67, 56) * M(56, 61)
      temp = temp + M(67, 57) * M(57, 61)
      temp = temp + M(67, 58) * M(58, 61)
      temp = temp + M(67, 59) * M(59, 61)
      temp = temp + M(67, 60) * M(60, 61)
      M(67, 61) = M(67, 61) - temp
C     Lower part.
      temp = M(68, 56) * M(56, 61)
      temp = temp + M(68, 57) * M(57, 61)
      temp = temp + M(68, 58) * M(58, 61)
      temp = temp + M(68, 59) * M(59, 61)
      temp = temp + M(68, 60) * M(60, 61)
      M(68, 61) = M(68, 61) - temp
C     Upper part.
      temp = M(61, 35) * M(35, 62)
      temp = temp + M(61, 36) * M(36, 62)
      temp = temp + M(61, 43) * M(43, 62)
      temp = temp + M(61, 44) * M(44, 62)
      temp = temp + M(61, 45) * M(45, 62)
      temp = temp + M(61, 55) * M(55, 62)
      temp = temp + M(61, 56) * M(56, 62)
      temp = temp + M(61, 57) * M(57, 62)
      temp = temp + M(61, 58) * M(58, 62)
      temp = temp + M(61, 59) * M(59, 62)
      temp = temp + M(61, 60) * M(60, 62)
      M(61, 62) = ( M(61, 62) - temp ) / M(61, 61)
C     Upper part.
      temp = M(61, 18) * M(18, 63)
      temp = temp + M(61, 56) * M(56, 63)
      temp = temp + M(61, 57) * M(57, 63)
      temp = temp + M(61, 58) * M(58, 63)
      temp = temp + M(61, 59) * M(59, 63)
      temp = temp + M(61, 60) * M(60, 63)
      M(61, 63) = ( M(61, 63) - temp ) / M(61, 61)
C     Upper part.
      temp = M(61, 56) * M(56, 64)
      temp = temp + M(61, 57) * M(57, 64)
      temp = temp + M(61, 58) * M(58, 64)
      temp = temp + M(61, 59) * M(59, 64)
      temp = temp + M(61, 60) * M(60, 64)
      M(61, 64) = ( M(61, 64) - temp ) / M(61, 61)
C     Upper part.
      temp = M(61, 44) * M(44, 65)
      temp = temp + M(61, 45) * M(45, 65)
      temp = temp + M(61, 55) * M(55, 65)
      temp = temp + M(61, 56) * M(56, 65)
      temp = temp + M(61, 57) * M(57, 65)
      temp = temp + M(61, 58) * M(58, 65)
      temp = temp + M(61, 59) * M(59, 65)
      temp = temp + M(61, 60) * M(60, 65)
      M(61, 65) = ( M(61, 65) - temp ) / M(61, 61)
C     Upper part.
      temp = M(61, 18) * M(18, 66)
      temp = temp + M(61, 20) * M(20, 66)
      temp = temp + M(61, 43) * M(43, 66)
      temp = temp + M(61, 44) * M(44, 66)
      temp = temp + M(61, 45) * M(45, 66)
      temp = temp + M(61, 55) * M(55, 66)
      temp = temp + M(61, 56) * M(56, 66)
      temp = temp + M(61, 57) * M(57, 66)
      temp = temp + M(61, 58) * M(58, 66)
      temp = temp + M(61, 59) * M(59, 66)
      temp = temp + M(61, 60) * M(60, 66)
      M(61, 66) = ( M(61, 66) - temp ) / M(61, 61)
C     Upper part.
      temp = M(61, 31) * M(31, 67)
      temp = temp + M(61, 44) * M(44, 67)
      temp = temp + M(61, 45) * M(45, 67)
      temp = temp + M(61, 55) * M(55, 67)
      temp = temp + M(61, 56) * M(56, 67)
      temp = temp + M(61, 57) * M(57, 67)
      temp = temp + M(61, 58) * M(58, 67)
      temp = temp + M(61, 59) * M(59, 67)
      temp = temp + M(61, 60) * M(60, 67)
      M(61, 67) = ( M(61, 67) - temp ) / M(61, 61)
C     Upper part.
      temp = M(61, 31) * M(31, 68)
      temp = temp + M(61, 55) * M(55, 68)
      temp = temp + M(61, 56) * M(56, 68)
      temp = temp + M(61, 57) * M(57, 68)
      temp = temp + M(61, 58) * M(58, 68)
      temp = temp + M(61, 59) * M(59, 68)
      temp = temp + M(61, 60) * M(60, 68)
      M(61, 68) = ( M(61, 68) - temp ) / M(61, 61)

C     Lower part.
      temp = M(62, 33) * M(33, 62)
      temp = temp + M(62, 35) * M(35, 62)
      temp = temp + M(62, 36) * M(36, 62)
      temp = temp + M(62, 37) * M(37, 62)
      temp = temp + M(62, 39) * M(39, 62)
      temp = temp + M(62, 42) * M(42, 62)
      temp = temp + M(62, 43) * M(43, 62)
      temp = temp + M(62, 58) * M(58, 62)
      temp = temp + M(62, 59) * M(59, 62)
      temp = temp + M(62, 60) * M(60, 62)
      temp = temp + M(62, 61) * M(61, 62)
      M(62, 62) = M(62, 62) - temp
C     Lower part.
      temp = M(63, 37) * M(37, 62)
      temp = temp + M(63, 42) * M(42, 62)
      temp = temp + M(63, 43) * M(43, 62)
      temp = temp + M(63, 48) * M(48, 62)
      temp = temp + M(63, 55) * M(55, 62)
      temp = temp + M(63, 58) * M(58, 62)
      temp = temp + M(63, 59) * M(59, 62)
      temp = temp + M(63, 60) * M(60, 62)
      temp = temp + M(63, 61) * M(61, 62)
      M(63, 62) = M(63, 62) - temp
C     Lower part.
      temp = M(64, 39) * M(39, 62)
      temp = temp + M(64, 40) * M(40, 62)
      temp = temp + M(64, 43) * M(43, 62)
      temp = temp + M(64, 56) * M(56, 62)
      temp = temp + M(64, 57) * M(57, 62)
      temp = temp + M(64, 58) * M(58, 62)
      temp = temp + M(64, 59) * M(59, 62)
      temp = temp + M(64, 60) * M(60, 62)
      temp = temp + M(64, 61) * M(61, 62)
      M(64, 62) = M(64, 62) - temp
C     Lower part.
      temp = M(65, 42) * M(42, 62)
      temp = temp + M(65, 55) * M(55, 62)
      temp = temp + M(65, 56) * M(56, 62)
      temp = temp + M(65, 57) * M(57, 62)
      temp = temp + M(65, 58) * M(58, 62)
      temp = temp + M(65, 59) * M(59, 62)
      temp = temp + M(65, 60) * M(60, 62)
      temp = temp + M(65, 61) * M(61, 62)
      M(65, 62) = M(65, 62) - temp
C     Lower part.
      temp = M(66, 33) * M(33, 62)
      temp = temp + M(66, 35) * M(35, 62)
      temp = temp + M(66, 36) * M(36, 62)
      temp = temp + M(66, 37) * M(37, 62)
      temp = temp + M(66, 42) * M(42, 62)
      temp = temp + M(66, 44) * M(44, 62)
      temp = temp + M(66, 45) * M(45, 62)
      temp = temp + M(66, 50) * M(50, 62)
      temp = temp + M(66, 55) * M(55, 62)
      temp = temp + M(66, 56) * M(56, 62)
      temp = temp + M(66, 57) * M(57, 62)
      temp = temp + M(66, 58) * M(58, 62)
      temp = temp + M(66, 59) * M(59, 62)
      temp = temp + M(66, 60) * M(60, 62)
      temp = temp + M(66, 61) * M(61, 62)
      M(66, 62) = M(66, 62) - temp
C     Lower part.
      temp = M(67, 3) * M(3, 62)
      temp = temp + M(67, 33) * M(33, 62)
      temp = temp + M(67, 34) * M(34, 62)
      temp = temp + M(67, 35) * M(35, 62)
      temp = temp + M(67, 36) * M(36, 62)
      temp = temp + M(67, 37) * M(37, 62)
      temp = temp + M(67, 39) * M(39, 62)
      temp = temp + M(67, 40) * M(40, 62)
      temp = temp + M(67, 42) * M(42, 62)
      temp = temp + M(67, 43) * M(43, 62)
      temp = temp + M(67, 44) * M(44, 62)
      temp = temp + M(67, 45) * M(45, 62)
      temp = temp + M(67, 48) * M(48, 62)
      temp = temp + M(67, 51) * M(51, 62)
      temp = temp + M(67, 55) * M(55, 62)
      temp = temp + M(67, 56) * M(56, 62)
      temp = temp + M(67, 57) * M(57, 62)
      temp = temp + M(67, 58) * M(58, 62)
      temp = temp + M(67, 59) * M(59, 62)
      temp = temp + M(67, 60) * M(60, 62)
      temp = temp + M(67, 61) * M(61, 62)
      M(67, 62) = M(67, 62) - temp
C     Lower part.
      temp = M(68, 33) * M(33, 62)
      temp = temp + M(68, 35) * M(35, 62)
      temp = temp + M(68, 36) * M(36, 62)
      temp = temp + M(68, 37) * M(37, 62)
      temp = temp + M(68, 39) * M(39, 62)
      temp = temp + M(68, 40) * M(40, 62)
      temp = temp + M(68, 42) * M(42, 62)
      temp = temp + M(68, 43) * M(43, 62)
      temp = temp + M(68, 45) * M(45, 62)
      temp = temp + M(68, 55) * M(55, 62)
      temp = temp + M(68, 56) * M(56, 62)
      temp = temp + M(68, 57) * M(57, 62)
      temp = temp + M(68, 58) * M(58, 62)
      temp = temp + M(68, 59) * M(59, 62)
      temp = temp + M(68, 60) * M(60, 62)
      temp = temp + M(68, 61) * M(61, 62)
      M(68, 62) = M(68, 62) - temp
C     Upper part.
      temp = M(62, 58) * M(58, 63)
      temp = temp + M(62, 59) * M(59, 63)
      temp = temp + M(62, 60) * M(60, 63)
      temp = temp + M(62, 61) * M(61, 63)
      M(62, 63) = ( M(62, 63) - temp ) / M(62, 62)
C     Upper part.
      temp = M(62, 58) * M(58, 64)
      temp = temp + M(62, 59) * M(59, 64)
      temp = temp + M(62, 60) * M(60, 64)
      temp = temp + M(62, 61) * M(61, 64)
      M(62, 64) = ( M(62, 64) - temp ) / M(62, 62)
C     Upper part.
      temp = M(62, 39) * M(39, 65)
      temp = temp + M(62, 41) * M(41, 65)
      temp = temp + M(62, 58) * M(58, 65)
      temp = temp + M(62, 59) * M(59, 65)
      temp = temp + M(62, 60) * M(60, 65)
      temp = temp + M(62, 61) * M(61, 65)
      M(62, 65) = ( M(62, 65) - temp ) / M(62, 62)
C     Upper part.
      temp = M(62, 41) * M(41, 66)
      temp = temp + M(62, 42) * M(42, 66)
      temp = temp + M(62, 43) * M(43, 66)
      temp = temp + M(62, 58) * M(58, 66)
      temp = temp + M(62, 59) * M(59, 66)
      temp = temp + M(62, 60) * M(60, 66)
      temp = temp + M(62, 61) * M(61, 66)
      M(62, 66) = ( M(62, 66) - temp ) / M(62, 62)
C     Upper part.
      temp = M(62, 39) * M(39, 67)
      temp = temp + M(62, 41) * M(41, 67)
      temp = temp + M(62, 58) * M(58, 67)
      temp = temp + M(62, 59) * M(59, 67)
      temp = temp + M(62, 60) * M(60, 67)
      temp = temp + M(62, 61) * M(61, 67)
      M(62, 67) = ( M(62, 67) - temp ) / M(62, 62)
C     Upper part.
      temp = M(62, 58) * M(58, 68)
      temp = temp + M(62, 59) * M(59, 68)
      temp = temp + M(62, 60) * M(60, 68)
      temp = temp + M(62, 61) * M(61, 68)
      M(62, 68) = ( M(62, 68) - temp ) / M(62, 62)

C     Lower part.
      temp = M(63, 18) * M(18, 63)
      temp = temp + M(63, 58) * M(58, 63)
      temp = temp + M(63, 59) * M(59, 63)
      temp = temp + M(63, 60) * M(60, 63)
      temp = temp + M(63, 61) * M(61, 63)
      temp = temp + M(63, 62) * M(62, 63)
      M(63, 63) = M(63, 63) - temp
C     Lower part.
      temp = M(64, 32) * M(32, 63)
      temp = temp + M(64, 56) * M(56, 63)
      temp = temp + M(64, 57) * M(57, 63)
      temp = temp + M(64, 58) * M(58, 63)
      temp = temp + M(64, 59) * M(59, 63)
      temp = temp + M(64, 60) * M(60, 63)
      temp = temp + M(64, 61) * M(61, 63)
      temp = temp + M(64, 62) * M(62, 63)
      M(64, 63) = M(64, 63) - temp
C     Lower part.
      temp = M(65, 56) * M(56, 63)
      temp = temp + M(65, 57) * M(57, 63)
      temp = temp + M(65, 58) * M(58, 63)
      temp = temp + M(65, 59) * M(59, 63)
      temp = temp + M(65, 60) * M(60, 63)
      temp = temp + M(65, 61) * M(61, 63)
      temp = temp + M(65, 62) * M(62, 63)
      M(65, 63) = M(65, 63) - temp
C     Lower part.
      temp = M(66, 18) * M(18, 63)
      temp = temp + M(66, 56) * M(56, 63)
      temp = temp + M(66, 57) * M(57, 63)
      temp = temp + M(66, 58) * M(58, 63)
      temp = temp + M(66, 59) * M(59, 63)
      temp = temp + M(66, 60) * M(60, 63)
      temp = temp + M(66, 61) * M(61, 63)
      temp = temp + M(66, 62) * M(62, 63)
      M(66, 63) = M(66, 63) - temp
C     Lower part.
      temp = M(67, 56) * M(56, 63)
      temp = temp + M(67, 57) * M(57, 63)
      temp = temp + M(67, 58) * M(58, 63)
      temp = temp + M(67, 59) * M(59, 63)
      temp = temp + M(67, 60) * M(60, 63)
      temp = temp + M(67, 61) * M(61, 63)
      temp = temp + M(67, 62) * M(62, 63)
      M(67, 63) = M(67, 63) - temp
C     Lower part.
      temp = M(68, 56) * M(56, 63)
      temp = temp + M(68, 57) * M(57, 63)
      temp = temp + M(68, 58) * M(58, 63)
      temp = temp + M(68, 59) * M(59, 63)
      temp = temp + M(68, 60) * M(60, 63)
      temp = temp + M(68, 61) * M(61, 63)
      temp = temp + M(68, 62) * M(62, 63)
      M(68, 63) = M(68, 63) - temp
C     Upper part.
      temp = M(63, 58) * M(58, 64)
      temp = temp + M(63, 59) * M(59, 64)
      temp = temp + M(63, 60) * M(60, 64)
      temp = temp + M(63, 61) * M(61, 64)
      temp = temp + M(63, 62) * M(62, 64)
      M(63, 64) = ( M(63, 64) - temp ) / M(63, 63)
C     Upper part.
      temp = M(63, 48) * M(48, 65)
      temp = temp + M(63, 55) * M(55, 65)
      temp = temp + M(63, 58) * M(58, 65)
      temp = temp + M(63, 59) * M(59, 65)
      temp = temp + M(63, 60) * M(60, 65)
      temp = temp + M(63, 61) * M(61, 65)
      temp = temp + M(63, 62) * M(62, 65)
      M(63, 65) = ( M(63, 65) - temp ) / M(63, 63)
C     Upper part.
      temp = M(63, 18) * M(18, 66)
      temp = temp + M(63, 42) * M(42, 66)
      temp = temp + M(63, 43) * M(43, 66)
      temp = temp + M(63, 48) * M(48, 66)
      temp = temp + M(63, 55) * M(55, 66)
      temp = temp + M(63, 58) * M(58, 66)
      temp = temp + M(63, 59) * M(59, 66)
      temp = temp + M(63, 60) * M(60, 66)
      temp = temp + M(63, 61) * M(61, 66)
      temp = temp + M(63, 62) * M(62, 66)
      M(63, 66) = ( M(63, 66) - temp ) / M(63, 63)
C     Upper part.
      temp = M(63, 48) * M(48, 67)
      temp = temp + M(63, 55) * M(55, 67)
      temp = temp + M(63, 58) * M(58, 67)
      temp = temp + M(63, 59) * M(59, 67)
      temp = temp + M(63, 60) * M(60, 67)
      temp = temp + M(63, 61) * M(61, 67)
      temp = temp + M(63, 62) * M(62, 67)
      M(63, 67) = ( M(63, 67) - temp ) / M(63, 63)
C     Upper part.
      temp = M(63, 48) * M(48, 68)
      temp = temp + M(63, 55) * M(55, 68)
      temp = temp + M(63, 58) * M(58, 68)
      temp = temp + M(63, 59) * M(59, 68)
      temp = temp + M(63, 60) * M(60, 68)
      temp = temp + M(63, 61) * M(61, 68)
      temp = temp + M(63, 62) * M(62, 68)
      M(63, 68) = ( M(63, 68) - temp ) / M(63, 63)

C     Lower part.
      temp = M(64, 12) * M(12, 64)
      temp = temp + M(64, 32) * M(32, 64)
      temp = temp + M(64, 56) * M(56, 64)
      temp = temp + M(64, 57) * M(57, 64)
      temp = temp + M(64, 58) * M(58, 64)
      temp = temp + M(64, 59) * M(59, 64)
      temp = temp + M(64, 60) * M(60, 64)
      temp = temp + M(64, 61) * M(61, 64)
      temp = temp + M(64, 62) * M(62, 64)
      temp = temp + M(64, 63) * M(63, 64)
      M(64, 64) = M(64, 64) - temp
C     Lower part.
      temp = M(65, 56) * M(56, 64)
      temp = temp + M(65, 57) * M(57, 64)
      temp = temp + M(65, 58) * M(58, 64)
      temp = temp + M(65, 59) * M(59, 64)
      temp = temp + M(65, 60) * M(60, 64)
      temp = temp + M(65, 61) * M(61, 64)
      temp = temp + M(65, 62) * M(62, 64)
      temp = temp + M(65, 63) * M(63, 64)
      M(65, 64) = M(65, 64) - temp
C     Lower part.
      temp = M(66, 12) * M(12, 64)
      temp = temp + M(66, 56) * M(56, 64)
      temp = temp + M(66, 57) * M(57, 64)
      temp = temp + M(66, 58) * M(58, 64)
      temp = temp + M(66, 59) * M(59, 64)
      temp = temp + M(66, 60) * M(60, 64)
      temp = temp + M(66, 61) * M(61, 64)
      temp = temp + M(66, 62) * M(62, 64)
      temp = temp + M(66, 63) * M(63, 64)
      M(66, 64) = M(66, 64) - temp
C     Lower part.
      temp = M(67, 56) * M(56, 64)
      temp = temp + M(67, 57) * M(57, 64)
      temp = temp + M(67, 58) * M(58, 64)
      temp = temp + M(67, 59) * M(59, 64)
      temp = temp + M(67, 60) * M(60, 64)
      temp = temp + M(67, 61) * M(61, 64)
      temp = temp + M(67, 62) * M(62, 64)
      temp = temp + M(67, 63) * M(63, 64)
      M(67, 64) = M(67, 64) - temp
C     Lower part.
      temp = M(68, 56) * M(56, 64)
      temp = temp + M(68, 57) * M(57, 64)
      temp = temp + M(68, 58) * M(58, 64)
      temp = temp + M(68, 59) * M(59, 64)
      temp = temp + M(68, 60) * M(60, 64)
      temp = temp + M(68, 61) * M(61, 64)
      temp = temp + M(68, 62) * M(62, 64)
      temp = temp + M(68, 63) * M(63, 64)
      M(68, 64) = M(68, 64) - temp
C     Upper part.
      temp = M(64, 39) * M(39, 65)
      temp = temp + M(64, 40) * M(40, 65)
      temp = temp + M(64, 41) * M(41, 65)
      temp = temp + M(64, 56) * M(56, 65)
      temp = temp + M(64, 57) * M(57, 65)
      temp = temp + M(64, 58) * M(58, 65)
      temp = temp + M(64, 59) * M(59, 65)
      temp = temp + M(64, 60) * M(60, 65)
      temp = temp + M(64, 61) * M(61, 65)
      temp = temp + M(64, 62) * M(62, 65)
      temp = temp + M(64, 63) * M(63, 65)
      M(64, 65) = ( M(64, 65) - temp ) / M(64, 64)
C     Upper part.
      temp = M(64, 12) * M(12, 66)
      temp = temp + M(64, 41) * M(41, 66)
      temp = temp + M(64, 43) * M(43, 66)
      temp = temp + M(64, 56) * M(56, 66)
      temp = temp + M(64, 57) * M(57, 66)
      temp = temp + M(64, 58) * M(58, 66)
      temp = temp + M(64, 59) * M(59, 66)
      temp = temp + M(64, 60) * M(60, 66)
      temp = temp + M(64, 61) * M(61, 66)
      temp = temp + M(64, 62) * M(62, 66)
      temp = temp + M(64, 63) * M(63, 66)
      M(64, 66) = ( M(64, 66) - temp ) / M(64, 64)
C     Upper part.
      temp = M(64, 32) * M(32, 67)
      temp = temp + M(64, 39) * M(39, 67)
      temp = temp + M(64, 40) * M(40, 67)
      temp = temp + M(64, 41) * M(41, 67)
      temp = temp + M(64, 56) * M(56, 67)
      temp = temp + M(64, 57) * M(57, 67)
      temp = temp + M(64, 58) * M(58, 67)
      temp = temp + M(64, 59) * M(59, 67)
      temp = temp + M(64, 60) * M(60, 67)
      temp = temp + M(64, 61) * M(61, 67)
      temp = temp + M(64, 62) * M(62, 67)
      temp = temp + M(64, 63) * M(63, 67)
      M(64, 67) = ( M(64, 67) - temp ) / M(64, 64)
C     Upper part.
      temp = M(64, 56) * M(56, 68)
      temp = temp + M(64, 57) * M(57, 68)
      temp = temp + M(64, 58) * M(58, 68)
      temp = temp + M(64, 59) * M(59, 68)
      temp = temp + M(64, 60) * M(60, 68)
      temp = temp + M(64, 61) * M(61, 68)
      temp = temp + M(64, 62) * M(62, 68)
      temp = temp + M(64, 63) * M(63, 68)
      M(64, 68) = ( M(64, 68) - temp ) / M(64, 64)

C     Lower part.
      temp = M(65, 14) * M(14, 65)
      temp = temp + M(65, 22) * M(22, 65)
      temp = temp + M(65, 24) * M(24, 65)
      temp = temp + M(65, 55) * M(55, 65)
      temp = temp + M(65, 56) * M(56, 65)
      temp = temp + M(65, 57) * M(57, 65)
      temp = temp + M(65, 58) * M(58, 65)
      temp = temp + M(65, 59) * M(59, 65)
      temp = temp + M(65, 60) * M(60, 65)
      temp = temp + M(65, 61) * M(61, 65)
      temp = temp + M(65, 62) * M(62, 65)
      temp = temp + M(65, 63) * M(63, 65)
      temp = temp + M(65, 64) * M(64, 65)
      M(65, 65) = M(65, 65) - temp
C     Lower part.
      temp = M(66, 14) * M(14, 65)
      temp = temp + M(66, 22) * M(22, 65)
      temp = temp + M(66, 24) * M(24, 65)
      temp = temp + M(66, 41) * M(41, 65)
      temp = temp + M(66, 44) * M(44, 65)
      temp = temp + M(66, 45) * M(45, 65)
      temp = temp + M(66, 50) * M(50, 65)
      temp = temp + M(66, 55) * M(55, 65)
      temp = temp + M(66, 56) * M(56, 65)
      temp = temp + M(66, 57) * M(57, 65)
      temp = temp + M(66, 58) * M(58, 65)
      temp = temp + M(66, 59) * M(59, 65)
      temp = temp + M(66, 60) * M(60, 65)
      temp = temp + M(66, 61) * M(61, 65)
      temp = temp + M(66, 62) * M(62, 65)
      temp = temp + M(66, 63) * M(63, 65)
      temp = temp + M(66, 64) * M(64, 65)
      M(66, 65) = M(66, 65) - temp
C     Lower part.
      temp = M(67, 14) * M(14, 65)
      temp = temp + M(67, 22) * M(22, 65)
      temp = temp + M(67, 23) * M(23, 65)
      temp = temp + M(67, 34) * M(34, 65)
      temp = temp + M(67, 38) * M(38, 65)
      temp = temp + M(67, 39) * M(39, 65)
      temp = temp + M(67, 40) * M(40, 65)
      temp = temp + M(67, 41) * M(41, 65)
      temp = temp + M(67, 44) * M(44, 65)
      temp = temp + M(67, 45) * M(45, 65)
      temp = temp + M(67, 48) * M(48, 65)
      temp = temp + M(67, 51) * M(51, 65)
      temp = temp + M(67, 55) * M(55, 65)
      temp = temp + M(67, 56) * M(56, 65)
      temp = temp + M(67, 57) * M(57, 65)
      temp = temp + M(67, 58) * M(58, 65)
      temp = temp + M(67, 59) * M(59, 65)
      temp = temp + M(67, 60) * M(60, 65)
      temp = temp + M(67, 61) * M(61, 65)
      temp = temp + M(67, 62) * M(62, 65)
      temp = temp + M(67, 63) * M(63, 65)
      temp = temp + M(67, 64) * M(64, 65)
      M(67, 65) = M(67, 65) - temp
C     Lower part.
      temp = M(68, 23) * M(23, 65)
      temp = temp + M(68, 38) * M(38, 65)
      temp = temp + M(68, 39) * M(39, 65)
      temp = temp + M(68, 40) * M(40, 65)
      temp = temp + M(68, 41) * M(41, 65)
      temp = temp + M(68, 45) * M(45, 65)
      temp = temp + M(68, 55) * M(55, 65)
      temp = temp + M(68, 56) * M(56, 65)
      temp = temp + M(68, 57) * M(57, 65)
      temp = temp + M(68, 58) * M(58, 65)
      temp = temp + M(68, 59) * M(59, 65)
      temp = temp + M(68, 60) * M(60, 65)
      temp = temp + M(68, 61) * M(61, 65)
      temp = temp + M(68, 62) * M(62, 65)
      temp = temp + M(68, 63) * M(63, 65)
      temp = temp + M(68, 64) * M(64, 65)
      M(68, 65) = M(68, 65) - temp
C     Upper part.
      temp = M(65, 24) * M(24, 66)
      temp = temp + M(65, 42) * M(42, 66)
      temp = temp + M(65, 55) * M(55, 66)
      temp = temp + M(65, 56) * M(56, 66)
      temp = temp + M(65, 57) * M(57, 66)
      temp = temp + M(65, 58) * M(58, 66)
      temp = temp + M(65, 59) * M(59, 66)
      temp = temp + M(65, 60) * M(60, 66)
      temp = temp + M(65, 61) * M(61, 66)
      temp = temp + M(65, 62) * M(62, 66)
      temp = temp + M(65, 63) * M(63, 66)
      temp = temp + M(65, 64) * M(64, 66)
      M(65, 66) = ( M(65, 66) - temp ) / M(65, 65)
C     Upper part.
      temp = M(65, 22) * M(22, 67)
      temp = temp + M(65, 55) * M(55, 67)
      temp = temp + M(65, 56) * M(56, 67)
      temp = temp + M(65, 57) * M(57, 67)
      temp = temp + M(65, 58) * M(58, 67)
      temp = temp + M(65, 59) * M(59, 67)
      temp = temp + M(65, 60) * M(60, 67)
      temp = temp + M(65, 61) * M(61, 67)
      temp = temp + M(65, 62) * M(62, 67)
      temp = temp + M(65, 63) * M(63, 67)
      temp = temp + M(65, 64) * M(64, 67)
      M(65, 67) = ( M(65, 67) - temp ) / M(65, 65)
C     Upper part.
      temp = M(65, 55) * M(55, 68)
      temp = temp + M(65, 56) * M(56, 68)
      temp = temp + M(65, 57) * M(57, 68)
      temp = temp + M(65, 58) * M(58, 68)
      temp = temp + M(65, 59) * M(59, 68)
      temp = temp + M(65, 60) * M(60, 68)
      temp = temp + M(65, 61) * M(61, 68)
      temp = temp + M(65, 62) * M(62, 68)
      temp = temp + M(65, 63) * M(63, 68)
      temp = temp + M(65, 64) * M(64, 68)
      M(65, 68) = ( M(65, 68) - temp ) / M(65, 65)

C     Lower part.
      temp = M(66, 12) * M(12, 66)
      temp = temp + M(66, 15) * M(15, 66)
      temp = temp + M(66, 18) * M(18, 66)
      temp = temp + M(66, 19) * M(19, 66)
      temp = temp + M(66, 20) * M(20, 66)
      temp = temp + M(66, 24) * M(24, 66)
      temp = temp + M(66, 41) * M(41, 66)
      temp = temp + M(66, 42) * M(42, 66)
      temp = temp + M(66, 44) * M(44, 66)
      temp = temp + M(66, 45) * M(45, 66)
      temp = temp + M(66, 50) * M(50, 66)
      temp = temp + M(66, 55) * M(55, 66)
      temp = temp + M(66, 56) * M(56, 66)
      temp = temp + M(66, 57) * M(57, 66)
      temp = temp + M(66, 58) * M(58, 66)
      temp = temp + M(66, 59) * M(59, 66)
      temp = temp + M(66, 60) * M(60, 66)
      temp = temp + M(66, 61) * M(61, 66)
      temp = temp + M(66, 62) * M(62, 66)
      temp = temp + M(66, 63) * M(63, 66)
      temp = temp + M(66, 64) * M(64, 66)
      temp = temp + M(66, 65) * M(65, 66)
      M(66, 66) = M(66, 66) - temp
C     Lower part.
      temp = M(67, 19) * M(19, 66)
      temp = temp + M(67, 20) * M(20, 66)
      temp = temp + M(67, 41) * M(41, 66)
      temp = temp + M(67, 42) * M(42, 66)
      temp = temp + M(67, 43) * M(43, 66)
      temp = temp + M(67, 44) * M(44, 66)
      temp = temp + M(67, 45) * M(45, 66)
      temp = temp + M(67, 48) * M(48, 66)
      temp = temp + M(67, 51) * M(51, 66)
      temp = temp + M(67, 55) * M(55, 66)
      temp = temp + M(67, 56) * M(56, 66)
      temp = temp + M(67, 57) * M(57, 66)
      temp = temp + M(67, 58) * M(58, 66)
      temp = temp + M(67, 59) * M(59, 66)
      temp = temp + M(67, 60) * M(60, 66)
      temp = temp + M(67, 61) * M(61, 66)
      temp = temp + M(67, 62) * M(62, 66)
      temp = temp + M(67, 63) * M(63, 66)
      temp = temp + M(67, 64) * M(64, 66)
      temp = temp + M(67, 65) * M(65, 66)
      M(67, 66) = M(67, 66) - temp
C     Lower part.
      temp = M(68, 20) * M(20, 66)
      temp = temp + M(68, 41) * M(41, 66)
      temp = temp + M(68, 42) * M(42, 66)
      temp = temp + M(68, 43) * M(43, 66)
      temp = temp + M(68, 45) * M(45, 66)
      temp = temp + M(68, 55) * M(55, 66)
      temp = temp + M(68, 56) * M(56, 66)
      temp = temp + M(68, 57) * M(57, 66)
      temp = temp + M(68, 58) * M(58, 66)
      temp = temp + M(68, 59) * M(59, 66)
      temp = temp + M(68, 60) * M(60, 66)
      temp = temp + M(68, 61) * M(61, 66)
      temp = temp + M(68, 62) * M(62, 66)
      temp = temp + M(68, 63) * M(63, 66)
      temp = temp + M(68, 64) * M(64, 66)
      temp = temp + M(68, 65) * M(65, 66)
      M(68, 66) = M(68, 66) - temp
C     Upper part.
      temp = M(66, 19) * M(19, 67)
      temp = temp + M(66, 22) * M(22, 67)
      temp = temp + M(66, 41) * M(41, 67)
      temp = temp + M(66, 44) * M(44, 67)
      temp = temp + M(66, 45) * M(45, 67)
      temp = temp + M(66, 50) * M(50, 67)
      temp = temp + M(66, 55) * M(55, 67)
      temp = temp + M(66, 56) * M(56, 67)
      temp = temp + M(66, 57) * M(57, 67)
      temp = temp + M(66, 58) * M(58, 67)
      temp = temp + M(66, 59) * M(59, 67)
      temp = temp + M(66, 60) * M(60, 67)
      temp = temp + M(66, 61) * M(61, 67)
      temp = temp + M(66, 62) * M(62, 67)
      temp = temp + M(66, 63) * M(63, 67)
      temp = temp + M(66, 64) * M(64, 67)
      temp = temp + M(66, 65) * M(65, 67)
      M(66, 67) = ( M(66, 67) - temp ) / M(66, 66)
C     Upper part.
      temp = M(66, 50) * M(50, 68)
      temp = temp + M(66, 55) * M(55, 68)
      temp = temp + M(66, 56) * M(56, 68)
      temp = temp + M(66, 57) * M(57, 68)
      temp = temp + M(66, 58) * M(58, 68)
      temp = temp + M(66, 59) * M(59, 68)
      temp = temp + M(66, 60) * M(60, 68)
      temp = temp + M(66, 61) * M(61, 68)
      temp = temp + M(66, 62) * M(62, 68)
      temp = temp + M(66, 63) * M(63, 68)
      temp = temp + M(66, 64) * M(64, 68)
      temp = temp + M(66, 65) * M(65, 68)
      M(66, 68) = ( M(66, 68) - temp ) / M(66, 66)

C     Lower part.
      temp = M(67, 19) * M(19, 67)
      temp = temp + M(67, 21) * M(21, 67)
      temp = temp + M(67, 22) * M(22, 67)
      temp = temp + M(67, 23) * M(23, 67)
      temp = temp + M(67, 31) * M(31, 67)
      temp = temp + M(67, 34) * M(34, 67)
      temp = temp + M(67, 38) * M(38, 67)
      temp = temp + M(67, 39) * M(39, 67)
      temp = temp + M(67, 40) * M(40, 67)
      temp = temp + M(67, 41) * M(41, 67)
      temp = temp + M(67, 44) * M(44, 67)
      temp = temp + M(67, 45) * M(45, 67)
      temp = temp + M(67, 48) * M(48, 67)
      temp = temp + M(67, 51) * M(51, 67)
      temp = temp + M(67, 55) * M(55, 67)
      temp = temp + M(67, 56) * M(56, 67)
      temp = temp + M(67, 57) * M(57, 67)
      temp = temp + M(67, 58) * M(58, 67)
      temp = temp + M(67, 59) * M(59, 67)
      temp = temp + M(67, 60) * M(60, 67)
      temp = temp + M(67, 61) * M(61, 67)
      temp = temp + M(67, 62) * M(62, 67)
      temp = temp + M(67, 63) * M(63, 67)
      temp = temp + M(67, 64) * M(64, 67)
      temp = temp + M(67, 65) * M(65, 67)
      temp = temp + M(67, 66) * M(66, 67)
      M(67, 67) = M(67, 67) - temp
C     Lower part.
      temp = M(68, 23) * M(23, 67)
      temp = temp + M(68, 31) * M(31, 67)
      temp = temp + M(68, 38) * M(38, 67)
      temp = temp + M(68, 39) * M(39, 67)
      temp = temp + M(68, 40) * M(40, 67)
      temp = temp + M(68, 41) * M(41, 67)
      temp = temp + M(68, 45) * M(45, 67)
      temp = temp + M(68, 55) * M(55, 67)
      temp = temp + M(68, 56) * M(56, 67)
      temp = temp + M(68, 57) * M(57, 67)
      temp = temp + M(68, 58) * M(58, 67)
      temp = temp + M(68, 59) * M(59, 67)
      temp = temp + M(68, 60) * M(60, 67)
      temp = temp + M(68, 61) * M(61, 67)
      temp = temp + M(68, 62) * M(62, 67)
      temp = temp + M(68, 63) * M(63, 67)
      temp = temp + M(68, 64) * M(64, 67)
      temp = temp + M(68, 65) * M(65, 67)
      temp = temp + M(68, 66) * M(66, 67)
      M(68, 67) = M(68, 67) - temp
C     Upper part.
      temp = M(67, 31) * M(31, 68)
      temp = temp + M(67, 48) * M(48, 68)
      temp = temp + M(67, 51) * M(51, 68)
      temp = temp + M(67, 55) * M(55, 68)
      temp = temp + M(67, 56) * M(56, 68)
      temp = temp + M(67, 57) * M(57, 68)
      temp = temp + M(67, 58) * M(58, 68)
      temp = temp + M(67, 59) * M(59, 68)
      temp = temp + M(67, 60) * M(60, 68)
      temp = temp + M(67, 61) * M(61, 68)
      temp = temp + M(67, 62) * M(62, 68)
      temp = temp + M(67, 63) * M(63, 68)
      temp = temp + M(67, 64) * M(64, 68)
      temp = temp + M(67, 65) * M(65, 68)
      temp = temp + M(67, 66) * M(66, 68)
      M(67, 68) = ( M(67, 68) - temp ) / M(67, 67)

C     Lower part.
      temp = M(68, 31) * M(31, 68)
      temp = temp + M(68, 55) * M(55, 68)
      temp = temp + M(68, 56) * M(56, 68)
      temp = temp + M(68, 57) * M(57, 68)
      temp = temp + M(68, 58) * M(58, 68)
      temp = temp + M(68, 59) * M(59, 68)
      temp = temp + M(68, 60) * M(60, 68)
      temp = temp + M(68, 61) * M(61, 68)
      temp = temp + M(68, 62) * M(62, 68)
      temp = temp + M(68, 63) * M(63, 68)
      temp = temp + M(68, 64) * M(64, 68)
      temp = temp + M(68, 65) * M(65, 68)
      temp = temp + M(68, 66) * M(66, 68)
      temp = temp + M(68, 67) * M(67, 68)
      M(68, 68) = M(68, 68) - temp


      END
