C------------------------------------------------------------------------
C     Copyright (C) 2001-2008, ENPC - INRIA - EDF R&D
C
C     This file is part of the air quality modeling system Polyphemus.
C
C     Polyphemus is developed in the INRIA - ENPC joint project-team
C     CLIME and in the ENPC - EDF R&D joint laboratory CEREA.
C
C     Polyphemus is free software; you can redistribute i and/or modify
C     it under the terms of the GNU General Public License as published
C     by the Free Software Foundation; either version 2 of the License,
C     or (at your option) any later version.
C
C     Polyphemus is distributed in the hope that it will be useful, but
C     WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
C     General Public License for more details.
C
C     For more information, visit the Polyphemus web site:
C     http://cerea.enpc.fr/polyphemus/
C------------------------------------------------------------------------
 
      subroutine dratedc(ns,nr,rk,y,dw)
 
C------------------------------------------------------------------------
C
C     -- DESCRIPTION
C
C     This routine computes the derivative of reaction  rates.
C     This routine is automatically generated by SPACK.
C     Mechanism: RACM_AEC            
C     Species: _ciRACM_AEC         
C
C------------------------------------------------------------------------
C
C     -- INPUT VARIABLES
C
C     Ns: chemical species number.
C     NR: reaction number.
C     RK: kinetic rates.
C     Y: chemical concentrations.
C
C     -- INPUT/OUTPUT VARIABLES
C
C     -- OUTPUT VARIABLES
C
C     DW: derivative of reaction rates wrt Y.
C
C------------------------------------------------------------------------
C
C     -- REMARKS
C
C------------------------------------------------------------------------
C
C     -- MODIFICATIONS
C
C------------------------------------------------------------------------
C
C     -- AUTHOR(S)
C
C     SPACK.
C
C------------------------------------------------------------------------
 
      implicit none
 
      integer ns,nr
      double precision rk(nr),y(ns),dw(nr,ns)
 
 
 
      dw(  1, 84) =  rk(  1)
      dw(  2, 65) =  rk(  2)
      dw(  3, 65) =  rk(  3)
      dw(  4, 33) =  rk(  4)
      dw(  5, 74) =  rk(  5)
      dw(  6, 24) =  rk(  6)
      dw(  7, 87) =  rk(  7)
      dw(  8, 87) =  rk(  8)
      dw(  9, 44) =  rk(  9)
      dw( 10, 79) =  rk( 10)
      dw( 11, 79) =  rk( 11)
      dw( 12, 81) =  rk( 12)
      dw( 13, 21) =  rk( 13)
      dw( 14, 73) =  rk( 14)
      dw( 15, 38) =  rk( 15)
      dw( 16, 77) =  rk( 16)
      dw( 17, 66) =  rk( 17)
      dw( 18, 66) =  rk( 18)
      dw( 19, 72) =  rk( 19)
      dw( 20, 54) =  rk( 20)
      dw( 21, 83) =  rk( 21)
      dw( 22, 59) =  rk( 22)
      dw( 23, 47) =  rk( 23)
      dw( 24, 43) =  rk( 24)
      dw( 25, 43) =  rk( 25) * Y( 65)
      dw( 25, 65) =  rk( 25) * Y( 43)
      dw( 26,  9) =  rk( 26)
      dw( 27,  9) =  rk( 27)
      dw( 28,  9) =  rk( 28)
      dw( 29, 65) =  rk( 29) * Y( 80)
      dw( 29, 80) =  rk( 29) * Y( 65)
      dw( 30, 65) =  rk( 30) * Y( 88)
      dw( 30, 88) =  rk( 30) * Y( 65)
      dw( 31, 80) =  rk( 31) * Y( 88)
      dw( 31, 88) =  rk( 31) * Y( 80)
      dw( 32, 44) =  rk( 32) * Y( 80)
      dw( 32, 80) =  rk( 32) * Y( 44)
      dw( 33, 88) =  rk( 33) * Y( 88)
      dw( 33, 88) =  rk( 33) * Y( 88)
      dw( 34, 88) =  rk( 34) * Y( 88)
      dw( 34, 88) =  rk( 34) * Y( 88)
      dw( 35, 43) =  rk( 35) * Y( 85)
      dw( 35, 85) =  rk( 35) * Y( 43)
      dw( 36, 43) =  rk( 36) * Y( 84)
      dw( 36, 84) =  rk( 36) * Y( 43)
      dw( 37, 43) =  rk( 37) * Y( 84)
      dw( 37, 84) =  rk( 37) * Y( 43)
      dw( 38, 80) =  rk( 38) * Y( 85)
      dw( 38, 85) =  rk( 38) * Y( 80)
      dw( 39, 80) =  rk( 39) * Y( 84)
      dw( 39, 84) =  rk( 39) * Y( 80)
      dw( 40, 80) =  rk( 40) * Y( 87)
      dw( 40, 87) =  rk( 40) * Y( 80)
      dw( 41, 88) =  rk( 41) * Y( 85)
      dw( 41, 85) =  rk( 41) * Y( 88)
      dw( 42, 88) =  rk( 42) * Y( 84)
      dw( 42, 84) =  rk( 42) * Y( 88)
      dw( 43, 24) =  rk( 43)
      dw( 44, 88) =  rk( 44) * Y( 87)
      dw( 44, 87) =  rk( 44) * Y( 88)
      dw( 45, 80) =  rk( 45) * Y( 33)
      dw( 45, 33) =  rk( 45) * Y( 80)
      dw( 46, 80) =  rk( 46) * Y( 74)
      dw( 46, 74) =  rk( 46) * Y( 80)
      dw( 47, 80) =  rk( 47) * Y( 24)
      dw( 47, 24) =  rk( 47) * Y( 80)
      dw( 48, 65) =  rk( 48) * Y( 85)
      dw( 48, 85) =  rk( 48) * Y( 65)
      dw( 49, 65) =  rk( 49) * Y( 84)
      dw( 49, 84) =  rk( 49) * Y( 65)
      dw( 50, 85) =  rk( 50) * Y( 85)
      dw( 50, 85) =  rk( 50) * Y( 85)
      dw( 51, 87) =  rk( 51) * Y( 85)
      dw( 51, 85) =  rk( 51) * Y( 87)
      dw( 52, 87) =  rk( 52) * Y( 84)
      dw( 52, 84) =  rk( 52) * Y( 87)
      dw( 53, 87) =  rk( 53) * Y( 84)
      dw( 53, 84) =  rk( 53) * Y( 87)
      dw( 54, 17) =  rk( 54)
      dw( 55, 87) =  rk( 55) * Y( 87)
      dw( 55, 87) =  rk( 55) * Y( 87)
      dw( 56, 80) =  rk( 56)
      dw( 57, 80) =  rk( 57) * Y(  3)
      dw( 57,  3) =  rk( 57) * Y( 80)
      dw( 58, 67) =  rk( 58) * Y( 80)
      dw( 58, 80) =  rk( 58) * Y( 67)
      dw( 59, 35) =  rk( 59) * Y( 43)
      dw( 59, 43) =  rk( 59) * Y( 35)
      dw( 60, 59) =  rk( 60) * Y( 43)
      dw( 60, 43) =  rk( 60) * Y( 59)
      dw( 61, 37) =  rk( 61) * Y( 80)
      dw( 61, 80) =  rk( 61) * Y( 37)
      dw( 62, 34) =  rk( 62) * Y( 80)
      dw( 62, 80) =  rk( 62) * Y( 34)
      dw( 63,  4) =  rk( 63) * Y( 80)
      dw( 63, 80) =  rk( 63) * Y(  4)
      dw( 64,  5) =  rk( 64) * Y( 80)
      dw( 64, 80) =  rk( 64) * Y(  5)
      dw( 65,  6) =  rk( 65) * Y( 80)
      dw( 65, 80) =  rk( 65) * Y(  6)
      dw( 66, 25) =  rk( 66) * Y( 80)
      dw( 66, 80) =  rk( 66) * Y( 25)
      dw( 67, 60) =  rk( 67) * Y( 80)
      dw( 67, 80) =  rk( 67) * Y( 60)
      dw( 68, 62) =  rk( 68) * Y( 80)
      dw( 68, 80) =  rk( 68) * Y( 62)
      dw( 69, 26) =  rk( 69) * Y( 80)
      dw( 69, 80) =  rk( 69) * Y( 26)
      dw( 70, 35) =  rk( 70) * Y( 80)
      dw( 70, 80) =  rk( 70) * Y( 35)
      dw( 71, 27) =  rk( 71) * Y( 80)
      dw( 71, 80) =  rk( 71) * Y( 27)
      dw( 72, 30) =  rk( 72) * Y( 80)
      dw( 72, 80) =  rk( 72) * Y( 30)
      dw( 73,  7) =  rk( 73) * Y( 80)
      dw( 73, 80) =  rk( 73) * Y(  7)
      dw( 74,  8) =  rk( 74) * Y( 80)
      dw( 74, 80) =  rk( 74) * Y(  8)
      dw( 75, 45) =  rk( 75) * Y( 80)
      dw( 75, 80) =  rk( 75) * Y( 45)
      dw( 76, 79) =  rk( 76) * Y( 80)
      dw( 76, 80) =  rk( 76) * Y( 79)
      dw( 77, 81) =  rk( 77) * Y( 80)
      dw( 77, 80) =  rk( 77) * Y( 81)
      dw( 78, 77) =  rk( 78) * Y( 80)
      dw( 78, 80) =  rk( 78) * Y( 77)
      dw( 79, 47) =  rk( 79) * Y( 80)
      dw( 79, 80) =  rk( 79) * Y( 47)
      dw( 80, 66) =  rk( 80) * Y( 80)
      dw( 80, 80) =  rk( 80) * Y( 66)
      dw( 81, 72) =  rk( 81) * Y( 80)
      dw( 81, 80) =  rk( 81) * Y( 72)
      dw( 82, 59) =  rk( 82) * Y( 80)
      dw( 82, 80) =  rk( 82) * Y( 59)
      dw( 83, 80) =  rk( 83) * Y( 54)
      dw( 83, 54) =  rk( 83) * Y( 80)
      dw( 84, 80) =  rk( 84) * Y( 18)
      dw( 84, 18) =  rk( 84) * Y( 80)
      dw( 85, 21) =  rk( 85) * Y( 80)
      dw( 85, 80) =  rk( 85) * Y( 21)
      dw( 86, 73) =  rk( 86) * Y( 80)
      dw( 86, 80) =  rk( 86) * Y( 73)
      dw( 87, 38) =  rk( 87) * Y( 80)
      dw( 87, 80) =  rk( 87) * Y( 38)
      dw( 88, 50) =  rk( 88) * Y( 80)
      dw( 88, 80) =  rk( 88) * Y( 50)
      dw( 89, 48) =  rk( 89) * Y( 80)
      dw( 89, 80) =  rk( 89) * Y( 48)
      dw( 90, 83) =  rk( 90) * Y( 80)
      dw( 90, 80) =  rk( 90) * Y( 83)
      dw( 91, 79) =  rk( 91) * Y( 87)
      dw( 91, 87) =  rk( 91) * Y( 79)
      dw( 92, 81) =  rk( 92) * Y( 87)
      dw( 92, 87) =  rk( 92) * Y( 81)
      dw( 93, 66) =  rk( 93) * Y( 87)
      dw( 93, 87) =  rk( 93) * Y( 66)
      dw( 94, 72) =  rk( 94) * Y( 87)
      dw( 94, 87) =  rk( 94) * Y( 72)
      dw( 95, 59) =  rk( 95) * Y( 87)
      dw( 95, 87) =  rk( 95) * Y( 59)
      dw( 96, 54) =  rk( 96) * Y( 87)
      dw( 96, 87) =  rk( 96) * Y( 54)
      dw( 97, 45) =  rk( 97) * Y( 87)
      dw( 97, 87) =  rk( 97) * Y( 45)
      dw( 98, 25) =  rk( 98) * Y( 87)
      dw( 98, 87) =  rk( 98) * Y( 25)
      dw( 99, 60) =  rk( 99) * Y( 87)
      dw( 99, 87) =  rk( 99) * Y( 60)
      dw(100, 62) =  rk(100) * Y( 87)
      dw(100, 87) =  rk(100) * Y( 62)
      dw(101, 26) =  rk(101) * Y( 87)
      dw(101, 87) =  rk(101) * Y( 26)
      dw(102, 35) =  rk(102) * Y( 87)
      dw(102, 87) =  rk(102) * Y( 35)
      dw(103, 27) =  rk(103) * Y( 87)
      dw(103, 87) =  rk(103) * Y( 27)
      dw(104, 30) =  rk(104) * Y( 87)
      dw(104, 87) =  rk(104) * Y( 30)
      dw(105, 48) =  rk(105) * Y( 87)
      dw(105, 87) =  rk(105) * Y( 48)
      dw(106, 25) =  rk(106) * Y( 65)
      dw(106, 65) =  rk(106) * Y( 25)
      dw(107, 60) =  rk(107) * Y( 65)
      dw(107, 65) =  rk(107) * Y( 60)
      dw(108, 62) =  rk(108) * Y( 65)
      dw(108, 65) =  rk(108) * Y( 62)
      dw(109, 26) =  rk(109) * Y( 65)
      dw(109, 65) =  rk(109) * Y( 26)
      dw(110, 35) =  rk(110) * Y( 65)
      dw(110, 65) =  rk(110) * Y( 35)
      dw(111, 27) =  rk(111) * Y( 65)
      dw(111, 65) =  rk(111) * Y( 27)
      dw(112, 30) =  rk(112) * Y( 65)
      dw(112, 65) =  rk(112) * Y( 30)
      dw(113, 59) =  rk(113) * Y( 65)
      dw(113, 65) =  rk(113) * Y( 59)
      dw(114, 54) =  rk(114) * Y( 65)
      dw(114, 65) =  rk(114) * Y( 54)
      dw(115, 48) =  rk(115) * Y( 65)
      dw(115, 65) =  rk(115) * Y( 48)
      dw(116, 39) =  rk(116) * Y( 84)
      dw(116, 84) =  rk(116) * Y( 39)
      dw(117, 39) =  rk(117) * Y( 88)
      dw(117, 88) =  rk(117) * Y( 39)
      dw(118, 22) =  rk(118) * Y( 84)
      dw(118, 84) =  rk(118) * Y( 22)
      dw(119, 22) =  rk(119)
      dw(120, 22) =  rk(120) * Y( 65)
      dw(120, 65) =  rk(120) * Y( 22)
      dw(121, 23) =  rk(121) * Y( 84)
      dw(121, 84) =  rk(121) * Y( 23)
      dw(122, 23) =  rk(122)
      dw(123, 23) =  rk(123) * Y( 65)
      dw(123, 65) =  rk(123) * Y( 23)
      dw(124, 36) =  rk(124) * Y( 84)
      dw(124, 84) =  rk(124) * Y( 36)
      dw(125, 36) =  rk(125)
      dw(126, 36) =  rk(126) * Y( 65)
      dw(126, 65) =  rk(126) * Y( 36)
      dw(127, 89) =  rk(127) * Y( 84)
      dw(127, 84) =  rk(127) * Y( 89)
      dw(128, 50) =  rk(128)
      dw(129, 86) =  rk(129) * Y( 84)
      dw(129, 84) =  rk(129) * Y( 86)
      dw(130, 48) =  rk(130)
      dw(131, 82) =  rk(131) * Y( 85)
      dw(131, 85) =  rk(131) * Y( 82)
      dw(132, 78) =  rk(132) * Y( 85)
      dw(132, 85) =  rk(132) * Y( 78)
      dw(133, 76) =  rk(133) * Y( 85)
      dw(133, 85) =  rk(133) * Y( 76)
      dw(134, 53) =  rk(134) * Y( 85)
      dw(134, 85) =  rk(134) * Y( 53)
      dw(135, 57) =  rk(135) * Y( 85)
      dw(135, 85) =  rk(135) * Y( 57)
      dw(136, 56) =  rk(136) * Y( 85)
      dw(136, 85) =  rk(136) * Y( 56)
      dw(137, 61) =  rk(137) * Y( 85)
      dw(137, 85) =  rk(137) * Y( 61)
      dw(138, 68) =  rk(138) * Y( 85)
      dw(138, 85) =  rk(138) * Y( 68)
      dw(139, 58) =  rk(139) * Y( 85)
      dw(139, 85) =  rk(139) * Y( 58)
      dw(140, 69) =  rk(140) * Y( 85)
      dw(140, 85) =  rk(140) * Y( 69)
      dw(141, 52) =  rk(141) * Y( 85)
      dw(141, 85) =  rk(141) * Y( 52)
      dw(142, 40) =  rk(142) * Y( 85)
      dw(142, 85) =  rk(142) * Y( 40)
      dw(143, 51) =  rk(143) * Y( 85)
      dw(143, 85) =  rk(143) * Y( 51)
      dw(144, 42) =  rk(144) * Y( 85)
      dw(144, 85) =  rk(144) * Y( 42)
      dw(145, 89) =  rk(145) * Y( 85)
      dw(145, 85) =  rk(145) * Y( 89)
      dw(146, 86) =  rk(146) * Y( 85)
      dw(146, 85) =  rk(146) * Y( 86)
      dw(147, 70) =  rk(147) * Y( 85)
      dw(147, 85) =  rk(147) * Y( 70)
      dw(148, 64) =  rk(148) * Y( 85)
      dw(148, 85) =  rk(148) * Y( 64)
      dw(149, 63) =  rk(149) * Y( 85)
      dw(149, 85) =  rk(149) * Y( 63)
      dw(150, 82) =  rk(150) * Y( 88)
      dw(150, 88) =  rk(150) * Y( 82)
      dw(151, 78) =  rk(151) * Y( 88)
      dw(151, 88) =  rk(151) * Y( 78)
      dw(152, 76) =  rk(152) * Y( 88)
      dw(152, 88) =  rk(152) * Y( 76)
      dw(153, 53) =  rk(153) * Y( 88)
      dw(153, 88) =  rk(153) * Y( 53)
      dw(154, 57) =  rk(154) * Y( 88)
      dw(154, 88) =  rk(154) * Y( 57)
      dw(155, 56) =  rk(155) * Y( 88)
      dw(155, 88) =  rk(155) * Y( 56)
      dw(156, 61) =  rk(156) * Y( 88)
      dw(156, 88) =  rk(156) * Y( 61)
      dw(157, 68) =  rk(157) * Y( 88)
      dw(157, 88) =  rk(157) * Y( 68)
      dw(158, 58) =  rk(158) * Y( 88)
      dw(158, 88) =  rk(158) * Y( 58)
      dw(159, 69) =  rk(159) * Y( 88)
      dw(159, 88) =  rk(159) * Y( 69)
      dw(160, 52) =  rk(160) * Y( 88)
      dw(160, 88) =  rk(160) * Y( 52)
      dw(161, 40) =  rk(161) * Y( 88)
      dw(161, 88) =  rk(161) * Y( 40)
      dw(162, 51) =  rk(162) * Y( 88)
      dw(162, 88) =  rk(162) * Y( 51)
      dw(163, 42) =  rk(163) * Y( 88)
      dw(163, 88) =  rk(163) * Y( 42)
      dw(164, 89) =  rk(164) * Y( 88)
      dw(164, 88) =  rk(164) * Y( 89)
      dw(165, 89) =  rk(165) * Y( 88)
      dw(165, 88) =  rk(165) * Y( 89)
      dw(166, 86) =  rk(166) * Y( 88)
      dw(166, 88) =  rk(166) * Y( 86)
      dw(167, 86) =  rk(167) * Y( 88)
      dw(167, 88) =  rk(167) * Y( 86)
      dw(168, 70) =  rk(168) * Y( 88)
      dw(168, 88) =  rk(168) * Y( 70)
      dw(169, 64) =  rk(169) * Y( 88)
      dw(169, 88) =  rk(169) * Y( 64)
      dw(170, 63) =  rk(170) * Y( 88)
      dw(170, 88) =  rk(170) * Y( 63)
      dw(171, 82) =  rk(171) * Y( 82)
      dw(171, 82) =  rk(171) * Y( 82)
      dw(172, 78) =  rk(172) * Y( 82)
      dw(172, 82) =  rk(172) * Y( 78)
      dw(173, 76) =  rk(173) * Y( 82)
      dw(173, 82) =  rk(173) * Y( 76)
      dw(174, 53) =  rk(174) * Y( 82)
      dw(174, 82) =  rk(174) * Y( 53)
      dw(175, 57) =  rk(175) * Y( 82)
      dw(175, 82) =  rk(175) * Y( 57)
      dw(176, 56) =  rk(176) * Y( 82)
      dw(176, 82) =  rk(176) * Y( 56)
      dw(177, 61) =  rk(177) * Y( 82)
      dw(177, 82) =  rk(177) * Y( 61)
      dw(178, 68) =  rk(178) * Y( 82)
      dw(178, 82) =  rk(178) * Y( 68)
      dw(179, 58) =  rk(179) * Y( 82)
      dw(179, 82) =  rk(179) * Y( 58)
      dw(180, 69) =  rk(180) * Y( 82)
      dw(180, 82) =  rk(180) * Y( 69)
      dw(181, 52) =  rk(181) * Y( 82)
      dw(181, 82) =  rk(181) * Y( 52)
      dw(182, 40) =  rk(182) * Y( 82)
      dw(182, 82) =  rk(182) * Y( 40)
      dw(183, 51) =  rk(183) * Y( 82)
      dw(183, 82) =  rk(183) * Y( 51)
      dw(184, 42) =  rk(184) * Y( 82)
      dw(184, 82) =  rk(184) * Y( 42)
      dw(185, 89) =  rk(185) * Y( 82)
      dw(185, 82) =  rk(185) * Y( 89)
      dw(186, 89) =  rk(186) * Y( 82)
      dw(186, 82) =  rk(186) * Y( 89)
      dw(187, 86) =  rk(187) * Y( 82)
      dw(187, 82) =  rk(187) * Y( 86)
      dw(188, 86) =  rk(188) * Y( 82)
      dw(188, 82) =  rk(188) * Y( 86)
      dw(189, 70) =  rk(189) * Y( 82)
      dw(189, 82) =  rk(189) * Y( 70)
      dw(190, 64) =  rk(190) * Y( 82)
      dw(190, 82) =  rk(190) * Y( 64)
      dw(191, 63) =  rk(191) * Y( 82)
      dw(191, 82) =  rk(191) * Y( 63)
      dw(192, 78) =  rk(192) * Y( 89)
      dw(192, 89) =  rk(192) * Y( 78)
      dw(193, 76) =  rk(193) * Y( 89)
      dw(193, 89) =  rk(193) * Y( 76)
      dw(194, 53) =  rk(194) * Y( 89)
      dw(194, 89) =  rk(194) * Y( 53)
      dw(195, 57) =  rk(195) * Y( 89)
      dw(195, 89) =  rk(195) * Y( 57)
      dw(196, 56) =  rk(196) * Y( 89)
      dw(196, 89) =  rk(196) * Y( 56)
      dw(197, 61) =  rk(197) * Y( 89)
      dw(197, 89) =  rk(197) * Y( 61)
      dw(198, 68) =  rk(198) * Y( 89)
      dw(198, 89) =  rk(198) * Y( 68)
      dw(199, 58) =  rk(199) * Y( 89)
      dw(199, 89) =  rk(199) * Y( 58)
      dw(200, 69) =  rk(200) * Y( 89)
      dw(200, 89) =  rk(200) * Y( 69)
      dw(201, 52) =  rk(201) * Y( 89)
      dw(201, 89) =  rk(201) * Y( 52)
      dw(202, 40) =  rk(202) * Y( 89)
      dw(202, 89) =  rk(202) * Y( 40)
      dw(203, 51) =  rk(203) * Y( 89)
      dw(203, 89) =  rk(203) * Y( 51)
      dw(204, 42) =  rk(204) * Y( 89)
      dw(204, 89) =  rk(204) * Y( 42)
      dw(205, 89) =  rk(205) * Y( 89)
      dw(205, 89) =  rk(205) * Y( 89)
      dw(206, 86) =  rk(206) * Y( 89)
      dw(206, 89) =  rk(206) * Y( 86)
      dw(207, 70) =  rk(207) * Y( 89)
      dw(207, 89) =  rk(207) * Y( 70)
      dw(208, 64) =  rk(208) * Y( 89)
      dw(208, 89) =  rk(208) * Y( 64)
      dw(209, 63) =  rk(209) * Y( 89)
      dw(209, 89) =  rk(209) * Y( 63)
      dw(210, 64) =  rk(210) * Y( 64)
      dw(210, 64) =  rk(210) * Y( 64)
      dw(211, 64) =  rk(211) * Y( 63)
      dw(211, 63) =  rk(211) * Y( 64)
      dw(212, 63) =  rk(212) * Y( 63)
      dw(212, 63) =  rk(212) * Y( 63)
      dw(213, 82) =  rk(213) * Y( 87)
      dw(213, 87) =  rk(213) * Y( 82)
      dw(214, 78) =  rk(214) * Y( 87)
      dw(214, 87) =  rk(214) * Y( 78)
      dw(215, 76) =  rk(215) * Y( 87)
      dw(215, 87) =  rk(215) * Y( 76)
      dw(216, 53) =  rk(216) * Y( 87)
      dw(216, 87) =  rk(216) * Y( 53)
      dw(217, 57) =  rk(217) * Y( 87)
      dw(217, 87) =  rk(217) * Y( 57)
      dw(218, 56) =  rk(218) * Y( 87)
      dw(218, 87) =  rk(218) * Y( 56)
      dw(219, 61) =  rk(219) * Y( 87)
      dw(219, 87) =  rk(219) * Y( 61)
      dw(220, 68) =  rk(220) * Y( 87)
      dw(220, 87) =  rk(220) * Y( 68)
      dw(221, 58) =  rk(221) * Y( 87)
      dw(221, 87) =  rk(221) * Y( 58)
      dw(222, 69) =  rk(222) * Y( 87)
      dw(222, 87) =  rk(222) * Y( 69)
      dw(223, 52) =  rk(223) * Y( 87)
      dw(223, 87) =  rk(223) * Y( 52)
      dw(224, 40) =  rk(224) * Y( 87)
      dw(224, 87) =  rk(224) * Y( 40)
      dw(225, 51) =  rk(225) * Y( 87)
      dw(225, 87) =  rk(225) * Y( 51)
      dw(226, 42) =  rk(226) * Y( 87)
      dw(226, 87) =  rk(226) * Y( 42)
      dw(227, 89) =  rk(227) * Y( 87)
      dw(227, 87) =  rk(227) * Y( 89)
      dw(228, 86) =  rk(228) * Y( 87)
      dw(228, 87) =  rk(228) * Y( 86)
      dw(229, 70) =  rk(229) * Y( 87)
      dw(229, 87) =  rk(229) * Y( 70)
      dw(230, 64) =  rk(230) * Y( 87)
      dw(230, 87) =  rk(230) * Y( 64)
      dw(231, 63) =  rk(231) * Y( 87)
      dw(231, 87) =  rk(231) * Y( 63)
      dw(232, 75) =  rk(232) * Y( 88)
      dw(232, 88) =  rk(232) * Y( 75)
      dw(233, 75) =  rk(233) * Y( 82)
      dw(233, 82) =  rk(233) * Y( 75)
      dw(234, 75) =  rk(234) * Y( 89)
      dw(234, 89) =  rk(234) * Y( 75)
      dw(235, 75) =  rk(235) * Y( 75)
      dw(235, 75) =  rk(235) * Y( 75)
      dw(236, 75) =  rk(236) * Y( 85)
      dw(236, 85) =  rk(236) * Y( 75)
      dw(237, 75) =  rk(237) * Y( 87)
      dw(237, 87) =  rk(237) * Y( 75)
      dw(238, 88) =  rk(238)
      dw(239, 84) =  rk(239)
      dw(240, 87) =  rk(240)
      dw(241, 17) =  rk(241)
      dw(242, 11) =  rk(242) * Y( 80)
      dw(242, 80) =  rk(242) * Y( 11)
      dw(243, 13) =  rk(243) * Y( 80)
      dw(243, 80) =  rk(243) * Y( 13)
      dw(244, 14) =  rk(244) * Y( 80)
      dw(244, 80) =  rk(244) * Y( 14)
      dw(245, 15) =  rk(245) * Y( 80)
      dw(245, 80) =  rk(245) * Y( 15)
 
      RETURN
      END
 
