C------------------------------------------------------------------------
C     Copyright (C) 2001-2008, ENPC - INRIA - EDF R&D
C     
C     This file is part of the air quality modeling system Polyphemus.
C    
C     Polyphemus is developed in the INRIA - ENPC joint project-team
C     CLIME and in the ENPC - EDF R&D joint laboratory CEREA.
C    
C     Polyphemus is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published
C     by the Free Software Foundation; either version 2 of the License,
C     or (at your option) any later version.
C     
C     Polyphemus is distributed in the hope that it will be useful, but
C     WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
C     General Public License for more details.
C     
C     For more information, visit the Polyphemus web site:
C     http://cerea.enpc.fr/polyphemus/
C
C------------------------------------------------------------------------

      SUBROUTINE LU_decompose (ns,M)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine computes an LU factorization of M.
C	  This routine is automatically generated by LU.cpp
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C
C	  nesp: matrix row number from the chemical species number
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     M: on entry, an invertible matrix. On exit, an LU factorization
C     of M.
C     
C     -- OUTPUT VARIABLES
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C------------------------------------------------------------------------

      IMPLICIT NONE


      INTEGER ns
      DOUBLE PRECISION M(ns,ns)
      DOUBLE PRECISION temp




C     Upper part.
      M(3, 59) = M(3, 59) / M(3, 3)

C     Upper part.
      M(4, 55) = M(4, 55) / M(4, 4)

C     Upper part.
      M(5, 55) = M(5, 55) / M(5, 5)

C     Upper part.
      M(6, 55) = M(6, 55) / M(6, 6)

C     Upper part.
      M(7, 55) = M(7, 55) / M(7, 7)

C     Upper part.
      M(8, 55) = M(8, 55) / M(8, 8)

C     Upper part.
      M(9, 55) = M(9, 55) / M(9, 9)

C     Upper part.
      temp = M(10, 9) * M(9, 55)
      M(10, 55) = ( M(10, 55) - temp ) / M(10, 10)

C     Upper part.
      M(11, 55) = M(11, 55) / M(11, 11)

C     Upper part.
      temp = M(12, 11) * M(11, 55)
      M(12, 55) = ( M(12, 55) - temp ) / M(12, 12)

C     Upper part.
      M(13, 62) = M(13, 62) / M(13, 13)
C     Upper part.
      M(13, 65) = M(13, 65) / M(13, 13)

C     Upper part.
      M(14, 53) = M(14, 53) / M(14, 14)
C     Upper part.
      M(14, 55) = M(14, 55) / M(14, 14)

C     Upper part.
      temp = M(15, 7) * M(7, 55)
      temp = temp + M(15, 8) * M(8, 55)
      M(15, 55) = ( M(15, 55) - temp ) / M(15, 15)
C     Upper part.
      M(15, 64) = M(15, 64) / M(15, 15)

C     Upper part.
      M(16, 56) = M(16, 56) / M(16, 16)
C     Upper part.
      M(16, 65) = M(16, 65) / M(16, 16)

C     Upper part.
      M(17, 55) = M(17, 55) / M(17, 17)
C     Upper part.
      M(17, 61) = M(17, 61) / M(17, 17)
C     Upper part.
      M(17, 65) = M(17, 65) / M(17, 17)

C     Upper part.
      M(18, 55) = M(18, 55) / M(18, 18)
C     Upper part.
      M(18, 58) = M(18, 58) / M(18, 18)
C     Upper part.
      M(18, 65) = M(18, 65) / M(18, 18)

C     Upper part.
      M(19, 47) = M(19, 47) / M(19, 19)
C     Upper part.
      M(19, 55) = M(19, 55) / M(19, 19)
C     Upper part.
      M(19, 65) = M(19, 65) / M(19, 19)

C     Upper part.
      M(20, 55) = M(20, 55) / M(20, 20)
C     Upper part.
      M(20, 57) = M(20, 57) / M(20, 20)
C     Upper part.
      M(20, 61) = M(20, 61) / M(20, 20)

C     Upper part.
      M(21, 54) = M(21, 54) / M(21, 21)
C     Upper part.
      M(21, 61) = M(21, 61) / M(21, 21)
C     Upper part.
      M(21, 64) = M(21, 64) / M(21, 21)

C     Upper part.
      M(22, 53) = M(22, 53) / M(22, 22)
C     Upper part.
      temp = M(22, 21) * M(21, 54)
      M(22, 54) = ( M(22, 54) - temp ) / M(22, 22)
C     Upper part.
      M(22, 55) = M(22, 55) / M(22, 22)
C     Upper part.
      temp = M(22, 21) * M(21, 61)
      M(22, 61) = ( M(22, 61) - temp ) / M(22, 22)
C     Upper part.
      temp = M(22, 21) * M(21, 64)
      M(22, 64) = ( M(22, 64) - temp ) / M(22, 22)

C     Upper part.
      M(23, 55) = M(23, 55) / M(23, 23)
C     Upper part.
      M(23, 64) = M(23, 64) / M(23, 23)
C     Upper part.
      M(23, 65) = M(23, 65) / M(23, 23)

C     Upper part.
      M(24, 55) = M(24, 55) / M(24, 24)
C     Upper part.
      M(24, 56) = M(24, 56) / M(24, 24)
C     Upper part.
      M(24, 59) = M(24, 59) / M(24, 24)

C     Upper part.
      temp = M(25, 24) * M(24, 55)
      M(25, 55) = ( M(25, 55) - temp ) / M(25, 25)
C     Upper part.
      temp = M(25, 24) * M(24, 56)
      M(25, 56) = ( M(25, 56) - temp ) / M(25, 25)
C     Upper part.
      temp = M(25, 24) * M(24, 59)
      M(25, 59) = ( M(25, 59) - temp ) / M(25, 25)

C     Upper part.
      temp = M(26, 24) * M(24, 55)
      M(26, 55) = ( M(26, 55) - temp ) / M(26, 26)
C     Upper part.
      temp = M(26, 24) * M(24, 56)
      M(26, 56) = ( M(26, 56) - temp ) / M(26, 26)
C     Upper part.
      temp = M(26, 24) * M(24, 59)
      M(26, 59) = ( M(26, 59) - temp ) / M(26, 26)

C     Upper part.
      M(27, 55) = M(27, 55) / M(27, 27)
C     Upper part.
      M(27, 56) = M(27, 56) / M(27, 27)
C     Upper part.
      M(27, 59) = M(27, 59) / M(27, 27)

C     Upper part.
      temp = M(28, 27) * M(27, 55)
      M(28, 55) = ( M(28, 55) - temp ) / M(28, 28)
C     Upper part.
      temp = M(28, 27) * M(27, 56)
      M(28, 56) = ( M(28, 56) - temp ) / M(28, 28)
C     Upper part.
      temp = M(28, 27) * M(27, 59)
      M(28, 59) = ( M(28, 59) - temp ) / M(28, 28)

C     Upper part.
      temp = M(29, 27) * M(27, 55)
      M(29, 55) = ( M(29, 55) - temp ) / M(29, 29)
C     Upper part.
      temp = M(29, 27) * M(27, 56)
      M(29, 56) = ( M(29, 56) - temp ) / M(29, 29)
C     Upper part.
      temp = M(29, 27) * M(27, 59)
      M(29, 59) = ( M(29, 59) - temp ) / M(29, 29)

C     Upper part.
      M(30, 40) = M(30, 40) / M(30, 30)
C     Upper part.
      temp = M(30, 7) * M(7, 55)
      temp = temp + M(30, 8) * M(8, 55)
      M(30, 55) = ( M(30, 55) - temp ) / M(30, 30)
C     Upper part.
      M(30, 56) = M(30, 56) / M(30, 30)

C     Upper part.
      M(31, 40) = M(31, 40) / M(31, 31)
C     Upper part.
      temp = M(31, 7) * M(7, 55)
      temp = temp + M(31, 8) * M(8, 55)
      M(31, 55) = ( M(31, 55) - temp ) / M(31, 31)
C     Upper part.
      M(31, 56) = M(31, 56) / M(31, 31)

C     Upper part.
      M(32, 52) = M(32, 52) / M(32, 32)
C     Upper part.
      M(32, 55) = M(32, 55) / M(32, 32)
C     Upper part.
      M(32, 61) = M(32, 61) / M(32, 32)
C     Upper part.
      M(32, 63) = M(32, 63) / M(32, 32)

C     Upper part.
      M(33, 55) = M(33, 55) / M(33, 33)
C     Upper part.
      M(33, 58) = M(33, 58) / M(33, 33)
C     Upper part.
      M(33, 61) = M(33, 61) / M(33, 33)
C     Upper part.
      M(33, 62) = M(33, 62) / M(33, 33)

C     Upper part.
      M(34, 55) = M(34, 55) / M(34, 34)
C     Upper part.
      M(34, 56) = M(34, 56) / M(34, 34)
C     Upper part.
      M(34, 57) = M(34, 57) / M(34, 34)
C     Upper part.
      M(34, 59) = M(34, 59) / M(34, 34)

C     Upper part.
      temp = M(35, 21) * M(21, 54)
      M(35, 54) = ( M(35, 54) - temp ) / M(35, 35)
C     Upper part.
      temp = M(35, 34) * M(34, 55)
      M(35, 55) = ( M(35, 55) - temp ) / M(35, 35)
C     Upper part.
      temp = M(35, 34) * M(34, 56)
      M(35, 56) = ( M(35, 56) - temp ) / M(35, 35)
C     Upper part.
      temp = M(35, 34) * M(34, 57)
      M(35, 57) = ( M(35, 57) - temp ) / M(35, 35)
C     Upper part.
      temp = M(35, 34) * M(34, 59)
      M(35, 59) = ( M(35, 59) - temp ) / M(35, 35)
C     Upper part.
      temp = M(35, 21) * M(21, 61)
      M(35, 61) = ( M(35, 61) - temp ) / M(35, 35)
C     Upper part.
      temp = M(35, 21) * M(21, 64)
      M(35, 64) = ( M(35, 64) - temp ) / M(35, 35)

C     Upper part.
      M(36, 55) = M(36, 55) / M(36, 36)
C     Upper part.
      M(36, 56) = M(36, 56) / M(36, 36)
C     Upper part.
      M(36, 57) = M(36, 57) / M(36, 36)
C     Upper part.
      M(36, 59) = M(36, 59) / M(36, 36)

C     Upper part.
      M(37, 55) = M(37, 55) / M(37, 37)
C     Upper part.
      M(37, 56) = M(37, 56) / M(37, 37)
C     Upper part.
      M(37, 57) = M(37, 57) / M(37, 37)
C     Upper part.
      M(37, 59) = M(37, 59) / M(37, 37)

C     Upper part.
      temp = M(38, 36) * M(36, 55)
      temp = temp + M(38, 37) * M(37, 55)
      M(38, 55) = ( M(38, 55) - temp ) / M(38, 38)
C     Upper part.
      temp = M(38, 36) * M(36, 56)
      temp = temp + M(38, 37) * M(37, 56)
      M(38, 56) = ( M(38, 56) - temp ) / M(38, 38)
C     Upper part.
      temp = M(38, 36) * M(36, 57)
      temp = temp + M(38, 37) * M(37, 57)
      M(38, 57) = ( M(38, 57) - temp ) / M(38, 38)
C     Upper part.
      temp = M(38, 36) * M(36, 59)
      temp = temp + M(38, 37) * M(37, 59)
      M(38, 59) = ( M(38, 59) - temp ) / M(38, 38)

C     Upper part.
      M(39, 55) = M(39, 55) / M(39, 39)
C     Upper part.
      M(39, 56) = M(39, 56) / M(39, 39)
C     Upper part.
      M(39, 57) = M(39, 57) / M(39, 39)
C     Upper part.
      M(39, 59) = M(39, 59) / M(39, 39)

C     Upper part.
      M(40, 43) = M(40, 43) / M(40, 40)
C     Upper part.
      temp = M(40, 7) * M(7, 55)
      temp = temp + M(40, 8) * M(8, 55)
      temp = temp + M(40, 15) * M(15, 55)
      M(40, 55) = ( M(40, 55) - temp ) / M(40, 40)
C     Upper part.
      M(40, 56) = M(40, 56) / M(40, 40)
C     Upper part.
      M(40, 61) = M(40, 61) / M(40, 40)
C     Upper part.
      temp = M(40, 15) * M(15, 64)
      M(40, 64) = ( M(40, 64) - temp ) / M(40, 40)

C     Upper part.
      temp = M(41, 40) * M(40, 43)
      M(41, 43) = ( M(41, 43) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 15) * M(15, 55)
      temp = temp + M(41, 40) * M(40, 55)
      M(41, 55) = ( M(41, 55) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 40) * M(40, 56)
      M(41, 56) = ( M(41, 56) - temp ) / M(41, 41)
C     Upper part.
      M(41, 59) = M(41, 59) / M(41, 41)
C     Upper part.
      temp = M(41, 40) * M(40, 61)
      M(41, 61) = ( M(41, 61) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 15) * M(15, 64)
      temp = temp + M(41, 40) * M(40, 64)
      M(41, 64) = ( M(41, 64) - temp ) / M(41, 41)

C     Upper part.
      temp = M(42, 41) * M(41, 43)
      M(42, 43) = ( M(42, 43) - temp ) / M(42, 42)
C     Upper part.
      M(42, 45) = M(42, 45) / M(42, 42)
C     Upper part.
      temp = M(42, 8) * M(8, 55)
      temp = temp + M(42, 41) * M(41, 55)
      M(42, 55) = ( M(42, 55) - temp ) / M(42, 42)
C     Upper part.
      temp = M(42, 41) * M(41, 56)
      M(42, 56) = ( M(42, 56) - temp ) / M(42, 42)
C     Upper part.
      temp = M(42, 41) * M(41, 59)
      M(42, 59) = ( M(42, 59) - temp ) / M(42, 42)
C     Upper part.
      temp = M(42, 41) * M(41, 61)
      M(42, 61) = ( M(42, 61) - temp ) / M(42, 42)
C     Upper part.
      temp = M(42, 41) * M(41, 64)
      M(42, 64) = ( M(42, 64) - temp ) / M(42, 42)

C     Lower part.
      temp = M(43, 40) * M(40, 43)
      M(43, 43) = M(43, 43) - temp
C     Lower part.
      temp = M(48, 41) * M(41, 43)
      M(48, 43) = M(48, 43) - temp
C     Lower part.
      temp = M(50, 40) * M(40, 43)
      M(50, 43) = M(50, 43) - temp
C     Lower part.
      temp = M(51, 41) * M(41, 43)
      temp = temp + M(51, 42) * M(42, 43)
      M(51, 43) = M(51, 43) - temp
C     Lower part.
      temp = M(54, 41) * M(41, 43)
      M(54, 43) = M(54, 43) - temp
C     Lower part.
      temp = M(55, 40) * M(40, 43)
      temp = temp + M(55, 41) * M(41, 43)
      temp = temp + M(55, 42) * M(42, 43)
      M(55, 43) = M(55, 43) - temp
C     Lower part.
      temp = M(56, 40) * M(40, 43)
      M(56, 43) = M(56, 43) - temp
C     Lower part.
      temp = M(59, 41) * M(41, 43)
      M(59, 43) = M(59, 43) - temp
C     Lower part.
      temp = M(61, 40) * M(40, 43)
      temp = temp + M(61, 41) * M(41, 43)
      temp = temp + M(61, 42) * M(42, 43)
      M(61, 43) = M(61, 43) - temp
C     Lower part.
      temp = M(62, 41) * M(41, 43)
      temp = temp + M(62, 42) * M(42, 43)
      M(62, 43) = M(62, 43) - temp
C     Lower part.
      temp = M(63, 40) * M(40, 43)
      temp = temp + M(63, 41) * M(41, 43)
      temp = temp + M(63, 42) * M(42, 43)
      M(63, 43) = M(63, 43) - temp
C     Upper part.
      temp = M(43, 40) * M(40, 55)
      M(43, 55) = ( M(43, 55) - temp ) / M(43, 43)
C     Upper part.
      temp = M(43, 40) * M(40, 56)
      M(43, 56) = ( M(43, 56) - temp ) / M(43, 43)
C     Upper part.
      temp = M(43, 40) * M(40, 61)
      M(43, 61) = ( M(43, 61) - temp ) / M(43, 43)
C     Upper part.
      temp = M(43, 40) * M(40, 64)
      M(43, 64) = ( M(43, 64) - temp ) / M(43, 43)
C     Upper part.
      M(43, 65) = M(43, 65) / M(43, 43)

C     Upper part.
      M(44, 55) = M(44, 55) / M(44, 44)
C     Upper part.
      M(44, 56) = M(44, 56) / M(44, 44)
C     Upper part.
      M(44, 57) = M(44, 57) / M(44, 44)
C     Upper part.
      M(44, 59) = M(44, 59) / M(44, 44)
C     Upper part.
      M(44, 65) = M(44, 65) / M(44, 44)

C     Lower part.
      temp = M(51, 42) * M(42, 45)
      M(51, 45) = M(51, 45) - temp
C     Lower part.
      temp = M(55, 42) * M(42, 45)
      M(55, 45) = M(55, 45) - temp
C     Lower part.
      temp = M(61, 42) * M(42, 45)
      M(61, 45) = M(61, 45) - temp
C     Lower part.
      temp = M(62, 42) * M(42, 45)
      M(62, 45) = M(62, 45) - temp
C     Lower part.
      temp = M(63, 42) * M(42, 45)
      M(63, 45) = M(63, 45) - temp
C     Upper part.
      temp = M(45, 44) * M(44, 55)
      M(45, 55) = ( M(45, 55) - temp ) / M(45, 45)
C     Upper part.
      temp = M(45, 44) * M(44, 56)
      M(45, 56) = ( M(45, 56) - temp ) / M(45, 45)
C     Upper part.
      temp = M(45, 44) * M(44, 57)
      M(45, 57) = ( M(45, 57) - temp ) / M(45, 45)
C     Upper part.
      temp = M(45, 44) * M(44, 59)
      M(45, 59) = ( M(45, 59) - temp ) / M(45, 45)
C     Upper part.
      temp = M(45, 44) * M(44, 65)
      M(45, 65) = ( M(45, 65) - temp ) / M(45, 45)

C     Upper part.
      temp = M(46, 19) * M(19, 47)
      M(46, 47) = ( M(46, 47) - temp ) / M(46, 46)
C     Upper part.
      M(46, 52) = M(46, 52) / M(46, 46)
C     Upper part.
      temp = M(46, 15) * M(15, 55)
      temp = temp + M(46, 19) * M(19, 55)
      temp = temp + M(46, 39) * M(39, 55)
      temp = temp + M(46, 43) * M(43, 55)
      temp = temp + M(46, 44) * M(44, 55)
      temp = temp + M(46, 45) * M(45, 55)
      M(46, 55) = ( M(46, 55) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 39) * M(39, 56)
      temp = temp + M(46, 43) * M(43, 56)
      temp = temp + M(46, 44) * M(44, 56)
      temp = temp + M(46, 45) * M(45, 56)
      M(46, 56) = ( M(46, 56) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 39) * M(39, 57)
      temp = temp + M(46, 44) * M(44, 57)
      temp = temp + M(46, 45) * M(45, 57)
      M(46, 57) = ( M(46, 57) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 39) * M(39, 59)
      temp = temp + M(46, 44) * M(44, 59)
      temp = temp + M(46, 45) * M(45, 59)
      M(46, 59) = ( M(46, 59) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 43) * M(43, 61)
      M(46, 61) = ( M(46, 61) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 15) * M(15, 64)
      temp = temp + M(46, 43) * M(43, 64)
      M(46, 64) = ( M(46, 64) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 19) * M(19, 65)
      temp = temp + M(46, 43) * M(43, 65)
      temp = temp + M(46, 44) * M(44, 65)
      temp = temp + M(46, 45) * M(45, 65)
      M(46, 65) = ( M(46, 65) - temp ) / M(46, 46)

C     Lower part.
      temp = M(47, 19) * M(19, 47)
      temp = temp + M(47, 46) * M(46, 47)
      M(47, 47) = M(47, 47) - temp
C     Lower part.
      temp = M(48, 19) * M(19, 47)
      temp = temp + M(48, 46) * M(46, 47)
      M(48, 47) = M(48, 47) - temp
C     Lower part.
      temp = M(50, 46) * M(46, 47)
      M(50, 47) = M(50, 47) - temp
C     Lower part.
      temp = M(52, 19) * M(19, 47)
      M(52, 47) = M(52, 47) - temp
C     Lower part.
      temp = M(54, 46) * M(46, 47)
      M(54, 47) = M(54, 47) - temp
C     Lower part.
      temp = M(55, 46) * M(46, 47)
      M(55, 47) = M(55, 47) - temp
C     Lower part.
      temp = M(60, 19) * M(19, 47)
      temp = temp + M(60, 46) * M(46, 47)
      M(60, 47) = M(60, 47) - temp
C     Lower part.
      temp = M(61, 19) * M(19, 47)
      temp = temp + M(61, 46) * M(46, 47)
      M(61, 47) = M(61, 47) - temp
C     Lower part.
      temp = M(63, 19) * M(19, 47)
      M(63, 47) = M(63, 47) - temp
C     Lower part.
      temp = M(65, 19) * M(19, 47)
      temp = temp + M(65, 46) * M(46, 47)
      M(65, 47) = M(65, 47) - temp
C     Upper part.
      temp = M(47, 46) * M(46, 52)
      M(47, 52) = ( M(47, 52) - temp ) / M(47, 47)
C     Upper part.
      temp = M(47, 8) * M(8, 55)
      temp = temp + M(47, 19) * M(19, 55)
      temp = temp + M(47, 36) * M(36, 55)
      temp = temp + M(47, 37) * M(37, 55)
      temp = temp + M(47, 39) * M(39, 55)
      temp = temp + M(47, 44) * M(44, 55)
      temp = temp + M(47, 45) * M(45, 55)
      temp = temp + M(47, 46) * M(46, 55)
      M(47, 55) = ( M(47, 55) - temp ) / M(47, 47)
C     Upper part.
      temp = M(47, 36) * M(36, 56)
      temp = temp + M(47, 37) * M(37, 56)
      temp = temp + M(47, 39) * M(39, 56)
      temp = temp + M(47, 44) * M(44, 56)
      temp = temp + M(47, 45) * M(45, 56)
      temp = temp + M(47, 46) * M(46, 56)
      M(47, 56) = ( M(47, 56) - temp ) / M(47, 47)
C     Upper part.
      temp = M(47, 36) * M(36, 57)
      temp = temp + M(47, 37) * M(37, 57)
      temp = temp + M(47, 39) * M(39, 57)
      temp = temp + M(47, 44) * M(44, 57)
      temp = temp + M(47, 45) * M(45, 57)
      temp = temp + M(47, 46) * M(46, 57)
      M(47, 57) = ( M(47, 57) - temp ) / M(47, 47)
C     Upper part.
      temp = M(47, 36) * M(36, 59)
      temp = temp + M(47, 37) * M(37, 59)
      temp = temp + M(47, 39) * M(39, 59)
      temp = temp + M(47, 44) * M(44, 59)
      temp = temp + M(47, 45) * M(45, 59)
      temp = temp + M(47, 46) * M(46, 59)
      M(47, 59) = ( M(47, 59) - temp ) / M(47, 47)
C     Upper part.
      temp = M(47, 46) * M(46, 61)
      M(47, 61) = ( M(47, 61) - temp ) / M(47, 47)
C     Upper part.
      temp = M(47, 46) * M(46, 64)
      M(47, 64) = ( M(47, 64) - temp ) / M(47, 47)
C     Upper part.
      temp = M(47, 19) * M(19, 65)
      temp = temp + M(47, 44) * M(44, 65)
      temp = temp + M(47, 45) * M(45, 65)
      temp = temp + M(47, 46) * M(46, 65)
      M(47, 65) = ( M(47, 65) - temp ) / M(47, 47)

C     Upper part.
      temp = M(48, 32) * M(32, 52)
      temp = temp + M(48, 46) * M(46, 52)
      temp = temp + M(48, 47) * M(47, 52)
      M(48, 52) = ( M(48, 52) - temp ) / M(48, 48)
C     Upper part.
      temp = M(48, 4) * M(4, 55)
      temp = temp + M(48, 19) * M(19, 55)
      temp = temp + M(48, 32) * M(32, 55)
      temp = temp + M(48, 34) * M(34, 55)
      temp = temp + M(48, 36) * M(36, 55)
      temp = temp + M(48, 37) * M(37, 55)
      temp = temp + M(48, 39) * M(39, 55)
      temp = temp + M(48, 41) * M(41, 55)
      temp = temp + M(48, 43) * M(43, 55)
      temp = temp + M(48, 44) * M(44, 55)
      temp = temp + M(48, 45) * M(45, 55)
      temp = temp + M(48, 46) * M(46, 55)
      temp = temp + M(48, 47) * M(47, 55)
      M(48, 55) = ( M(48, 55) - temp ) / M(48, 48)
C     Upper part.
      temp = M(48, 34) * M(34, 56)
      temp = temp + M(48, 36) * M(36, 56)
      temp = temp + M(48, 37) * M(37, 56)
      temp = temp + M(48, 39) * M(39, 56)
      temp = temp + M(48, 41) * M(41, 56)
      temp = temp + M(48, 43) * M(43, 56)
      temp = temp + M(48, 44) * M(44, 56)
      temp = temp + M(48, 45) * M(45, 56)
      temp = temp + M(48, 46) * M(46, 56)
      temp = temp + M(48, 47) * M(47, 56)
      M(48, 56) = ( M(48, 56) - temp ) / M(48, 48)
C     Upper part.
      temp = M(48, 34) * M(34, 57)
      temp = temp + M(48, 36) * M(36, 57)
      temp = temp + M(48, 37) * M(37, 57)
      temp = temp + M(48, 39) * M(39, 57)
      temp = temp + M(48, 44) * M(44, 57)
      temp = temp + M(48, 45) * M(45, 57)
      temp = temp + M(48, 46) * M(46, 57)
      temp = temp + M(48, 47) * M(47, 57)
      M(48, 57) = ( M(48, 57) - temp ) / M(48, 48)
C     Upper part.
      temp = M(48, 34) * M(34, 59)
      temp = temp + M(48, 36) * M(36, 59)
      temp = temp + M(48, 37) * M(37, 59)
      temp = temp + M(48, 39) * M(39, 59)
      temp = temp + M(48, 41) * M(41, 59)
      temp = temp + M(48, 44) * M(44, 59)
      temp = temp + M(48, 45) * M(45, 59)
      temp = temp + M(48, 46) * M(46, 59)
      temp = temp + M(48, 47) * M(47, 59)
      M(48, 59) = ( M(48, 59) - temp ) / M(48, 48)
C     Upper part.
      temp = M(48, 32) * M(32, 61)
      temp = temp + M(48, 41) * M(41, 61)
      temp = temp + M(48, 43) * M(43, 61)
      temp = temp + M(48, 46) * M(46, 61)
      temp = temp + M(48, 47) * M(47, 61)
      M(48, 61) = ( M(48, 61) - temp ) / M(48, 48)
C     Upper part.
      temp = M(48, 32) * M(32, 63)
      M(48, 63) = ( M(48, 63) - temp ) / M(48, 48)
C     Upper part.
      temp = M(48, 41) * M(41, 64)
      temp = temp + M(48, 43) * M(43, 64)
      temp = temp + M(48, 46) * M(46, 64)
      temp = temp + M(48, 47) * M(47, 64)
      M(48, 64) = ( M(48, 64) - temp ) / M(48, 48)
C     Upper part.
      temp = M(48, 19) * M(19, 65)
      temp = temp + M(48, 43) * M(43, 65)
      temp = temp + M(48, 44) * M(44, 65)
      temp = temp + M(48, 45) * M(45, 65)
      temp = temp + M(48, 46) * M(46, 65)
      temp = temp + M(48, 47) * M(47, 65)
      M(48, 65) = ( M(48, 65) - temp ) / M(48, 48)

C     Upper part.
      M(49, 53) = M(49, 53) / M(49, 49)
C     Upper part.
      M(49, 55) = M(49, 55) / M(49, 49)
C     Upper part.
      M(49, 58) = M(49, 58) / M(49, 49)
C     Upper part.
      M(49, 61) = M(49, 61) / M(49, 49)
C     Upper part.
      M(49, 62) = M(49, 62) / M(49, 49)
C     Upper part.
      M(49, 63) = M(49, 63) / M(49, 49)

C     Upper part.
      temp = M(50, 46) * M(46, 52)
      temp = temp + M(50, 47) * M(47, 52)
      temp = temp + M(50, 48) * M(48, 52)
      M(50, 52) = ( M(50, 52) - temp ) / M(50, 50)
C     Upper part.
      M(50, 54) = M(50, 54) / M(50, 50)
C     Upper part.
      temp = M(50, 40) * M(40, 55)
      temp = temp + M(50, 43) * M(43, 55)
      temp = temp + M(50, 45) * M(45, 55)
      temp = temp + M(50, 46) * M(46, 55)
      temp = temp + M(50, 47) * M(47, 55)
      temp = temp + M(50, 48) * M(48, 55)
      M(50, 55) = ( M(50, 55) - temp ) / M(50, 50)
C     Upper part.
      temp = M(50, 16) * M(16, 56)
      temp = temp + M(50, 40) * M(40, 56)
      temp = temp + M(50, 43) * M(43, 56)
      temp = temp + M(50, 45) * M(45, 56)
      temp = temp + M(50, 46) * M(46, 56)
      temp = temp + M(50, 47) * M(47, 56)
      temp = temp + M(50, 48) * M(48, 56)
      M(50, 56) = ( M(50, 56) - temp ) / M(50, 50)
C     Upper part.
      temp = M(50, 45) * M(45, 57)
      temp = temp + M(50, 46) * M(46, 57)
      temp = temp + M(50, 47) * M(47, 57)
      temp = temp + M(50, 48) * M(48, 57)
      M(50, 57) = ( M(50, 57) - temp ) / M(50, 50)
C     Upper part.
      temp = M(50, 45) * M(45, 59)
      temp = temp + M(50, 46) * M(46, 59)
      temp = temp + M(50, 47) * M(47, 59)
      temp = temp + M(50, 48) * M(48, 59)
      M(50, 59) = ( M(50, 59) - temp ) / M(50, 50)
C     Upper part.
      M(50, 60) = M(50, 60) / M(50, 50)
C     Upper part.
      temp = M(50, 40) * M(40, 61)
      temp = temp + M(50, 43) * M(43, 61)
      temp = temp + M(50, 46) * M(46, 61)
      temp = temp + M(50, 47) * M(47, 61)
      temp = temp + M(50, 48) * M(48, 61)
      M(50, 61) = ( M(50, 61) - temp ) / M(50, 50)
C     Upper part.
      temp = M(50, 48) * M(48, 63)
      M(50, 63) = ( M(50, 63) - temp ) / M(50, 50)
C     Upper part.
      temp = M(50, 40) * M(40, 64)
      temp = temp + M(50, 43) * M(43, 64)
      temp = temp + M(50, 46) * M(46, 64)
      temp = temp + M(50, 47) * M(47, 64)
      temp = temp + M(50, 48) * M(48, 64)
      M(50, 64) = ( M(50, 64) - temp ) / M(50, 50)
C     Upper part.
      temp = M(50, 16) * M(16, 65)
      temp = temp + M(50, 43) * M(43, 65)
      temp = temp + M(50, 45) * M(45, 65)
      temp = temp + M(50, 46) * M(46, 65)
      temp = temp + M(50, 47) * M(47, 65)
      temp = temp + M(50, 48) * M(48, 65)
      M(50, 65) = ( M(50, 65) - temp ) / M(50, 50)

C     Upper part.
      temp = M(51, 48) * M(48, 52)
      M(51, 52) = ( M(51, 52) - temp ) / M(51, 51)
C     Upper part.
      M(51, 54) = M(51, 54) / M(51, 51)
C     Upper part.
      temp = M(51, 34) * M(34, 55)
      temp = temp + M(51, 36) * M(36, 55)
      temp = temp + M(51, 37) * M(37, 55)
      temp = temp + M(51, 39) * M(39, 55)
      temp = temp + M(51, 41) * M(41, 55)
      temp = temp + M(51, 42) * M(42, 55)
      temp = temp + M(51, 43) * M(43, 55)
      temp = temp + M(51, 44) * M(44, 55)
      temp = temp + M(51, 45) * M(45, 55)
      temp = temp + M(51, 48) * M(48, 55)
      M(51, 55) = ( M(51, 55) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 34) * M(34, 56)
      temp = temp + M(51, 36) * M(36, 56)
      temp = temp + M(51, 37) * M(37, 56)
      temp = temp + M(51, 39) * M(39, 56)
      temp = temp + M(51, 41) * M(41, 56)
      temp = temp + M(51, 42) * M(42, 56)
      temp = temp + M(51, 43) * M(43, 56)
      temp = temp + M(51, 44) * M(44, 56)
      temp = temp + M(51, 45) * M(45, 56)
      temp = temp + M(51, 48) * M(48, 56)
      M(51, 56) = ( M(51, 56) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 34) * M(34, 57)
      temp = temp + M(51, 36) * M(36, 57)
      temp = temp + M(51, 37) * M(37, 57)
      temp = temp + M(51, 39) * M(39, 57)
      temp = temp + M(51, 44) * M(44, 57)
      temp = temp + M(51, 45) * M(45, 57)
      temp = temp + M(51, 48) * M(48, 57)
      M(51, 57) = ( M(51, 57) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 34) * M(34, 59)
      temp = temp + M(51, 36) * M(36, 59)
      temp = temp + M(51, 37) * M(37, 59)
      temp = temp + M(51, 39) * M(39, 59)
      temp = temp + M(51, 41) * M(41, 59)
      temp = temp + M(51, 42) * M(42, 59)
      temp = temp + M(51, 44) * M(44, 59)
      temp = temp + M(51, 45) * M(45, 59)
      temp = temp + M(51, 48) * M(48, 59)
      M(51, 59) = ( M(51, 59) - temp ) / M(51, 51)
C     Upper part.
      M(51, 60) = M(51, 60) / M(51, 51)
C     Upper part.
      temp = M(51, 41) * M(41, 61)
      temp = temp + M(51, 42) * M(42, 61)
      temp = temp + M(51, 43) * M(43, 61)
      temp = temp + M(51, 48) * M(48, 61)
      M(51, 61) = ( M(51, 61) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 48) * M(48, 63)
      M(51, 63) = ( M(51, 63) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 41) * M(41, 64)
      temp = temp + M(51, 42) * M(42, 64)
      temp = temp + M(51, 43) * M(43, 64)
      temp = temp + M(51, 48) * M(48, 64)
      M(51, 64) = ( M(51, 64) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 43) * M(43, 65)
      temp = temp + M(51, 44) * M(44, 65)
      temp = temp + M(51, 45) * M(45, 65)
      temp = temp + M(51, 48) * M(48, 65)
      M(51, 65) = ( M(51, 65) - temp ) / M(51, 51)

C     Lower part.
      temp = M(52, 47) * M(47, 52)
      M(52, 52) = M(52, 52) - temp
C     Lower part.
      temp = M(53, 48) * M(48, 52)
      M(53, 52) = M(53, 52) - temp
C     Lower part.
      temp = M(54, 46) * M(46, 52)
      temp = temp + M(54, 47) * M(47, 52)
      M(54, 52) = M(54, 52) - temp
C     Lower part.
      temp = M(55, 32) * M(32, 52)
      temp = temp + M(55, 46) * M(46, 52)
      temp = temp + M(55, 47) * M(47, 52)
      temp = temp + M(55, 48) * M(48, 52)
      temp = temp + M(55, 50) * M(50, 52)
      temp = temp + M(55, 51) * M(51, 52)
      M(55, 52) = M(55, 52) - temp
C     Lower part.
      temp = M(56, 48) * M(48, 52)
      temp = temp + M(56, 50) * M(50, 52)
      M(56, 52) = M(56, 52) - temp
C     Lower part.
      temp = M(57, 48) * M(48, 52)
      M(57, 52) = M(57, 52) - temp
C     Lower part.
      temp = M(58, 48) * M(48, 52)
      M(58, 52) = M(58, 52) - temp
C     Lower part.
      temp = M(60, 32) * M(32, 52)
      temp = temp + M(60, 46) * M(46, 52)
      temp = temp + M(60, 47) * M(47, 52)
      M(60, 52) = M(60, 52) - temp
C     Lower part.
      temp = M(61, 32) * M(32, 52)
      temp = temp + M(61, 46) * M(46, 52)
      temp = temp + M(61, 47) * M(47, 52)
      temp = temp + M(61, 48) * M(48, 52)
      temp = temp + M(61, 51) * M(51, 52)
      M(61, 52) = M(61, 52) - temp
C     Lower part.
      temp = M(63, 32) * M(32, 52)
      temp = temp + M(63, 47) * M(47, 52)
      M(63, 52) = M(63, 52) - temp
C     Lower part.
      temp = M(65, 46) * M(46, 52)
      temp = temp + M(65, 47) * M(47, 52)
      temp = temp + M(65, 50) * M(50, 52)
      M(65, 52) = M(65, 52) - temp
C     Upper part.
      temp = M(52, 6) * M(6, 55)
      temp = temp + M(52, 19) * M(19, 55)
      temp = temp + M(52, 36) * M(36, 55)
      temp = temp + M(52, 39) * M(39, 55)
      temp = temp + M(52, 44) * M(44, 55)
      temp = temp + M(52, 47) * M(47, 55)
      M(52, 55) = ( M(52, 55) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 36) * M(36, 56)
      temp = temp + M(52, 39) * M(39, 56)
      temp = temp + M(52, 44) * M(44, 56)
      temp = temp + M(52, 47) * M(47, 56)
      M(52, 56) = ( M(52, 56) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 36) * M(36, 57)
      temp = temp + M(52, 39) * M(39, 57)
      temp = temp + M(52, 44) * M(44, 57)
      temp = temp + M(52, 47) * M(47, 57)
      M(52, 57) = ( M(52, 57) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 36) * M(36, 59)
      temp = temp + M(52, 39) * M(39, 59)
      temp = temp + M(52, 44) * M(44, 59)
      temp = temp + M(52, 47) * M(47, 59)
      M(52, 59) = ( M(52, 59) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 47) * M(47, 61)
      M(52, 61) = ( M(52, 61) - temp ) / M(52, 52)
C     Upper part.
      M(52, 63) = M(52, 63) / M(52, 52)
C     Upper part.
      temp = M(52, 47) * M(47, 64)
      M(52, 64) = ( M(52, 64) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 19) * M(19, 65)
      temp = temp + M(52, 44) * M(44, 65)
      temp = temp + M(52, 47) * M(47, 65)
      M(52, 65) = ( M(52, 65) - temp ) / M(52, 52)

C     Lower part.
      temp = M(53, 22) * M(22, 53)
      temp = temp + M(53, 49) * M(49, 53)
      M(53, 53) = M(53, 53) - temp
C     Lower part.
      temp = M(54, 14) * M(14, 53)
      temp = temp + M(54, 22) * M(22, 53)
      M(54, 53) = M(54, 53) - temp
C     Lower part.
      temp = M(55, 14) * M(14, 53)
      temp = temp + M(55, 22) * M(22, 53)
      temp = temp + M(55, 49) * M(49, 53)
      M(55, 53) = M(55, 53) - temp
C     Lower part.
      temp = M(61, 14) * M(14, 53)
      temp = temp + M(61, 22) * M(22, 53)
      M(61, 53) = M(61, 53) - temp
C     Lower part.
      temp = M(63, 22) * M(22, 53)
      M(63, 53) = M(63, 53) - temp
C     Upper part.
      temp = M(53, 22) * M(22, 54)
      M(53, 54) = ( M(53, 54) - temp ) / M(53, 53)
C     Upper part.
      temp = M(53, 5) * M(5, 55)
      temp = temp + M(53, 22) * M(22, 55)
      temp = temp + M(53, 33) * M(33, 55)
      temp = temp + M(53, 48) * M(48, 55)
      temp = temp + M(53, 49) * M(49, 55)
      temp = temp + M(53, 52) * M(52, 55)
      M(53, 55) = ( M(53, 55) - temp ) / M(53, 53)
C     Upper part.
      temp = M(53, 48) * M(48, 56)
      temp = temp + M(53, 52) * M(52, 56)
      M(53, 56) = ( M(53, 56) - temp ) / M(53, 53)
C     Upper part.
      temp = M(53, 48) * M(48, 57)
      temp = temp + M(53, 52) * M(52, 57)
      M(53, 57) = ( M(53, 57) - temp ) / M(53, 53)
C     Upper part.
      temp = M(53, 33) * M(33, 58)
      temp = temp + M(53, 49) * M(49, 58)
      M(53, 58) = ( M(53, 58) - temp ) / M(53, 53)
C     Upper part.
      temp = M(53, 48) * M(48, 59)
      temp = temp + M(53, 52) * M(52, 59)
      M(53, 59) = ( M(53, 59) - temp ) / M(53, 53)
C     Upper part.
      M(53, 60) = M(53, 60) / M(53, 53)
C     Upper part.
      temp = M(53, 22) * M(22, 61)
      temp = temp + M(53, 33) * M(33, 61)
      temp = temp + M(53, 48) * M(48, 61)
      temp = temp + M(53, 49) * M(49, 61)
      temp = temp + M(53, 52) * M(52, 61)
      M(53, 61) = ( M(53, 61) - temp ) / M(53, 53)
C     Upper part.
      temp = M(53, 33) * M(33, 62)
      temp = temp + M(53, 49) * M(49, 62)
      M(53, 62) = ( M(53, 62) - temp ) / M(53, 53)
C     Upper part.
      temp = M(53, 48) * M(48, 63)
      temp = temp + M(53, 49) * M(49, 63)
      temp = temp + M(53, 52) * M(52, 63)
      M(53, 63) = ( M(53, 63) - temp ) / M(53, 53)
C     Upper part.
      temp = M(53, 22) * M(22, 64)
      temp = temp + M(53, 48) * M(48, 64)
      temp = temp + M(53, 52) * M(52, 64)
      M(53, 64) = ( M(53, 64) - temp ) / M(53, 53)
C     Upper part.
      temp = M(53, 48) * M(48, 65)
      temp = temp + M(53, 52) * M(52, 65)
      M(53, 65) = ( M(53, 65) - temp ) / M(53, 53)

C     Lower part.
      temp = M(54, 21) * M(21, 54)
      temp = temp + M(54, 22) * M(22, 54)
      temp = temp + M(54, 53) * M(53, 54)
      M(54, 54) = M(54, 54) - temp
C     Lower part.
      temp = M(55, 22) * M(22, 54)
      temp = temp + M(55, 35) * M(35, 54)
      temp = temp + M(55, 50) * M(50, 54)
      temp = temp + M(55, 51) * M(51, 54)
      temp = temp + M(55, 53) * M(53, 54)
      M(55, 54) = M(55, 54) - temp
C     Lower part.
      temp = M(56, 50) * M(50, 54)
      M(56, 54) = M(56, 54) - temp
C     Lower part.
      temp = M(60, 53) * M(53, 54)
      M(60, 54) = M(60, 54) - temp
C     Lower part.
      temp = M(61, 21) * M(21, 54)
      temp = temp + M(61, 22) * M(22, 54)
      temp = temp + M(61, 35) * M(35, 54)
      temp = temp + M(61, 51) * M(51, 54)
      temp = temp + M(61, 53) * M(53, 54)
      M(61, 54) = M(61, 54) - temp
C     Lower part.
      temp = M(62, 53) * M(53, 54)
      M(62, 54) = M(62, 54) - temp
C     Lower part.
      temp = M(63, 22) * M(22, 54)
      temp = temp + M(63, 53) * M(53, 54)
      M(63, 54) = M(63, 54) - temp
C     Lower part.
      temp = M(64, 21) * M(21, 54)
      temp = temp + M(64, 53) * M(53, 54)
      M(64, 54) = M(64, 54) - temp
C     Lower part.
      temp = M(65, 21) * M(21, 54)
      temp = temp + M(65, 50) * M(50, 54)
      temp = temp + M(65, 53) * M(53, 54)
      M(65, 54) = M(65, 54) - temp
C     Upper part.
      temp = M(54, 4) * M(4, 55)
      temp = temp + M(54, 14) * M(14, 55)
      temp = temp + M(54, 22) * M(22, 55)
      temp = temp + M(54, 34) * M(34, 55)
      temp = temp + M(54, 36) * M(36, 55)
      temp = temp + M(54, 37) * M(37, 55)
      temp = temp + M(54, 39) * M(39, 55)
      temp = temp + M(54, 41) * M(41, 55)
      temp = temp + M(54, 43) * M(43, 55)
      temp = temp + M(54, 44) * M(44, 55)
      temp = temp + M(54, 45) * M(45, 55)
      temp = temp + M(54, 46) * M(46, 55)
      temp = temp + M(54, 47) * M(47, 55)
      temp = temp + M(54, 52) * M(52, 55)
      temp = temp + M(54, 53) * M(53, 55)
      M(54, 55) = ( M(54, 55) - temp ) / M(54, 54)
C     Upper part.
      temp = M(54, 34) * M(34, 56)
      temp = temp + M(54, 36) * M(36, 56)
      temp = temp + M(54, 37) * M(37, 56)
      temp = temp + M(54, 39) * M(39, 56)
      temp = temp + M(54, 41) * M(41, 56)
      temp = temp + M(54, 43) * M(43, 56)
      temp = temp + M(54, 44) * M(44, 56)
      temp = temp + M(54, 45) * M(45, 56)
      temp = temp + M(54, 46) * M(46, 56)
      temp = temp + M(54, 47) * M(47, 56)
      temp = temp + M(54, 52) * M(52, 56)
      temp = temp + M(54, 53) * M(53, 56)
      M(54, 56) = ( M(54, 56) - temp ) / M(54, 54)
C     Upper part.
      temp = M(54, 34) * M(34, 57)
      temp = temp + M(54, 36) * M(36, 57)
      temp = temp + M(54, 37) * M(37, 57)
      temp = temp + M(54, 39) * M(39, 57)
      temp = temp + M(54, 44) * M(44, 57)
      temp = temp + M(54, 45) * M(45, 57)
      temp = temp + M(54, 46) * M(46, 57)
      temp = temp + M(54, 47) * M(47, 57)
      temp = temp + M(54, 52) * M(52, 57)
      temp = temp + M(54, 53) * M(53, 57)
      M(54, 57) = ( M(54, 57) - temp ) / M(54, 54)
C     Upper part.
      temp = M(54, 53) * M(53, 58)
      M(54, 58) = ( M(54, 58) - temp ) / M(54, 54)
C     Upper part.
      temp = M(54, 34) * M(34, 59)
      temp = temp + M(54, 36) * M(36, 59)
      temp = temp + M(54, 37) * M(37, 59)
      temp = temp + M(54, 39) * M(39, 59)
      temp = temp + M(54, 41) * M(41, 59)
      temp = temp + M(54, 44) * M(44, 59)
      temp = temp + M(54, 45) * M(45, 59)
      temp = temp + M(54, 46) * M(46, 59)
      temp = temp + M(54, 47) * M(47, 59)
      temp = temp + M(54, 52) * M(52, 59)
      temp = temp + M(54, 53) * M(53, 59)
      M(54, 59) = ( M(54, 59) - temp ) / M(54, 54)
C     Upper part.
      temp = M(54, 53) * M(53, 60)
      M(54, 60) = ( M(54, 60) - temp ) / M(54, 54)
C     Upper part.
      temp = M(54, 21) * M(21, 61)
      temp = temp + M(54, 22) * M(22, 61)
      temp = temp + M(54, 41) * M(41, 61)
      temp = temp + M(54, 43) * M(43, 61)
      temp = temp + M(54, 46) * M(46, 61)
      temp = temp + M(54, 47) * M(47, 61)
      temp = temp + M(54, 52) * M(52, 61)
      temp = temp + M(54, 53) * M(53, 61)
      M(54, 61) = ( M(54, 61) - temp ) / M(54, 54)
C     Upper part.
      temp = M(54, 53) * M(53, 62)
      M(54, 62) = ( M(54, 62) - temp ) / M(54, 54)
C     Upper part.
      temp = M(54, 52) * M(52, 63)
      temp = temp + M(54, 53) * M(53, 63)
      M(54, 63) = ( M(54, 63) - temp ) / M(54, 54)
C     Upper part.
      temp = M(54, 21) * M(21, 64)
      temp = temp + M(54, 22) * M(22, 64)
      temp = temp + M(54, 41) * M(41, 64)
      temp = temp + M(54, 43) * M(43, 64)
      temp = temp + M(54, 46) * M(46, 64)
      temp = temp + M(54, 47) * M(47, 64)
      temp = temp + M(54, 52) * M(52, 64)
      temp = temp + M(54, 53) * M(53, 64)
      M(54, 64) = ( M(54, 64) - temp ) / M(54, 54)
C     Upper part.
      temp = M(54, 43) * M(43, 65)
      temp = temp + M(54, 44) * M(44, 65)
      temp = temp + M(54, 45) * M(45, 65)
      temp = temp + M(54, 46) * M(46, 65)
      temp = temp + M(54, 47) * M(47, 65)
      temp = temp + M(54, 52) * M(52, 65)
      temp = temp + M(54, 53) * M(53, 65)
      M(54, 65) = ( M(54, 65) - temp ) / M(54, 54)

C     Lower part.
      temp = M(55, 4) * M(4, 55)
      temp = temp + M(55, 5) * M(5, 55)
      temp = temp + M(55, 6) * M(6, 55)
      temp = temp + M(55, 7) * M(7, 55)
      temp = temp + M(55, 8) * M(8, 55)
      temp = temp + M(55, 9) * M(9, 55)
      temp = temp + M(55, 14) * M(14, 55)
      temp = temp + M(55, 17) * M(17, 55)
      temp = temp + M(55, 18) * M(18, 55)
      temp = temp + M(55, 20) * M(20, 55)
      temp = temp + M(55, 22) * M(22, 55)
      temp = temp + M(55, 23) * M(23, 55)
      temp = temp + M(55, 32) * M(32, 55)
      temp = temp + M(55, 33) * M(33, 55)
      temp = temp + M(55, 34) * M(34, 55)
      temp = temp + M(55, 35) * M(35, 55)
      temp = temp + M(55, 36) * M(36, 55)
      temp = temp + M(55, 37) * M(37, 55)
      temp = temp + M(55, 39) * M(39, 55)
      temp = temp + M(55, 40) * M(40, 55)
      temp = temp + M(55, 41) * M(41, 55)
      temp = temp + M(55, 42) * M(42, 55)
      temp = temp + M(55, 43) * M(43, 55)
      temp = temp + M(55, 44) * M(44, 55)
      temp = temp + M(55, 45) * M(45, 55)
      temp = temp + M(55, 46) * M(46, 55)
      temp = temp + M(55, 47) * M(47, 55)
      temp = temp + M(55, 48) * M(48, 55)
      temp = temp + M(55, 49) * M(49, 55)
      temp = temp + M(55, 50) * M(50, 55)
      temp = temp + M(55, 51) * M(51, 55)
      temp = temp + M(55, 52) * M(52, 55)
      temp = temp + M(55, 53) * M(53, 55)
      temp = temp + M(55, 54) * M(54, 55)
      M(55, 55) = M(55, 55) - temp
C     Lower part.
      temp = M(56, 17) * M(17, 55)
      temp = temp + M(56, 34) * M(34, 55)
      temp = temp + M(56, 36) * M(36, 55)
      temp = temp + M(56, 37) * M(37, 55)
      temp = temp + M(56, 39) * M(39, 55)
      temp = temp + M(56, 40) * M(40, 55)
      temp = temp + M(56, 43) * M(43, 55)
      temp = temp + M(56, 44) * M(44, 55)
      temp = temp + M(56, 45) * M(45, 55)
      temp = temp + M(56, 48) * M(48, 55)
      temp = temp + M(56, 50) * M(50, 55)
      temp = temp + M(56, 52) * M(52, 55)
      temp = temp + M(56, 54) * M(54, 55)
      M(56, 55) = M(56, 55) - temp
C     Lower part.
      temp = M(57, 20) * M(20, 55)
      temp = temp + M(57, 34) * M(34, 55)
      temp = temp + M(57, 36) * M(36, 55)
      temp = temp + M(57, 37) * M(37, 55)
      temp = temp + M(57, 39) * M(39, 55)
      temp = temp + M(57, 44) * M(44, 55)
      temp = temp + M(57, 48) * M(48, 55)
      temp = temp + M(57, 52) * M(52, 55)
      temp = temp + M(57, 54) * M(54, 55)
      M(57, 55) = M(57, 55) - temp
C     Lower part.
      temp = M(58, 18) * M(18, 55)
      temp = temp + M(58, 39) * M(39, 55)
      temp = temp + M(58, 44) * M(44, 55)
      temp = temp + M(58, 45) * M(45, 55)
      temp = temp + M(58, 48) * M(48, 55)
      temp = temp + M(58, 52) * M(52, 55)
      M(58, 55) = M(58, 55) - temp
C     Lower part.
      temp = M(59, 34) * M(34, 55)
      temp = temp + M(59, 36) * M(36, 55)
      temp = temp + M(59, 37) * M(37, 55)
      temp = temp + M(59, 39) * M(39, 55)
      temp = temp + M(59, 41) * M(41, 55)
      temp = temp + M(59, 43) * M(43, 55)
      temp = temp + M(59, 44) * M(44, 55)
      temp = temp + M(59, 45) * M(45, 55)
      M(59, 55) = M(59, 55) - temp
C     Lower part.
      temp = M(60, 4) * M(4, 55)
      temp = temp + M(60, 6) * M(6, 55)
      temp = temp + M(60, 18) * M(18, 55)
      temp = temp + M(60, 19) * M(19, 55)
      temp = temp + M(60, 32) * M(32, 55)
      temp = temp + M(60, 36) * M(36, 55)
      temp = temp + M(60, 37) * M(37, 55)
      temp = temp + M(60, 45) * M(45, 55)
      temp = temp + M(60, 46) * M(46, 55)
      temp = temp + M(60, 47) * M(47, 55)
      temp = temp + M(60, 52) * M(52, 55)
      temp = temp + M(60, 53) * M(53, 55)
      temp = temp + M(60, 54) * M(54, 55)
      M(60, 55) = M(60, 55) - temp
C     Lower part.
      temp = M(61, 4) * M(4, 55)
      temp = temp + M(61, 6) * M(6, 55)
      temp = temp + M(61, 7) * M(7, 55)
      temp = temp + M(61, 8) * M(8, 55)
      temp = temp + M(61, 9) * M(9, 55)
      temp = temp + M(61, 14) * M(14, 55)
      temp = temp + M(61, 15) * M(15, 55)
      temp = temp + M(61, 17) * M(17, 55)
      temp = temp + M(61, 19) * M(19, 55)
      temp = temp + M(61, 20) * M(20, 55)
      temp = temp + M(61, 22) * M(22, 55)
      temp = temp + M(61, 32) * M(32, 55)
      temp = temp + M(61, 34) * M(34, 55)
      temp = temp + M(61, 35) * M(35, 55)
      temp = temp + M(61, 36) * M(36, 55)
      temp = temp + M(61, 37) * M(37, 55)
      temp = temp + M(61, 39) * M(39, 55)
      temp = temp + M(61, 40) * M(40, 55)
      temp = temp + M(61, 41) * M(41, 55)
      temp = temp + M(61, 42) * M(42, 55)
      temp = temp + M(61, 43) * M(43, 55)
      temp = temp + M(61, 44) * M(44, 55)
      temp = temp + M(61, 45) * M(45, 55)
      temp = temp + M(61, 46) * M(46, 55)
      temp = temp + M(61, 47) * M(47, 55)
      temp = temp + M(61, 48) * M(48, 55)
      temp = temp + M(61, 51) * M(51, 55)
      temp = temp + M(61, 52) * M(52, 55)
      temp = temp + M(61, 53) * M(53, 55)
      temp = temp + M(61, 54) * M(54, 55)
      M(61, 55) = M(61, 55) - temp
C     Lower part.
      temp = M(62, 33) * M(33, 55)
      temp = temp + M(62, 41) * M(41, 55)
      temp = temp + M(62, 42) * M(42, 55)
      temp = temp + M(62, 43) * M(43, 55)
      temp = temp + M(62, 45) * M(45, 55)
      temp = temp + M(62, 53) * M(53, 55)
      temp = temp + M(62, 54) * M(54, 55)
      M(62, 55) = M(62, 55) - temp
C     Lower part.
      temp = M(63, 4) * M(4, 55)
      temp = temp + M(63, 6) * M(6, 55)
      temp = temp + M(63, 7) * M(7, 55)
      temp = temp + M(63, 8) * M(8, 55)
      temp = temp + M(63, 19) * M(19, 55)
      temp = temp + M(63, 22) * M(22, 55)
      temp = temp + M(63, 32) * M(32, 55)
      temp = temp + M(63, 34) * M(34, 55)
      temp = temp + M(63, 36) * M(36, 55)
      temp = temp + M(63, 37) * M(37, 55)
      temp = temp + M(63, 39) * M(39, 55)
      temp = temp + M(63, 40) * M(40, 55)
      temp = temp + M(63, 41) * M(41, 55)
      temp = temp + M(63, 42) * M(42, 55)
      temp = temp + M(63, 43) * M(43, 55)
      temp = temp + M(63, 44) * M(44, 55)
      temp = temp + M(63, 45) * M(45, 55)
      temp = temp + M(63, 47) * M(47, 55)
      temp = temp + M(63, 52) * M(52, 55)
      temp = temp + M(63, 53) * M(53, 55)
      temp = temp + M(63, 54) * M(54, 55)
      M(63, 55) = M(63, 55) - temp
C     Lower part.
      temp = M(64, 15) * M(15, 55)
      temp = temp + M(64, 23) * M(23, 55)
      temp = temp + M(64, 44) * M(44, 55)
      temp = temp + M(64, 52) * M(52, 55)
      temp = temp + M(64, 53) * M(53, 55)
      temp = temp + M(64, 54) * M(54, 55)
      M(64, 55) = M(64, 55) - temp
C     Lower part.
      temp = M(65, 15) * M(15, 55)
      temp = temp + M(65, 17) * M(17, 55)
      temp = temp + M(65, 18) * M(18, 55)
      temp = temp + M(65, 19) * M(19, 55)
      temp = temp + M(65, 23) * M(23, 55)
      temp = temp + M(65, 34) * M(34, 55)
      temp = temp + M(65, 36) * M(36, 55)
      temp = temp + M(65, 37) * M(37, 55)
      temp = temp + M(65, 39) * M(39, 55)
      temp = temp + M(65, 43) * M(43, 55)
      temp = temp + M(65, 44) * M(44, 55)
      temp = temp + M(65, 46) * M(46, 55)
      temp = temp + M(65, 47) * M(47, 55)
      temp = temp + M(65, 50) * M(50, 55)
      temp = temp + M(65, 52) * M(52, 55)
      temp = temp + M(65, 53) * M(53, 55)
      temp = temp + M(65, 54) * M(54, 55)
      M(65, 55) = M(65, 55) - temp
C     Upper part.
      temp = M(55, 34) * M(34, 56)
      temp = temp + M(55, 35) * M(35, 56)
      temp = temp + M(55, 36) * M(36, 56)
      temp = temp + M(55, 37) * M(37, 56)
      temp = temp + M(55, 39) * M(39, 56)
      temp = temp + M(55, 40) * M(40, 56)
      temp = temp + M(55, 41) * M(41, 56)
      temp = temp + M(55, 42) * M(42, 56)
      temp = temp + M(55, 43) * M(43, 56)
      temp = temp + M(55, 44) * M(44, 56)
      temp = temp + M(55, 45) * M(45, 56)
      temp = temp + M(55, 46) * M(46, 56)
      temp = temp + M(55, 47) * M(47, 56)
      temp = temp + M(55, 48) * M(48, 56)
      temp = temp + M(55, 50) * M(50, 56)
      temp = temp + M(55, 51) * M(51, 56)
      temp = temp + M(55, 52) * M(52, 56)
      temp = temp + M(55, 53) * M(53, 56)
      temp = temp + M(55, 54) * M(54, 56)
      M(55, 56) = ( M(55, 56) - temp ) / M(55, 55)
C     Upper part.
      temp = M(55, 20) * M(20, 57)
      temp = temp + M(55, 34) * M(34, 57)
      temp = temp + M(55, 35) * M(35, 57)
      temp = temp + M(55, 36) * M(36, 57)
      temp = temp + M(55, 37) * M(37, 57)
      temp = temp + M(55, 39) * M(39, 57)
      temp = temp + M(55, 44) * M(44, 57)
      temp = temp + M(55, 45) * M(45, 57)
      temp = temp + M(55, 46) * M(46, 57)
      temp = temp + M(55, 47) * M(47, 57)
      temp = temp + M(55, 48) * M(48, 57)
      temp = temp + M(55, 50) * M(50, 57)
      temp = temp + M(55, 51) * M(51, 57)
      temp = temp + M(55, 52) * M(52, 57)
      temp = temp + M(55, 53) * M(53, 57)
      temp = temp + M(55, 54) * M(54, 57)
      M(55, 57) = ( M(55, 57) - temp ) / M(55, 55)
C     Upper part.
      temp = M(55, 18) * M(18, 58)
      temp = temp + M(55, 33) * M(33, 58)
      temp = temp + M(55, 49) * M(49, 58)
      temp = temp + M(55, 53) * M(53, 58)
      temp = temp + M(55, 54) * M(54, 58)
      M(55, 58) = ( M(55, 58) - temp ) / M(55, 55)
C     Upper part.
      temp = M(55, 3) * M(3, 59)
      temp = temp + M(55, 34) * M(34, 59)
      temp = temp + M(55, 35) * M(35, 59)
      temp = temp + M(55, 36) * M(36, 59)
      temp = temp + M(55, 37) * M(37, 59)
      temp = temp + M(55, 39) * M(39, 59)
      temp = temp + M(55, 41) * M(41, 59)
      temp = temp + M(55, 42) * M(42, 59)
      temp = temp + M(55, 44) * M(44, 59)
      temp = temp + M(55, 45) * M(45, 59)
      temp = temp + M(55, 46) * M(46, 59)
      temp = temp + M(55, 47) * M(47, 59)
      temp = temp + M(55, 48) * M(48, 59)
      temp = temp + M(55, 50) * M(50, 59)
      temp = temp + M(55, 51) * M(51, 59)
      temp = temp + M(55, 52) * M(52, 59)
      temp = temp + M(55, 53) * M(53, 59)
      temp = temp + M(55, 54) * M(54, 59)
      M(55, 59) = ( M(55, 59) - temp ) / M(55, 55)
C     Upper part.
      temp = M(55, 50) * M(50, 60)
      temp = temp + M(55, 51) * M(51, 60)
      temp = temp + M(55, 53) * M(53, 60)
      temp = temp + M(55, 54) * M(54, 60)
      M(55, 60) = ( M(55, 60) - temp ) / M(55, 55)
C     Upper part.
      temp = M(55, 17) * M(17, 61)
      temp = temp + M(55, 20) * M(20, 61)
      temp = temp + M(55, 22) * M(22, 61)
      temp = temp + M(55, 32) * M(32, 61)
      temp = temp + M(55, 33) * M(33, 61)
      temp = temp + M(55, 35) * M(35, 61)
      temp = temp + M(55, 40) * M(40, 61)
      temp = temp + M(55, 41) * M(41, 61)
      temp = temp + M(55, 42) * M(42, 61)
      temp = temp + M(55, 43) * M(43, 61)
      temp = temp + M(55, 46) * M(46, 61)
      temp = temp + M(55, 47) * M(47, 61)
      temp = temp + M(55, 48) * M(48, 61)
      temp = temp + M(55, 49) * M(49, 61)
      temp = temp + M(55, 50) * M(50, 61)
      temp = temp + M(55, 51) * M(51, 61)
      temp = temp + M(55, 52) * M(52, 61)
      temp = temp + M(55, 53) * M(53, 61)
      temp = temp + M(55, 54) * M(54, 61)
      M(55, 61) = ( M(55, 61) - temp ) / M(55, 55)
C     Upper part.
      temp = M(55, 33) * M(33, 62)
      temp = temp + M(55, 49) * M(49, 62)
      temp = temp + M(55, 53) * M(53, 62)
      temp = temp + M(55, 54) * M(54, 62)
      M(55, 62) = ( M(55, 62) - temp ) / M(55, 55)
C     Upper part.
      temp = M(55, 32) * M(32, 63)
      temp = temp + M(55, 48) * M(48, 63)
      temp = temp + M(55, 49) * M(49, 63)
      temp = temp + M(55, 50) * M(50, 63)
      temp = temp + M(55, 51) * M(51, 63)
      temp = temp + M(55, 52) * M(52, 63)
      temp = temp + M(55, 53) * M(53, 63)
      temp = temp + M(55, 54) * M(54, 63)
      M(55, 63) = ( M(55, 63) - temp ) / M(55, 55)
C     Upper part.
      temp = M(55, 22) * M(22, 64)
      temp = temp + M(55, 23) * M(23, 64)
      temp = temp + M(55, 35) * M(35, 64)
      temp = temp + M(55, 40) * M(40, 64)
      temp = temp + M(55, 41) * M(41, 64)
      temp = temp + M(55, 42) * M(42, 64)
      temp = temp + M(55, 43) * M(43, 64)
      temp = temp + M(55, 46) * M(46, 64)
      temp = temp + M(55, 47) * M(47, 64)
      temp = temp + M(55, 48) * M(48, 64)
      temp = temp + M(55, 50) * M(50, 64)
      temp = temp + M(55, 51) * M(51, 64)
      temp = temp + M(55, 52) * M(52, 64)
      temp = temp + M(55, 53) * M(53, 64)
      temp = temp + M(55, 54) * M(54, 64)
      M(55, 64) = ( M(55, 64) - temp ) / M(55, 55)
C     Upper part.
      temp = M(55, 17) * M(17, 65)
      temp = temp + M(55, 18) * M(18, 65)
      temp = temp + M(55, 23) * M(23, 65)
      temp = temp + M(55, 43) * M(43, 65)
      temp = temp + M(55, 44) * M(44, 65)
      temp = temp + M(55, 45) * M(45, 65)
      temp = temp + M(55, 46) * M(46, 65)
      temp = temp + M(55, 47) * M(47, 65)
      temp = temp + M(55, 48) * M(48, 65)
      temp = temp + M(55, 50) * M(50, 65)
      temp = temp + M(55, 51) * M(51, 65)
      temp = temp + M(55, 52) * M(52, 65)
      temp = temp + M(55, 53) * M(53, 65)
      temp = temp + M(55, 54) * M(54, 65)
      M(55, 65) = ( M(55, 65) - temp ) / M(55, 55)

C     Lower part.
      temp = M(56, 16) * M(16, 56)
      temp = temp + M(56, 34) * M(34, 56)
      temp = temp + M(56, 36) * M(36, 56)
      temp = temp + M(56, 37) * M(37, 56)
      temp = temp + M(56, 39) * M(39, 56)
      temp = temp + M(56, 40) * M(40, 56)
      temp = temp + M(56, 43) * M(43, 56)
      temp = temp + M(56, 44) * M(44, 56)
      temp = temp + M(56, 45) * M(45, 56)
      temp = temp + M(56, 48) * M(48, 56)
      temp = temp + M(56, 50) * M(50, 56)
      temp = temp + M(56, 52) * M(52, 56)
      temp = temp + M(56, 54) * M(54, 56)
      temp = temp + M(56, 55) * M(55, 56)
      M(56, 56) = M(56, 56) - temp
C     Lower part.
      temp = M(57, 34) * M(34, 56)
      temp = temp + M(57, 36) * M(36, 56)
      temp = temp + M(57, 37) * M(37, 56)
      temp = temp + M(57, 39) * M(39, 56)
      temp = temp + M(57, 44) * M(44, 56)
      temp = temp + M(57, 48) * M(48, 56)
      temp = temp + M(57, 52) * M(52, 56)
      temp = temp + M(57, 54) * M(54, 56)
      temp = temp + M(57, 55) * M(55, 56)
      M(57, 56) = M(57, 56) - temp
C     Lower part.
      temp = M(58, 39) * M(39, 56)
      temp = temp + M(58, 44) * M(44, 56)
      temp = temp + M(58, 45) * M(45, 56)
      temp = temp + M(58, 48) * M(48, 56)
      temp = temp + M(58, 52) * M(52, 56)
      temp = temp + M(58, 55) * M(55, 56)
      M(58, 56) = M(58, 56) - temp
C     Lower part.
      temp = M(59, 34) * M(34, 56)
      temp = temp + M(59, 36) * M(36, 56)
      temp = temp + M(59, 37) * M(37, 56)
      temp = temp + M(59, 39) * M(39, 56)
      temp = temp + M(59, 41) * M(41, 56)
      temp = temp + M(59, 43) * M(43, 56)
      temp = temp + M(59, 44) * M(44, 56)
      temp = temp + M(59, 45) * M(45, 56)
      temp = temp + M(59, 55) * M(55, 56)
      M(59, 56) = M(59, 56) - temp
C     Lower part.
      temp = M(60, 36) * M(36, 56)
      temp = temp + M(60, 37) * M(37, 56)
      temp = temp + M(60, 45) * M(45, 56)
      temp = temp + M(60, 46) * M(46, 56)
      temp = temp + M(60, 47) * M(47, 56)
      temp = temp + M(60, 52) * M(52, 56)
      temp = temp + M(60, 53) * M(53, 56)
      temp = temp + M(60, 54) * M(54, 56)
      temp = temp + M(60, 55) * M(55, 56)
      M(60, 56) = M(60, 56) - temp
C     Lower part.
      temp = M(61, 34) * M(34, 56)
      temp = temp + M(61, 35) * M(35, 56)
      temp = temp + M(61, 36) * M(36, 56)
      temp = temp + M(61, 37) * M(37, 56)
      temp = temp + M(61, 39) * M(39, 56)
      temp = temp + M(61, 40) * M(40, 56)
      temp = temp + M(61, 41) * M(41, 56)
      temp = temp + M(61, 42) * M(42, 56)
      temp = temp + M(61, 43) * M(43, 56)
      temp = temp + M(61, 44) * M(44, 56)
      temp = temp + M(61, 45) * M(45, 56)
      temp = temp + M(61, 46) * M(46, 56)
      temp = temp + M(61, 47) * M(47, 56)
      temp = temp + M(61, 48) * M(48, 56)
      temp = temp + M(61, 51) * M(51, 56)
      temp = temp + M(61, 52) * M(52, 56)
      temp = temp + M(61, 53) * M(53, 56)
      temp = temp + M(61, 54) * M(54, 56)
      temp = temp + M(61, 55) * M(55, 56)
      M(61, 56) = M(61, 56) - temp
C     Lower part.
      temp = M(62, 41) * M(41, 56)
      temp = temp + M(62, 42) * M(42, 56)
      temp = temp + M(62, 43) * M(43, 56)
      temp = temp + M(62, 45) * M(45, 56)
      temp = temp + M(62, 53) * M(53, 56)
      temp = temp + M(62, 54) * M(54, 56)
      temp = temp + M(62, 55) * M(55, 56)
      M(62, 56) = M(62, 56) - temp
C     Lower part.
      temp = M(63, 34) * M(34, 56)
      temp = temp + M(63, 36) * M(36, 56)
      temp = temp + M(63, 37) * M(37, 56)
      temp = temp + M(63, 39) * M(39, 56)
      temp = temp + M(63, 40) * M(40, 56)
      temp = temp + M(63, 41) * M(41, 56)
      temp = temp + M(63, 42) * M(42, 56)
      temp = temp + M(63, 43) * M(43, 56)
      temp = temp + M(63, 44) * M(44, 56)
      temp = temp + M(63, 45) * M(45, 56)
      temp = temp + M(63, 47) * M(47, 56)
      temp = temp + M(63, 52) * M(52, 56)
      temp = temp + M(63, 53) * M(53, 56)
      temp = temp + M(63, 54) * M(54, 56)
      temp = temp + M(63, 55) * M(55, 56)
      M(63, 56) = M(63, 56) - temp
C     Lower part.
      temp = M(64, 44) * M(44, 56)
      temp = temp + M(64, 52) * M(52, 56)
      temp = temp + M(64, 53) * M(53, 56)
      temp = temp + M(64, 54) * M(54, 56)
      temp = temp + M(64, 55) * M(55, 56)
      M(64, 56) = M(64, 56) - temp
C     Lower part.
      temp = M(65, 16) * M(16, 56)
      temp = temp + M(65, 34) * M(34, 56)
      temp = temp + M(65, 36) * M(36, 56)
      temp = temp + M(65, 37) * M(37, 56)
      temp = temp + M(65, 39) * M(39, 56)
      temp = temp + M(65, 43) * M(43, 56)
      temp = temp + M(65, 44) * M(44, 56)
      temp = temp + M(65, 46) * M(46, 56)
      temp = temp + M(65, 47) * M(47, 56)
      temp = temp + M(65, 50) * M(50, 56)
      temp = temp + M(65, 52) * M(52, 56)
      temp = temp + M(65, 53) * M(53, 56)
      temp = temp + M(65, 54) * M(54, 56)
      temp = temp + M(65, 55) * M(55, 56)
      M(65, 56) = M(65, 56) - temp
C     Upper part.
      temp = M(56, 34) * M(34, 57)
      temp = temp + M(56, 36) * M(36, 57)
      temp = temp + M(56, 37) * M(37, 57)
      temp = temp + M(56, 39) * M(39, 57)
      temp = temp + M(56, 44) * M(44, 57)
      temp = temp + M(56, 45) * M(45, 57)
      temp = temp + M(56, 48) * M(48, 57)
      temp = temp + M(56, 50) * M(50, 57)
      temp = temp + M(56, 52) * M(52, 57)
      temp = temp + M(56, 54) * M(54, 57)
      temp = temp + M(56, 55) * M(55, 57)
      M(56, 57) = ( M(56, 57) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 54) * M(54, 58)
      temp = temp + M(56, 55) * M(55, 58)
      M(56, 58) = ( M(56, 58) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 34) * M(34, 59)
      temp = temp + M(56, 36) * M(36, 59)
      temp = temp + M(56, 37) * M(37, 59)
      temp = temp + M(56, 39) * M(39, 59)
      temp = temp + M(56, 44) * M(44, 59)
      temp = temp + M(56, 45) * M(45, 59)
      temp = temp + M(56, 48) * M(48, 59)
      temp = temp + M(56, 50) * M(50, 59)
      temp = temp + M(56, 52) * M(52, 59)
      temp = temp + M(56, 54) * M(54, 59)
      temp = temp + M(56, 55) * M(55, 59)
      M(56, 59) = ( M(56, 59) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 50) * M(50, 60)
      temp = temp + M(56, 54) * M(54, 60)
      temp = temp + M(56, 55) * M(55, 60)
      M(56, 60) = ( M(56, 60) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 17) * M(17, 61)
      temp = temp + M(56, 40) * M(40, 61)
      temp = temp + M(56, 43) * M(43, 61)
      temp = temp + M(56, 48) * M(48, 61)
      temp = temp + M(56, 50) * M(50, 61)
      temp = temp + M(56, 52) * M(52, 61)
      temp = temp + M(56, 54) * M(54, 61)
      temp = temp + M(56, 55) * M(55, 61)
      M(56, 61) = ( M(56, 61) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 54) * M(54, 62)
      temp = temp + M(56, 55) * M(55, 62)
      M(56, 62) = ( M(56, 62) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 48) * M(48, 63)
      temp = temp + M(56, 50) * M(50, 63)
      temp = temp + M(56, 52) * M(52, 63)
      temp = temp + M(56, 54) * M(54, 63)
      temp = temp + M(56, 55) * M(55, 63)
      M(56, 63) = ( M(56, 63) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 40) * M(40, 64)
      temp = temp + M(56, 43) * M(43, 64)
      temp = temp + M(56, 48) * M(48, 64)
      temp = temp + M(56, 50) * M(50, 64)
      temp = temp + M(56, 52) * M(52, 64)
      temp = temp + M(56, 54) * M(54, 64)
      temp = temp + M(56, 55) * M(55, 64)
      M(56, 64) = ( M(56, 64) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 16) * M(16, 65)
      temp = temp + M(56, 17) * M(17, 65)
      temp = temp + M(56, 43) * M(43, 65)
      temp = temp + M(56, 44) * M(44, 65)
      temp = temp + M(56, 45) * M(45, 65)
      temp = temp + M(56, 48) * M(48, 65)
      temp = temp + M(56, 50) * M(50, 65)
      temp = temp + M(56, 52) * M(52, 65)
      temp = temp + M(56, 54) * M(54, 65)
      temp = temp + M(56, 55) * M(55, 65)
      M(56, 65) = ( M(56, 65) - temp ) / M(56, 56)

C     Lower part.
      temp = M(57, 20) * M(20, 57)
      temp = temp + M(57, 34) * M(34, 57)
      temp = temp + M(57, 36) * M(36, 57)
      temp = temp + M(57, 37) * M(37, 57)
      temp = temp + M(57, 39) * M(39, 57)
      temp = temp + M(57, 44) * M(44, 57)
      temp = temp + M(57, 48) * M(48, 57)
      temp = temp + M(57, 52) * M(52, 57)
      temp = temp + M(57, 54) * M(54, 57)
      temp = temp + M(57, 55) * M(55, 57)
      temp = temp + M(57, 56) * M(56, 57)
      M(57, 57) = M(57, 57) - temp
C     Lower part.
      temp = M(58, 39) * M(39, 57)
      temp = temp + M(58, 44) * M(44, 57)
      temp = temp + M(58, 45) * M(45, 57)
      temp = temp + M(58, 48) * M(48, 57)
      temp = temp + M(58, 52) * M(52, 57)
      temp = temp + M(58, 55) * M(55, 57)
      temp = temp + M(58, 56) * M(56, 57)
      M(58, 57) = M(58, 57) - temp
C     Lower part.
      temp = M(59, 34) * M(34, 57)
      temp = temp + M(59, 36) * M(36, 57)
      temp = temp + M(59, 37) * M(37, 57)
      temp = temp + M(59, 39) * M(39, 57)
      temp = temp + M(59, 44) * M(44, 57)
      temp = temp + M(59, 45) * M(45, 57)
      temp = temp + M(59, 55) * M(55, 57)
      temp = temp + M(59, 56) * M(56, 57)
      M(59, 57) = M(59, 57) - temp
C     Lower part.
      temp = M(60, 36) * M(36, 57)
      temp = temp + M(60, 37) * M(37, 57)
      temp = temp + M(60, 45) * M(45, 57)
      temp = temp + M(60, 46) * M(46, 57)
      temp = temp + M(60, 47) * M(47, 57)
      temp = temp + M(60, 52) * M(52, 57)
      temp = temp + M(60, 53) * M(53, 57)
      temp = temp + M(60, 54) * M(54, 57)
      temp = temp + M(60, 55) * M(55, 57)
      temp = temp + M(60, 56) * M(56, 57)
      M(60, 57) = M(60, 57) - temp
C     Lower part.
      temp = M(61, 20) * M(20, 57)
      temp = temp + M(61, 34) * M(34, 57)
      temp = temp + M(61, 35) * M(35, 57)
      temp = temp + M(61, 36) * M(36, 57)
      temp = temp + M(61, 37) * M(37, 57)
      temp = temp + M(61, 39) * M(39, 57)
      temp = temp + M(61, 44) * M(44, 57)
      temp = temp + M(61, 45) * M(45, 57)
      temp = temp + M(61, 46) * M(46, 57)
      temp = temp + M(61, 47) * M(47, 57)
      temp = temp + M(61, 48) * M(48, 57)
      temp = temp + M(61, 51) * M(51, 57)
      temp = temp + M(61, 52) * M(52, 57)
      temp = temp + M(61, 53) * M(53, 57)
      temp = temp + M(61, 54) * M(54, 57)
      temp = temp + M(61, 55) * M(55, 57)
      temp = temp + M(61, 56) * M(56, 57)
      M(61, 57) = M(61, 57) - temp
C     Lower part.
      temp = M(62, 45) * M(45, 57)
      temp = temp + M(62, 53) * M(53, 57)
      temp = temp + M(62, 54) * M(54, 57)
      temp = temp + M(62, 55) * M(55, 57)
      temp = temp + M(62, 56) * M(56, 57)
      M(62, 57) = M(62, 57) - temp
C     Lower part.
      temp = M(63, 34) * M(34, 57)
      temp = temp + M(63, 36) * M(36, 57)
      temp = temp + M(63, 37) * M(37, 57)
      temp = temp + M(63, 39) * M(39, 57)
      temp = temp + M(63, 44) * M(44, 57)
      temp = temp + M(63, 45) * M(45, 57)
      temp = temp + M(63, 47) * M(47, 57)
      temp = temp + M(63, 52) * M(52, 57)
      temp = temp + M(63, 53) * M(53, 57)
      temp = temp + M(63, 54) * M(54, 57)
      temp = temp + M(63, 55) * M(55, 57)
      temp = temp + M(63, 56) * M(56, 57)
      M(63, 57) = M(63, 57) - temp
C     Lower part.
      temp = M(64, 44) * M(44, 57)
      temp = temp + M(64, 52) * M(52, 57)
      temp = temp + M(64, 53) * M(53, 57)
      temp = temp + M(64, 54) * M(54, 57)
      temp = temp + M(64, 55) * M(55, 57)
      temp = temp + M(64, 56) * M(56, 57)
      M(64, 57) = M(64, 57) - temp
C     Lower part.
      temp = M(65, 34) * M(34, 57)
      temp = temp + M(65, 36) * M(36, 57)
      temp = temp + M(65, 37) * M(37, 57)
      temp = temp + M(65, 39) * M(39, 57)
      temp = temp + M(65, 44) * M(44, 57)
      temp = temp + M(65, 46) * M(46, 57)
      temp = temp + M(65, 47) * M(47, 57)
      temp = temp + M(65, 50) * M(50, 57)
      temp = temp + M(65, 52) * M(52, 57)
      temp = temp + M(65, 53) * M(53, 57)
      temp = temp + M(65, 54) * M(54, 57)
      temp = temp + M(65, 55) * M(55, 57)
      temp = temp + M(65, 56) * M(56, 57)
      M(65, 57) = M(65, 57) - temp
C     Upper part.
      temp = M(57, 54) * M(54, 58)
      temp = temp + M(57, 55) * M(55, 58)
      temp = temp + M(57, 56) * M(56, 58)
      M(57, 58) = ( M(57, 58) - temp ) / M(57, 57)
C     Upper part.
      temp = M(57, 3) * M(3, 59)
      temp = temp + M(57, 34) * M(34, 59)
      temp = temp + M(57, 36) * M(36, 59)
      temp = temp + M(57, 37) * M(37, 59)
      temp = temp + M(57, 39) * M(39, 59)
      temp = temp + M(57, 44) * M(44, 59)
      temp = temp + M(57, 48) * M(48, 59)
      temp = temp + M(57, 52) * M(52, 59)
      temp = temp + M(57, 54) * M(54, 59)
      temp = temp + M(57, 55) * M(55, 59)
      temp = temp + M(57, 56) * M(56, 59)
      M(57, 59) = ( M(57, 59) - temp ) / M(57, 57)
C     Upper part.
      temp = M(57, 54) * M(54, 60)
      temp = temp + M(57, 55) * M(55, 60)
      temp = temp + M(57, 56) * M(56, 60)
      M(57, 60) = ( M(57, 60) - temp ) / M(57, 57)
C     Upper part.
      temp = M(57, 20) * M(20, 61)
      temp = temp + M(57, 48) * M(48, 61)
      temp = temp + M(57, 52) * M(52, 61)
      temp = temp + M(57, 54) * M(54, 61)
      temp = temp + M(57, 55) * M(55, 61)
      temp = temp + M(57, 56) * M(56, 61)
      M(57, 61) = ( M(57, 61) - temp ) / M(57, 57)
C     Upper part.
      temp = M(57, 54) * M(54, 62)
      temp = temp + M(57, 55) * M(55, 62)
      temp = temp + M(57, 56) * M(56, 62)
      M(57, 62) = ( M(57, 62) - temp ) / M(57, 57)
C     Upper part.
      temp = M(57, 48) * M(48, 63)
      temp = temp + M(57, 52) * M(52, 63)
      temp = temp + M(57, 54) * M(54, 63)
      temp = temp + M(57, 55) * M(55, 63)
      temp = temp + M(57, 56) * M(56, 63)
      M(57, 63) = ( M(57, 63) - temp ) / M(57, 57)
C     Upper part.
      temp = M(57, 48) * M(48, 64)
      temp = temp + M(57, 52) * M(52, 64)
      temp = temp + M(57, 54) * M(54, 64)
      temp = temp + M(57, 55) * M(55, 64)
      temp = temp + M(57, 56) * M(56, 64)
      M(57, 64) = ( M(57, 64) - temp ) / M(57, 57)
C     Upper part.
      temp = M(57, 44) * M(44, 65)
      temp = temp + M(57, 48) * M(48, 65)
      temp = temp + M(57, 52) * M(52, 65)
      temp = temp + M(57, 54) * M(54, 65)
      temp = temp + M(57, 55) * M(55, 65)
      temp = temp + M(57, 56) * M(56, 65)
      M(57, 65) = ( M(57, 65) - temp ) / M(57, 57)

C     Lower part.
      temp = M(58, 18) * M(18, 58)
      temp = temp + M(58, 55) * M(55, 58)
      temp = temp + M(58, 56) * M(56, 58)
      temp = temp + M(58, 57) * M(57, 58)
      M(58, 58) = M(58, 58) - temp
C     Lower part.
      temp = M(59, 55) * M(55, 58)
      temp = temp + M(59, 56) * M(56, 58)
      temp = temp + M(59, 57) * M(57, 58)
      M(59, 58) = M(59, 58) - temp
C     Lower part.
      temp = M(60, 18) * M(18, 58)
      temp = temp + M(60, 53) * M(53, 58)
      temp = temp + M(60, 54) * M(54, 58)
      temp = temp + M(60, 55) * M(55, 58)
      temp = temp + M(60, 56) * M(56, 58)
      temp = temp + M(60, 57) * M(57, 58)
      M(60, 58) = M(60, 58) - temp
C     Lower part.
      temp = M(61, 53) * M(53, 58)
      temp = temp + M(61, 54) * M(54, 58)
      temp = temp + M(61, 55) * M(55, 58)
      temp = temp + M(61, 56) * M(56, 58)
      temp = temp + M(61, 57) * M(57, 58)
      M(61, 58) = M(61, 58) - temp
C     Lower part.
      temp = M(62, 33) * M(33, 58)
      temp = temp + M(62, 53) * M(53, 58)
      temp = temp + M(62, 54) * M(54, 58)
      temp = temp + M(62, 55) * M(55, 58)
      temp = temp + M(62, 56) * M(56, 58)
      temp = temp + M(62, 57) * M(57, 58)
      M(62, 58) = M(62, 58) - temp
C     Lower part.
      temp = M(63, 53) * M(53, 58)
      temp = temp + M(63, 54) * M(54, 58)
      temp = temp + M(63, 55) * M(55, 58)
      temp = temp + M(63, 56) * M(56, 58)
      temp = temp + M(63, 57) * M(57, 58)
      M(63, 58) = M(63, 58) - temp
C     Lower part.
      temp = M(64, 53) * M(53, 58)
      temp = temp + M(64, 54) * M(54, 58)
      temp = temp + M(64, 55) * M(55, 58)
      temp = temp + M(64, 56) * M(56, 58)
      temp = temp + M(64, 57) * M(57, 58)
      M(64, 58) = M(64, 58) - temp
C     Lower part.
      temp = M(65, 18) * M(18, 58)
      temp = temp + M(65, 53) * M(53, 58)
      temp = temp + M(65, 54) * M(54, 58)
      temp = temp + M(65, 55) * M(55, 58)
      temp = temp + M(65, 56) * M(56, 58)
      temp = temp + M(65, 57) * M(57, 58)
      M(65, 58) = M(65, 58) - temp
C     Upper part.
      temp = M(58, 39) * M(39, 59)
      temp = temp + M(58, 44) * M(44, 59)
      temp = temp + M(58, 45) * M(45, 59)
      temp = temp + M(58, 48) * M(48, 59)
      temp = temp + M(58, 52) * M(52, 59)
      temp = temp + M(58, 55) * M(55, 59)
      temp = temp + M(58, 56) * M(56, 59)
      temp = temp + M(58, 57) * M(57, 59)
      M(58, 59) = ( M(58, 59) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 55) * M(55, 60)
      temp = temp + M(58, 56) * M(56, 60)
      temp = temp + M(58, 57) * M(57, 60)
      M(58, 60) = ( M(58, 60) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 48) * M(48, 61)
      temp = temp + M(58, 52) * M(52, 61)
      temp = temp + M(58, 55) * M(55, 61)
      temp = temp + M(58, 56) * M(56, 61)
      temp = temp + M(58, 57) * M(57, 61)
      M(58, 61) = ( M(58, 61) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 55) * M(55, 62)
      temp = temp + M(58, 56) * M(56, 62)
      temp = temp + M(58, 57) * M(57, 62)
      M(58, 62) = ( M(58, 62) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 48) * M(48, 63)
      temp = temp + M(58, 52) * M(52, 63)
      temp = temp + M(58, 55) * M(55, 63)
      temp = temp + M(58, 56) * M(56, 63)
      temp = temp + M(58, 57) * M(57, 63)
      M(58, 63) = ( M(58, 63) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 48) * M(48, 64)
      temp = temp + M(58, 52) * M(52, 64)
      temp = temp + M(58, 55) * M(55, 64)
      temp = temp + M(58, 56) * M(56, 64)
      temp = temp + M(58, 57) * M(57, 64)
      M(58, 64) = ( M(58, 64) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 18) * M(18, 65)
      temp = temp + M(58, 44) * M(44, 65)
      temp = temp + M(58, 45) * M(45, 65)
      temp = temp + M(58, 48) * M(48, 65)
      temp = temp + M(58, 52) * M(52, 65)
      temp = temp + M(58, 55) * M(55, 65)
      temp = temp + M(58, 56) * M(56, 65)
      temp = temp + M(58, 57) * M(57, 65)
      M(58, 65) = ( M(58, 65) - temp ) / M(58, 58)

C     Lower part.
      temp = M(59, 34) * M(34, 59)
      temp = temp + M(59, 36) * M(36, 59)
      temp = temp + M(59, 37) * M(37, 59)
      temp = temp + M(59, 39) * M(39, 59)
      temp = temp + M(59, 41) * M(41, 59)
      temp = temp + M(59, 44) * M(44, 59)
      temp = temp + M(59, 45) * M(45, 59)
      temp = temp + M(59, 55) * M(55, 59)
      temp = temp + M(59, 56) * M(56, 59)
      temp = temp + M(59, 57) * M(57, 59)
      temp = temp + M(59, 58) * M(58, 59)
      M(59, 59) = M(59, 59) - temp
C     Lower part.
      temp = M(60, 36) * M(36, 59)
      temp = temp + M(60, 37) * M(37, 59)
      temp = temp + M(60, 45) * M(45, 59)
      temp = temp + M(60, 46) * M(46, 59)
      temp = temp + M(60, 47) * M(47, 59)
      temp = temp + M(60, 52) * M(52, 59)
      temp = temp + M(60, 53) * M(53, 59)
      temp = temp + M(60, 54) * M(54, 59)
      temp = temp + M(60, 55) * M(55, 59)
      temp = temp + M(60, 56) * M(56, 59)
      temp = temp + M(60, 57) * M(57, 59)
      temp = temp + M(60, 58) * M(58, 59)
      M(60, 59) = M(60, 59) - temp
C     Lower part.
      temp = M(61, 3) * M(3, 59)
      temp = temp + M(61, 34) * M(34, 59)
      temp = temp + M(61, 35) * M(35, 59)
      temp = temp + M(61, 36) * M(36, 59)
      temp = temp + M(61, 37) * M(37, 59)
      temp = temp + M(61, 39) * M(39, 59)
      temp = temp + M(61, 41) * M(41, 59)
      temp = temp + M(61, 42) * M(42, 59)
      temp = temp + M(61, 44) * M(44, 59)
      temp = temp + M(61, 45) * M(45, 59)
      temp = temp + M(61, 46) * M(46, 59)
      temp = temp + M(61, 47) * M(47, 59)
      temp = temp + M(61, 48) * M(48, 59)
      temp = temp + M(61, 51) * M(51, 59)
      temp = temp + M(61, 52) * M(52, 59)
      temp = temp + M(61, 53) * M(53, 59)
      temp = temp + M(61, 54) * M(54, 59)
      temp = temp + M(61, 55) * M(55, 59)
      temp = temp + M(61, 56) * M(56, 59)
      temp = temp + M(61, 57) * M(57, 59)
      temp = temp + M(61, 58) * M(58, 59)
      M(61, 59) = M(61, 59) - temp
C     Lower part.
      temp = M(62, 41) * M(41, 59)
      temp = temp + M(62, 42) * M(42, 59)
      temp = temp + M(62, 45) * M(45, 59)
      temp = temp + M(62, 53) * M(53, 59)
      temp = temp + M(62, 54) * M(54, 59)
      temp = temp + M(62, 55) * M(55, 59)
      temp = temp + M(62, 56) * M(56, 59)
      temp = temp + M(62, 57) * M(57, 59)
      temp = temp + M(62, 58) * M(58, 59)
      M(62, 59) = M(62, 59) - temp
C     Lower part.
      temp = M(63, 34) * M(34, 59)
      temp = temp + M(63, 36) * M(36, 59)
      temp = temp + M(63, 37) * M(37, 59)
      temp = temp + M(63, 39) * M(39, 59)
      temp = temp + M(63, 41) * M(41, 59)
      temp = temp + M(63, 42) * M(42, 59)
      temp = temp + M(63, 44) * M(44, 59)
      temp = temp + M(63, 45) * M(45, 59)
      temp = temp + M(63, 47) * M(47, 59)
      temp = temp + M(63, 52) * M(52, 59)
      temp = temp + M(63, 53) * M(53, 59)
      temp = temp + M(63, 54) * M(54, 59)
      temp = temp + M(63, 55) * M(55, 59)
      temp = temp + M(63, 56) * M(56, 59)
      temp = temp + M(63, 57) * M(57, 59)
      temp = temp + M(63, 58) * M(58, 59)
      M(63, 59) = M(63, 59) - temp
C     Lower part.
      temp = M(64, 44) * M(44, 59)
      temp = temp + M(64, 52) * M(52, 59)
      temp = temp + M(64, 53) * M(53, 59)
      temp = temp + M(64, 54) * M(54, 59)
      temp = temp + M(64, 55) * M(55, 59)
      temp = temp + M(64, 56) * M(56, 59)
      temp = temp + M(64, 57) * M(57, 59)
      temp = temp + M(64, 58) * M(58, 59)
      M(64, 59) = M(64, 59) - temp
C     Lower part.
      temp = M(65, 34) * M(34, 59)
      temp = temp + M(65, 36) * M(36, 59)
      temp = temp + M(65, 37) * M(37, 59)
      temp = temp + M(65, 39) * M(39, 59)
      temp = temp + M(65, 44) * M(44, 59)
      temp = temp + M(65, 46) * M(46, 59)
      temp = temp + M(65, 47) * M(47, 59)
      temp = temp + M(65, 50) * M(50, 59)
      temp = temp + M(65, 52) * M(52, 59)
      temp = temp + M(65, 53) * M(53, 59)
      temp = temp + M(65, 54) * M(54, 59)
      temp = temp + M(65, 55) * M(55, 59)
      temp = temp + M(65, 56) * M(56, 59)
      temp = temp + M(65, 57) * M(57, 59)
      temp = temp + M(65, 58) * M(58, 59)
      M(65, 59) = M(65, 59) - temp
C     Upper part.
      temp = M(59, 55) * M(55, 60)
      temp = temp + M(59, 56) * M(56, 60)
      temp = temp + M(59, 57) * M(57, 60)
      temp = temp + M(59, 58) * M(58, 60)
      M(59, 60) = ( M(59, 60) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 41) * M(41, 61)
      temp = temp + M(59, 43) * M(43, 61)
      temp = temp + M(59, 55) * M(55, 61)
      temp = temp + M(59, 56) * M(56, 61)
      temp = temp + M(59, 57) * M(57, 61)
      temp = temp + M(59, 58) * M(58, 61)
      M(59, 61) = ( M(59, 61) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 55) * M(55, 62)
      temp = temp + M(59, 56) * M(56, 62)
      temp = temp + M(59, 57) * M(57, 62)
      temp = temp + M(59, 58) * M(58, 62)
      M(59, 62) = ( M(59, 62) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 55) * M(55, 63)
      temp = temp + M(59, 56) * M(56, 63)
      temp = temp + M(59, 57) * M(57, 63)
      temp = temp + M(59, 58) * M(58, 63)
      M(59, 63) = ( M(59, 63) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 41) * M(41, 64)
      temp = temp + M(59, 43) * M(43, 64)
      temp = temp + M(59, 55) * M(55, 64)
      temp = temp + M(59, 56) * M(56, 64)
      temp = temp + M(59, 57) * M(57, 64)
      temp = temp + M(59, 58) * M(58, 64)
      M(59, 64) = ( M(59, 64) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 43) * M(43, 65)
      temp = temp + M(59, 44) * M(44, 65)
      temp = temp + M(59, 45) * M(45, 65)
      temp = temp + M(59, 55) * M(55, 65)
      temp = temp + M(59, 56) * M(56, 65)
      temp = temp + M(59, 57) * M(57, 65)
      temp = temp + M(59, 58) * M(58, 65)
      M(59, 65) = ( M(59, 65) - temp ) / M(59, 59)

C     Lower part.
      temp = M(60, 53) * M(53, 60)
      temp = temp + M(60, 54) * M(54, 60)
      temp = temp + M(60, 55) * M(55, 60)
      temp = temp + M(60, 56) * M(56, 60)
      temp = temp + M(60, 57) * M(57, 60)
      temp = temp + M(60, 58) * M(58, 60)
      temp = temp + M(60, 59) * M(59, 60)
      M(60, 60) = M(60, 60) - temp
C     Lower part.
      temp = M(61, 51) * M(51, 60)
      temp = temp + M(61, 53) * M(53, 60)
      temp = temp + M(61, 54) * M(54, 60)
      temp = temp + M(61, 55) * M(55, 60)
      temp = temp + M(61, 56) * M(56, 60)
      temp = temp + M(61, 57) * M(57, 60)
      temp = temp + M(61, 58) * M(58, 60)
      temp = temp + M(61, 59) * M(59, 60)
      M(61, 60) = M(61, 60) - temp
C     Lower part.
      temp = M(62, 53) * M(53, 60)
      temp = temp + M(62, 54) * M(54, 60)
      temp = temp + M(62, 55) * M(55, 60)
      temp = temp + M(62, 56) * M(56, 60)
      temp = temp + M(62, 57) * M(57, 60)
      temp = temp + M(62, 58) * M(58, 60)
      temp = temp + M(62, 59) * M(59, 60)
      M(62, 60) = M(62, 60) - temp
C     Lower part.
      temp = M(63, 53) * M(53, 60)
      temp = temp + M(63, 54) * M(54, 60)
      temp = temp + M(63, 55) * M(55, 60)
      temp = temp + M(63, 56) * M(56, 60)
      temp = temp + M(63, 57) * M(57, 60)
      temp = temp + M(63, 58) * M(58, 60)
      temp = temp + M(63, 59) * M(59, 60)
      M(63, 60) = M(63, 60) - temp
C     Lower part.
      temp = M(64, 53) * M(53, 60)
      temp = temp + M(64, 54) * M(54, 60)
      temp = temp + M(64, 55) * M(55, 60)
      temp = temp + M(64, 56) * M(56, 60)
      temp = temp + M(64, 57) * M(57, 60)
      temp = temp + M(64, 58) * M(58, 60)
      temp = temp + M(64, 59) * M(59, 60)
      M(64, 60) = M(64, 60) - temp
C     Lower part.
      temp = M(65, 50) * M(50, 60)
      temp = temp + M(65, 53) * M(53, 60)
      temp = temp + M(65, 54) * M(54, 60)
      temp = temp + M(65, 55) * M(55, 60)
      temp = temp + M(65, 56) * M(56, 60)
      temp = temp + M(65, 57) * M(57, 60)
      temp = temp + M(65, 58) * M(58, 60)
      temp = temp + M(65, 59) * M(59, 60)
      M(65, 60) = M(65, 60) - temp
C     Upper part.
      temp = M(60, 32) * M(32, 61)
      temp = temp + M(60, 46) * M(46, 61)
      temp = temp + M(60, 47) * M(47, 61)
      temp = temp + M(60, 52) * M(52, 61)
      temp = temp + M(60, 53) * M(53, 61)
      temp = temp + M(60, 54) * M(54, 61)
      temp = temp + M(60, 55) * M(55, 61)
      temp = temp + M(60, 56) * M(56, 61)
      temp = temp + M(60, 57) * M(57, 61)
      temp = temp + M(60, 58) * M(58, 61)
      temp = temp + M(60, 59) * M(59, 61)
      M(60, 61) = ( M(60, 61) - temp ) / M(60, 60)
C     Upper part.
      temp = M(60, 53) * M(53, 62)
      temp = temp + M(60, 54) * M(54, 62)
      temp = temp + M(60, 55) * M(55, 62)
      temp = temp + M(60, 56) * M(56, 62)
      temp = temp + M(60, 57) * M(57, 62)
      temp = temp + M(60, 58) * M(58, 62)
      temp = temp + M(60, 59) * M(59, 62)
      M(60, 62) = ( M(60, 62) - temp ) / M(60, 60)
C     Upper part.
      temp = M(60, 32) * M(32, 63)
      temp = temp + M(60, 52) * M(52, 63)
      temp = temp + M(60, 53) * M(53, 63)
      temp = temp + M(60, 54) * M(54, 63)
      temp = temp + M(60, 55) * M(55, 63)
      temp = temp + M(60, 56) * M(56, 63)
      temp = temp + M(60, 57) * M(57, 63)
      temp = temp + M(60, 58) * M(58, 63)
      temp = temp + M(60, 59) * M(59, 63)
      M(60, 63) = ( M(60, 63) - temp ) / M(60, 60)
C     Upper part.
      temp = M(60, 46) * M(46, 64)
      temp = temp + M(60, 47) * M(47, 64)
      temp = temp + M(60, 52) * M(52, 64)
      temp = temp + M(60, 53) * M(53, 64)
      temp = temp + M(60, 54) * M(54, 64)
      temp = temp + M(60, 55) * M(55, 64)
      temp = temp + M(60, 56) * M(56, 64)
      temp = temp + M(60, 57) * M(57, 64)
      temp = temp + M(60, 58) * M(58, 64)
      temp = temp + M(60, 59) * M(59, 64)
      M(60, 64) = ( M(60, 64) - temp ) / M(60, 60)
C     Upper part.
      temp = M(60, 18) * M(18, 65)
      temp = temp + M(60, 19) * M(19, 65)
      temp = temp + M(60, 45) * M(45, 65)
      temp = temp + M(60, 46) * M(46, 65)
      temp = temp + M(60, 47) * M(47, 65)
      temp = temp + M(60, 52) * M(52, 65)
      temp = temp + M(60, 53) * M(53, 65)
      temp = temp + M(60, 54) * M(54, 65)
      temp = temp + M(60, 55) * M(55, 65)
      temp = temp + M(60, 56) * M(56, 65)
      temp = temp + M(60, 57) * M(57, 65)
      temp = temp + M(60, 58) * M(58, 65)
      temp = temp + M(60, 59) * M(59, 65)
      M(60, 65) = ( M(60, 65) - temp ) / M(60, 60)

C     Lower part.
      temp = M(61, 17) * M(17, 61)
      temp = temp + M(61, 20) * M(20, 61)
      temp = temp + M(61, 21) * M(21, 61)
      temp = temp + M(61, 22) * M(22, 61)
      temp = temp + M(61, 32) * M(32, 61)
      temp = temp + M(61, 35) * M(35, 61)
      temp = temp + M(61, 40) * M(40, 61)
      temp = temp + M(61, 41) * M(41, 61)
      temp = temp + M(61, 42) * M(42, 61)
      temp = temp + M(61, 43) * M(43, 61)
      temp = temp + M(61, 46) * M(46, 61)
      temp = temp + M(61, 47) * M(47, 61)
      temp = temp + M(61, 48) * M(48, 61)
      temp = temp + M(61, 51) * M(51, 61)
      temp = temp + M(61, 52) * M(52, 61)
      temp = temp + M(61, 53) * M(53, 61)
      temp = temp + M(61, 54) * M(54, 61)
      temp = temp + M(61, 55) * M(55, 61)
      temp = temp + M(61, 56) * M(56, 61)
      temp = temp + M(61, 57) * M(57, 61)
      temp = temp + M(61, 58) * M(58, 61)
      temp = temp + M(61, 59) * M(59, 61)
      temp = temp + M(61, 60) * M(60, 61)
      M(61, 61) = M(61, 61) - temp
C     Lower part.
      temp = M(62, 33) * M(33, 61)
      temp = temp + M(62, 41) * M(41, 61)
      temp = temp + M(62, 42) * M(42, 61)
      temp = temp + M(62, 43) * M(43, 61)
      temp = temp + M(62, 53) * M(53, 61)
      temp = temp + M(62, 54) * M(54, 61)
      temp = temp + M(62, 55) * M(55, 61)
      temp = temp + M(62, 56) * M(56, 61)
      temp = temp + M(62, 57) * M(57, 61)
      temp = temp + M(62, 58) * M(58, 61)
      temp = temp + M(62, 59) * M(59, 61)
      temp = temp + M(62, 60) * M(60, 61)
      M(62, 61) = M(62, 61) - temp
C     Lower part.
      temp = M(63, 22) * M(22, 61)
      temp = temp + M(63, 32) * M(32, 61)
      temp = temp + M(63, 40) * M(40, 61)
      temp = temp + M(63, 41) * M(41, 61)
      temp = temp + M(63, 42) * M(42, 61)
      temp = temp + M(63, 43) * M(43, 61)
      temp = temp + M(63, 47) * M(47, 61)
      temp = temp + M(63, 52) * M(52, 61)
      temp = temp + M(63, 53) * M(53, 61)
      temp = temp + M(63, 54) * M(54, 61)
      temp = temp + M(63, 55) * M(55, 61)
      temp = temp + M(63, 56) * M(56, 61)
      temp = temp + M(63, 57) * M(57, 61)
      temp = temp + M(63, 58) * M(58, 61)
      temp = temp + M(63, 59) * M(59, 61)
      temp = temp + M(63, 60) * M(60, 61)
      M(63, 61) = M(63, 61) - temp
C     Lower part.
      temp = M(64, 21) * M(21, 61)
      temp = temp + M(64, 52) * M(52, 61)
      temp = temp + M(64, 53) * M(53, 61)
      temp = temp + M(64, 54) * M(54, 61)
      temp = temp + M(64, 55) * M(55, 61)
      temp = temp + M(64, 56) * M(56, 61)
      temp = temp + M(64, 57) * M(57, 61)
      temp = temp + M(64, 58) * M(58, 61)
      temp = temp + M(64, 59) * M(59, 61)
      temp = temp + M(64, 60) * M(60, 61)
      M(64, 61) = M(64, 61) - temp
C     Lower part.
      temp = M(65, 17) * M(17, 61)
      temp = temp + M(65, 21) * M(21, 61)
      temp = temp + M(65, 43) * M(43, 61)
      temp = temp + M(65, 46) * M(46, 61)
      temp = temp + M(65, 47) * M(47, 61)
      temp = temp + M(65, 50) * M(50, 61)
      temp = temp + M(65, 52) * M(52, 61)
      temp = temp + M(65, 53) * M(53, 61)
      temp = temp + M(65, 54) * M(54, 61)
      temp = temp + M(65, 55) * M(55, 61)
      temp = temp + M(65, 56) * M(56, 61)
      temp = temp + M(65, 57) * M(57, 61)
      temp = temp + M(65, 58) * M(58, 61)
      temp = temp + M(65, 59) * M(59, 61)
      temp = temp + M(65, 60) * M(60, 61)
      M(65, 61) = M(65, 61) - temp
C     Upper part.
      temp = M(61, 53) * M(53, 62)
      temp = temp + M(61, 54) * M(54, 62)
      temp = temp + M(61, 55) * M(55, 62)
      temp = temp + M(61, 56) * M(56, 62)
      temp = temp + M(61, 57) * M(57, 62)
      temp = temp + M(61, 58) * M(58, 62)
      temp = temp + M(61, 59) * M(59, 62)
      temp = temp + M(61, 60) * M(60, 62)
      M(61, 62) = ( M(61, 62) - temp ) / M(61, 61)
C     Upper part.
      temp = M(61, 32) * M(32, 63)
      temp = temp + M(61, 48) * M(48, 63)
      temp = temp + M(61, 51) * M(51, 63)
      temp = temp + M(61, 52) * M(52, 63)
      temp = temp + M(61, 53) * M(53, 63)
      temp = temp + M(61, 54) * M(54, 63)
      temp = temp + M(61, 55) * M(55, 63)
      temp = temp + M(61, 56) * M(56, 63)
      temp = temp + M(61, 57) * M(57, 63)
      temp = temp + M(61, 58) * M(58, 63)
      temp = temp + M(61, 59) * M(59, 63)
      temp = temp + M(61, 60) * M(60, 63)
      M(61, 63) = ( M(61, 63) - temp ) / M(61, 61)
C     Upper part.
      temp = M(61, 15) * M(15, 64)
      temp = temp + M(61, 21) * M(21, 64)
      temp = temp + M(61, 22) * M(22, 64)
      temp = temp + M(61, 35) * M(35, 64)
      temp = temp + M(61, 40) * M(40, 64)
      temp = temp + M(61, 41) * M(41, 64)
      temp = temp + M(61, 42) * M(42, 64)
      temp = temp + M(61, 43) * M(43, 64)
      temp = temp + M(61, 46) * M(46, 64)
      temp = temp + M(61, 47) * M(47, 64)
      temp = temp + M(61, 48) * M(48, 64)
      temp = temp + M(61, 51) * M(51, 64)
      temp = temp + M(61, 52) * M(52, 64)
      temp = temp + M(61, 53) * M(53, 64)
      temp = temp + M(61, 54) * M(54, 64)
      temp = temp + M(61, 55) * M(55, 64)
      temp = temp + M(61, 56) * M(56, 64)
      temp = temp + M(61, 57) * M(57, 64)
      temp = temp + M(61, 58) * M(58, 64)
      temp = temp + M(61, 59) * M(59, 64)
      temp = temp + M(61, 60) * M(60, 64)
      M(61, 64) = ( M(61, 64) - temp ) / M(61, 61)
C     Upper part.
      temp = M(61, 17) * M(17, 65)
      temp = temp + M(61, 19) * M(19, 65)
      temp = temp + M(61, 43) * M(43, 65)
      temp = temp + M(61, 44) * M(44, 65)
      temp = temp + M(61, 45) * M(45, 65)
      temp = temp + M(61, 46) * M(46, 65)
      temp = temp + M(61, 47) * M(47, 65)
      temp = temp + M(61, 48) * M(48, 65)
      temp = temp + M(61, 51) * M(51, 65)
      temp = temp + M(61, 52) * M(52, 65)
      temp = temp + M(61, 53) * M(53, 65)
      temp = temp + M(61, 54) * M(54, 65)
      temp = temp + M(61, 55) * M(55, 65)
      temp = temp + M(61, 56) * M(56, 65)
      temp = temp + M(61, 57) * M(57, 65)
      temp = temp + M(61, 58) * M(58, 65)
      temp = temp + M(61, 59) * M(59, 65)
      temp = temp + M(61, 60) * M(60, 65)
      M(61, 65) = ( M(61, 65) - temp ) / M(61, 61)

C     Lower part.
      temp = M(62, 13) * M(13, 62)
      temp = temp + M(62, 33) * M(33, 62)
      temp = temp + M(62, 53) * M(53, 62)
      temp = temp + M(62, 54) * M(54, 62)
      temp = temp + M(62, 55) * M(55, 62)
      temp = temp + M(62, 56) * M(56, 62)
      temp = temp + M(62, 57) * M(57, 62)
      temp = temp + M(62, 58) * M(58, 62)
      temp = temp + M(62, 59) * M(59, 62)
      temp = temp + M(62, 60) * M(60, 62)
      temp = temp + M(62, 61) * M(61, 62)
      M(62, 62) = M(62, 62) - temp
C     Lower part.
      temp = M(63, 53) * M(53, 62)
      temp = temp + M(63, 54) * M(54, 62)
      temp = temp + M(63, 55) * M(55, 62)
      temp = temp + M(63, 56) * M(56, 62)
      temp = temp + M(63, 57) * M(57, 62)
      temp = temp + M(63, 58) * M(58, 62)
      temp = temp + M(63, 59) * M(59, 62)
      temp = temp + M(63, 60) * M(60, 62)
      temp = temp + M(63, 61) * M(61, 62)
      M(63, 62) = M(63, 62) - temp
C     Lower part.
      temp = M(64, 53) * M(53, 62)
      temp = temp + M(64, 54) * M(54, 62)
      temp = temp + M(64, 55) * M(55, 62)
      temp = temp + M(64, 56) * M(56, 62)
      temp = temp + M(64, 57) * M(57, 62)
      temp = temp + M(64, 58) * M(58, 62)
      temp = temp + M(64, 59) * M(59, 62)
      temp = temp + M(64, 60) * M(60, 62)
      temp = temp + M(64, 61) * M(61, 62)
      M(64, 62) = M(64, 62) - temp
C     Lower part.
      temp = M(65, 13) * M(13, 62)
      temp = temp + M(65, 53) * M(53, 62)
      temp = temp + M(65, 54) * M(54, 62)
      temp = temp + M(65, 55) * M(55, 62)
      temp = temp + M(65, 56) * M(56, 62)
      temp = temp + M(65, 57) * M(57, 62)
      temp = temp + M(65, 58) * M(58, 62)
      temp = temp + M(65, 59) * M(59, 62)
      temp = temp + M(65, 60) * M(60, 62)
      temp = temp + M(65, 61) * M(61, 62)
      M(65, 62) = M(65, 62) - temp
C     Upper part.
      temp = M(62, 53) * M(53, 63)
      temp = temp + M(62, 54) * M(54, 63)
      temp = temp + M(62, 55) * M(55, 63)
      temp = temp + M(62, 56) * M(56, 63)
      temp = temp + M(62, 57) * M(57, 63)
      temp = temp + M(62, 58) * M(58, 63)
      temp = temp + M(62, 59) * M(59, 63)
      temp = temp + M(62, 60) * M(60, 63)
      temp = temp + M(62, 61) * M(61, 63)
      M(62, 63) = ( M(62, 63) - temp ) / M(62, 62)
C     Upper part.
      temp = M(62, 41) * M(41, 64)
      temp = temp + M(62, 42) * M(42, 64)
      temp = temp + M(62, 43) * M(43, 64)
      temp = temp + M(62, 53) * M(53, 64)
      temp = temp + M(62, 54) * M(54, 64)
      temp = temp + M(62, 55) * M(55, 64)
      temp = temp + M(62, 56) * M(56, 64)
      temp = temp + M(62, 57) * M(57, 64)
      temp = temp + M(62, 58) * M(58, 64)
      temp = temp + M(62, 59) * M(59, 64)
      temp = temp + M(62, 60) * M(60, 64)
      temp = temp + M(62, 61) * M(61, 64)
      M(62, 64) = ( M(62, 64) - temp ) / M(62, 62)
C     Upper part.
      temp = M(62, 13) * M(13, 65)
      temp = temp + M(62, 43) * M(43, 65)
      temp = temp + M(62, 45) * M(45, 65)
      temp = temp + M(62, 53) * M(53, 65)
      temp = temp + M(62, 54) * M(54, 65)
      temp = temp + M(62, 55) * M(55, 65)
      temp = temp + M(62, 56) * M(56, 65)
      temp = temp + M(62, 57) * M(57, 65)
      temp = temp + M(62, 58) * M(58, 65)
      temp = temp + M(62, 59) * M(59, 65)
      temp = temp + M(62, 60) * M(60, 65)
      temp = temp + M(62, 61) * M(61, 65)
      M(62, 65) = ( M(62, 65) - temp ) / M(62, 62)

C     Lower part.
      temp = M(63, 32) * M(32, 63)
      temp = temp + M(63, 52) * M(52, 63)
      temp = temp + M(63, 53) * M(53, 63)
      temp = temp + M(63, 54) * M(54, 63)
      temp = temp + M(63, 55) * M(55, 63)
      temp = temp + M(63, 56) * M(56, 63)
      temp = temp + M(63, 57) * M(57, 63)
      temp = temp + M(63, 58) * M(58, 63)
      temp = temp + M(63, 59) * M(59, 63)
      temp = temp + M(63, 60) * M(60, 63)
      temp = temp + M(63, 61) * M(61, 63)
      temp = temp + M(63, 62) * M(62, 63)
      M(63, 63) = M(63, 63) - temp
C     Lower part.
      temp = M(64, 52) * M(52, 63)
      temp = temp + M(64, 53) * M(53, 63)
      temp = temp + M(64, 54) * M(54, 63)
      temp = temp + M(64, 55) * M(55, 63)
      temp = temp + M(64, 56) * M(56, 63)
      temp = temp + M(64, 57) * M(57, 63)
      temp = temp + M(64, 58) * M(58, 63)
      temp = temp + M(64, 59) * M(59, 63)
      temp = temp + M(64, 60) * M(60, 63)
      temp = temp + M(64, 61) * M(61, 63)
      temp = temp + M(64, 62) * M(62, 63)
      M(64, 63) = M(64, 63) - temp
C     Lower part.
      temp = M(65, 50) * M(50, 63)
      temp = temp + M(65, 52) * M(52, 63)
      temp = temp + M(65, 53) * M(53, 63)
      temp = temp + M(65, 54) * M(54, 63)
      temp = temp + M(65, 55) * M(55, 63)
      temp = temp + M(65, 56) * M(56, 63)
      temp = temp + M(65, 57) * M(57, 63)
      temp = temp + M(65, 58) * M(58, 63)
      temp = temp + M(65, 59) * M(59, 63)
      temp = temp + M(65, 60) * M(60, 63)
      temp = temp + M(65, 61) * M(61, 63)
      temp = temp + M(65, 62) * M(62, 63)
      M(65, 63) = M(65, 63) - temp
C     Upper part.
      temp = M(63, 22) * M(22, 64)
      temp = temp + M(63, 40) * M(40, 64)
      temp = temp + M(63, 41) * M(41, 64)
      temp = temp + M(63, 42) * M(42, 64)
      temp = temp + M(63, 43) * M(43, 64)
      temp = temp + M(63, 47) * M(47, 64)
      temp = temp + M(63, 52) * M(52, 64)
      temp = temp + M(63, 53) * M(53, 64)
      temp = temp + M(63, 54) * M(54, 64)
      temp = temp + M(63, 55) * M(55, 64)
      temp = temp + M(63, 56) * M(56, 64)
      temp = temp + M(63, 57) * M(57, 64)
      temp = temp + M(63, 58) * M(58, 64)
      temp = temp + M(63, 59) * M(59, 64)
      temp = temp + M(63, 60) * M(60, 64)
      temp = temp + M(63, 61) * M(61, 64)
      temp = temp + M(63, 62) * M(62, 64)
      M(63, 64) = ( M(63, 64) - temp ) / M(63, 63)
C     Upper part.
      temp = M(63, 19) * M(19, 65)
      temp = temp + M(63, 43) * M(43, 65)
      temp = temp + M(63, 44) * M(44, 65)
      temp = temp + M(63, 45) * M(45, 65)
      temp = temp + M(63, 47) * M(47, 65)
      temp = temp + M(63, 52) * M(52, 65)
      temp = temp + M(63, 53) * M(53, 65)
      temp = temp + M(63, 54) * M(54, 65)
      temp = temp + M(63, 55) * M(55, 65)
      temp = temp + M(63, 56) * M(56, 65)
      temp = temp + M(63, 57) * M(57, 65)
      temp = temp + M(63, 58) * M(58, 65)
      temp = temp + M(63, 59) * M(59, 65)
      temp = temp + M(63, 60) * M(60, 65)
      temp = temp + M(63, 61) * M(61, 65)
      temp = temp + M(63, 62) * M(62, 65)
      M(63, 65) = ( M(63, 65) - temp ) / M(63, 63)

C     Lower part.
      temp = M(64, 15) * M(15, 64)
      temp = temp + M(64, 21) * M(21, 64)
      temp = temp + M(64, 23) * M(23, 64)
      temp = temp + M(64, 52) * M(52, 64)
      temp = temp + M(64, 53) * M(53, 64)
      temp = temp + M(64, 54) * M(54, 64)
      temp = temp + M(64, 55) * M(55, 64)
      temp = temp + M(64, 56) * M(56, 64)
      temp = temp + M(64, 57) * M(57, 64)
      temp = temp + M(64, 58) * M(58, 64)
      temp = temp + M(64, 59) * M(59, 64)
      temp = temp + M(64, 60) * M(60, 64)
      temp = temp + M(64, 61) * M(61, 64)
      temp = temp + M(64, 62) * M(62, 64)
      temp = temp + M(64, 63) * M(63, 64)
      M(64, 64) = M(64, 64) - temp
C     Lower part.
      temp = M(65, 15) * M(15, 64)
      temp = temp + M(65, 21) * M(21, 64)
      temp = temp + M(65, 23) * M(23, 64)
      temp = temp + M(65, 43) * M(43, 64)
      temp = temp + M(65, 46) * M(46, 64)
      temp = temp + M(65, 47) * M(47, 64)
      temp = temp + M(65, 50) * M(50, 64)
      temp = temp + M(65, 52) * M(52, 64)
      temp = temp + M(65, 53) * M(53, 64)
      temp = temp + M(65, 54) * M(54, 64)
      temp = temp + M(65, 55) * M(55, 64)
      temp = temp + M(65, 56) * M(56, 64)
      temp = temp + M(65, 57) * M(57, 64)
      temp = temp + M(65, 58) * M(58, 64)
      temp = temp + M(65, 59) * M(59, 64)
      temp = temp + M(65, 60) * M(60, 64)
      temp = temp + M(65, 61) * M(61, 64)
      temp = temp + M(65, 62) * M(62, 64)
      temp = temp + M(65, 63) * M(63, 64)
      M(65, 64) = M(65, 64) - temp
C     Upper part.
      temp = M(64, 23) * M(23, 65)
      temp = temp + M(64, 44) * M(44, 65)
      temp = temp + M(64, 52) * M(52, 65)
      temp = temp + M(64, 53) * M(53, 65)
      temp = temp + M(64, 54) * M(54, 65)
      temp = temp + M(64, 55) * M(55, 65)
      temp = temp + M(64, 56) * M(56, 65)
      temp = temp + M(64, 57) * M(57, 65)
      temp = temp + M(64, 58) * M(58, 65)
      temp = temp + M(64, 59) * M(59, 65)
      temp = temp + M(64, 60) * M(60, 65)
      temp = temp + M(64, 61) * M(61, 65)
      temp = temp + M(64, 62) * M(62, 65)
      temp = temp + M(64, 63) * M(63, 65)
      M(64, 65) = ( M(64, 65) - temp ) / M(64, 64)

C     Lower part.
      temp = M(65, 13) * M(13, 65)
      temp = temp + M(65, 16) * M(16, 65)
      temp = temp + M(65, 17) * M(17, 65)
      temp = temp + M(65, 18) * M(18, 65)
      temp = temp + M(65, 19) * M(19, 65)
      temp = temp + M(65, 23) * M(23, 65)
      temp = temp + M(65, 43) * M(43, 65)
      temp = temp + M(65, 44) * M(44, 65)
      temp = temp + M(65, 46) * M(46, 65)
      temp = temp + M(65, 47) * M(47, 65)
      temp = temp + M(65, 50) * M(50, 65)
      temp = temp + M(65, 52) * M(52, 65)
      temp = temp + M(65, 53) * M(53, 65)
      temp = temp + M(65, 54) * M(54, 65)
      temp = temp + M(65, 55) * M(55, 65)
      temp = temp + M(65, 56) * M(56, 65)
      temp = temp + M(65, 57) * M(57, 65)
      temp = temp + M(65, 58) * M(58, 65)
      temp = temp + M(65, 59) * M(59, 65)
      temp = temp + M(65, 60) * M(60, 65)
      temp = temp + M(65, 61) * M(61, 65)
      temp = temp + M(65, 62) * M(62, 65)
      temp = temp + M(65, 63) * M(63, 65)
      temp = temp + M(65, 64) * M(64, 65)
      M(65, 65) = M(65, 65) - temp


      END
