C------------------------------------------------------------------------
C     Copyright (C) 2001-2008, ENPC - INRIA - EDF R&D
C     
C     This file is part of the air quality modeling system Polyphemus.
C    
C     Polyphemus is developed in the INRIA - ENPC joint project-team
C     CLIME and in the ENPC - EDF R&D joint laboratory CEREA.
C    
C     Polyphemus is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published
C     by the Free Software Foundation; either version 2 of the License,
C     or (at your option) any later version.
C     
C     Polyphemus is distributed in the hope that it will be useful, but
C     WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
C     General Public License for more details.
C     
C     For more information, visit the Polyphemus web site:
C     http://cerea.enpc.fr/polyphemus/
C
C------------------------------------------------------------------------

      SUBROUTINE LU_solve (ns, M, x)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine solves M * y = x where M is an LU factorization
C     computed by LU_decompose.
C	  This routine is automatically generated by LU.cpp
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C	  nesp: matrix row number from the chemical species number
C     M: LU factorization computed by LU_decompose.
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     x: on entry, the right-hand side of the equation. On exit,
C     the solution of the equation.
C     
C     -- OUTPUT VARIABLES
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C------------------------------------------------------------------------

      IMPLICIT NONE

      INTEGER ns
      DOUBLE PRECISION M(ns,ns)
      DOUBLE PRECISION x(ns)
      DOUBLE PRECISION temp


C     Forward substitution.

      x(1) = x(1) / M(1, 1)

      x(2) = x(2) / M(2, 2)

      x(3) = x(3) / M(3, 3)

      x(4) = x(4) / M(4, 4)

      x(5) = x(5) / M(5, 5)

      x(6) = x(6) / M(6, 6)

      x(7) = x(7) / M(7, 7)

      x(8) = x(8) / M(8, 8)

      x(9) = x(9) / M(9, 9)

      temp = M(10, 9) * x(9)
      x(10) = ( x(10) - temp ) / M(10, 10)

      x(11) = x(11) / M(11, 11)

      temp = M(12, 11) * x(11)
      x(12) = ( x(12) - temp ) / M(12, 12)

      x(13) = x(13) / M(13, 13)

      x(14) = x(14) / M(14, 14)

      temp = M(15, 7) * x(7)
      temp = temp + M(15, 8) * x(8)
      x(15) = ( x(15) - temp ) / M(15, 15)

      x(16) = x(16) / M(16, 16)

      x(17) = x(17) / M(17, 17)

      x(18) = x(18) / M(18, 18)

      x(19) = x(19) / M(19, 19)

      x(20) = x(20) / M(20, 20)

      x(21) = x(21) / M(21, 21)

      temp = M(22, 21) * x(21)
      x(22) = ( x(22) - temp ) / M(22, 22)

      x(23) = x(23) / M(23, 23)

      x(24) = x(24) / M(24, 24)

      temp = M(25, 24) * x(24)
      x(25) = ( x(25) - temp ) / M(25, 25)

      temp = M(26, 24) * x(24)
      x(26) = ( x(26) - temp ) / M(26, 26)

      x(27) = x(27) / M(27, 27)

      temp = M(28, 27) * x(27)
      x(28) = ( x(28) - temp ) / M(28, 28)

      temp = M(29, 27) * x(27)
      x(29) = ( x(29) - temp ) / M(29, 29)

      temp = M(30, 7) * x(7)
      temp = temp + M(30, 8) * x(8)
      x(30) = ( x(30) - temp ) / M(30, 30)

      temp = M(31, 7) * x(7)
      temp = temp + M(31, 8) * x(8)
      x(31) = ( x(31) - temp ) / M(31, 31)

      x(32) = x(32) / M(32, 32)

      x(33) = x(33) / M(33, 33)

      x(34) = x(34) / M(34, 34)

      temp = M(35, 21) * x(21)
      temp = temp + M(35, 34) * x(34)
      x(35) = ( x(35) - temp ) / M(35, 35)

      x(36) = x(36) / M(36, 36)

      x(37) = x(37) / M(37, 37)

      temp = M(38, 36) * x(36)
      temp = temp + M(38, 37) * x(37)
      x(38) = ( x(38) - temp ) / M(38, 38)

      x(39) = x(39) / M(39, 39)

      temp = M(40, 7) * x(7)
      temp = temp + M(40, 8) * x(8)
      temp = temp + M(40, 15) * x(15)
      x(40) = ( x(40) - temp ) / M(40, 40)

      temp = M(41, 15) * x(15)
      temp = temp + M(41, 40) * x(40)
      x(41) = ( x(41) - temp ) / M(41, 41)

      temp = M(42, 8) * x(8)
      temp = temp + M(42, 41) * x(41)
      x(42) = ( x(42) - temp ) / M(42, 42)

      temp = M(43, 40) * x(40)
      x(43) = ( x(43) - temp ) / M(43, 43)

      x(44) = x(44) / M(44, 44)

      temp = M(45, 44) * x(44)
      x(45) = ( x(45) - temp ) / M(45, 45)

      temp = M(46, 15) * x(15)
      temp = temp + M(46, 19) * x(19)
      temp = temp + M(46, 39) * x(39)
      temp = temp + M(46, 43) * x(43)
      temp = temp + M(46, 44) * x(44)
      temp = temp + M(46, 45) * x(45)
      x(46) = ( x(46) - temp ) / M(46, 46)

      temp = M(47, 8) * x(8)
      temp = temp + M(47, 19) * x(19)
      temp = temp + M(47, 36) * x(36)
      temp = temp + M(47, 37) * x(37)
      temp = temp + M(47, 39) * x(39)
      temp = temp + M(47, 44) * x(44)
      temp = temp + M(47, 45) * x(45)
      temp = temp + M(47, 46) * x(46)
      x(47) = ( x(47) - temp ) / M(47, 47)

      temp = M(48, 4) * x(4)
      temp = temp + M(48, 19) * x(19)
      temp = temp + M(48, 32) * x(32)
      temp = temp + M(48, 34) * x(34)
      temp = temp + M(48, 36) * x(36)
      temp = temp + M(48, 37) * x(37)
      temp = temp + M(48, 39) * x(39)
      temp = temp + M(48, 41) * x(41)
      temp = temp + M(48, 43) * x(43)
      temp = temp + M(48, 44) * x(44)
      temp = temp + M(48, 45) * x(45)
      temp = temp + M(48, 46) * x(46)
      temp = temp + M(48, 47) * x(47)
      x(48) = ( x(48) - temp ) / M(48, 48)

      x(49) = x(49) / M(49, 49)

      temp = M(50, 16) * x(16)
      temp = temp + M(50, 40) * x(40)
      temp = temp + M(50, 43) * x(43)
      temp = temp + M(50, 45) * x(45)
      temp = temp + M(50, 46) * x(46)
      temp = temp + M(50, 47) * x(47)
      temp = temp + M(50, 48) * x(48)
      x(50) = ( x(50) - temp ) / M(50, 50)

      temp = M(51, 34) * x(34)
      temp = temp + M(51, 36) * x(36)
      temp = temp + M(51, 37) * x(37)
      temp = temp + M(51, 39) * x(39)
      temp = temp + M(51, 41) * x(41)
      temp = temp + M(51, 42) * x(42)
      temp = temp + M(51, 43) * x(43)
      temp = temp + M(51, 44) * x(44)
      temp = temp + M(51, 45) * x(45)
      temp = temp + M(51, 48) * x(48)
      x(51) = ( x(51) - temp ) / M(51, 51)

      temp = M(52, 6) * x(6)
      temp = temp + M(52, 19) * x(19)
      temp = temp + M(52, 36) * x(36)
      temp = temp + M(52, 39) * x(39)
      temp = temp + M(52, 44) * x(44)
      temp = temp + M(52, 47) * x(47)
      x(52) = ( x(52) - temp ) / M(52, 52)

      temp = M(53, 5) * x(5)
      temp = temp + M(53, 22) * x(22)
      temp = temp + M(53, 33) * x(33)
      temp = temp + M(53, 48) * x(48)
      temp = temp + M(53, 49) * x(49)
      temp = temp + M(53, 52) * x(52)
      x(53) = ( x(53) - temp ) / M(53, 53)

      temp = M(54, 4) * x(4)
      temp = temp + M(54, 14) * x(14)
      temp = temp + M(54, 21) * x(21)
      temp = temp + M(54, 22) * x(22)
      temp = temp + M(54, 34) * x(34)
      temp = temp + M(54, 36) * x(36)
      temp = temp + M(54, 37) * x(37)
      temp = temp + M(54, 39) * x(39)
      temp = temp + M(54, 41) * x(41)
      temp = temp + M(54, 43) * x(43)
      temp = temp + M(54, 44) * x(44)
      temp = temp + M(54, 45) * x(45)
      temp = temp + M(54, 46) * x(46)
      temp = temp + M(54, 47) * x(47)
      temp = temp + M(54, 52) * x(52)
      temp = temp + M(54, 53) * x(53)
      x(54) = ( x(54) - temp ) / M(54, 54)

      temp = M(55, 3) * x(3)
      temp = temp + M(55, 4) * x(4)
      temp = temp + M(55, 5) * x(5)
      temp = temp + M(55, 6) * x(6)
      temp = temp + M(55, 7) * x(7)
      temp = temp + M(55, 8) * x(8)
      temp = temp + M(55, 9) * x(9)
      temp = temp + M(55, 14) * x(14)
      temp = temp + M(55, 17) * x(17)
      temp = temp + M(55, 18) * x(18)
      temp = temp + M(55, 20) * x(20)
      temp = temp + M(55, 22) * x(22)
      temp = temp + M(55, 23) * x(23)
      temp = temp + M(55, 32) * x(32)
      temp = temp + M(55, 33) * x(33)
      temp = temp + M(55, 34) * x(34)
      temp = temp + M(55, 35) * x(35)
      temp = temp + M(55, 36) * x(36)
      temp = temp + M(55, 37) * x(37)
      temp = temp + M(55, 39) * x(39)
      temp = temp + M(55, 40) * x(40)
      temp = temp + M(55, 41) * x(41)
      temp = temp + M(55, 42) * x(42)
      temp = temp + M(55, 43) * x(43)
      temp = temp + M(55, 44) * x(44)
      temp = temp + M(55, 45) * x(45)
      temp = temp + M(55, 46) * x(46)
      temp = temp + M(55, 47) * x(47)
      temp = temp + M(55, 48) * x(48)
      temp = temp + M(55, 49) * x(49)
      temp = temp + M(55, 50) * x(50)
      temp = temp + M(55, 51) * x(51)
      temp = temp + M(55, 52) * x(52)
      temp = temp + M(55, 53) * x(53)
      temp = temp + M(55, 54) * x(54)
      x(55) = ( x(55) - temp ) / M(55, 55)

      temp = M(56, 16) * x(16)
      temp = temp + M(56, 17) * x(17)
      temp = temp + M(56, 34) * x(34)
      temp = temp + M(56, 36) * x(36)
      temp = temp + M(56, 37) * x(37)
      temp = temp + M(56, 39) * x(39)
      temp = temp + M(56, 40) * x(40)
      temp = temp + M(56, 43) * x(43)
      temp = temp + M(56, 44) * x(44)
      temp = temp + M(56, 45) * x(45)
      temp = temp + M(56, 48) * x(48)
      temp = temp + M(56, 50) * x(50)
      temp = temp + M(56, 52) * x(52)
      temp = temp + M(56, 54) * x(54)
      temp = temp + M(56, 55) * x(55)
      x(56) = ( x(56) - temp ) / M(56, 56)

      temp = M(57, 3) * x(3)
      temp = temp + M(57, 20) * x(20)
      temp = temp + M(57, 34) * x(34)
      temp = temp + M(57, 36) * x(36)
      temp = temp + M(57, 37) * x(37)
      temp = temp + M(57, 39) * x(39)
      temp = temp + M(57, 44) * x(44)
      temp = temp + M(57, 48) * x(48)
      temp = temp + M(57, 52) * x(52)
      temp = temp + M(57, 54) * x(54)
      temp = temp + M(57, 55) * x(55)
      temp = temp + M(57, 56) * x(56)
      x(57) = ( x(57) - temp ) / M(57, 57)

      temp = M(58, 18) * x(18)
      temp = temp + M(58, 39) * x(39)
      temp = temp + M(58, 44) * x(44)
      temp = temp + M(58, 45) * x(45)
      temp = temp + M(58, 48) * x(48)
      temp = temp + M(58, 52) * x(52)
      temp = temp + M(58, 55) * x(55)
      temp = temp + M(58, 56) * x(56)
      temp = temp + M(58, 57) * x(57)
      x(58) = ( x(58) - temp ) / M(58, 58)

      temp = M(59, 34) * x(34)
      temp = temp + M(59, 36) * x(36)
      temp = temp + M(59, 37) * x(37)
      temp = temp + M(59, 39) * x(39)
      temp = temp + M(59, 41) * x(41)
      temp = temp + M(59, 43) * x(43)
      temp = temp + M(59, 44) * x(44)
      temp = temp + M(59, 45) * x(45)
      temp = temp + M(59, 55) * x(55)
      temp = temp + M(59, 56) * x(56)
      temp = temp + M(59, 57) * x(57)
      temp = temp + M(59, 58) * x(58)
      x(59) = ( x(59) - temp ) / M(59, 59)

      temp = M(60, 4) * x(4)
      temp = temp + M(60, 6) * x(6)
      temp = temp + M(60, 18) * x(18)
      temp = temp + M(60, 19) * x(19)
      temp = temp + M(60, 32) * x(32)
      temp = temp + M(60, 36) * x(36)
      temp = temp + M(60, 37) * x(37)
      temp = temp + M(60, 45) * x(45)
      temp = temp + M(60, 46) * x(46)
      temp = temp + M(60, 47) * x(47)
      temp = temp + M(60, 52) * x(52)
      temp = temp + M(60, 53) * x(53)
      temp = temp + M(60, 54) * x(54)
      temp = temp + M(60, 55) * x(55)
      temp = temp + M(60, 56) * x(56)
      temp = temp + M(60, 57) * x(57)
      temp = temp + M(60, 58) * x(58)
      temp = temp + M(60, 59) * x(59)
      x(60) = ( x(60) - temp ) / M(60, 60)

      temp = M(61, 3) * x(3)
      temp = temp + M(61, 4) * x(4)
      temp = temp + M(61, 6) * x(6)
      temp = temp + M(61, 7) * x(7)
      temp = temp + M(61, 8) * x(8)
      temp = temp + M(61, 9) * x(9)
      temp = temp + M(61, 14) * x(14)
      temp = temp + M(61, 15) * x(15)
      temp = temp + M(61, 17) * x(17)
      temp = temp + M(61, 19) * x(19)
      temp = temp + M(61, 20) * x(20)
      temp = temp + M(61, 21) * x(21)
      temp = temp + M(61, 22) * x(22)
      temp = temp + M(61, 32) * x(32)
      temp = temp + M(61, 34) * x(34)
      temp = temp + M(61, 35) * x(35)
      temp = temp + M(61, 36) * x(36)
      temp = temp + M(61, 37) * x(37)
      temp = temp + M(61, 39) * x(39)
      temp = temp + M(61, 40) * x(40)
      temp = temp + M(61, 41) * x(41)
      temp = temp + M(61, 42) * x(42)
      temp = temp + M(61, 43) * x(43)
      temp = temp + M(61, 44) * x(44)
      temp = temp + M(61, 45) * x(45)
      temp = temp + M(61, 46) * x(46)
      temp = temp + M(61, 47) * x(47)
      temp = temp + M(61, 48) * x(48)
      temp = temp + M(61, 51) * x(51)
      temp = temp + M(61, 52) * x(52)
      temp = temp + M(61, 53) * x(53)
      temp = temp + M(61, 54) * x(54)
      temp = temp + M(61, 55) * x(55)
      temp = temp + M(61, 56) * x(56)
      temp = temp + M(61, 57) * x(57)
      temp = temp + M(61, 58) * x(58)
      temp = temp + M(61, 59) * x(59)
      temp = temp + M(61, 60) * x(60)
      x(61) = ( x(61) - temp ) / M(61, 61)

      temp = M(62, 13) * x(13)
      temp = temp + M(62, 33) * x(33)
      temp = temp + M(62, 41) * x(41)
      temp = temp + M(62, 42) * x(42)
      temp = temp + M(62, 43) * x(43)
      temp = temp + M(62, 45) * x(45)
      temp = temp + M(62, 53) * x(53)
      temp = temp + M(62, 54) * x(54)
      temp = temp + M(62, 55) * x(55)
      temp = temp + M(62, 56) * x(56)
      temp = temp + M(62, 57) * x(57)
      temp = temp + M(62, 58) * x(58)
      temp = temp + M(62, 59) * x(59)
      temp = temp + M(62, 60) * x(60)
      temp = temp + M(62, 61) * x(61)
      x(62) = ( x(62) - temp ) / M(62, 62)

      temp = M(63, 4) * x(4)
      temp = temp + M(63, 6) * x(6)
      temp = temp + M(63, 7) * x(7)
      temp = temp + M(63, 8) * x(8)
      temp = temp + M(63, 19) * x(19)
      temp = temp + M(63, 22) * x(22)
      temp = temp + M(63, 32) * x(32)
      temp = temp + M(63, 34) * x(34)
      temp = temp + M(63, 36) * x(36)
      temp = temp + M(63, 37) * x(37)
      temp = temp + M(63, 39) * x(39)
      temp = temp + M(63, 40) * x(40)
      temp = temp + M(63, 41) * x(41)
      temp = temp + M(63, 42) * x(42)
      temp = temp + M(63, 43) * x(43)
      temp = temp + M(63, 44) * x(44)
      temp = temp + M(63, 45) * x(45)
      temp = temp + M(63, 47) * x(47)
      temp = temp + M(63, 52) * x(52)
      temp = temp + M(63, 53) * x(53)
      temp = temp + M(63, 54) * x(54)
      temp = temp + M(63, 55) * x(55)
      temp = temp + M(63, 56) * x(56)
      temp = temp + M(63, 57) * x(57)
      temp = temp + M(63, 58) * x(58)
      temp = temp + M(63, 59) * x(59)
      temp = temp + M(63, 60) * x(60)
      temp = temp + M(63, 61) * x(61)
      temp = temp + M(63, 62) * x(62)
      x(63) = ( x(63) - temp ) / M(63, 63)

      temp = M(64, 15) * x(15)
      temp = temp + M(64, 21) * x(21)
      temp = temp + M(64, 23) * x(23)
      temp = temp + M(64, 44) * x(44)
      temp = temp + M(64, 52) * x(52)
      temp = temp + M(64, 53) * x(53)
      temp = temp + M(64, 54) * x(54)
      temp = temp + M(64, 55) * x(55)
      temp = temp + M(64, 56) * x(56)
      temp = temp + M(64, 57) * x(57)
      temp = temp + M(64, 58) * x(58)
      temp = temp + M(64, 59) * x(59)
      temp = temp + M(64, 60) * x(60)
      temp = temp + M(64, 61) * x(61)
      temp = temp + M(64, 62) * x(62)
      temp = temp + M(64, 63) * x(63)
      x(64) = ( x(64) - temp ) / M(64, 64)

      temp = M(65, 13) * x(13)
      temp = temp + M(65, 15) * x(15)
      temp = temp + M(65, 16) * x(16)
      temp = temp + M(65, 17) * x(17)
      temp = temp + M(65, 18) * x(18)
      temp = temp + M(65, 19) * x(19)
      temp = temp + M(65, 21) * x(21)
      temp = temp + M(65, 23) * x(23)
      temp = temp + M(65, 34) * x(34)
      temp = temp + M(65, 36) * x(36)
      temp = temp + M(65, 37) * x(37)
      temp = temp + M(65, 39) * x(39)
      temp = temp + M(65, 43) * x(43)
      temp = temp + M(65, 44) * x(44)
      temp = temp + M(65, 46) * x(46)
      temp = temp + M(65, 47) * x(47)
      temp = temp + M(65, 50) * x(50)
      temp = temp + M(65, 52) * x(52)
      temp = temp + M(65, 53) * x(53)
      temp = temp + M(65, 54) * x(54)
      temp = temp + M(65, 55) * x(55)
      temp = temp + M(65, 56) * x(56)
      temp = temp + M(65, 57) * x(57)
      temp = temp + M(65, 58) * x(58)
      temp = temp + M(65, 59) * x(59)
      temp = temp + M(65, 60) * x(60)
      temp = temp + M(65, 61) * x(61)
      temp = temp + M(65, 62) * x(62)
      temp = temp + M(65, 63) * x(63)
      temp = temp + M(65, 64) * x(64)
      x(65) = ( x(65) - temp ) / M(65, 65)


C     Backward substitution.

      temp = M(64, 65) * x(65)
      x(64) = x(64) - temp

      temp = M(63, 64) * x(64)
      temp = temp + M(63, 65) * x(65)
      x(63) = x(63) - temp

      temp = M(62, 63) * x(63)
      temp = temp + M(62, 64) * x(64)
      temp = temp + M(62, 65) * x(65)
      x(62) = x(62) - temp

      temp = M(61, 62) * x(62)
      temp = temp + M(61, 63) * x(63)
      temp = temp + M(61, 64) * x(64)
      temp = temp + M(61, 65) * x(65)
      x(61) = x(61) - temp

      temp = M(60, 61) * x(61)
      temp = temp + M(60, 62) * x(62)
      temp = temp + M(60, 63) * x(63)
      temp = temp + M(60, 64) * x(64)
      temp = temp + M(60, 65) * x(65)
      x(60) = x(60) - temp

      temp = M(59, 60) * x(60)
      temp = temp + M(59, 61) * x(61)
      temp = temp + M(59, 62) * x(62)
      temp = temp + M(59, 63) * x(63)
      temp = temp + M(59, 64) * x(64)
      temp = temp + M(59, 65) * x(65)
      x(59) = x(59) - temp

      temp = M(58, 59) * x(59)
      temp = temp + M(58, 60) * x(60)
      temp = temp + M(58, 61) * x(61)
      temp = temp + M(58, 62) * x(62)
      temp = temp + M(58, 63) * x(63)
      temp = temp + M(58, 64) * x(64)
      temp = temp + M(58, 65) * x(65)
      x(58) = x(58) - temp

      temp = M(57, 58) * x(58)
      temp = temp + M(57, 59) * x(59)
      temp = temp + M(57, 60) * x(60)
      temp = temp + M(57, 61) * x(61)
      temp = temp + M(57, 62) * x(62)
      temp = temp + M(57, 63) * x(63)
      temp = temp + M(57, 64) * x(64)
      temp = temp + M(57, 65) * x(65)
      x(57) = x(57) - temp

      temp = M(56, 57) * x(57)
      temp = temp + M(56, 58) * x(58)
      temp = temp + M(56, 59) * x(59)
      temp = temp + M(56, 60) * x(60)
      temp = temp + M(56, 61) * x(61)
      temp = temp + M(56, 62) * x(62)
      temp = temp + M(56, 63) * x(63)
      temp = temp + M(56, 64) * x(64)
      temp = temp + M(56, 65) * x(65)
      x(56) = x(56) - temp

      temp = M(55, 56) * x(56)
      temp = temp + M(55, 57) * x(57)
      temp = temp + M(55, 58) * x(58)
      temp = temp + M(55, 59) * x(59)
      temp = temp + M(55, 60) * x(60)
      temp = temp + M(55, 61) * x(61)
      temp = temp + M(55, 62) * x(62)
      temp = temp + M(55, 63) * x(63)
      temp = temp + M(55, 64) * x(64)
      temp = temp + M(55, 65) * x(65)
      x(55) = x(55) - temp

      temp = M(54, 55) * x(55)
      temp = temp + M(54, 56) * x(56)
      temp = temp + M(54, 57) * x(57)
      temp = temp + M(54, 58) * x(58)
      temp = temp + M(54, 59) * x(59)
      temp = temp + M(54, 60) * x(60)
      temp = temp + M(54, 61) * x(61)
      temp = temp + M(54, 62) * x(62)
      temp = temp + M(54, 63) * x(63)
      temp = temp + M(54, 64) * x(64)
      temp = temp + M(54, 65) * x(65)
      x(54) = x(54) - temp

      temp = M(53, 54) * x(54)
      temp = temp + M(53, 55) * x(55)
      temp = temp + M(53, 56) * x(56)
      temp = temp + M(53, 57) * x(57)
      temp = temp + M(53, 58) * x(58)
      temp = temp + M(53, 59) * x(59)
      temp = temp + M(53, 60) * x(60)
      temp = temp + M(53, 61) * x(61)
      temp = temp + M(53, 62) * x(62)
      temp = temp + M(53, 63) * x(63)
      temp = temp + M(53, 64) * x(64)
      temp = temp + M(53, 65) * x(65)
      x(53) = x(53) - temp

      temp = M(52, 55) * x(55)
      temp = temp + M(52, 56) * x(56)
      temp = temp + M(52, 57) * x(57)
      temp = temp + M(52, 59) * x(59)
      temp = temp + M(52, 61) * x(61)
      temp = temp + M(52, 63) * x(63)
      temp = temp + M(52, 64) * x(64)
      temp = temp + M(52, 65) * x(65)
      x(52) = x(52) - temp

      temp = M(51, 52) * x(52)
      temp = temp + M(51, 54) * x(54)
      temp = temp + M(51, 55) * x(55)
      temp = temp + M(51, 56) * x(56)
      temp = temp + M(51, 57) * x(57)
      temp = temp + M(51, 59) * x(59)
      temp = temp + M(51, 60) * x(60)
      temp = temp + M(51, 61) * x(61)
      temp = temp + M(51, 63) * x(63)
      temp = temp + M(51, 64) * x(64)
      temp = temp + M(51, 65) * x(65)
      x(51) = x(51) - temp

      temp = M(50, 52) * x(52)
      temp = temp + M(50, 54) * x(54)
      temp = temp + M(50, 55) * x(55)
      temp = temp + M(50, 56) * x(56)
      temp = temp + M(50, 57) * x(57)
      temp = temp + M(50, 59) * x(59)
      temp = temp + M(50, 60) * x(60)
      temp = temp + M(50, 61) * x(61)
      temp = temp + M(50, 63) * x(63)
      temp = temp + M(50, 64) * x(64)
      temp = temp + M(50, 65) * x(65)
      x(50) = x(50) - temp

      temp = M(49, 53) * x(53)
      temp = temp + M(49, 55) * x(55)
      temp = temp + M(49, 58) * x(58)
      temp = temp + M(49, 61) * x(61)
      temp = temp + M(49, 62) * x(62)
      temp = temp + M(49, 63) * x(63)
      x(49) = x(49) - temp

      temp = M(48, 52) * x(52)
      temp = temp + M(48, 55) * x(55)
      temp = temp + M(48, 56) * x(56)
      temp = temp + M(48, 57) * x(57)
      temp = temp + M(48, 59) * x(59)
      temp = temp + M(48, 61) * x(61)
      temp = temp + M(48, 63) * x(63)
      temp = temp + M(48, 64) * x(64)
      temp = temp + M(48, 65) * x(65)
      x(48) = x(48) - temp

      temp = M(47, 52) * x(52)
      temp = temp + M(47, 55) * x(55)
      temp = temp + M(47, 56) * x(56)
      temp = temp + M(47, 57) * x(57)
      temp = temp + M(47, 59) * x(59)
      temp = temp + M(47, 61) * x(61)
      temp = temp + M(47, 64) * x(64)
      temp = temp + M(47, 65) * x(65)
      x(47) = x(47) - temp

      temp = M(46, 47) * x(47)
      temp = temp + M(46, 52) * x(52)
      temp = temp + M(46, 55) * x(55)
      temp = temp + M(46, 56) * x(56)
      temp = temp + M(46, 57) * x(57)
      temp = temp + M(46, 59) * x(59)
      temp = temp + M(46, 61) * x(61)
      temp = temp + M(46, 64) * x(64)
      temp = temp + M(46, 65) * x(65)
      x(46) = x(46) - temp

      temp = M(45, 55) * x(55)
      temp = temp + M(45, 56) * x(56)
      temp = temp + M(45, 57) * x(57)
      temp = temp + M(45, 59) * x(59)
      temp = temp + M(45, 65) * x(65)
      x(45) = x(45) - temp

      temp = M(44, 55) * x(55)
      temp = temp + M(44, 56) * x(56)
      temp = temp + M(44, 57) * x(57)
      temp = temp + M(44, 59) * x(59)
      temp = temp + M(44, 65) * x(65)
      x(44) = x(44) - temp

      temp = M(43, 55) * x(55)
      temp = temp + M(43, 56) * x(56)
      temp = temp + M(43, 61) * x(61)
      temp = temp + M(43, 64) * x(64)
      temp = temp + M(43, 65) * x(65)
      x(43) = x(43) - temp

      temp = M(42, 43) * x(43)
      temp = temp + M(42, 45) * x(45)
      temp = temp + M(42, 55) * x(55)
      temp = temp + M(42, 56) * x(56)
      temp = temp + M(42, 59) * x(59)
      temp = temp + M(42, 61) * x(61)
      temp = temp + M(42, 64) * x(64)
      x(42) = x(42) - temp

      temp = M(41, 43) * x(43)
      temp = temp + M(41, 55) * x(55)
      temp = temp + M(41, 56) * x(56)
      temp = temp + M(41, 59) * x(59)
      temp = temp + M(41, 61) * x(61)
      temp = temp + M(41, 64) * x(64)
      x(41) = x(41) - temp

      temp = M(40, 43) * x(43)
      temp = temp + M(40, 55) * x(55)
      temp = temp + M(40, 56) * x(56)
      temp = temp + M(40, 61) * x(61)
      temp = temp + M(40, 64) * x(64)
      x(40) = x(40) - temp

      temp = M(39, 55) * x(55)
      temp = temp + M(39, 56) * x(56)
      temp = temp + M(39, 57) * x(57)
      temp = temp + M(39, 59) * x(59)
      x(39) = x(39) - temp

      temp = M(38, 55) * x(55)
      temp = temp + M(38, 56) * x(56)
      temp = temp + M(38, 57) * x(57)
      temp = temp + M(38, 59) * x(59)
      x(38) = x(38) - temp

      temp = M(37, 55) * x(55)
      temp = temp + M(37, 56) * x(56)
      temp = temp + M(37, 57) * x(57)
      temp = temp + M(37, 59) * x(59)
      x(37) = x(37) - temp

      temp = M(36, 55) * x(55)
      temp = temp + M(36, 56) * x(56)
      temp = temp + M(36, 57) * x(57)
      temp = temp + M(36, 59) * x(59)
      x(36) = x(36) - temp

      temp = M(35, 54) * x(54)
      temp = temp + M(35, 55) * x(55)
      temp = temp + M(35, 56) * x(56)
      temp = temp + M(35, 57) * x(57)
      temp = temp + M(35, 59) * x(59)
      temp = temp + M(35, 61) * x(61)
      temp = temp + M(35, 64) * x(64)
      x(35) = x(35) - temp

      temp = M(34, 55) * x(55)
      temp = temp + M(34, 56) * x(56)
      temp = temp + M(34, 57) * x(57)
      temp = temp + M(34, 59) * x(59)
      x(34) = x(34) - temp

      temp = M(33, 55) * x(55)
      temp = temp + M(33, 58) * x(58)
      temp = temp + M(33, 61) * x(61)
      temp = temp + M(33, 62) * x(62)
      x(33) = x(33) - temp

      temp = M(32, 52) * x(52)
      temp = temp + M(32, 55) * x(55)
      temp = temp + M(32, 61) * x(61)
      temp = temp + M(32, 63) * x(63)
      x(32) = x(32) - temp

      temp = M(31, 40) * x(40)
      temp = temp + M(31, 55) * x(55)
      temp = temp + M(31, 56) * x(56)
      x(31) = x(31) - temp

      temp = M(30, 40) * x(40)
      temp = temp + M(30, 55) * x(55)
      temp = temp + M(30, 56) * x(56)
      x(30) = x(30) - temp

      temp = M(29, 55) * x(55)
      temp = temp + M(29, 56) * x(56)
      temp = temp + M(29, 59) * x(59)
      x(29) = x(29) - temp

      temp = M(28, 55) * x(55)
      temp = temp + M(28, 56) * x(56)
      temp = temp + M(28, 59) * x(59)
      x(28) = x(28) - temp

      temp = M(27, 55) * x(55)
      temp = temp + M(27, 56) * x(56)
      temp = temp + M(27, 59) * x(59)
      x(27) = x(27) - temp

      temp = M(26, 55) * x(55)
      temp = temp + M(26, 56) * x(56)
      temp = temp + M(26, 59) * x(59)
      x(26) = x(26) - temp

      temp = M(25, 55) * x(55)
      temp = temp + M(25, 56) * x(56)
      temp = temp + M(25, 59) * x(59)
      x(25) = x(25) - temp

      temp = M(24, 55) * x(55)
      temp = temp + M(24, 56) * x(56)
      temp = temp + M(24, 59) * x(59)
      x(24) = x(24) - temp

      temp = M(23, 55) * x(55)
      temp = temp + M(23, 64) * x(64)
      temp = temp + M(23, 65) * x(65)
      x(23) = x(23) - temp

      temp = M(22, 53) * x(53)
      temp = temp + M(22, 54) * x(54)
      temp = temp + M(22, 55) * x(55)
      temp = temp + M(22, 61) * x(61)
      temp = temp + M(22, 64) * x(64)
      x(22) = x(22) - temp

      temp = M(21, 54) * x(54)
      temp = temp + M(21, 61) * x(61)
      temp = temp + M(21, 64) * x(64)
      x(21) = x(21) - temp

      temp = M(20, 55) * x(55)
      temp = temp + M(20, 57) * x(57)
      temp = temp + M(20, 61) * x(61)
      x(20) = x(20) - temp

      temp = M(19, 47) * x(47)
      temp = temp + M(19, 55) * x(55)
      temp = temp + M(19, 65) * x(65)
      x(19) = x(19) - temp

      temp = M(18, 55) * x(55)
      temp = temp + M(18, 58) * x(58)
      temp = temp + M(18, 65) * x(65)
      x(18) = x(18) - temp

      temp = M(17, 55) * x(55)
      temp = temp + M(17, 61) * x(61)
      temp = temp + M(17, 65) * x(65)
      x(17) = x(17) - temp

      temp = M(16, 56) * x(56)
      temp = temp + M(16, 65) * x(65)
      x(16) = x(16) - temp

      temp = M(15, 55) * x(55)
      temp = temp + M(15, 64) * x(64)
      x(15) = x(15) - temp

      temp = M(14, 53) * x(53)
      temp = temp + M(14, 55) * x(55)
      x(14) = x(14) - temp

      temp = M(13, 62) * x(62)
      temp = temp + M(13, 65) * x(65)
      x(13) = x(13) - temp

      temp = M(12, 55) * x(55)
      x(12) = x(12) - temp

      temp = M(11, 55) * x(55)
      x(11) = x(11) - temp

      temp = M(10, 55) * x(55)
      x(10) = x(10) - temp

      temp = M(9, 55) * x(55)
      x(9) = x(9) - temp

      temp = M(8, 55) * x(55)
      x(8) = x(8) - temp

      temp = M(7, 55) * x(55)
      x(7) = x(7) - temp

      temp = M(6, 55) * x(55)
      x(6) = x(6) - temp

      temp = M(5, 55) * x(55)
      x(5) = x(5) - temp

      temp = M(4, 55) * x(55)
      x(4) = x(4) - temp

      temp = M(3, 59) * x(59)
      x(3) = x(3) - temp


      END
