C------------------------------------------------------------------------
C     Copyright (C) 2001-2008, ENPC - INRIA - EDF R&D
C
C     This file is part of the air quality modeling system Polyphemus.
C
C     Polyphemus is developed in the INRIA - ENPC joint project-team
C     CLIME and in the ENPC - EDF R&D joint laboratory CEREA.
C
C     Polyphemus is free software; you can redistribute i and/or modify
C     it under the terms of the GNU General Public License as published
C     by the Free Software Foundation; either version 2 of the License,
C     or (at your option) any later version.
C
C     Polyphemus is distributed in the hope that it will be useful, but
C     WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
C     General Public License for more details.
C
C     For more information, visit the Polyphemus web site:
C     http://cerea.enpc.fr/polyphemus/
C------------------------------------------------------------------------
 
      subroutine fexchem_racm2(ns,nr,y,rk,ZCsourc,convers_factor,chem)
 
C------------------------------------------------------------------------
C
C     -- DESCRIPTION
C
C     This routine computes the chemical production term.
C     This routine is automatically generated by SPACK.
C     Mechanism: RACM2               
C     Species: _ciRACM2            
C
C------------------------------------------------------------------------
C
C     -- INPUT VARIABLES
C
C     Ns: chemical species number.
C     Y: chemical concentrations.
C     RK: kinetic rates.
C     ZCSOURC: volumic emissions.
C
C     -- INPUT/OUTPUT VARIABLES
C
C     -- OUTPUT VARIABLES
C
C     CHEM: array of chemical production terms.
C
C------------------------------------------------------------------------
C
C     -- REMARKS
C
C------------------------------------------------------------------------
C
C     -- MODIFICATIONS
C
C------------------------------------------------------------------------
C
C     -- AUTHOR(S)
C
C     SPACK.
C
C------------------------------------------------------------------------
 
      implicit none
 
 
 
      integer nr,ns,i
      double precision w(nr),rk(nr),y(ns),chem(ns),ZCsourc(ns)
      double precision conc(ns), convers_factor(ns)
 
      do i=1,ns
       chem(i)=0.d0
      enddo
 
C     Conversion mug/m3 to molecules/cm3.
 
      do i = 1, ns
         conc(i) = y(i) * convers_factor(i)
      enddo
 
C     Compute reaction rates.
 
      call rates_racm2(ns,nr,rk,conc,w)
 
C     Chemical production terms.
 
      chem( 44) = chem( 44) + w(  1)
      chem(102) = chem(102) + w(  1)
      chem(110) = chem(110) - w(  1)
      chem(  1) = chem(  1) + w(  2)
      chem( 81) = chem( 81) - w(  2)
      chem( 44) = chem( 44) + w(  3)
      chem( 81) = chem( 81) - w(  3)
      chem( 15) = chem( 15) - w(  4)
      chem(102) = chem(102) + w(  4)
      chem(112) = chem(112) + w(  4)
      chem( 94) = chem( 94) - w(  5)
      chem(110) = chem(110) + w(  5)
      chem(112) = chem(112) + w(  5)
      chem( 36) = chem( 36) - w(  6)
      chem(109) = chem(109) +  0.2000000000000000D+00 * w(  6)
      chem(110) = chem(110) +  0.8000000000000000D+00 * w(  6)
      chem(111) = chem(111) +  0.8000000000000000D+00 * w(  6)
      chem(112) = chem(112) +  0.2000000000000000D+00 * w(  6)
      chem(102) = chem(102) + w(  7)
      chem(109) = chem(109) - w(  7)
      chem( 44) = chem( 44) + w(  8)
      chem(109) = chem(109) - w(  8)
      chem(110) = chem(110) + w(  8)
      chem( 38) = chem( 38) - w(  9)
      chem(112) = chem(112) +  0.2000000000000000D+01 * w(  9)
      chem( 96) = chem( 96) + w( 10)
      chem(108) = chem(108) - w( 10)
      chem( 96) = chem( 96) + w( 11)
      chem(108) = chem(108) - w( 11)
      chem(111) = chem(111) +  0.2000000000000000D+01 * w( 11)
      chem( 87) = chem( 87) - w( 12)
      chem( 96) = chem( 96) + w( 12)
      chem(100) = chem(100) + w( 12)
      chem(111) = chem(111) + w( 12)
      chem( 96) = chem( 96) + w( 13)
      chem(104) = chem(104) + w( 13)
      chem(107) = chem(107) - w( 13)
      chem(111) = chem(111) + w( 13)
      chem( 58) = chem( 58) - w( 14)
      chem(100) = chem(100) + w( 14)
      chem(105) = chem(105) + w( 14)
      chem( 30) = chem( 30) - w( 15)
      chem(100) = chem(100) +  0.5000000000000000D+00 * w( 15)
      chem(104) = chem(104) +  0.5000000000000000D+00 * w( 15)
      chem(105) = chem(105) + w( 15)
      chem(103) = chem(103) - w( 16)
      chem(104) = chem(104) + w( 16)
      chem(105) = chem(105) + w( 16)
      chem( 76) = chem( 76) - w( 17)
      chem(105) = chem(105) + w( 17)
      chem(108) = chem(108) + w( 17)
      chem(111) = chem(111) + w( 17)
      chem( 61) = chem( 61) - w( 18)
      chem( 95) = chem( 95) +  0.3300000000000000D+00 * w( 18)
      chem( 96) = chem( 96) +  0.6700000000000000D+00 * w( 18)
      chem(101) = chem(101) +  0.3400000000000000D+00 * w( 18)
      chem(105) = chem(105) +  0.6700000000000000D+00 * w( 18)
      chem(108) = chem(108) +  0.6700000000000000D+00 * w( 18)
      chem(111) = chem(111) +  0.6600000000000000D+00 * w( 18)
      chem(112) = chem(112) +  0.3400000000000000D+00 * w( 18)
      chem( 66) = chem( 66) - w( 19)
      chem( 80) = chem( 80) +  0.7000000000000000D+00 * w( 19)
      chem( 95) = chem( 95) +  0.3000000000000000D+00 * w( 19)
      chem( 96) = chem( 96) +  0.7000000000000000D+00 * w( 19)
      chem(100) = chem(100) +  0.3000000000000000D+00 * w( 19)
      chem( 80) = chem( 80) - w( 20)
      chem( 96) = chem( 96) +  0.1220000000000000D+01 * w( 20)
      chem(103) = chem(103) +  0.2160000000000000D+00 * w( 20)
      chem(105) = chem(105) +  0.7840000000000000D+00 * w( 20)
      chem(107) = chem(107) +  0.4340000000000000D+00 * w( 20)
      chem(108) = chem(108) +  0.3500000000000000D+00 * w( 20)
      chem(111) = chem(111) +  0.1220000000000000D+01 * w( 20)
      chem( 91) = chem( 91) - w( 21)
      chem( 96) = chem( 96) +  0.2000000000000000D+01 * w( 21)
      chem(111) = chem(111) +  0.2000000000000000D+01 * w( 21)
      chem( 91) = chem( 91) - w( 22)
      chem( 96) = chem( 96) +  0.2000000000000000D+01 * w( 22)
      chem( 91) = chem( 91) - w( 23)
      chem( 96) = chem( 96) +  0.2000000000000000D+01 * w( 23)
      chem(108) = chem(108) + w( 23)
      chem( 93) = chem( 93) - w( 24)
      chem( 96) = chem( 96) + w( 24)
      chem(105) = chem(105) + w( 24)
      chem(111) = chem(111) + w( 24)
      chem( 77) = chem( 77) - w( 25)
      chem( 91) = chem( 91) +  0.5000000000000000D+00 * w( 25)
      chem( 93) = chem( 93) +  0.5000000000000000D+00 * w( 25)
      chem( 96) = chem( 96) + w( 25)
      chem(101) = chem(101) +  0.2000000000000000D+01 * w( 25)
      chem(105) = chem(105) +  0.5000000000000000D+00 * w( 25)
      chem(111) = chem(111) +  0.1500000000000000D+01 * w( 25)
      chem( 56) = chem( 56) - w( 26)
      chem( 91) = chem( 91) +  0.5000000000000000D+00 * w( 26)
      chem( 93) = chem( 93) +  0.5000000000000000D+00 * w( 26)
      chem( 96) = chem( 96) + w( 26)
      chem(101) = chem(101) +  0.2000000000000000D+01 * w( 26)
      chem(105) = chem(105) +  0.5000000000000000D+00 * w( 26)
      chem(111) = chem(111) +  0.1500000000000000D+01 * w( 26)
      chem( 78) = chem( 78) - w( 27)
      chem( 79) = chem( 79) + w( 27)
      chem( 96) = chem( 96) + w( 27)
      chem(105) = chem(105) + w( 27)
      chem(111) = chem(111) + w( 27)
      chem( 48) = chem( 48) + w( 28)
      chem( 53) = chem( 53) - w( 28)
      chem( 96) = chem( 96) + w( 28)
      chem(111) = chem(111) + w( 28)
      chem( 34) = chem( 34) - w( 29)
      chem(108) = chem(108) + w( 29)
      chem(111) = chem(111) + w( 29)
      chem(112) = chem(112) + w( 29)
      chem(106) = chem(106) - w( 30)
      chem(107) = chem(107) + w( 30)
      chem(111) = chem(111) + w( 30)
      chem(112) = chem(112) + w( 30)
      chem( 74) = chem( 74) - w( 31)
      chem(100) = chem(100) + w( 31)
      chem(112) = chem(112) + w( 31)
      chem(103) = chem(103) +  0.8000000000000000D+00 * w( 32)
      chem(107) = chem(107) +  0.2000000000000000D+00 * w( 32)
      chem(110) = chem(110) + w( 32)
      chem(111) = chem(111) + w( 32)
      chem(113) = chem(113) - w( 32)
      chem( 35) = chem( 35) - w( 33)
      chem(105) = chem(105) + w( 33)
      chem(110) = chem(110) + w( 33)
      chem( 35) = chem( 35) - w( 34)
      chem(100) = chem(100) + w( 34)
      chem(109) = chem(109) + w( 34)
      chem( 44) = chem( 44) - w( 35)
      chem( 81) = chem( 81) + w( 35)
      chem( 44) = chem( 44) - w( 36)
      chem( 81) = chem( 81) - w( 36)
      chem(  1) = chem(  1) - w( 37)
      chem( 44) = chem( 44) + w( 37)
      chem(  1) = chem(  1) - w( 38)
      chem( 44) = chem( 44) + w( 38)
      chem(  1) = chem(  1) - w( 39)
      chem(112) = chem(112) +  0.2000000000000000D+01 * w( 39)
      chem( 81) = chem( 81) - w( 40)
      chem(111) = chem(111) + w( 40)
      chem(112) = chem(112) - w( 40)
      chem( 81) = chem( 81) - w( 41)
      chem(111) = chem(111) - w( 41)
      chem(112) = chem(112) + w( 41)
      chem(111) = chem(111) - w( 42)
      chem(112) = chem(112) - w( 42)
      chem( 38) = chem( 38) - w( 43)
      chem(111) = chem(111) + w( 43)
      chem(112) = chem(112) - w( 43)
      chem( 38) = chem( 38) + w( 44)
      chem(111) = chem(111) -  0.2000000000000000D+01 * w( 44)
      chem( 38) = chem( 38) + w( 45)
      chem(111) = chem(111) -  0.2000000000000000D+01 * w( 45)
      chem( 44) = chem( 44) - w( 46)
      chem(102) = chem(102) - w( 46)
      chem(110) = chem(110) + w( 46)
      chem( 44) = chem( 44) - w( 47)
      chem(102) = chem(102) + w( 47)
      chem(110) = chem(110) - w( 47)
      chem( 44) = chem( 44) - w( 48)
      chem(109) = chem(109) + w( 48)
      chem(110) = chem(110) - w( 48)
      chem( 15) = chem( 15) + w( 49)
      chem(102) = chem(102) - w( 49)
      chem(112) = chem(112) - w( 49)
      chem( 94) = chem( 94) + w( 50)
      chem(110) = chem(110) - w( 50)
      chem(112) = chem(112) - w( 50)
      chem(109) = chem(109) - w( 51)
      chem(110) = chem(110) + w( 51)
      chem(111) = chem(111) + w( 51)
      chem(112) = chem(112) - w( 51)
      chem(102) = chem(102) - w( 52)
      chem(110) = chem(110) + w( 52)
      chem(111) = chem(111) - w( 52)
      chem(112) = chem(112) + w( 52)
      chem( 36) = chem( 36) + w( 53)
      chem(110) = chem(110) - w( 53)
      chem(111) = chem(111) - w( 53)
      chem( 36) = chem( 36) - w( 54)
      chem(110) = chem(110) + w( 54)
      chem(111) = chem(111) + w( 54)
      chem( 94) = chem( 94) +  0.3000000000000000D+00 * w( 55)
      chem(109) = chem(109) - w( 55)
      chem(110) = chem(110) +  0.7000000000000000D+00 * w( 55)
      chem(111) = chem(111) - w( 55)
      chem(112) = chem(112) +  0.7000000000000000D+00 * w( 55)
      chem( 15) = chem( 15) - w( 56)
      chem(110) = chem(110) + w( 56)
      chem(112) = chem(112) - w( 56)
      chem( 94) = chem( 94) - w( 57)
      chem(109) = chem(109) + w( 57)
      chem(112) = chem(112) - w( 57)
      chem( 36) = chem( 36) - w( 58)
      chem(110) = chem(110) + w( 58)
      chem(112) = chem(112) - w( 58)
      chem( 81) = chem( 81) - w( 59)
      chem(102) = chem(102) - w( 59)
      chem(110) = chem(110) + w( 59)
      chem( 81) = chem( 81) - w( 60)
      chem(109) = chem(109) + w( 60)
      chem(110) = chem(110) - w( 60)
      chem(102) = chem(102) -  0.2000000000000000D+01 * w( 61)
      chem(110) = chem(110) +  0.2000000000000000D+01 * w( 61)
      chem(102) = chem(102) - w( 62)
      chem(109) = chem(109) - w( 62)
      chem(110) = chem(110) +  0.2000000000000000D+01 * w( 62)
      chem(102) = chem(102) + w( 63)
      chem(109) = chem(109) - w( 63)
      chem( 16) = chem( 16) + w( 64)
      chem(109) = chem(109) - w( 64)
      chem(110) = chem(110) - w( 64)
      chem( 16) = chem( 16) - w( 65)
      chem(109) = chem(109) + w( 65)
      chem(110) = chem(110) + w( 65)
      chem( 16) = chem( 16) - w( 66)
      chem( 94) = chem( 94) +  0.2000000000000000D+01 * w( 66)
      chem(109) = chem(109) -  0.2000000000000000D+01 * w( 67)
      chem(110) = chem(110) +  0.2000000000000000D+01 * w( 67)
      chem(111) = chem(111) + w( 68)
      chem(112) = chem(112) - w( 68)
      chem(  2) = chem(  2) - w( 69)
      chem(  3) = chem(  3) + w( 69)
      chem(111) = chem(111) + w( 69)
      chem(112) = chem(112) - w( 69)
      chem( 96) = chem( 96) - w( 70)
      chem(111) = chem(111) + w( 70)
      chem(112) = chem(112) - w( 70)
      chem( 32) = chem( 32) - w( 71)
      chem(100) = chem(100) + w( 71)
      chem(112) = chem(112) - w( 71)
      chem( 33) = chem( 33) - w( 72)
      chem(104) = chem(104) + w( 72)
      chem(112) = chem(112) - w( 72)
      chem( 89) = chem( 89) - w( 73)
      chem(108) = chem(108) + w( 73)
      chem(111) = chem(111) + w( 73)
      chem(112) = chem(112) - w( 73)
      chem( 21) = chem( 21) - w( 74)
      chem( 87) = chem( 87) + w( 74)
      chem(111) = chem(111) + w( 74)
      chem(112) = chem(112) - w( 74)
      chem( 85) = chem( 85) - w( 75)
      chem( 87) = chem( 87) +  0.1840000000000000D+00 * w( 75)
      chem(107) = chem(107) +  0.7190000000000000D+00 * w( 75)
      chem(111) = chem(111) + w( 75)
      chem(112) = chem(112) - w( 75)
      chem(  4) = chem(  4) - w( 76)
      chem( 67) = chem( 67) +  0.3500000000000000D+00 * w( 76)
      chem( 91) = chem( 91) +  0.6500000000000000D+00 * w( 76)
      chem( 96) = chem( 96) +  0.3500000000000000D+00 * w( 76)
      chem(111) = chem(111) +  0.3500000000000000D+00 * w( 76)
      chem(112) = chem(112) -  0.3500000000000000D+00 * w( 76)
      chem(  6) = chem(  6) - w( 77)
      chem( 99) = chem( 99) + w( 77)
      chem(112) = chem(112) - w( 77)
      chem(  7) = chem(  7) - w( 78)
      chem( 86) = chem( 86) + w( 78)
      chem(112) = chem(112) - w( 78)
      chem(  8) = chem(  8) - w( 79)
      chem( 62) = chem( 62) +  0.9510000000000000D+00 * w( 79)
      chem( 76) = chem( 76) +  0.2400000000000000D-01 * w( 79)
      chem(107) = chem(107) +  0.2500000000000000D-01 * w( 79)
      chem(111) = chem(111) +  0.4900000000000000D-01 * w( 79)
      chem(112) = chem(112) - w( 79)
      chem( 23) = chem( 23) - w( 80)
      chem( 88) = chem( 88) + w( 80)
      chem(112) = chem(112) - w( 80)
      chem( 31) = chem( 31) - w( 81)
      chem( 72) = chem( 72) + w( 81)
      chem(112) = chem(112) - w( 81)
      chem( 69) = chem( 69) - w( 82)
      chem( 79) = chem( 79) + w( 82)
      chem(112) = chem(112) - w( 82)
      chem( 20) = chem( 20) - w( 83)
      chem( 79) = chem( 79) + w( 83)
      chem(112) = chem(112) - w( 83)
      chem( 26) = chem( 26) - w( 84)
      chem( 59) = chem( 59) + w( 84)
      chem(112) = chem(112) - w( 84)
      chem( 19) = chem( 19) - w( 85)
      chem( 57) = chem( 57) + w( 85)
      chem(112) = chem(112) - w( 85)
      chem( 27) = chem( 27) - w( 86)
      chem( 60) = chem( 60) + w( 86)
      chem(112) = chem(112) - w( 86)
      chem( 25) = chem( 25) - w( 87)
      chem( 61) = chem( 61) + w( 87)
      chem( 17) = chem( 17) + w( 88)
      chem( 39) = chem( 39) - w( 88)
      chem( 73) = chem( 73) + w( 88)
      chem(112) = chem(112) - w( 88)
      chem( 28) = chem( 28) - w( 89)
      chem( 95) = chem( 95) + w( 89)
      chem(112) = chem(112) - w( 89)
      chem( 73) = chem( 73) - w( 90)
      chem( 93) = chem( 93) + w( 90)
      chem(111) = chem(111) + w( 90)
      chem(112) = chem(112) - w( 90)
      chem( 17) = chem( 17) - w( 91)
      chem( 96) = chem( 96) + w( 91)
      chem(108) = chem(108) + w( 91)
      chem(110) = chem(110) + w( 91)
      chem(112) = chem(112) - w( 91)
      chem( 24) = chem( 24) - w( 92)
      chem(107) = chem(107) + w( 92)
      chem(111) = chem(111) + w( 92)
      chem(112) = chem(112) - w( 92)
      chem(  5) = chem(  5) - w( 93)
      chem( 18) = chem( 18) +  0.5300000000000000D+00 * w( 93)
      chem( 63) = chem( 63) +  0.3520000000000000D+00 * w( 93)
      chem( 80) = chem( 80) +  0.1180000000000000D+00 * w( 93)
      chem(111) = chem(111) +  0.6480000000000000D+00 * w( 93)
      chem(112) = chem(112) - w( 93)
      chem(  9) = chem(  9) - w( 94)
      chem( 10) = chem( 10) +  0.8900000000000000D+00 * w( 94)
      chem( 47) = chem( 47) +  0.5000000000000000D-01 * w( 94)
      chem( 50) = chem( 50) +  0.6000000000000000D-01 * w( 94)
      chem(111) = chem(111) +  0.5000000000000000D-01 * w( 94)
      chem(112) = chem(112) - w( 94)
      chem( 50) = chem( 50) - w( 95)
      chem( 53) = chem( 53) + w( 95)
      chem(102) = chem(102) - w( 95)
      chem(110) = chem(110) + w( 95)
      chem( 10) = chem( 10) - w( 96)
      chem( 22) = chem( 22) +  0.2800000000000000D+00 * w( 96)
      chem( 41) = chem( 41) +  0.2800000000000000D+00 * w( 96)
      chem( 42) = chem( 42) +  0.1500000000000000D+00 * w( 96)
      chem( 47) = chem( 47) +  0.1000000000000000D-01 * w( 96)
      chem( 56) = chem( 56) +  0.2800000000000000D+00 * w( 96)
      chem(111) = chem(111) +  0.2900000000000000D+00 * w( 96)
      chem(112) = chem(112) +  0.2800000000000000D+00 * w( 96)
      chem( 41) = chem( 41) - w( 97)
      chem( 42) = chem( 42) +  0.5000000000000000D+00 * w( 97)
      chem( 47) = chem( 47) +  0.1000000000000000D-01 * w( 97)
      chem( 56) = chem( 56) +  0.4900000000000000D+00 * w( 97)
      chem(111) = chem(111) +  0.1000000000000000D-01 * w( 97)
      chem(112) = chem(112) +  0.4900000000000000D+00 * w( 97)
      chem( 41) = chem( 41) - w( 98)
      chem( 56) = chem( 56) +  0.9500000000000000D+00 * w( 98)
      chem(102) = chem(102) - w( 98)
      chem(110) = chem(110) +  0.9500000000000000D+00 * w( 98)
      chem(111) = chem(111) +  0.9500000000000000D+00 * w( 98)
      chem(113) = chem(113) +  0.5000000000000000D-01 * w( 98)
      chem( 42) = chem( 42) - w( 99)
      chem( 77) = chem( 77) +  0.9500000000000000D+00 * w( 99)
      chem( 93) = chem( 93) +  0.9500000000000000D+00 * w( 99)
      chem(102) = chem(102) - w( 99)
      chem(110) = chem(110) +  0.9500000000000000D+00 * w( 99)
      chem(111) = chem(111) +  0.9500000000000000D+00 * w( 99)
      chem(113) = chem(113) +  0.5000000000000000D-01 * w( 99)
      chem( 13) = chem( 13) - w(100)
      chem( 14) = chem( 14) +  0.8900000000000000D+00 * w(100)
      chem( 47) = chem( 47) +  0.5000000000000000D-01 * w(100)
      chem( 52) = chem( 52) +  0.6000000000000000D-01 * w(100)
      chem(111) = chem(111) +  0.5000000000000000D-01 * w(100)
      chem(112) = chem(112) - w(100)
      chem( 11) = chem( 11) - w(101)
      chem( 12) = chem( 12) +  0.8900000000000000D+00 * w(101)
      chem( 47) = chem( 47) +  0.5000000000000000D-01 * w(101)
      chem( 52) = chem( 52) +  0.6000000000000000D-01 * w(101)
      chem(111) = chem(111) +  0.5000000000000000D-01 * w(101)
      chem(112) = chem(112) - w(101)
      chem( 52) = chem( 52) - w(102)
      chem( 53) = chem( 53) + w(102)
      chem(102) = chem(102) - w(102)
      chem(110) = chem(110) + w(102)
      chem( 12) = chem( 12) - w(103)
      chem( 22) = chem( 22) +  0.8400000000000000D+00 * w(103)
      chem( 43) = chem( 43) +  0.3080000000000000D+00 * w(103)
      chem( 47) = chem( 47) +  0.1000000000000000D-01 * w(103)
      chem( 49) = chem( 49) +  0.1500000000000000D+00 * w(103)
      chem( 56) = chem( 56) +  0.2240000000000000D+00 * w(103)
      chem(111) = chem(111) +  0.3080000000000000D+00 * w(103)
      chem(112) = chem(112) +  0.3080000000000000D+00 * w(103)
      chem( 14) = chem( 14) - w(104)
      chem( 22) = chem( 22) +  0.8400000000000000D+00 * w(104)
      chem( 47) = chem( 47) +  0.1000000000000000D-01 * w(104)
      chem( 49) = chem( 49) +  0.1500000000000000D+00 * w(104)
      chem( 55) = chem( 55) +  0.3080000000000000D+00 * w(104)
      chem( 56) = chem( 56) +  0.2240000000000000D+00 * w(104)
      chem(111) = chem(111) +  0.3080000000000000D+00 * w(104)
      chem(112) = chem(112) +  0.3080000000000000D+00 * w(104)
      chem( 43) = chem( 43) - w(105)
      chem( 47) = chem( 47) +  0.1000000000000000D-01 * w(105)
      chem( 49) = chem( 49) +  0.5000000000000000D+00 * w(105)
      chem( 56) = chem( 56) +  0.4900000000000000D+00 * w(105)
      chem(111) = chem(111) +  0.1000000000000000D-01 * w(105)
      chem(112) = chem(112) +  0.4900000000000000D+00 * w(105)
      chem( 47) = chem( 47) +  0.1000000000000000D-01 * w(106)
      chem( 49) = chem( 49) +  0.5000000000000000D+00 * w(106)
      chem( 55) = chem( 55) - w(106)
      chem( 56) = chem( 56) +  0.4900000000000000D+00 * w(106)
      chem(111) = chem(111) +  0.1000000000000000D-01 * w(106)
      chem(112) = chem(112) +  0.4900000000000000D+00 * w(106)
      chem( 43) = chem( 43) - w(107)
      chem( 56) = chem( 56) +  0.9500000000000000D+00 * w(107)
      chem(102) = chem(102) - w(107)
      chem(110) = chem(110) +  0.9500000000000000D+00 * w(107)
      chem(111) = chem(111) +  0.9500000000000000D+00 * w(107)
      chem(113) = chem(113) +  0.5000000000000000D-01 * w(107)
      chem( 49) = chem( 49) - w(108)
      chem( 77) = chem( 77) +  0.9500000000000000D+00 * w(108)
      chem( 78) = chem( 78) +  0.1950000000000000D+01 * w(108)
      chem( 93) = chem( 93) +  0.9500000000000000D+00 * w(108)
      chem(102) = chem(102) - w(108)
      chem(110) = chem(110) +  0.9500000000000000D+00 * w(108)
      chem(111) = chem(111) +  0.9500000000000000D+00 * w(108)
      chem(113) = chem(113) +  0.5000000000000000D-01 * w(108)
      chem( 53) = chem( 53) - w(109)
      chem( 54) = chem( 54) + w(109)
      chem(112) = chem(112) - w(109)
      chem( 45) = chem( 45) + w(110)
      chem( 54) = chem( 54) - w(110)
      chem(102) = chem(102) - w(110)
      chem(110) = chem(110) + w(110)
      chem( 45) = chem( 45) - w(111)
      chem( 46) = chem( 46) + w(111)
      chem(102) = chem(102) - w(111)
      chem(110) = chem(110) + w(111)
      chem( 46) = chem( 46) - w(112)
      chem(110) = chem(110) - w(112)
      chem(113) = chem(113) + w(112)
      chem( 18) = chem( 18) - w(113)
      chem( 29) = chem( 29) +  0.7300000000000000D+00 * w(113)
      chem( 48) = chem( 48) +  0.7000000000000001D-01 * w(113)
      chem( 75) = chem( 75) +  0.2000000000000000D+00 * w(113)
      chem(111) = chem(111) +  0.7300000000000000D+00 * w(113)
      chem(112) = chem(112) - w(113)
      chem( 29) = chem( 29) +  0.7300000000000000D+00 * w(114)
      chem( 47) = chem( 47) - w(114)
      chem( 48) = chem( 48) +  0.7000000000000001D-01 * w(114)
      chem( 75) = chem( 75) +  0.2000000000000000D+00 * w(114)
      chem(111) = chem(111) +  0.7300000000000000D+00 * w(114)
      chem(112) = chem(112) - w(114)
      chem( 29) = chem( 29) - w(115)
      chem( 83) = chem( 83) + w(115)
      chem(112) = chem(112) - w(115)
      chem( 29) = chem( 29) - w(116)
      chem( 83) = chem( 83) + w(116)
      chem( 94) = chem( 94) + w(116)
      chem(109) = chem(109) - w(116)
      chem( 81) = chem( 81) - w(117)
      chem( 82) = chem( 82) + w(117)
      chem( 83) = chem( 83) - w(117)
      chem( 83) = chem( 83) - w(118)
      chem(110) = chem(110) - w(118)
      chem(113) = chem(113) + w(118)
      chem( 82) = chem( 82) - w(119)
      chem( 83) = chem( 83) + w(119)
      chem(102) = chem(102) - w(119)
      chem(110) = chem(110) + w(119)
      chem( 82) = chem( 82) - w(120)
      chem( 83) = chem( 83) + w(120)
      chem(100) = chem(100) - w(120)
      chem(108) = chem(108) + w(120)
      chem(111) = chem(111) + w(120)
      chem( 82) = chem( 82) - w(121)
      chem( 83) = chem( 83) + w(121)
      chem(100) = chem(100) + w(121)
      chem(105) = chem(105) - w(121)
      chem(111) = chem(111) + w(121)
      chem( 82) = chem( 82) - w(122)
      chem(106) = chem(106) + w(122)
      chem(111) = chem(111) - w(122)
      chem( 82) = chem( 82) - w(123)
      chem( 83) = chem( 83) + w(123)
      chem(109) = chem(109) - w(123)
      chem(110) = chem(110) + w(123)
      chem( 96) = chem( 96) + w(124)
      chem(108) = chem(108) - w(124)
      chem(111) = chem(111) + w(124)
      chem(112) = chem(112) - w(124)
      chem( 87) = chem( 87) - w(125)
      chem(105) = chem(105) + w(125)
      chem(112) = chem(112) - w(125)
      chem( 98) = chem( 98) + w(126)
      chem(107) = chem(107) - w(126)
      chem(112) = chem(112) - w(126)
      chem( 58) = chem( 58) - w(127)
      chem( 65) = chem( 65) + w(127)
      chem(112) = chem(112) - w(127)
      chem( 30) = chem( 30) - w(128)
      chem( 64) = chem( 64) + w(128)
      chem(112) = chem(112) - w(128)
      chem( 92) = chem( 92) + w(129)
      chem(103) = chem(103) - w(129)
      chem(112) = chem(112) - w(129)
      chem( 76) = chem( 76) - w(130)
      chem( 93) = chem( 93) + w(130)
      chem(111) = chem(111) + w(130)
      chem(112) = chem(112) - w(130)
      chem( 91) = chem( 91) - w(131)
      chem( 96) = chem( 96) +  0.2000000000000000D+01 * w(131)
      chem(111) = chem(111) + w(131)
      chem(112) = chem(112) - w(131)
      chem( 93) = chem( 93) - w(132)
      chem( 96) = chem( 96) + w(132)
      chem(105) = chem(105) + w(132)
      chem(112) = chem(112) - w(132)
      chem( 61) = chem( 61) - w(133)
      chem( 95) = chem( 95) + w(133)
      chem(112) = chem(112) - w(133)
      chem( 66) = chem( 66) - w(134)
      chem( 68) = chem( 68) + w(134)
      chem(112) = chem(112) - w(134)
      chem( 80) = chem( 80) - w(135)
      chem( 84) = chem( 84) +  0.6870000000000001D+00 * w(135)
      chem(105) = chem(105) +  0.3130000000000000D+00 * w(135)
      chem(112) = chem(112) - w(135)
      chem( 22) = chem( 22) - w(136)
      chem( 96) = chem( 96) + w(136)
      chem(101) = chem(101) + w(136)
      chem(107) = chem(107) + w(136)
      chem(111) = chem(111) + w(136)
      chem(112) = chem(112) - w(136)
      chem( 56) = chem( 56) - w(137)
      chem(101) = chem(101) + w(137)
      chem(105) = chem(105) + w(137)
      chem(107) = chem(107) + w(137)
      chem(112) = chem(112) - w(137)
      chem( 77) = chem( 77) - w(138)
      chem(101) = chem(101) + w(138)
      chem(105) = chem(105) + w(138)
      chem(107) = chem(107) + w(138)
      chem(112) = chem(112) - w(138)
      chem( 78) = chem( 78) - w(139)
      chem( 96) = chem( 96) + w(139)
      chem(105) = chem(105) + w(139)
      chem(112) = chem(112) - w(139)
      chem( 34) = chem( 34) - w(140)
      chem(100) = chem(100) +  0.6500000000000000D+00 * w(140)
      chem(108) = chem(108) +  0.3500000000000000D+00 * w(140)
      chem(112) = chem(112) -  0.6500000000000000D+00 * w(140)
      chem( 99) = chem( 99) +  0.4400000000000000D+00 * w(141)
      chem(101) = chem(101) +  0.7000000000000001D-01 * w(141)
      chem(103) = chem(103) +  0.4100000000000000D+00 * w(141)
      chem(106) = chem(106) - w(141)
      chem(107) = chem(107) +  0.8000000000000000D-01 * w(141)
      chem(112) = chem(112) -  0.5100000000000000D+00 * w(141)
      chem( 74) = chem( 74) - w(142)
      chem(101) = chem(101) +  0.3500000000000000D+00 * w(142)
      chem(105) = chem(105) +  0.6500000000000000D+00 * w(142)
      chem(108) = chem(108) +  0.3500000000000000D+00 * w(142)
      chem(112) = chem(112) -  0.6500000000000000D+00 * w(142)
      chem( 35) = chem( 35) - w(143)
      chem(101) = chem(101) + w(143)
      chem(108) = chem(108) + w(143)
      chem(109) = chem(109) + w(143)
      chem(112) = chem(112) - w(143)
      chem( 37) = chem( 37) - w(144)
      chem(101) = chem(101) + w(144)
      chem(108) = chem(108) + w(144)
      chem(109) = chem(109) + w(144)
      chem(112) = chem(112) - w(144)
      chem( 40) = chem( 40) - w(145)
      chem( 73) = chem( 73) + w(145)
      chem(110) = chem(110) + w(145)
      chem(112) = chem(112) - w(145)
      chem( 99) = chem( 99) + w(146)
      chem(110) = chem(110) + w(146)
      chem(112) = chem(112) - w(146)
      chem(113) = chem(113) - w(146)
      chem( 67) = chem( 67) - w(147)
      chem(111) = chem(111) + w(147)
      chem(112) = chem(112) - w(147)
      chem( 90) = chem( 90) +  0.3600000000000000D+00 * w(148)
      chem( 97) = chem( 97) - w(148)
      chem(100) = chem(100) +  0.6400000000000000D+00 * w(148)
      chem(112) = chem(112) - w(148)
      chem( 94) = chem( 94) + w(149)
      chem( 96) = chem( 96) + w(149)
      chem(108) = chem(108) - w(149)
      chem(109) = chem(109) - w(149)
      chem(111) = chem(111) + w(149)
      chem( 87) = chem( 87) - w(150)
      chem( 94) = chem( 94) + w(150)
      chem(105) = chem(105) + w(150)
      chem(109) = chem(109) - w(150)
      chem( 94) = chem( 94) + w(151)
      chem( 98) = chem( 98) + w(151)
      chem(107) = chem(107) - w(151)
      chem(109) = chem(109) - w(151)
      chem( 91) = chem( 91) - w(152)
      chem( 94) = chem( 94) + w(152)
      chem( 96) = chem( 96) +  0.2000000000000000D+01 * w(152)
      chem(109) = chem(109) - w(152)
      chem(111) = chem(111) + w(152)
      chem( 93) = chem( 93) - w(153)
      chem( 94) = chem( 94) + w(153)
      chem( 96) = chem( 96) + w(153)
      chem(105) = chem(105) + w(153)
      chem(109) = chem(109) - w(153)
      chem( 22) = chem( 22) - w(154)
      chem( 91) = chem( 91) + w(154)
      chem( 94) = chem( 94) +  0.5000000000000000D+00 * w(154)
      chem( 96) = chem( 96) +  0.1500000000000000D+01 * w(154)
      chem(109) = chem(109) - w(154)
      chem(110) = chem(110) +  0.5000000000000000D+00 * w(154)
      chem(111) = chem(111) +  0.1500000000000000D+01 * w(154)
      chem(112) = chem(112) +  0.5000000000000000D+00 * w(154)
      chem( 18) = chem( 18) - w(155)
      chem( 48) = chem( 48) +  0.4000000000000000D+00 * w(155)
      chem( 51) = chem( 51) +  0.5000000000000000D+00 * w(155)
      chem( 75) = chem( 75) +  0.1000000000000000D+00 * w(155)
      chem( 94) = chem( 94) +  0.5000000000000000D+00 * w(155)
      chem(109) = chem(109) - w(155)
      chem( 47) = chem( 47) - w(156)
      chem( 48) = chem( 48) +  0.4000000000000000D+00 * w(156)
      chem( 51) = chem( 51) +  0.5000000000000000D+00 * w(156)
      chem( 75) = chem( 75) +  0.1000000000000000D+00 * w(156)
      chem( 94) = chem( 94) +  0.5000000000000000D+00 * w(156)
      chem(109) = chem(109) - w(156)
      chem( 51) = chem( 51) - w(157)
      chem( 91) = chem( 91) + w(157)
      chem(102) = chem(102) - w(157)
      chem(106) = chem(106) + w(157)
      chem(110) = chem(110) +  0.2000000000000000D+01 * w(157)
      chem( 51) = chem( 51) - w(158)
      chem( 91) = chem( 91) + w(158)
      chem(106) = chem(106) + w(158)
      chem(109) = chem(109) - w(158)
      chem(110) = chem(110) +  0.2000000000000000D+01 * w(158)
      chem( 51) = chem( 51) - w(159)
      chem( 91) = chem( 91) +  0.7000000000000000D+00 * w(159)
      chem(100) = chem(100) - w(159)
      chem(106) = chem(106) +  0.7000000000000000D+00 * w(159)
      chem(108) = chem(108) + w(159)
      chem(110) = chem(110) +  0.7000000000000000D+00 * w(159)
      chem(111) = chem(111) + w(159)
      chem(113) = chem(113) +  0.3000000000000000D+00 * w(159)
      chem( 51) = chem( 51) - w(160)
      chem( 91) = chem( 91) +  0.7000000000000000D+00 * w(160)
      chem(100) = chem(100) + w(160)
      chem(105) = chem(105) - w(160)
      chem(106) = chem(106) +  0.7000000000000000D+00 * w(160)
      chem(110) = chem(110) +  0.7000000000000000D+00 * w(160)
      chem(111) = chem(111) + w(160)
      chem(113) = chem(113) +  0.3000000000000000D+00 * w(160)
      chem( 51) = chem( 51) - w(161)
      chem(106) = chem(106) + w(161)
      chem(111) = chem(111) - w(161)
      chem( 23) = chem( 23) - w(162)
      chem( 70) = chem( 70) +  0.2000000000000000D+00 * w(162)
      chem( 71) = chem( 71) +  0.8000000000000000D+00 * w(162)
      chem(109) = chem(109) - w(162)
      chem( 31) = chem( 31) - w(163)
      chem( 70) = chem( 70) +  0.5700000000000000D+00 * w(163)
      chem( 71) = chem( 71) +  0.4300000000000000D+00 * w(163)
      chem(109) = chem(109) - w(163)
      chem( 69) = chem( 69) - w(164)
      chem( 70) = chem( 70) +  0.8900000000000000D+00 * w(164)
      chem( 71) = chem( 71) +  0.1100000000000000D+00 * w(164)
      chem(109) = chem(109) - w(164)
      chem( 20) = chem( 20) - w(165)
      chem( 61) = chem( 61) +  0.9000000000000000D+00 * w(165)
      chem( 70) = chem( 70) +  0.1000000000000000D+00 * w(165)
      chem( 71) = chem( 71) +  0.9000000000000000D+00 * w(165)
      chem(109) = chem(109) - w(165)
      chem( 26) = chem( 26) - w(166)
      chem( 39) = chem( 39) + w(166)
      chem(109) = chem(109) - w(166)
      chem( 61) = chem( 61) - w(167)
      chem( 94) = chem( 94) +  0.5000000000000000D+00 * w(167)
      chem( 95) = chem( 95) +  0.5000000000000000D+00 * w(167)
      chem( 96) = chem( 96) +  0.5000000000000000D+00 * w(167)
      chem(101) = chem(101) +  0.5000000000000000D+00 * w(167)
      chem(109) = chem(109) - w(167)
      chem(111) = chem(111) +  0.5000000000000000D+00 * w(167)
      chem(113) = chem(113) +  0.5000000000000000D+00 * w(167)
      chem( 80) = chem( 80) - w(168)
      chem( 96) = chem( 96) +  0.6680000000000000D+00 * w(168)
      chem(101) = chem(101) + w(168)
      chem(107) = chem(107) +  0.3320000000000000D+00 * w(168)
      chem(108) = chem(108) +  0.3320000000000000D+00 * w(168)
      chem(109) = chem(109) - w(168)
      chem(111) = chem(111) + w(168)
      chem(113) = chem(113) + w(168)
      chem( 19) = chem( 19) - w(169)
      chem( 70) = chem( 70) +  0.9000000000000000D+00 * w(169)
      chem( 71) = chem( 71) +  0.1000000000000000D+00 * w(169)
      chem(109) = chem(109) - w(169)
      chem( 27) = chem( 27) - w(170)
      chem( 70) = chem( 70) +  0.8700000000000000D+00 * w(170)
      chem( 71) = chem( 71) +  0.1300000000000000D+00 * w(170)
      chem(109) = chem(109) - w(170)
      chem( 40) = chem( 40) - w(171)
      chem( 95) = chem( 95) + w(171)
      chem(109) = chem(109) - w(171)
      chem(110) = chem(110) + w(171)
      chem( 23) = chem( 23) - w(172)
      chem( 67) = chem( 67) +  0.3700000000000000D+00 * w(172)
      chem( 81) = chem( 81) - w(172)
      chem( 96) = chem( 96) +  0.4300000000000000D+00 * w(172)
      chem(108) = chem(108) + w(172)
      chem(111) = chem(111) +  0.2600000000000000D+00 * w(172)
      chem(112) = chem(112) +  0.1200000000000000D+00 * w(172)
      chem( 31) = chem( 31) - w(173)
      chem( 32) = chem( 32) +  0.6000000000000000D-01 * w(173)
      chem( 33) = chem( 33) +  0.3000000000000000D-01 * w(173)
      chem( 38) = chem( 38) +  0.6000000000000000D-02 * w(173)
      chem( 67) = chem( 67) +  0.1400000000000000D+00 * w(173)
      chem( 81) = chem( 81) - w(173)
      chem( 92) = chem( 92) +  0.3000000000000000D-01 * w(173)
      chem( 96) = chem( 96) +  0.3700000000000000D+00 * w(173)
      chem( 97) = chem( 97) +  0.1000000000000000D+00 * w(173)
      chem(100) = chem(100) +  0.1900000000000000D+00 * w(173)
      chem(103) = chem(103) +  0.3000000000000000D-01 * w(173)
      chem(104) = chem(104) +  0.1000000000000000D+00 * w(173)
      chem(107) = chem(107) +  0.4400000000000000D+00 * w(173)
      chem(108) = chem(108) +  0.6400000000000000D+00 * w(173)
      chem(111) = chem(111) +  0.2500000000000000D+00 * w(173)
      chem(112) = chem(112) +  0.4000000000000000D+00 * w(173)
      chem( 32) = chem( 32) +  0.7000000000000001D-01 * w(174)
      chem( 33) = chem( 33) +  0.6000000000000000D-01 * w(174)
      chem( 38) = chem( 38) +  0.1100000000000000D-01 * w(174)
      chem( 69) = chem( 69) - w(174)
      chem( 81) = chem( 81) - w(174)
      chem( 92) = chem( 92) +  0.1200000000000000D+00 * w(174)
      chem( 96) = chem( 96) +  0.3000000000000000D+00 * w(174)
      chem( 97) = chem( 97) +  0.1400000000000000D+00 * w(174)
      chem(100) = chem(100) +  0.2300000000000000D+00 * w(174)
      chem(103) = chem(103) +  0.1600000000000000D+00 * w(174)
      chem(104) = chem(104) +  0.1800000000000000D+00 * w(174)
      chem(107) = chem(107) +  0.9900000000000000D+00 * w(174)
      chem(108) = chem(108) +  0.2000000000000000D-01 * w(174)
      chem(111) = chem(111) +  0.2200000000000000D+00 * w(174)
      chem(112) = chem(112) +  0.6300000000000000D+00 * w(174)
      chem( 20) = chem( 20) - w(175)
      chem( 31) = chem( 31) +  0.3500000000000000D+00 * w(175)
      chem( 38) = chem( 38) +  0.1000000000000000D-02 * w(175)
      chem( 44) = chem( 44) +  0.9000000000000000D-01 * w(175)
      chem( 61) = chem( 61) +  0.3900000000000000D+00 * w(175)
      chem( 67) = chem( 67) +  0.1500000000000000D+00 * w(175)
      chem( 81) = chem( 81) - w(175)
      chem( 92) = chem( 92) +  0.2000000000000000D-01 * w(175)
      chem( 96) = chem( 96) +  0.3600000000000000D+00 * w(175)
      chem(100) = chem(100) +  0.3000000000000000D-01 * w(175)
      chem(101) = chem(101) +  0.1300000000000000D+00 * w(175)
      chem(105) = chem(105) +  0.1500000000000000D+00 * w(175)
      chem(108) = chem(108) +  0.9000000000000000D+00 * w(175)
      chem(111) = chem(111) +  0.3000000000000000D+00 * w(175)
      chem(112) = chem(112) +  0.2800000000000000D+00 * w(175)
      chem( 26) = chem( 26) - w(176)
      chem( 38) = chem( 38) +  0.9000000000000000D-01 * w(176)
      chem( 61) = chem( 61) +  0.4610000000000000D+00 * w(176)
      chem( 66) = chem( 66) +  0.1890000000000000D+00 * w(176)
      chem( 67) = chem( 67) +  0.2800000000000000D+00 * w(176)
      chem( 81) = chem( 81) - w(176)
      chem( 95) = chem( 95) +  0.1000000000000000D+00 * w(176)
      chem( 96) = chem( 96) +  0.1400000000000000D+00 * w(176)
      chem(100) = chem(100) +  0.8000000000000000D-01 * w(176)
      chem(105) = chem(105) +  0.1000000000000000D+00 * w(176)
      chem(108) = chem(108) +  0.5800000000000000D+00 * w(176)
      chem(111) = chem(111) +  0.2500000000000000D+00 * w(176)
      chem(112) = chem(112) +  0.2500000000000000D+00 * w(176)
      chem( 61) = chem( 61) - w(177)
      chem( 67) = chem( 67) +  0.4500000000000000D+00 * w(177)
      chem( 81) = chem( 81) - w(177)
      chem( 93) = chem( 93) +  0.9000000000000000D+00 * w(177)
      chem( 96) = chem( 96) +  0.2200000000000000D+00 * w(177)
      chem(105) = chem(105) +  0.1000000000000000D+00 * w(177)
      chem(111) = chem(111) +  0.3200000000000000D+00 * w(177)
      chem(112) = chem(112) +  0.1900000000000000D+00 * w(177)
      chem( 66) = chem( 66) - w(178)
      chem( 67) = chem( 67) +  0.6700000000000000D+00 * w(178)
      chem( 81) = chem( 81) - w(178)
      chem( 93) = chem( 93) +  0.9500000000000000D+00 * w(178)
      chem( 96) = chem( 96) +  0.1100000000000000D+00 * w(178)
      chem(101) = chem(101) +  0.5000000000000000D-01 * w(178)
      chem(105) = chem(105) +  0.5000000000000000D-01 * w(178)
      chem(108) = chem(108) +  0.1000000000000000D+00 * w(178)
      chem(111) = chem(111) +  0.1100000000000000D+00 * w(178)
      chem(112) = chem(112) +  0.1600000000000000D+00 * w(178)
      chem( 67) = chem( 67) +  0.4400000000000000D-01 * w(179)
      chem( 80) = chem( 80) - w(179)
      chem( 81) = chem( 81) - w(179)
      chem( 91) = chem( 91) +  0.3100000000000000D-01 * w(179)
      chem( 93) = chem( 93) +  0.6530000000000000D+00 * w(179)
      chem( 96) = chem( 96) +  0.2430000000000000D+00 * w(179)
      chem(100) = chem(100) +  0.1680000000000000D+00 * w(179)
      chem(101) = chem(101) +  0.1000000000000000D+00 * w(179)
      chem(103) = chem(103) +  0.2780000000000000D+00 * w(179)
      chem(105) = chem(105) +  0.2370000000000000D+00 * w(179)
      chem(107) = chem(107) +  0.6200000000000000D-01 * w(179)
      chem(108) = chem(108) +  0.2180000000000000D+00 * w(179)
      chem(111) = chem(111) +  0.7199999999999999D-01 * w(179)
      chem(112) = chem(112) +  0.4760000000000000D+00 * w(179)
      chem( 19) = chem( 19) - w(180)
      chem( 38) = chem( 38) +  0.2000000000000000D-01 * w(180)
      chem( 81) = chem( 81) - w(180)
      chem( 92) = chem( 92) +  0.4200000000000000D+00 * w(180)
      chem( 96) = chem( 96) +  0.1400000000000000D+00 * w(180)
      chem(103) = chem(103) +  0.5300000000000000D+00 * w(180)
      chem(104) = chem(104) +  0.2000000000000000D+00 * w(180)
      chem(107) = chem(107) +  0.6500000000000000D+00 * w(180)
      chem(111) = chem(111) +  0.1000000000000000D+00 * w(180)
      chem(112) = chem(112) +  0.8500000000000000D+00 * w(180)
      chem( 27) = chem( 27) - w(181)
      chem( 31) = chem( 31) +  0.4600000000000000D+00 * w(181)
      chem( 38) = chem( 38) +  0.2000000000000000D-01 * w(181)
      chem( 61) = chem( 61) +  0.7900000000000000D+00 * w(181)
      chem( 67) = chem( 67) +  0.1000000000000000D-01 * w(181)
      chem( 81) = chem( 81) - w(181)
      chem( 92) = chem( 92) +  0.4200000000000000D+00 * w(181)
      chem( 96) = chem( 96) +  0.1400000000000000D+00 * w(181)
      chem( 97) = chem( 97) +  0.7000000000000001D-01 * w(181)
      chem(104) = chem(104) +  0.1600000000000000D+00 * w(181)
      chem(108) = chem(108) +  0.4000000000000000D-01 * w(181)
      chem(111) = chem(111) +  0.1000000000000000D+00 * w(181)
      chem(112) = chem(112) +  0.8500000000000000D+00 * w(181)
      chem( 22) = chem( 22) - w(182)
      chem( 81) = chem( 81) - w(182)
      chem( 91) = chem( 91) + w(182)
      chem( 96) = chem( 96) +  0.1500000000000000D+01 * w(182)
      chem(111) = chem(111) +  0.1500000000000000D+01 * w(182)
      chem(112) = chem(112) +  0.5000000000000000D+00 * w(182)
      chem( 67) = chem( 67) +  0.2500000000000000D+00 * w(183)
      chem( 74) = chem( 74) +  0.1100000000000000D+00 * w(183)
      chem( 78) = chem( 78) - w(183)
      chem( 81) = chem( 81) - w(183)
      chem( 93) = chem( 93) +  0.2480000000000000D+01 * w(183)
      chem( 96) = chem( 96) +  0.1500000000000000D+01 * w(183)
      chem( 97) = chem( 97) +  0.2500000000000000D+00 * w(183)
      chem(111) = chem(111) + w(183)
      chem(112) = chem(112) +  0.5000000000000000D+00 * w(183)
      chem( 48) = chem( 48) - w(184)
      chem(110) = chem(110) - w(184)
      chem(113) = chem(113) + w(184)
      chem( 35) = chem( 35) + w(185)
      chem(105) = chem(105) - w(185)
      chem(110) = chem(110) - w(185)
      chem( 37) = chem( 37) + w(186)
      chem( 98) = chem( 98) - w(186)
      chem(110) = chem(110) - w(186)
      chem( 35) = chem( 35) - w(187)
      chem(105) = chem(105) + w(187)
      chem(110) = chem(110) + w(187)
      chem( 37) = chem( 37) - w(188)
      chem( 98) = chem( 98) + w(188)
      chem(110) = chem(110) + w(188)
      chem( 40) = chem( 40) + w(189)
      chem( 95) = chem( 95) - w(189)
      chem(110) = chem(110) - w(189)
      chem( 40) = chem( 40) - w(190)
      chem( 95) = chem( 95) + w(190)
      chem(110) = chem(110) + w(190)
      chem(100) = chem(100) - w(191)
      chem(102) = chem(102) - w(191)
      chem(108) = chem(108) + w(191)
      chem(110) = chem(110) + w(191)
      chem(111) = chem(111) + w(191)
      chem( 87) = chem( 87) + w(192)
      chem(102) = chem(102) - w(192)
      chem(104) = chem(104) - w(192)
      chem(110) = chem(110) + w(192)
      chem(111) = chem(111) + w(192)
      chem( 58) = chem( 58) +  0.6230000000000000D+00 * w(193)
      chem( 91) = chem( 91) +  0.6300000000000000D-01 * w(193)
      chem( 99) = chem( 99) - w(193)
      chem(100) = chem(100) +  0.1500000000000000D+00 * w(193)
      chem(101) = chem(101) +  0.4800000000000000D-01 * w(193)
      chem(102) = chem(102) - w(193)
      chem(104) = chem(104) +  0.4800000000000000D-01 * w(193)
      chem(107) = chem(107) +  0.2330000000000000D+00 * w(193)
      chem(108) = chem(108) +  0.4700000000000000D-01 * w(193)
      chem(110) = chem(110) +  0.9409999999999999D+00 * w(193)
      chem(111) = chem(111) +  0.7420000000000000D+00 * w(193)
      chem(113) = chem(113) +  0.5900000000000000D-01 * w(193)
      chem( 30) = chem( 30) +  0.1220000000000000D+00 * w(194)
      chem( 58) = chem( 58) +  0.1000000000000000D+00 * w(194)
      chem( 86) = chem( 86) - w(194)
      chem(100) = chem(100) +  0.3100000000000000D-01 * w(194)
      chem(101) = chem(101) +  0.3340000000000000D+00 * w(194)
      chem(102) = chem(102) - w(194)
      chem(103) = chem(103) +  0.5000000000000000D+00 * w(194)
      chem(104) = chem(104) +  0.2450000000000000D+00 * w(194)
      chem(107) = chem(107) +  0.2110000000000000D+00 * w(194)
      chem(108) = chem(108) +  0.2100000000000000D-01 * w(194)
      chem(110) = chem(110) +  0.8760000000000000D+00 * w(194)
      chem(111) = chem(111) +  0.5990000000000000D+00 * w(194)
      chem(113) = chem(113) +  0.1240000000000000D+00 * w(194)
      chem( 62) = chem( 62) - w(195)
      chem(101) = chem(101) +  0.4160000000000000D+00 * w(195)
      chem(102) = chem(102) - w(195)
      chem(103) = chem(103) +  0.6420000000000000D+00 * w(195)
      chem(104) = chem(104) +  0.1330000000000000D+00 * w(195)
      chem(107) = chem(107) +  0.1500000000000000D+00 * w(195)
      chem(110) = chem(110) +  0.7390000000000000D+00 * w(195)
      chem(111) = chem(111) +  0.6060000000000000D+00 * w(195)
      chem(113) = chem(113) +  0.2610000000000000D+00 * w(195)
      chem( 88) = chem( 88) - w(196)
      chem(102) = chem(102) - w(196)
      chem(107) = chem(107) +  0.2000000000000000D+00 * w(196)
      chem(108) = chem(108) +  0.1600000000000000D+01 * w(196)
      chem(110) = chem(110) + w(196)
      chem(111) = chem(111) + w(196)
      chem( 72) = chem( 72) - w(197)
      chem(102) = chem(102) - w(197)
      chem(103) = chem(103) +  0.6000000000000000D-01 * w(197)
      chem(107) = chem(107) +  0.9399999999999999D+00 * w(197)
      chem(108) = chem(108) + w(197)
      chem(110) = chem(110) + w(197)
      chem(111) = chem(111) + w(197)
      chem( 79) = chem( 79) - w(198)
      chem(102) = chem(102) - w(198)
      chem(103) = chem(103) +  0.2900000000000000D+00 * w(198)
      chem(107) = chem(107) +  0.1710000000000000D+01 * w(198)
      chem(110) = chem(110) + w(198)
      chem(111) = chem(111) + w(198)
      chem( 39) = chem( 39) +  0.4600000000000000D-01 * w(199)
      chem( 59) = chem( 59) - w(199)
      chem( 61) = chem( 61) +  0.4180000000000000D+00 * w(199)
      chem( 66) = chem( 66) +  0.5820000000000000D+00 * w(199)
      chem(102) = chem(102) - w(199)
      chem(108) = chem(108) + w(199)
      chem(110) = chem(110) +  0.9540000000000000D+00 * w(199)
      chem(111) = chem(111) +  0.9540000000000000D+00 * w(199)
      chem( 73) = chem( 73) +  0.2500000000000000D+00 * w(200)
      chem( 93) = chem( 93) +  0.5000000000000000D+00 * w(200)
      chem( 95) = chem( 95) - w(200)
      chem( 96) = chem( 96) +  0.2500000000000000D+00 * w(200)
      chem(102) = chem(102) - w(200)
      chem(105) = chem(105) +  0.2500000000000000D+00 * w(200)
      chem(108) = chem(108) +  0.7500000000000000D+00 * w(200)
      chem(110) = chem(110) + w(200)
      chem(111) = chem(111) +  0.7500000000000000D+00 * w(200)
      chem( 68) = chem( 68) - w(201)
      chem( 93) = chem( 93) +  0.3000000000000000D+00 * w(201)
      chem(101) = chem(101) +  0.7000000000000000D+00 * w(201)
      chem(102) = chem(102) - w(201)
      chem(105) = chem(105) +  0.7000000000000000D+00 * w(201)
      chem(107) = chem(107) +  0.7000000000000000D+00 * w(201)
      chem(108) = chem(108) +  0.3000000000000000D+00 * w(201)
      chem(110) = chem(110) + w(201)
      chem(111) = chem(111) +  0.3000000000000000D+00 * w(201)
      chem( 64) = chem( 64) - w(202)
      chem( 77) = chem( 77) +  0.6700000000000000D+00 * w(202)
      chem(102) = chem(102) - w(202)
      chem(108) = chem(108) +  0.3300000000000000D+00 * w(202)
      chem(110) = chem(110) + w(202)
      chem(111) = chem(111) +  0.6700000000000000D+00 * w(202)
      chem( 84) = chem( 84) - w(203)
      chem( 91) = chem( 91) +  0.1800000000000000D+00 * w(203)
      chem( 93) = chem( 93) +  0.2100000000000000D+00 * w(203)
      chem( 96) = chem( 96) +  0.6100000000000000D+00 * w(203)
      chem(102) = chem(102) - w(203)
      chem(103) = chem(103) +  0.7000000000000000D+00 * w(203)
      chem(107) = chem(107) +  0.2700000000000000D+00 * w(203)
      chem(108) = chem(108) +  0.3000000000000000D-01 * w(203)
      chem(110) = chem(110) + w(203)
      chem(111) = chem(111) + w(203)
      chem( 57) = chem( 57) - w(204)
      chem( 58) = chem( 58) +  0.1100000000000000D+00 * w(204)
      chem( 67) = chem( 67) +  0.7000000000000001D-01 * w(204)
      chem(102) = chem(102) - w(204)
      chem(103) = chem(103) +  0.4400000000000000D+00 * w(204)
      chem(107) = chem(107) +  0.4300000000000000D+00 * w(204)
      chem(108) = chem(108) +  0.2300000000000000D+00 * w(204)
      chem(110) = chem(110) +  0.8200000000000000D+00 * w(204)
      chem(111) = chem(111) +  0.8200000000000000D+00 * w(204)
      chem(113) = chem(113) +  0.1800000000000000D+00 * w(204)
      chem( 58) = chem( 58) +  0.3000000000000000D-01 * w(205)
      chem( 60) = chem( 60) - w(205)
      chem( 61) = chem( 61) +  0.2500000000000000D+00 * w(205)
      chem(102) = chem(102) - w(205)
      chem(103) = chem(103) +  0.2500000000000000D+00 * w(205)
      chem(110) = chem(110) +  0.9000000000000000D+00 * w(205)
      chem(111) = chem(111) +  0.9000000000000000D+00 * w(205)
      chem(113) = chem(113) +  0.1000000000000000D+00 * w(205)
      chem( 63) = chem( 63) - w(206)
      chem( 69) = chem( 69) +  0.4590000000000000D+00 * w(206)
      chem( 80) = chem( 80) +  0.4590000000000000D+00 * w(206)
      chem( 91) = chem( 91) +  0.9180000000000000D+00 * w(206)
      chem(102) = chem(102) - w(206)
      chem(110) = chem(110) +  0.9180000000000000D+00 * w(206)
      chem(111) = chem(111) +  0.9180000000000000D+00 * w(206)
      chem(113) = chem(113) +  0.8200000000000000D-01 * w(206)
      chem( 55) = chem( 55) - w(207)
      chem( 56) = chem( 56) +  0.7300000000000000D-01 * w(207)
      chem( 77) = chem( 77) +  0.7000000000000000D+00 * w(207)
      chem( 78) = chem( 78) +  0.1770000000000000D+00 * w(207)
      chem( 91) = chem( 91) +  0.3500000000000000D+00 * w(207)
      chem( 93) = chem( 93) +  0.6000000000000000D+00 * w(207)
      chem(102) = chem(102) - w(207)
      chem(110) = chem(110) +  0.9500000000000000D+00 * w(207)
      chem(111) = chem(111) +  0.9500000000000000D+00 * w(207)
      chem(113) = chem(113) +  0.5000000000000000D-01 * w(207)
      chem( 75) = chem( 75) - w(208)
      chem( 76) = chem( 76) +  0.3200000000000000D+00 * w(208)
      chem( 91) = chem( 91) +  0.6800000000000000D+00 * w(208)
      chem(102) = chem(102) - w(208)
      chem(106) = chem(106) +  0.6800000000000000D+00 * w(208)
      chem(110) = chem(110) + w(208)
      chem(111) = chem(111) + w(208)
      chem(100) = chem(100) + w(209)
      chem(102) = chem(102) - w(209)
      chem(105) = chem(105) - w(209)
      chem(110) = chem(110) + w(209)
      chem( 98) = chem( 98) - w(210)
      chem(102) = chem(102) - w(210)
      chem(104) = chem(104) + w(210)
      chem(110) = chem(110) + w(210)
      chem( 92) = chem( 92) - w(211)
      chem( 93) = chem( 93) +  0.5400000000000000D+00 * w(211)
      chem(101) = chem(101) +  0.1600000000000000D+00 * w(211)
      chem(102) = chem(102) - w(211)
      chem(105) = chem(105) +  0.2300000000000000D+00 * w(211)
      chem(107) = chem(107) +  0.4600000000000000D+00 * w(211)
      chem(110) = chem(110) + w(211)
      chem(111) = chem(111) +  0.7700000000000000D+00 * w(211)
      chem( 65) = chem( 65) - w(212)
      chem(102) = chem(102) - w(212)
      chem(105) = chem(105) + w(212)
      chem(108) = chem(108) + w(212)
      chem(110) = chem(110) + w(212)
      chem( 71) = chem( 71) - w(213)
      chem(102) = chem(102) - w(213)
      chem(110) = chem(110) + w(213)
      chem(111) = chem(111) + w(213)
      chem(113) = chem(113) + w(213)
      chem( 70) = chem( 70) - w(214)
      chem(102) = chem(102) - w(214)
      chem(103) = chem(103) +  0.4640000000000000D+00 * w(214)
      chem(107) = chem(107) +  0.1240000000000000D+01 * w(214)
      chem(108) = chem(108) +  0.2870000000000000D+00 * w(214)
      chem(110) = chem(110) +  0.2000000000000000D+01 * w(214)
      chem( 34) = chem( 34) + w(215)
      chem(100) = chem(100) - w(215)
      chem(111) = chem(111) - w(215)
      chem(104) = chem(104) - w(216)
      chem(106) = chem(106) + w(216)
      chem(111) = chem(111) - w(216)
      chem( 99) = chem( 99) - w(217)
      chem(106) = chem(106) + w(217)
      chem(111) = chem(111) - w(217)
      chem( 86) = chem( 86) - w(218)
      chem(106) = chem(106) + w(218)
      chem(111) = chem(111) - w(218)
      chem( 62) = chem( 62) - w(219)
      chem(106) = chem(106) + w(219)
      chem(111) = chem(111) - w(219)
      chem( 88) = chem( 88) - w(220)
      chem(106) = chem(106) + w(220)
      chem(111) = chem(111) - w(220)
      chem( 72) = chem( 72) - w(221)
      chem(106) = chem(106) + w(221)
      chem(111) = chem(111) - w(221)
      chem( 79) = chem( 79) - w(222)
      chem(106) = chem(106) + w(222)
      chem(111) = chem(111) - w(222)
      chem( 25) = chem( 25) + w(223)
      chem( 59) = chem( 59) - w(223)
      chem(111) = chem(111) - w(223)
      chem( 28) = chem( 28) + w(224)
      chem( 95) = chem( 95) - w(224)
      chem(111) = chem(111) - w(224)
      chem( 68) = chem( 68) - w(225)
      chem(106) = chem(106) + w(225)
      chem(111) = chem(111) - w(225)
      chem( 84) = chem( 84) - w(226)
      chem(106) = chem(106) + w(226)
      chem(111) = chem(111) - w(226)
      chem( 57) = chem( 57) - w(227)
      chem(106) = chem(106) + w(227)
      chem(111) = chem(111) - w(227)
      chem( 60) = chem( 60) - w(228)
      chem(106) = chem(106) + w(228)
      chem(111) = chem(111) - w(228)
      chem( 63) = chem( 63) - w(229)
      chem(106) = chem(106) + w(229)
      chem(111) = chem(111) - w(229)
      chem( 55) = chem( 55) - w(230)
      chem(106) = chem(106) + w(230)
      chem(111) = chem(111) - w(230)
      chem( 75) = chem( 75) - w(231)
      chem(106) = chem(106) + w(231)
      chem(111) = chem(111) - w(231)
      chem( 47) = chem( 47) + w(232)
      chem( 48) = chem( 48) - w(232)
      chem(111) = chem(111) - w(232)
      chem( 74) = chem( 74) +  0.4000000000000000D+00 * w(233)
      chem( 97) = chem( 97) +  0.2000000000000000D+00 * w(233)
      chem(100) = chem(100) +  0.4000000000000000D+00 * w(233)
      chem(105) = chem(105) - w(233)
      chem(111) = chem(111) - w(233)
      chem(112) = chem(112) +  0.4000000000000000D+00 * w(233)
      chem( 74) = chem( 74) +  0.4000000000000000D+00 * w(234)
      chem( 97) = chem( 97) +  0.2000000000000000D+00 * w(234)
      chem( 98) = chem( 98) - w(234)
      chem(104) = chem(104) +  0.4000000000000000D+00 * w(234)
      chem(111) = chem(111) - w(234)
      chem(112) = chem(112) +  0.4000000000000000D+00 * w(234)
      chem( 65) = chem( 65) - w(235)
      chem(105) = chem(105) +  0.6700000000000000D+00 * w(235)
      chem(106) = chem(106) +  0.3300000000000000D+00 * w(235)
      chem(108) = chem(108) +  0.6700000000000000D+00 * w(235)
      chem(111) = chem(111) - w(235)
      chem(112) = chem(112) +  0.6700000000000000D+00 * w(235)
      chem( 64) = chem( 64) - w(236)
      chem(106) = chem(106) + w(236)
      chem(111) = chem(111) - w(236)
      chem( 92) = chem( 92) - w(237)
      chem(106) = chem(106) + w(237)
      chem(111) = chem(111) - w(237)
      chem( 71) = chem( 71) - w(238)
      chem(111) = chem(111) - w(238)
      chem(113) = chem(113) + w(238)
      chem( 70) = chem( 70) - w(239)
      chem(111) = chem(111) - w(239)
      chem(113) = chem(113) + w(239)
      chem( 89) = chem( 89) +  0.6300000000000000D+00 * w(240)
      chem(100) = chem(100) -  0.2000000000000000D+01 * w(240)
      chem(108) = chem(108) +  0.1370000000000000D+01 * w(240)
      chem(111) = chem(111) +  0.7400000000000000D+00 * w(240)
      chem( 21) = chem( 21) +  0.2500000000000000D+00 * w(241)
      chem( 87) = chem( 87) +  0.7500000000000000D+00 * w(241)
      chem( 89) = chem( 89) +  0.2500000000000000D+00 * w(241)
      chem(100) = chem(100) - w(241)
      chem(104) = chem(104) - w(241)
      chem(108) = chem(108) +  0.7500000000000000D+00 * w(241)
      chem(111) = chem(111) + w(241)
      chem( 85) = chem( 85) +  0.2500000000000000D+00 * w(242)
      chem( 89) = chem( 89) +  0.2500000000000000D+00 * w(242)
      chem( 91) = chem( 91) +  0.5000000000000000D-01 * w(242)
      chem( 99) = chem( 99) - w(242)
      chem(100) = chem(100) -  0.9200000000000000D+00 * w(242)
      chem(101) = chem(101) +  0.2600000000000000D-01 * w(242)
      chem(103) = chem(103) +  0.4970000000000000D+00 * w(242)
      chem(104) = chem(104) +  0.2600000000000000D-01 * w(242)
      chem(107) = chem(107) +  0.1980000000000000D+00 * w(242)
      chem(108) = chem(108) +  0.8270000000000000D+00 * w(242)
      chem(111) = chem(111) +  0.8940000000000000D+00 * w(242)
      chem( 85) = chem( 85) +  0.2500000000000000D+00 * w(243)
      chem( 86) = chem( 86) - w(243)
      chem( 89) = chem( 89) +  0.2500000000000000D+00 * w(243)
      chem(100) = chem(100) -  0.9820000000000000D+00 * w(243)
      chem(101) = chem(101) +  0.1910000000000000D+00 * w(243)
      chem(103) = chem(103) +  0.6180000000000000D+00 * w(243)
      chem(104) = chem(104) +  0.1400000000000000D+00 * w(243)
      chem(107) = chem(107) +  0.2510000000000000D+00 * w(243)
      chem(108) = chem(108) +  0.7770000000000000D+00 * w(243)
      chem(111) = chem(111) +  0.8420000000000000D+00 * w(243)
      chem( 62) = chem( 62) - w(244)
      chem( 85) = chem( 85) +  0.2500000000000000D+00 * w(244)
      chem( 89) = chem( 89) +  0.2500000000000000D+00 * w(244)
      chem(100) = chem(100) - w(244)
      chem(101) = chem(101) +  0.2810000000000000D+00 * w(244)
      chem(103) = chem(103) +  0.6520000000000000D+00 * w(244)
      chem(104) = chem(104) +  0.9000000000000000D-01 * w(244)
      chem(107) = chem(107) +  0.1970000000000000D+00 * w(244)
      chem(108) = chem(108) +  0.7500000000000000D+00 * w(244)
      chem(111) = chem(111) +  0.9100000000000000D+00 * w(244)
      chem( 24) = chem( 24) +  0.2500000000000000D+00 * w(245)
      chem( 88) = chem( 88) - w(245)
      chem( 89) = chem( 89) +  0.2500000000000000D+00 * w(245)
      chem(100) = chem(100) - w(245)
      chem(107) = chem(107) +  0.1500000000000000D+00 * w(245)
      chem(108) = chem(108) +  0.1950000000000000D+01 * w(245)
      chem(111) = chem(111) + w(245)
      chem( 72) = chem( 72) - w(246)
      chem( 85) = chem( 85) +  0.2500000000000000D+00 * w(246)
      chem( 89) = chem( 89) +  0.2500000000000000D+00 * w(246)
      chem(100) = chem(100) - w(246)
      chem(103) = chem(103) +  0.4500000000000000D-01 * w(246)
      chem(107) = chem(107) +  0.7050000000000000D+00 * w(246)
      chem(108) = chem(108) +  0.1500000000000000D+01 * w(246)
      chem(111) = chem(111) + w(246)
      chem( 79) = chem( 79) - w(247)
      chem( 85) = chem( 85) +  0.2500000000000000D+00 * w(247)
      chem( 89) = chem( 89) +  0.2500000000000000D+00 * w(247)
      chem(100) = chem(100) - w(247)
      chem(103) = chem(103) +  0.2180000000000000D+00 * w(247)
      chem(107) = chem(107) +  0.1280000000000000D+01 * w(247)
      chem(108) = chem(108) +  0.7500000000000000D+00 * w(247)
      chem(111) = chem(111) + w(247)
      chem( 59) = chem( 59) - w(248)
      chem( 61) = chem( 61) +  0.2190000000000000D+00 * w(248)
      chem( 66) = chem( 66) +  0.3050000000000000D+00 * w(248)
      chem( 85) = chem( 85) +  0.2500000000000000D+00 * w(248)
      chem( 89) = chem( 89) +  0.2500000000000000D+00 * w(248)
      chem(100) = chem(100) - w(248)
      chem(108) = chem(108) +  0.1540000000000000D+01 * w(248)
      chem(111) = chem(111) + w(248)
      chem( 73) = chem( 73) +  0.1670000000000000D+00 * w(249)
      chem( 85) = chem( 85) +  0.2500000000000000D+00 * w(249)
      chem( 89) = chem( 89) +  0.2500000000000000D+00 * w(249)
      chem( 93) = chem( 93) +  0.3330000000000000D+00 * w(249)
      chem( 95) = chem( 95) - w(249)
      chem( 96) = chem( 96) +  0.1670000000000000D+00 * w(249)
      chem( 97) = chem( 97) +  0.4200000000000000D-01 * w(249)
      chem(100) = chem(100) - w(249)
      chem(105) = chem(105) +  0.1670000000000000D+00 * w(249)
      chem(108) = chem(108) +  0.1500000000000000D+01 * w(249)
      chem(111) = chem(111) + w(249)
      chem( 68) = chem( 68) - w(250)
      chem( 85) = chem( 85) +  0.2500000000000000D+00 * w(250)
      chem( 89) = chem( 89) +  0.2500000000000000D+00 * w(250)
      chem( 93) = chem( 93) +  0.5000000000000000D+00 * w(250)
      chem( 97) = chem( 97) +  0.2920000000000000D+00 * w(250)
      chem(100) = chem(100) - w(250)
      chem(101) = chem(101) +  0.1160000000000000D+01 * w(250)
      chem(105) = chem(105) +  0.1160000000000000D+01 * w(250)
      chem(107) = chem(107) +  0.1750000000000000D+01 * w(250)
      chem(108) = chem(108) +  0.1500000000000000D+01 * w(250)
      chem(111) = chem(111) + w(250)
      chem( 84) = chem( 84) - w(251)
      chem( 85) = chem( 85) +  0.2500000000000000D+00 * w(251)
      chem( 89) = chem( 89) +  0.2500000000000000D+00 * w(251)
      chem( 91) = chem( 91) +  0.1350000000000000D+00 * w(251)
      chem( 93) = chem( 93) +  0.1050000000000000D+00 * w(251)
      chem( 96) = chem( 96) +  0.3050000000000000D+00 * w(251)
      chem(100) = chem(100) - w(251)
      chem(103) = chem(103) +  0.5250000000000000D+00 * w(251)
      chem(107) = chem(107) +  0.2030000000000000D+00 * w(251)
      chem(108) = chem(108) +  0.7730000000000000D+00 * w(251)
      chem(111) = chem(111) + w(251)
      chem( 57) = chem( 57) - w(252)
      chem( 85) = chem( 85) +  0.2500000000000000D+00 * w(252)
      chem( 89) = chem( 89) +  0.2500000000000000D+00 * w(252)
      chem(100) = chem(100) - w(252)
      chem(103) = chem(103) +  0.7500000000000000D+00 * w(252)
      chem(107) = chem(107) +  0.7500000000000000D+00 * w(252)
      chem(108) = chem(108) +  0.7500000000000000D+00 * w(252)
      chem(111) = chem(111) + w(252)
      chem( 60) = chem( 60) - w(253)
      chem( 61) = chem( 61) +  0.3080000000000000D+00 * w(253)
      chem( 69) = chem( 69) +  0.1920000000000000D+00 * w(253)
      chem( 85) = chem( 85) +  0.2500000000000000D+00 * w(253)
      chem( 89) = chem( 89) +  0.2500000000000000D+00 * w(253)
      chem(100) = chem(100) - w(253)
      chem(108) = chem(108) +  0.1040000000000000D+01 * w(253)
      chem(111) = chem(111) + w(253)
      chem( 63) = chem( 63) - w(254)
      chem( 69) = chem( 69) +  0.3000000000000000D+00 * w(254)
      chem( 80) = chem( 80) +  0.7000000000000000D+00 * w(254)
      chem( 91) = chem( 91) +  0.6000000000000000D+00 * w(254)
      chem(100) = chem(100) - w(254)
      chem(108) = chem(108) + w(254)
      chem(111) = chem(111) +  0.2600000000000000D+01 * w(254)
      chem( 41) = chem( 41) - w(255)
      chem( 56) = chem( 56) + w(255)
      chem( 91) = chem( 91) +  0.2710000000000000D+00 * w(255)
      chem(100) = chem(100) - w(255)
      chem(108) = chem(108) + w(255)
      chem(111) = chem(111) +  0.2000000000000000D+01 * w(255)
      chem( 50) = chem( 50) - w(256)
      chem( 53) = chem( 53) + w(256)
      chem(100) = chem(100) - w(256)
      chem(108) = chem(108) + w(256)
      chem(111) = chem(111) + w(256)
      chem( 42) = chem( 42) - w(257)
      chem( 77) = chem( 77) + w(257)
      chem( 93) = chem( 93) + w(257)
      chem(100) = chem(100) - w(257)
      chem(108) = chem(108) + w(257)
      chem(111) = chem(111) +  0.2000000000000000D+01 * w(257)
      chem( 55) = chem( 55) - w(258)
      chem( 56) = chem( 56) +  0.7700000000000000D-01 * w(258)
      chem( 77) = chem( 77) +  0.7370000000000000D+00 * w(258)
      chem( 78) = chem( 78) +  0.1860000000000000D+00 * w(258)
      chem( 91) = chem( 91) +  0.3680000000000000D+00 * w(258)
      chem( 93) = chem( 93) +  0.6320000000000000D+00 * w(258)
      chem(100) = chem(100) - w(258)
      chem(108) = chem(108) + w(258)
      chem(111) = chem(111) +  0.2000000000000000D+01 * w(258)
      chem( 52) = chem( 52) - w(259)
      chem( 53) = chem( 53) + w(259)
      chem(100) = chem(100) - w(259)
      chem(108) = chem(108) + w(259)
      chem(111) = chem(111) + w(259)
      chem( 43) = chem( 43) - w(260)
      chem( 56) = chem( 56) + w(260)
      chem(100) = chem(100) - w(260)
      chem(108) = chem(108) + w(260)
      chem(111) = chem(111) +  0.2000000000000000D+01 * w(260)
      chem( 49) = chem( 49) - w(261)
      chem( 77) = chem( 77) + w(261)
      chem( 78) = chem( 78) +  0.2050000000000000D+01 * w(261)
      chem( 93) = chem( 93) + w(261)
      chem(100) = chem(100) - w(261)
      chem(108) = chem(108) + w(261)
      chem(111) = chem(111) +  0.2000000000000000D+01 * w(261)
      chem( 45) = chem( 45) + w(262)
      chem( 54) = chem( 54) - w(262)
      chem(100) = chem(100) - w(262)
      chem(108) = chem(108) + w(262)
      chem(111) = chem(111) + w(262)
      chem( 45) = chem( 45) - w(263)
      chem( 46) = chem( 46) + w(263)
      chem(100) = chem(100) - w(263)
      chem(108) = chem(108) + w(263)
      chem(111) = chem(111) + w(263)
      chem( 75) = chem( 75) - w(264)
      chem( 76) = chem( 76) +  0.3200000000000000D+00 * w(264)
      chem( 91) = chem( 91) +  0.6800000000000000D+00 * w(264)
      chem(100) = chem(100) - w(264)
      chem(106) = chem(106) +  0.6800000000000000D+00 * w(264)
      chem(108) = chem(108) + w(264)
      chem(111) = chem(111) +  0.2000000000000000D+01 * w(264)
      chem( 97) = chem( 97) +  0.1000000000000000D+00 * w(265)
      chem(100) = chem(100) -  0.9999999999999998D-01 * w(265)
      chem(105) = chem(105) - w(265)
      chem(108) = chem(108) + w(265)
      chem(111) = chem(111) +  0.9000000000000000D+00 * w(265)
      chem( 97) = chem( 97) +  0.1000000000000000D+00 * w(266)
      chem( 98) = chem( 98) - w(266)
      chem(100) = chem(100) -  0.9999999999999998D-01 * w(266)
      chem(108) = chem(108) + w(266)
      chem(111) = chem(111) +  0.9000000000000000D+00 * w(266)
      chem( 65) = chem( 65) - w(267)
      chem( 85) = chem( 85) +  0.2500000000000000D+00 * w(267)
      chem( 89) = chem( 89) +  0.2500000000000000D+00 * w(267)
      chem( 97) = chem( 97) +  0.1250000000000000D+00 * w(267)
      chem(100) = chem(100) - w(267)
      chem(105) = chem(105) +  0.5000000000000000D+00 * w(267)
      chem(108) = chem(108) +  0.1500000000000000D+01 * w(267)
      chem(111) = chem(111) +  0.5000000000000000D+00 * w(267)
      chem( 64) = chem( 64) - w(268)
      chem( 77) = chem( 77) +  0.3340000000000000D+00 * w(268)
      chem( 85) = chem( 85) +  0.2500000000000000D+00 * w(268)
      chem( 89) = chem( 89) +  0.2500000000000000D+00 * w(268)
      chem(100) = chem(100) - w(268)
      chem(108) = chem(108) + w(268)
      chem(111) = chem(111) +  0.8340000000000000D+00 * w(268)
      chem( 77) = chem( 77) +  0.5000000000000000D+00 * w(269)
      chem( 85) = chem( 85) +  0.2500000000000000D+00 * w(269)
      chem( 89) = chem( 89) +  0.2500000000000000D+00 * w(269)
      chem( 92) = chem( 92) - w(269)
      chem(100) = chem(100) - w(269)
      chem(108) = chem(108) +  0.7500000000000000D+00 * w(269)
      chem(111) = chem(111) + w(269)
      chem( 71) = chem( 71) - w(270)
      chem(100) = chem(100) - w(270)
      chem(108) = chem(108) + w(270)
      chem(111) = chem(111) +  0.2000000000000000D+01 * w(270)
      chem(113) = chem(113) + w(270)
      chem( 70) = chem( 70) - w(271)
      chem( 85) = chem( 85) +  0.2500000000000000D+00 * w(271)
      chem( 89) = chem( 89) +  0.2500000000000000D+00 * w(271)
      chem(100) = chem(100) - w(271)
      chem(103) = chem(103) +  0.3480000000000000D+00 * w(271)
      chem(107) = chem(107) +  0.9300000000000000D+00 * w(271)
      chem(108) = chem(108) +  0.9650000000000000D+00 * w(271)
      chem(110) = chem(110) +  0.5000000000000000D+00 * w(271)
      chem(111) = chem(111) +  0.5000000000000000D+00 * w(271)
      chem(113) = chem(113) +  0.5000000000000000D+00 * w(271)
      chem( 87) = chem( 87) + w(272)
      chem( 97) = chem( 97) +  0.5000000000000000D+00 * w(272)
      chem(100) = chem(100) +  0.5000000000000000D+00 * w(272)
      chem(104) = chem(104) - w(272)
      chem(105) = chem(105) - w(272)
      chem(111) = chem(111) +  0.5000000000000000D+00 * w(272)
      chem( 91) = chem( 91) +  0.6700000000000000D-01 * w(273)
      chem( 97) = chem( 97) +  0.5000000000000000D+00 * w(273)
      chem( 99) = chem( 99) - w(273)
      chem(100) = chem(100) +  0.5800000000000000D+00 * w(273)
      chem(101) = chem(101) +  0.2600000000000000D-01 * w(273)
      chem(103) = chem(103) +  0.6620000000000000D+00 * w(273)
      chem(104) = chem(104) +  0.2600000000000000D-01 * w(273)
      chem(105) = chem(105) - w(273)
      chem(107) = chem(107) +  0.2730000000000000D+00 * w(273)
      chem(108) = chem(108) +  0.1300000000000000D+00 * w(273)
      chem(111) = chem(111) +  0.3940000000000000D+00 * w(273)
      chem( 86) = chem( 86) - w(274)
      chem( 97) = chem( 97) +  0.5000000000000000D+00 * w(274)
      chem(100) = chem(100) +  0.5180000000000000D+00 * w(274)
      chem(101) = chem(101) +  0.1910000000000000D+00 * w(274)
      chem(103) = chem(103) +  0.8240000000000000D+00 * w(274)
      chem(104) = chem(104) +  0.1400000000000000D+00 * w(274)
      chem(105) = chem(105) - w(274)
      chem(107) = chem(107) +  0.3810000000000000D+00 * w(274)
      chem(108) = chem(108) +  0.4200000000000000D-01 * w(274)
      chem(111) = chem(111) +  0.3420000000000000D+00 * w(274)
      chem( 62) = chem( 62) - w(275)
      chem( 97) = chem( 97) +  0.4950000000000000D+00 * w(275)
      chem(100) = chem(100) +  0.5000000000000000D+00 * w(275)
      chem(101) = chem(101) +  0.2080000000000000D+00 * w(275)
      chem(103) = chem(103) +  0.6420000000000000D+00 * w(275)
      chem(104) = chem(104) +  0.6700000000000000D-01 * w(275)
      chem(105) = chem(105) - w(275)
      chem(107) = chem(107) +  0.2170000000000000D+00 * w(275)
      chem(111) = chem(111) +  0.3030000000000000D+00 * w(275)
      chem( 88) = chem( 88) - w(276)
      chem( 97) = chem( 97) +  0.5000000000000000D+00 * w(276)
      chem(100) = chem(100) +  0.5000000000000000D+00 * w(276)
      chem(105) = chem(105) - w(276)
      chem(107) = chem(107) +  0.2000000000000000D+00 * w(276)
      chem(108) = chem(108) +  0.1600000000000000D+01 * w(276)
      chem(111) = chem(111) +  0.5000000000000000D+00 * w(276)
      chem( 72) = chem( 72) - w(277)
      chem( 97) = chem( 97) +  0.5000000000000000D+00 * w(277)
      chem(100) = chem(100) +  0.5000000000000000D+00 * w(277)
      chem(103) = chem(103) +  0.6000000000000000D-01 * w(277)
      chem(105) = chem(105) - w(277)
      chem(107) = chem(107) +  0.9399999999999999D+00 * w(277)
      chem(108) = chem(108) + w(277)
      chem(111) = chem(111) +  0.5000000000000000D+00 * w(277)
      chem( 79) = chem( 79) - w(278)
      chem( 97) = chem( 97) +  0.5000000000000000D+00 * w(278)
      chem(100) = chem(100) +  0.5000000000000000D+00 * w(278)
      chem(103) = chem(103) +  0.2900000000000000D+00 * w(278)
      chem(105) = chem(105) - w(278)
      chem(107) = chem(107) +  0.1710000000000000D+01 * w(278)
      chem(111) = chem(111) +  0.5000000000000000D+00 * w(278)
      chem( 59) = chem( 59) - w(279)
      chem( 61) = chem( 61) +  0.2190000000000000D+00 * w(279)
      chem( 66) = chem( 66) +  0.3050000000000000D+00 * w(279)
      chem( 97) = chem( 97) +  0.5000000000000000D+00 * w(279)
      chem(100) = chem(100) +  0.5000000000000000D+00 * w(279)
      chem(105) = chem(105) - w(279)
      chem(108) = chem(108) +  0.1048000000000000D+01 * w(279)
      chem(111) = chem(111) +  0.5000000000000000D+00 * w(279)
      chem( 73) = chem( 73) +  0.1670000000000000D+00 * w(280)
      chem( 93) = chem( 93) +  0.3300000000000000D+00 * w(280)
      chem( 95) = chem( 95) - w(280)
      chem( 96) = chem( 96) +  0.1670000000000000D+00 * w(280)
      chem( 97) = chem( 97) +  0.5830000000000000D+00 * w(280)
      chem(100) = chem(100) +  0.5000000000000000D+00 * w(280)
      chem(105) = chem(105) -  0.8330000000000000D+00 * w(280)
      chem(108) = chem(108) + w(280)
      chem(111) = chem(111) +  0.5000000000000000D+00 * w(280)
      chem( 68) = chem( 68) - w(281)
      chem( 93) = chem( 93) +  0.5000000000000000D+00 * w(281)
      chem( 97) = chem( 97) +  0.1083000000000000D+01 * w(281)
      chem(100) = chem(100) +  0.5000000000000000D+00 * w(281)
      chem(101) = chem(101) +  0.1160000000000000D+01 * w(281)
      chem(105) = chem(105) +  0.1599999999999999D+00 * w(281)
      chem(107) = chem(107) +  0.2300000000000000D+01 * w(281)
      chem(108) = chem(108) + w(281)
      chem(111) = chem(111) +  0.5000000000000000D+00 * w(281)
      chem( 84) = chem( 84) - w(282)
      chem( 91) = chem( 91) +  0.1800000000000000D+00 * w(282)
      chem( 93) = chem( 93) +  0.1050000000000000D+00 * w(282)
      chem( 96) = chem( 96) +  0.5000000000000000D+00 * w(282)
      chem( 97) = chem( 97) +  0.5000000000000000D+00 * w(282)
      chem(100) = chem(100) +  0.5000000000000000D+00 * w(282)
      chem(103) = chem(103) +  0.7000000000000000D+00 * w(282)
      chem(105) = chem(105) - w(282)
      chem(107) = chem(107) +  0.2700000000000000D+00 * w(282)
      chem(108) = chem(108) +  0.3000000000000000D-01 * w(282)
      chem(111) = chem(111) +  0.5000000000000000D+00 * w(282)
      chem( 57) = chem( 57) - w(283)
      chem( 97) = chem( 97) + w(283)
      chem(100) = chem(100) +  0.5000000000000000D+00 * w(283)
      chem(103) = chem(103) + w(283)
      chem(105) = chem(105) - w(283)
      chem(107) = chem(107) + w(283)
      chem(111) = chem(111) +  0.5000000000000000D+00 * w(283)
      chem( 60) = chem( 60) - w(284)
      chem( 61) = chem( 61) +  0.3080000000000000D+00 * w(284)
      chem( 69) = chem( 69) +  0.1920000000000000D+00 * w(284)
      chem( 97) = chem( 97) +  0.5000000000000000D+00 * w(284)
      chem(100) = chem(100) +  0.5000000000000000D+00 * w(284)
      chem(105) = chem(105) - w(284)
      chem(108) = chem(108) +  0.3850000000000000D+00 * w(284)
      chem(111) = chem(111) +  0.5000000000000000D+00 * w(284)
      chem( 63) = chem( 63) - w(285)
      chem( 69) = chem( 69) +  0.3000000000000000D+00 * w(285)
      chem( 80) = chem( 80) +  0.7000000000000000D+00 * w(285)
      chem( 91) = chem( 91) +  0.6000000000000000D+00 * w(285)
      chem(100) = chem(100) + w(285)
      chem(105) = chem(105) - w(285)
      chem(111) = chem(111) +  0.6000000000000000D+00 * w(285)
      chem( 41) = chem( 41) - w(286)
      chem( 56) = chem( 56) + w(286)
      chem(100) = chem(100) + w(286)
      chem(105) = chem(105) - w(286)
      chem(111) = chem(111) + w(286)
      chem( 50) = chem( 50) - w(287)
      chem( 53) = chem( 53) + w(287)
      chem(100) = chem(100) + w(287)
      chem(105) = chem(105) - w(287)
      chem( 42) = chem( 42) - w(288)
      chem( 77) = chem( 77) + w(288)
      chem( 93) = chem( 93) + w(288)
      chem(100) = chem(100) + w(288)
      chem(105) = chem(105) - w(288)
      chem(111) = chem(111) + w(288)
      chem( 49) = chem( 49) - w(289)
      chem( 77) = chem( 77) + w(289)
      chem( 78) = chem( 78) +  0.2050000000000000D+01 * w(289)
      chem( 93) = chem( 93) + w(289)
      chem(100) = chem(100) + w(289)
      chem(105) = chem(105) - w(289)
      chem(111) = chem(111) + w(289)
      chem( 45) = chem( 45) + w(290)
      chem( 54) = chem( 54) - w(290)
      chem(100) = chem(100) + w(290)
      chem(105) = chem(105) - w(290)
      chem( 45) = chem( 45) - w(291)
      chem( 46) = chem( 46) + w(291)
      chem(100) = chem(100) + w(291)
      chem(105) = chem(105) - w(291)
      chem( 55) = chem( 55) - w(292)
      chem( 56) = chem( 56) +  0.7700000000000000D-01 * w(292)
      chem( 77) = chem( 77) +  0.7370000000000000D+00 * w(292)
      chem( 78) = chem( 78) +  0.1860000000000000D+00 * w(292)
      chem( 91) = chem( 91) +  0.3680000000000000D+00 * w(292)
      chem( 93) = chem( 93) +  0.6320000000000000D+00 * w(292)
      chem(100) = chem(100) + w(292)
      chem(105) = chem(105) - w(292)
      chem(111) = chem(111) + w(292)
      chem( 52) = chem( 52) - w(293)
      chem( 53) = chem( 53) + w(293)
      chem(100) = chem(100) + w(293)
      chem(105) = chem(105) - w(293)
      chem( 43) = chem( 43) - w(294)
      chem( 56) = chem( 56) + w(294)
      chem(100) = chem(100) + w(294)
      chem(105) = chem(105) - w(294)
      chem(111) = chem(111) + w(294)
      chem( 75) = chem( 75) - w(295)
      chem( 76) = chem( 76) +  0.3200000000000000D+00 * w(295)
      chem( 91) = chem( 91) +  0.6800000000000000D+00 * w(295)
      chem(100) = chem(100) + w(295)
      chem(105) = chem(105) - w(295)
      chem(106) = chem(106) +  0.6800000000000000D+00 * w(295)
      chem(111) = chem(111) +  0.2000000000000000D+01 * w(295)
      chem(100) = chem(100) +  0.2000000000000000D+01 * w(296)
      chem(105) = chem(105) -  0.2000000000000000D+01 * w(296)
      chem( 98) = chem( 98) -  0.2000000000000000D+01 * w(297)
      chem(104) = chem(104) +  0.2000000000000000D+01 * w(297)
      chem( 77) = chem( 77) +  0.5000000000000000D+00 * w(298)
      chem( 92) = chem( 92) - w(298)
      chem( 97) = chem( 97) +  0.5000000000000000D+00 * w(298)
      chem(100) = chem(100) +  0.5000000000000000D+00 * w(298)
      chem(105) = chem(105) - w(298)
      chem(111) = chem(111) +  0.5000000000000000D+00 * w(298)
      chem( 65) = chem( 65) - w(299)
      chem( 97) = chem( 97) +  0.7500000000000000D+00 * w(299)
      chem(100) = chem(100) +  0.5000000000000000D+00 * w(299)
      chem(105) = chem(105) -  0.5000000000000000D+00 * w(299)
      chem(108) = chem(108) + w(299)
      chem( 64) = chem( 64) - w(300)
      chem( 77) = chem( 77) +  0.3340000000000000D+00 * w(300)
      chem( 97) = chem( 97) +  0.5000000000000000D+00 * w(300)
      chem(100) = chem(100) +  0.5000000000000000D+00 * w(300)
      chem(105) = chem(105) - w(300)
      chem(108) = chem(108) +  0.3300000000000000D+00 * w(300)
      chem(111) = chem(111) +  0.3300000000000000D+00 * w(300)
      chem( 71) = chem( 71) - w(301)
      chem(100) = chem(100) + w(301)
      chem(105) = chem(105) - w(301)
      chem(111) = chem(111) + w(301)
      chem(113) = chem(113) + w(301)
      chem( 70) = chem( 70) - w(302)
      chem( 97) = chem( 97) +  0.5000000000000000D+00 * w(302)
      chem(100) = chem(100) +  0.5000000000000000D+00 * w(302)
      chem(103) = chem(103) +  0.4640000000000000D+00 * w(302)
      chem(105) = chem(105) - w(302)
      chem(107) = chem(107) +  0.1240000000000000D+01 * w(302)
      chem(108) = chem(108) +  0.2870000000000000D+00 * w(302)
      chem(110) = chem(110) + w(302)
      chem( 71) = chem( 71) -  0.2000000000000000D+01 * w(303)
      chem(111) = chem(111) + w(303)
      chem(113) = chem(113) +  0.2000000000000000D+01 * w(303)
      chem( 70) = chem( 70) - w(304)
      chem( 71) = chem( 71) - w(304)
      chem(103) = chem(103) +  0.1490000000000000D+00 * w(304)
      chem(107) = chem(107) +  0.6400000000000000D+00 * w(304)
      chem(108) = chem(108) +  0.2020000000000000D+00 * w(304)
      chem(110) = chem(110) +  0.5000000000000000D+00 * w(304)
      chem(111) = chem(111) +  0.5000000000000000D+00 * w(304)
      chem(113) = chem(113) +  0.1500000000000000D+01 * w(304)
      chem( 70) = chem( 70) -  0.2000000000000000D+01 * w(305)
      chem(103) = chem(103) +  0.2850000000000000D+00 * w(305)
      chem(107) = chem(107) +  0.1210000000000000D+01 * w(305)
      chem(108) = chem(108) +  0.5040000000000000D+00 * w(305)
      chem(110) = chem(110) + w(305)
      chem(113) = chem(113) + w(305)
      chem(100) = chem(100) - w(306)
      chem(108) = chem(108) + w(306)
      chem(109) = chem(109) - w(306)
      chem(110) = chem(110) + w(306)
      chem(111) = chem(111) + w(306)
      chem( 87) = chem( 87) + w(307)
      chem(104) = chem(104) - w(307)
      chem(109) = chem(109) - w(307)
      chem(110) = chem(110) + w(307)
      chem(111) = chem(111) + w(307)
      chem( 91) = chem( 91) +  0.6700000000000000D-01 * w(308)
      chem( 99) = chem( 99) - w(308)
      chem(100) = chem(100) +  0.1590000000000000D+00 * w(308)
      chem(101) = chem(101) +  0.5100000000000000D-01 * w(308)
      chem(103) = chem(103) +  0.6620000000000000D+00 * w(308)
      chem(104) = chem(104) +  0.5100000000000000D-01 * w(308)
      chem(107) = chem(107) +  0.2480000000000000D+00 * w(308)
      chem(108) = chem(108) +  0.5000000000000000D-01 * w(308)
      chem(109) = chem(109) - w(308)
      chem(110) = chem(110) + w(308)
      chem(111) = chem(111) +  0.7890000000000000D+00 * w(308)
      chem( 86) = chem( 86) - w(309)
      chem(100) = chem(100) +  0.3500000000000000D-01 * w(309)
      chem(101) = chem(101) +  0.3810000000000000D+00 * w(309)
      chem(103) = chem(103) +  0.8240000000000000D+00 * w(309)
      chem(104) = chem(104) +  0.2800000000000000D+00 * w(309)
      chem(107) = chem(107) +  0.2410000000000000D+00 * w(309)
      chem(108) = chem(108) +  0.2400000000000000D-01 * w(309)
      chem(109) = chem(109) - w(309)
      chem(110) = chem(110) + w(309)
      chem(111) = chem(111) +  0.6840000000000001D+00 * w(309)
      chem( 62) = chem( 62) - w(310)
      chem(101) = chem(101) +  0.5629999999999999D+00 * w(310)
      chem(103) = chem(103) +  0.8690000000000000D+00 * w(310)
      chem(104) = chem(104) +  0.1800000000000000D+00 * w(310)
      chem(107) = chem(107) +  0.2030000000000000D+00 * w(310)
      chem(109) = chem(109) - w(310)
      chem(110) = chem(110) + w(310)
      chem(111) = chem(111) +  0.8200000000000000D+00 * w(310)
      chem( 88) = chem( 88) - w(311)
      chem(107) = chem(107) +  0.2000000000000000D+00 * w(311)
      chem(108) = chem(108) +  0.1600000000000000D+01 * w(311)
      chem(109) = chem(109) - w(311)
      chem(110) = chem(110) + w(311)
      chem(111) = chem(111) + w(311)
      chem( 72) = chem( 72) - w(312)
      chem(103) = chem(103) +  0.6000000000000000D-01 * w(312)
      chem(107) = chem(107) +  0.9399999999999999D+00 * w(312)
      chem(108) = chem(108) + w(312)
      chem(109) = chem(109) - w(312)
      chem(110) = chem(110) + w(312)
      chem(111) = chem(111) + w(312)
      chem( 79) = chem( 79) - w(313)
      chem(103) = chem(103) +  0.2900000000000000D+00 * w(313)
      chem(107) = chem(107) +  0.1710000000000000D+01 * w(313)
      chem(109) = chem(109) - w(313)
      chem(110) = chem(110) + w(313)
      chem(111) = chem(111) + w(313)
      chem( 59) = chem( 59) - w(314)
      chem( 61) = chem( 61) +  0.4380000000000000D+00 * w(314)
      chem( 66) = chem( 66) +  0.6100000000000000D+00 * w(314)
      chem(108) = chem(108) +  0.1050000000000000D+01 * w(314)
      chem(109) = chem(109) - w(314)
      chem(110) = chem(110) + w(314)
      chem(111) = chem(111) + w(314)
      chem( 57) = chem( 57) - w(315)
      chem(103) = chem(103) + w(315)
      chem(107) = chem(107) + w(315)
      chem(109) = chem(109) - w(315)
      chem(110) = chem(110) + w(315)
      chem(111) = chem(111) + w(315)
      chem( 60) = chem( 60) - w(316)
      chem( 61) = chem( 61) +  0.6150000000000000D+00 * w(316)
      chem( 69) = chem( 69) +  0.3850000000000000D+00 * w(316)
      chem(108) = chem(108) +  0.3850000000000000D+00 * w(316)
      chem(109) = chem(109) - w(316)
      chem(110) = chem(110) + w(316)
      chem(111) = chem(111) + w(316)
      chem( 63) = chem( 63) - w(317)
      chem( 69) = chem( 69) +  0.5000000000000000D+00 * w(317)
      chem( 80) = chem( 80) +  0.5000000000000000D+00 * w(317)
      chem( 91) = chem( 91) + w(317)
      chem(109) = chem(109) - w(317)
      chem(110) = chem(110) + w(317)
      chem(111) = chem(111) + w(317)
      chem( 55) = chem( 55) - w(318)
      chem( 56) = chem( 56) +  0.7700000000000000D-01 * w(318)
      chem( 77) = chem( 77) +  0.7370000000000000D+00 * w(318)
      chem( 78) = chem( 78) +  0.1860000000000000D+00 * w(318)
      chem( 91) = chem( 91) +  0.3680000000000000D+00 * w(318)
      chem( 93) = chem( 93) +  0.6320000000000000D+00 * w(318)
      chem(109) = chem(109) - w(318)
      chem(110) = chem(110) + w(318)
      chem(111) = chem(111) + w(318)
      chem( 75) = chem( 75) - w(319)
      chem( 76) = chem( 76) +  0.3200000000000000D+00 * w(319)
      chem( 91) = chem( 91) +  0.6800000000000000D+00 * w(319)
      chem(106) = chem(106) +  0.6800000000000000D+00 * w(319)
      chem(109) = chem(109) - w(319)
      chem(110) = chem(110) + w(319)
      chem(111) = chem(111) + w(319)
      chem(100) = chem(100) + w(320)
      chem(105) = chem(105) - w(320)
      chem(109) = chem(109) - w(320)
      chem(110) = chem(110) + w(320)
      chem( 98) = chem( 98) - w(321)
      chem(104) = chem(104) + w(321)
      chem(109) = chem(109) - w(321)
      chem(110) = chem(110) + w(321)
      chem( 64) = chem( 64) - w(322)
      chem( 77) = chem( 77) +  0.6700000000000000D+00 * w(322)
      chem(108) = chem(108) +  0.3300000000000000D+00 * w(322)
      chem(109) = chem(109) - w(322)
      chem(110) = chem(110) + w(322)
      chem(111) = chem(111) +  0.6700000000000000D+00 * w(322)
      chem( 77) = chem( 77) + w(323)
      chem( 92) = chem( 92) - w(323)
      chem(109) = chem(109) - w(323)
      chem(110) = chem(110) + w(323)
      chem(111) = chem(111) + w(323)
      chem( 65) = chem( 65) - w(324)
      chem(105) = chem(105) + w(324)
      chem(108) = chem(108) + w(324)
      chem(109) = chem(109) - w(324)
      chem(110) = chem(110) + w(324)
      chem( 71) = chem( 71) - w(325)
      chem(109) = chem(109) - w(325)
      chem(110) = chem(110) + w(325)
      chem(111) = chem(111) + w(325)
      chem(113) = chem(113) + w(325)
      chem( 70) = chem( 70) - w(326)
      chem(103) = chem(103) +  0.4640000000000000D+00 * w(326)
      chem(107) = chem(107) +  0.1240000000000000D+01 * w(326)
      chem(108) = chem(108) +  0.2870000000000000D+00 * w(326)
      chem(109) = chem(109) - w(326)
      chem(110) = chem(110) +  0.2000000000000000D+01 * w(326)
      chem( 68) = chem( 68) - w(327)
      chem( 93) = chem( 93) + w(327)
      chem(101) = chem(101) +  0.2300000000000000D+01 * w(327)
      chem(105) = chem(105) +  0.2300000000000000D+01 * w(327)
      chem(107) = chem(107) +  0.7000000000000000D+00 * w(327)
      chem(108) = chem(108) +  0.3000000000000000D+00 * w(327)
      chem(109) = chem(109) - w(327)
      chem(110) = chem(110) + w(327)
      chem(111) = chem(111) + w(327)
      chem( 73) = chem( 73) +  0.3300000000000000D+00 * w(328)
      chem( 93) = chem( 93) +  0.6670000000000000D+00 * w(328)
      chem( 95) = chem( 95) - w(328)
      chem( 96) = chem( 96) +  0.3300000000000000D+00 * w(328)
      chem(105) = chem(105) +  0.3300000000000000D+00 * w(328)
      chem(108) = chem(108) + w(328)
      chem(109) = chem(109) - w(328)
      chem(110) = chem(110) + w(328)
      chem(111) = chem(111) + w(328)
      chem( 50) = chem( 50) - w(329)
      chem( 53) = chem( 53) + w(329)
      chem(109) = chem(109) - w(329)
      chem(110) = chem(110) + w(329)
      chem( 41) = chem( 41) - w(330)
      chem( 56) = chem( 56) + w(330)
      chem(109) = chem(109) - w(330)
      chem(110) = chem(110) + w(330)
      chem(111) = chem(111) + w(330)
      chem( 42) = chem( 42) - w(331)
      chem( 77) = chem( 77) + w(331)
      chem( 93) = chem( 93) + w(331)
      chem(109) = chem(109) - w(331)
      chem(110) = chem(110) + w(331)
      chem(111) = chem(111) + w(331)
      chem( 52) = chem( 52) - w(332)
      chem( 53) = chem( 53) + w(332)
      chem(109) = chem(109) - w(332)
      chem(110) = chem(110) + w(332)
      chem( 43) = chem( 43) - w(333)
      chem( 56) = chem( 56) + w(333)
      chem(109) = chem(109) - w(333)
      chem(110) = chem(110) + w(333)
      chem(111) = chem(111) + w(333)
      chem( 49) = chem( 49) - w(334)
      chem( 77) = chem( 77) + w(334)
      chem( 78) = chem( 78) +  0.2050000000000000D+01 * w(334)
      chem( 93) = chem( 93) + w(334)
      chem(109) = chem(109) - w(334)
      chem(110) = chem(110) + w(334)
      chem(111) = chem(111) + w(334)
      chem( 45) = chem( 45) + w(335)
      chem( 54) = chem( 54) - w(335)
      chem(109) = chem(109) - w(335)
      chem(110) = chem(110) + w(335)
      chem( 45) = chem( 45) - w(336)
      chem( 46) = chem( 46) + w(336)
      chem(109) = chem(109) - w(336)
      chem(110) = chem(110) + w(336)
      chem( 84) = chem( 84) - w(337)
      chem( 91) = chem( 91) +  0.1800000000000000D+00 * w(337)
      chem( 93) = chem( 93) +  0.2100000000000000D+00 * w(337)
      chem( 96) = chem( 96) +  0.6100000000000000D+00 * w(337)
      chem(103) = chem(103) +  0.7000000000000000D+00 * w(337)
      chem(107) = chem(107) +  0.2700000000000000D+00 * w(337)
      chem(108) = chem(108) +  0.3000000000000000D-01 * w(337)
      chem(109) = chem(109) - w(337)
      chem(110) = chem(110) + w(337)
      chem(111) = chem(111) + w(337)
      chem(101) = chem(101) - w(338)
      chem(106) = chem(106) + w(338)
      chem(111) = chem(111) - w(338)
      chem(100) = chem(100) - w(339)
      chem(101) = chem(101) - w(339)
      chem(108) = chem(108) + w(339)
      chem(111) = chem(111) + w(339)
      chem(100) = chem(100) + w(340)
      chem(101) = chem(101) - w(340)
      chem(105) = chem(105) - w(340)
      chem(101) = chem(101) -  0.2000000000000000D+01 * w(341)
      chem(101) = chem(101) - w(342)
      chem(102) = chem(102) - w(342)
      chem(110) = chem(110) + w(342)
      chem(101) = chem(101) - w(343)
      chem(109) = chem(109) - w(343)
      chem(110) = chem(110) + w(343)
      chem( 90) = chem( 90) - w(344)
      chem( 91) = chem( 91) + w(344)
      chem(102) = chem(102) - w(344)
      chem(110) = chem(110) + w(344)
      chem(111) = chem(111) + w(344)
      chem( 90) = chem( 90) - w(345)
      chem(106) = chem(106) + w(345)
      chem(111) = chem(111) - w(345)
      chem( 90) = chem( 90) - w(346)
      chem( 91) = chem( 91) + w(346)
      chem(100) = chem(100) - w(346)
      chem(108) = chem(108) + w(346)
      chem(111) = chem(111) + w(346)
      chem( 90) = chem( 90) - w(347)
      chem( 91) = chem( 91) + w(347)
      chem(100) = chem(100) + w(347)
      chem(105) = chem(105) - w(347)
      chem( 90) = chem( 90) - w(348)
      chem( 91) = chem( 91) + w(348)
      chem(109) = chem(109) - w(348)
      chem(110) = chem(110) + w(348)
      chem(111) = chem(111) + w(348)
      chem( 98) = chem( 98) - w(349)
      chem(100) = chem(100) + w(349)
      chem(104) = chem(104) + w(349)
      chem(105) = chem(105) - w(349)
 
C    Conversion molecules/cm3 to mug/m3.
 
      do i = 1, ns
         chem(i) = chem(i) / convers_factor(i)
      enddo
 
C     Volumic source terms.
 
      do i=1,ns
      chem(i)=chem(i)+ZCsourc(i)
      enddo
 
      RETURN
      END
 
