C------------------------------------------------------------------------
C     Copyright (C) 2001-2008, ENPC - INRIA - EDF R&D
C     
C     This file is part of the air quality modeling system Polyphemus.
C    
C     Polyphemus is developed in the INRIA - ENPC joint project-team
C     CLIME and in the ENPC - EDF R&D joint laboratory CEREA.
C    
C     Polyphemus is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published
C     by the Free Software Foundation; either version 2 of the License,
C     or (at your option) any later version.
C     
C     Polyphemus is distributed in the hope that it will be useful, but
C     WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
C     General Public License for more details.
C     
C     For more information, visit the Polyphemus web site:
C     http://cerea.enpc.fr/polyphemus/
C
C------------------------------------------------------------------------

      SUBROUTINE LU_decompose_radm (ns,M)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine computes an LU factorization of M.
C     This routine is automatically generated by "LU.cpp".
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C
C     ns: matrix row number from the chemical species number.
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     M: on entry, an invertible matrix. On exit, an LU factorization
C     of M.
C     
C     -- OUTPUT VARIABLES
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C------------------------------------------------------------------------

      IMPLICIT NONE


      INTEGER ns
      DOUBLE PRECISION M(ns,ns)
      DOUBLE PRECISION temp


C     Upper part.
      M(1, 50) = M(1, 50) / M(1, 1)

C     Upper part.
      M(2, 50) = M(2, 50) / M(2, 2)

C     Upper part.
      M(3, 50) = M(3, 50) / M(3, 3)

C     Upper part.
      M(4, 50) = M(4, 50) / M(4, 4)

C     Upper part.
      M(5, 50) = M(5, 50) / M(5, 5)

C     Upper part.
      M(6, 50) = M(6, 50) / M(6, 6)

C     Upper part.
      M(7, 50) = M(7, 50) / M(7, 7)

C     Upper part.
      M(8, 26) = M(8, 26) / M(8, 8)

C     Upper part.
      temp = M(9, 1) * M(1, 50)
      M(9, 50) = ( M(9, 50) - temp ) / M(9, 9)

C     Upper part.
      M(10, 50) = M(10, 50) / M(10, 10)
C     Upper part.
      M(10, 57) = M(10, 57) / M(10, 10)

C     Upper part.
      M(11, 51) = M(11, 51) / M(11, 11)
C     Upper part.
      M(11, 55) = M(11, 55) / M(11, 11)

C     Upper part.
      M(12, 50) = M(12, 50) / M(12, 12)
C     Upper part.
      M(12, 56) = M(12, 56) / M(12, 12)

C     Upper part.
      temp = M(13, 6) * M(6, 50)
      temp = temp + M(13, 7) * M(7, 50)
      M(13, 50) = ( M(13, 50) - temp ) / M(13, 13)
C     Upper part.
      M(13, 51) = M(13, 51) / M(13, 13)

C     Upper part.
      M(14, 54) = M(14, 54) / M(14, 14)
C     Upper part.
      M(14, 55) = M(14, 55) / M(14, 14)

C     Upper part.
      M(15, 26) = M(15, 26) / M(15, 15)
C     Upper part.
      M(15, 50) = M(15, 50) / M(15, 15)
C     Upper part.
      M(15, 51) = M(15, 51) / M(15, 15)

C     Upper part.
      M(16, 26) = M(16, 26) / M(16, 16)
C     Upper part.
      M(16, 50) = M(16, 50) / M(16, 16)
C     Upper part.
      M(16, 51) = M(16, 51) / M(16, 16)

C     Upper part.
      temp = M(17, 15) * M(15, 26)
      temp = temp + M(17, 16) * M(16, 26)
      M(17, 26) = ( M(17, 26) - temp ) / M(17, 17)
C     Upper part.
      temp = M(17, 15) * M(15, 50)
      temp = temp + M(17, 16) * M(16, 50)
      M(17, 50) = ( M(17, 50) - temp ) / M(17, 17)
C     Upper part.
      temp = M(17, 15) * M(15, 51)
      temp = temp + M(17, 16) * M(16, 51)
      M(17, 51) = ( M(17, 51) - temp ) / M(17, 17)

C     Upper part.
      M(18, 26) = M(18, 26) / M(18, 18)
C     Upper part.
      M(18, 50) = M(18, 50) / M(18, 18)
C     Upper part.
      M(18, 51) = M(18, 51) / M(18, 18)

C     Upper part.
      M(19, 25) = M(19, 25) / M(19, 19)
C     Upper part.
      temp = M(19, 15) * M(15, 26)
      temp = temp + M(19, 16) * M(16, 26)
      temp = temp + M(19, 18) * M(18, 26)
      M(19, 26) = ( M(19, 26) - temp ) / M(19, 19)
C     Upper part.
      temp = M(19, 15) * M(15, 50)
      temp = temp + M(19, 16) * M(16, 50)
      temp = temp + M(19, 18) * M(18, 50)
      M(19, 50) = ( M(19, 50) - temp ) / M(19, 19)
C     Upper part.
      temp = M(19, 15) * M(15, 51)
      temp = temp + M(19, 16) * M(16, 51)
      temp = temp + M(19, 18) * M(18, 51)
      M(19, 51) = ( M(19, 51) - temp ) / M(19, 19)

C     Upper part.
      M(20, 50) = M(20, 50) / M(20, 20)
C     Upper part.
      M(20, 55) = M(20, 55) / M(20, 20)
C     Upper part.
      M(20, 58) = M(20, 58) / M(20, 20)

C     Upper part.
      M(21, 46) = M(21, 46) / M(21, 21)
C     Upper part.
      M(21, 50) = M(21, 50) / M(21, 21)
C     Upper part.
      M(21, 57) = M(21, 57) / M(21, 21)

C     Upper part.
      M(22, 50) = M(22, 50) / M(22, 22)
C     Upper part.
      M(22, 57) = M(22, 57) / M(22, 22)
C     Upper part.
      M(22, 58) = M(22, 58) / M(22, 22)

C     Upper part.
      temp = M(23, 8) * M(8, 26)
      M(23, 26) = ( M(23, 26) - temp ) / M(23, 23)
C     Upper part.
      M(23, 51) = M(23, 51) / M(23, 23)
C     Upper part.
      M(23, 55) = M(23, 55) / M(23, 23)

C     Upper part.
      M(24, 50) = M(24, 50) / M(24, 24)
C     Upper part.
      M(24, 55) = M(24, 55) / M(24, 24)
C     Upper part.
      M(24, 57) = M(24, 57) / M(24, 24)

C     Upper part.
      M(25, 26) = M(25, 26) / M(25, 25)
C     Upper part.
      M(25, 50) = M(25, 50) / M(25, 25)
C     Upper part.
      M(25, 51) = M(25, 51) / M(25, 25)

C     Lower part.
      temp = M(26, 15) * M(15, 26)
      temp = temp + M(26, 16) * M(16, 26)
      temp = temp + M(26, 18) * M(18, 26)
      temp = temp + M(26, 23) * M(23, 26)
      temp = temp + M(26, 25) * M(25, 26)
      M(26, 26) = M(26, 26) - temp
C     Lower part.
      temp = M(29, 15) * M(15, 26)
      temp = temp + M(29, 18) * M(18, 26)
      M(29, 26) = M(29, 26) - temp
C     Lower part.
      temp = M(30, 16) * M(16, 26)
      M(30, 26) = M(30, 26) - temp
C     Lower part.
      temp = M(34, 25) * M(25, 26)
      M(34, 26) = M(34, 26) - temp
C     Lower part.
      temp = M(35, 15) * M(15, 26)
      temp = temp + M(35, 16) * M(16, 26)
      temp = temp + M(35, 18) * M(18, 26)
      temp = temp + M(35, 25) * M(25, 26)
      M(35, 26) = M(35, 26) - temp
C     Lower part.
      temp = M(38, 16) * M(16, 26)
      M(38, 26) = M(38, 26) - temp
C     Lower part.
      temp = M(41, 15) * M(15, 26)
      temp = temp + M(41, 16) * M(16, 26)
      temp = temp + M(41, 18) * M(18, 26)
      M(41, 26) = M(41, 26) - temp
C     Lower part.
      temp = M(44, 15) * M(15, 26)
      temp = temp + M(44, 16) * M(16, 26)
      temp = temp + M(44, 18) * M(18, 26)
      M(44, 26) = M(44, 26) - temp
C     Lower part.
      temp = M(46, 15) * M(15, 26)
      temp = temp + M(46, 16) * M(16, 26)
      temp = temp + M(46, 17) * M(17, 26)
      temp = temp + M(46, 18) * M(18, 26)
      M(46, 26) = M(46, 26) - temp
C     Lower part.
      temp = M(48, 15) * M(15, 26)
      temp = temp + M(48, 16) * M(16, 26)
      temp = temp + M(48, 18) * M(18, 26)
      temp = temp + M(48, 25) * M(25, 26)
      M(48, 26) = M(48, 26) - temp
C     Lower part.
      temp = M(50, 8) * M(8, 26)
      temp = temp + M(50, 15) * M(15, 26)
      temp = temp + M(50, 16) * M(16, 26)
      temp = temp + M(50, 17) * M(17, 26)
      temp = temp + M(50, 18) * M(18, 26)
      temp = temp + M(50, 25) * M(25, 26)
      M(50, 26) = M(50, 26) - temp
C     Lower part.
      temp = M(51, 15) * M(15, 26)
      temp = temp + M(51, 16) * M(16, 26)
      temp = temp + M(51, 18) * M(18, 26)
      temp = temp + M(51, 25) * M(25, 26)
      M(51, 26) = M(51, 26) - temp
C     Lower part.
      temp = M(53, 15) * M(15, 26)
      temp = temp + M(53, 16) * M(16, 26)
      temp = temp + M(53, 18) * M(18, 26)
      temp = temp + M(53, 25) * M(25, 26)
      M(53, 26) = M(53, 26) - temp
C     Lower part.
      temp = M(55, 23) * M(23, 26)
      M(55, 26) = M(55, 26) - temp
C     Lower part.
      temp = M(56, 23) * M(23, 26)
      M(56, 26) = M(56, 26) - temp
C     Lower part.
      temp = M(57, 15) * M(15, 26)
      temp = temp + M(57, 16) * M(16, 26)
      temp = temp + M(57, 18) * M(18, 26)
      temp = temp + M(57, 25) * M(25, 26)
      M(57, 26) = M(57, 26) - temp
C     Upper part.
      temp = M(26, 15) * M(15, 50)
      temp = temp + M(26, 16) * M(16, 50)
      temp = temp + M(26, 18) * M(18, 50)
      temp = temp + M(26, 25) * M(25, 50)
      M(26, 50) = ( M(26, 50) - temp ) / M(26, 26)
C     Upper part.
      temp = M(26, 15) * M(15, 51)
      temp = temp + M(26, 16) * M(16, 51)
      temp = temp + M(26, 18) * M(18, 51)
      temp = temp + M(26, 23) * M(23, 51)
      temp = temp + M(26, 25) * M(25, 51)
      M(26, 51) = ( M(26, 51) - temp ) / M(26, 26)
C     Upper part.
      temp = M(26, 23) * M(23, 55)
      M(26, 55) = ( M(26, 55) - temp ) / M(26, 26)
C     Upper part.
      M(26, 56) = M(26, 56) / M(26, 26)
C     Upper part.
      M(26, 57) = M(26, 57) / M(26, 26)

C     Upper part.
      M(27, 46) = M(27, 46) / M(27, 27)
C     Upper part.
      temp = M(27, 4) * M(4, 50)
      M(27, 50) = ( M(27, 50) - temp ) / M(27, 27)
C     Upper part.
      M(27, 56) = M(27, 56) / M(27, 27)
C     Upper part.
      M(27, 57) = M(27, 57) / M(27, 27)
C     Upper part.
      M(27, 58) = M(27, 58) / M(27, 27)

C     Upper part.
      M(28, 46) = M(28, 46) / M(28, 28)
C     Upper part.
      temp = M(28, 5) * M(5, 50)
      M(28, 50) = ( M(28, 50) - temp ) / M(28, 28)
C     Upper part.
      M(28, 56) = M(28, 56) / M(28, 28)
C     Upper part.
      M(28, 57) = M(28, 57) / M(28, 28)
C     Upper part.
      M(28, 58) = M(28, 58) / M(28, 28)

C     Upper part.
      M(29, 46) = M(29, 46) / M(29, 29)
C     Upper part.
      temp = M(29, 15) * M(15, 50)
      temp = temp + M(29, 18) * M(18, 50)
      temp = temp + M(29, 26) * M(26, 50)
      M(29, 50) = ( M(29, 50) - temp ) / M(29, 29)
C     Upper part.
      temp = M(29, 15) * M(15, 51)
      temp = temp + M(29, 18) * M(18, 51)
      temp = temp + M(29, 26) * M(26, 51)
      M(29, 51) = ( M(29, 51) - temp ) / M(29, 29)
C     Upper part.
      temp = M(29, 26) * M(26, 55)
      M(29, 55) = ( M(29, 55) - temp ) / M(29, 29)
C     Upper part.
      temp = M(29, 26) * M(26, 56)
      M(29, 56) = ( M(29, 56) - temp ) / M(29, 29)
C     Upper part.
      temp = M(29, 26) * M(26, 57)
      M(29, 57) = ( M(29, 57) - temp ) / M(29, 29)
C     Upper part.
      M(29, 58) = M(29, 58) / M(29, 29)

C     Upper part.
      M(30, 46) = M(30, 46) / M(30, 30)
C     Upper part.
      temp = M(30, 16) * M(16, 50)
      temp = temp + M(30, 26) * M(26, 50)
      M(30, 50) = ( M(30, 50) - temp ) / M(30, 30)
C     Upper part.
      temp = M(30, 16) * M(16, 51)
      temp = temp + M(30, 26) * M(26, 51)
      M(30, 51) = ( M(30, 51) - temp ) / M(30, 30)
C     Upper part.
      temp = M(30, 26) * M(26, 55)
      M(30, 55) = ( M(30, 55) - temp ) / M(30, 30)
C     Upper part.
      temp = M(30, 26) * M(26, 56)
      M(30, 56) = ( M(30, 56) - temp ) / M(30, 30)
C     Upper part.
      temp = M(30, 26) * M(26, 57)
      M(30, 57) = ( M(30, 57) - temp ) / M(30, 30)
C     Upper part.
      M(30, 58) = M(30, 58) / M(30, 30)

C     Upper part.
      M(31, 46) = M(31, 46) / M(31, 31)
C     Upper part.
      temp = M(31, 6) * M(6, 50)
      M(31, 50) = ( M(31, 50) - temp ) / M(31, 31)
C     Upper part.
      M(31, 56) = M(31, 56) / M(31, 31)
C     Upper part.
      M(31, 57) = M(31, 57) / M(31, 31)
C     Upper part.
      M(31, 58) = M(31, 58) / M(31, 31)

C     Upper part.
      M(32, 46) = M(32, 46) / M(32, 32)
C     Upper part.
      temp = M(32, 7) * M(7, 50)
      M(32, 50) = ( M(32, 50) - temp ) / M(32, 32)
C     Upper part.
      M(32, 56) = M(32, 56) / M(32, 32)
C     Upper part.
      M(32, 57) = M(32, 57) / M(32, 32)
C     Upper part.
      M(32, 58) = M(32, 58) / M(32, 32)

C     Upper part.
      temp = M(33, 31) * M(31, 46)
      temp = temp + M(33, 32) * M(32, 46)
      M(33, 46) = ( M(33, 46) - temp ) / M(33, 33)
C     Upper part.
      temp = M(33, 31) * M(31, 50)
      temp = temp + M(33, 32) * M(32, 50)
      M(33, 50) = ( M(33, 50) - temp ) / M(33, 33)
C     Upper part.
      M(33, 51) = M(33, 51) / M(33, 33)
C     Upper part.
      temp = M(33, 31) * M(31, 56)
      temp = temp + M(33, 32) * M(32, 56)
      M(33, 56) = ( M(33, 56) - temp ) / M(33, 33)
C     Upper part.
      temp = M(33, 31) * M(31, 57)
      temp = temp + M(33, 32) * M(32, 57)
      M(33, 57) = ( M(33, 57) - temp ) / M(33, 33)
C     Upper part.
      temp = M(33, 31) * M(31, 58)
      temp = temp + M(33, 32) * M(32, 58)
      M(33, 58) = ( M(33, 58) - temp ) / M(33, 33)

C     Upper part.
      M(34, 46) = M(34, 46) / M(34, 34)
C     Upper part.
      temp = M(34, 25) * M(25, 50)
      temp = temp + M(34, 26) * M(26, 50)
      M(34, 50) = ( M(34, 50) - temp ) / M(34, 34)
C     Upper part.
      temp = M(34, 25) * M(25, 51)
      temp = temp + M(34, 26) * M(26, 51)
      M(34, 51) = ( M(34, 51) - temp ) / M(34, 34)
C     Upper part.
      temp = M(34, 26) * M(26, 55)
      M(34, 55) = ( M(34, 55) - temp ) / M(34, 34)
C     Upper part.
      temp = M(34, 26) * M(26, 56)
      M(34, 56) = ( M(34, 56) - temp ) / M(34, 34)
C     Upper part.
      temp = M(34, 26) * M(26, 57)
      M(34, 57) = ( M(34, 57) - temp ) / M(34, 34)
C     Upper part.
      M(34, 58) = M(34, 58) / M(34, 34)

C     Upper part.
      M(35, 46) = M(35, 46) / M(35, 35)
C     Upper part.
      temp = M(35, 15) * M(15, 50)
      temp = temp + M(35, 16) * M(16, 50)
      temp = temp + M(35, 18) * M(18, 50)
      temp = temp + M(35, 25) * M(25, 50)
      temp = temp + M(35, 26) * M(26, 50)
      M(35, 50) = ( M(35, 50) - temp ) / M(35, 35)
C     Upper part.
      temp = M(35, 15) * M(15, 51)
      temp = temp + M(35, 16) * M(16, 51)
      temp = temp + M(35, 18) * M(18, 51)
      temp = temp + M(35, 25) * M(25, 51)
      temp = temp + M(35, 26) * M(26, 51)
      M(35, 51) = ( M(35, 51) - temp ) / M(35, 35)
C     Upper part.
      temp = M(35, 26) * M(26, 55)
      M(35, 55) = ( M(35, 55) - temp ) / M(35, 35)
C     Upper part.
      temp = M(35, 26) * M(26, 56)
      M(35, 56) = ( M(35, 56) - temp ) / M(35, 35)
C     Upper part.
      temp = M(35, 26) * M(26, 57)
      M(35, 57) = ( M(35, 57) - temp ) / M(35, 35)
C     Upper part.
      M(35, 58) = M(35, 58) / M(35, 35)

C     Upper part.
      M(36, 46) = M(36, 46) / M(36, 36)
C     Upper part.
      temp = M(36, 13) * M(13, 50)
      M(36, 50) = ( M(36, 50) - temp ) / M(36, 36)
C     Upper part.
      temp = M(36, 13) * M(13, 51)
      M(36, 51) = ( M(36, 51) - temp ) / M(36, 36)
C     Upper part.
      M(36, 55) = M(36, 55) / M(36, 36)
C     Upper part.
      M(36, 57) = M(36, 57) / M(36, 36)
C     Upper part.
      M(36, 58) = M(36, 58) / M(36, 36)

C     Upper part.
      M(37, 43) = M(37, 43) / M(37, 37)
C     Upper part.
      temp = M(37, 27) * M(27, 46)
      temp = temp + M(37, 28) * M(28, 46)
      temp = temp + M(37, 35) * M(35, 46)
      temp = temp + M(37, 36) * M(36, 46)
      M(37, 46) = ( M(37, 46) - temp ) / M(37, 37)
C     Upper part.
      temp = M(37, 27) * M(27, 50)
      temp = temp + M(37, 28) * M(28, 50)
      temp = temp + M(37, 35) * M(35, 50)
      temp = temp + M(37, 36) * M(36, 50)
      M(37, 50) = ( M(37, 50) - temp ) / M(37, 37)
C     Upper part.
      temp = M(37, 35) * M(35, 51)
      temp = temp + M(37, 36) * M(36, 51)
      M(37, 51) = ( M(37, 51) - temp ) / M(37, 37)
C     Upper part.
      temp = M(37, 35) * M(35, 55)
      temp = temp + M(37, 36) * M(36, 55)
      M(37, 55) = ( M(37, 55) - temp ) / M(37, 37)
C     Upper part.
      temp = M(37, 27) * M(27, 56)
      temp = temp + M(37, 28) * M(28, 56)
      temp = temp + M(37, 35) * M(35, 56)
      M(37, 56) = ( M(37, 56) - temp ) / M(37, 37)
C     Upper part.
      temp = M(37, 27) * M(27, 57)
      temp = temp + M(37, 28) * M(28, 57)
      temp = temp + M(37, 35) * M(35, 57)
      temp = temp + M(37, 36) * M(36, 57)
      M(37, 57) = ( M(37, 57) - temp ) / M(37, 37)
C     Upper part.
      temp = M(37, 27) * M(27, 58)
      temp = temp + M(37, 28) * M(28, 58)
      temp = temp + M(37, 35) * M(35, 58)
      temp = temp + M(37, 36) * M(36, 58)
      M(37, 58) = ( M(37, 58) - temp ) / M(37, 37)

C     Upper part.
      temp = M(38, 37) * M(37, 43)
      M(38, 43) = ( M(38, 43) - temp ) / M(38, 38)
C     Upper part.
      temp = M(38, 27) * M(27, 46)
      temp = temp + M(38, 28) * M(28, 46)
      temp = temp + M(38, 30) * M(30, 46)
      temp = temp + M(38, 37) * M(37, 46)
      M(38, 46) = ( M(38, 46) - temp ) / M(38, 38)
C     Upper part.
      temp = M(38, 3) * M(3, 50)
      temp = temp + M(38, 16) * M(16, 50)
      temp = temp + M(38, 26) * M(26, 50)
      temp = temp + M(38, 27) * M(27, 50)
      temp = temp + M(38, 28) * M(28, 50)
      temp = temp + M(38, 30) * M(30, 50)
      temp = temp + M(38, 37) * M(37, 50)
      M(38, 50) = ( M(38, 50) - temp ) / M(38, 38)
C     Upper part.
      temp = M(38, 16) * M(16, 51)
      temp = temp + M(38, 26) * M(26, 51)
      temp = temp + M(38, 30) * M(30, 51)
      temp = temp + M(38, 37) * M(37, 51)
      M(38, 51) = ( M(38, 51) - temp ) / M(38, 38)
C     Upper part.
      temp = M(38, 26) * M(26, 55)
      temp = temp + M(38, 30) * M(30, 55)
      temp = temp + M(38, 37) * M(37, 55)
      M(38, 55) = ( M(38, 55) - temp ) / M(38, 38)
C     Upper part.
      temp = M(38, 26) * M(26, 56)
      temp = temp + M(38, 27) * M(27, 56)
      temp = temp + M(38, 28) * M(28, 56)
      temp = temp + M(38, 30) * M(30, 56)
      temp = temp + M(38, 37) * M(37, 56)
      M(38, 56) = ( M(38, 56) - temp ) / M(38, 38)
C     Upper part.
      temp = M(38, 26) * M(26, 57)
      temp = temp + M(38, 27) * M(27, 57)
      temp = temp + M(38, 28) * M(28, 57)
      temp = temp + M(38, 30) * M(30, 57)
      temp = temp + M(38, 37) * M(37, 57)
      M(38, 57) = ( M(38, 57) - temp ) / M(38, 38)
C     Upper part.
      temp = M(38, 27) * M(27, 58)
      temp = temp + M(38, 28) * M(28, 58)
      temp = temp + M(38, 30) * M(30, 58)
      temp = temp + M(38, 37) * M(37, 58)
      M(38, 58) = ( M(38, 58) - temp ) / M(38, 38)

C     Upper part.
      temp = M(39, 38) * M(38, 43)
      M(39, 43) = ( M(39, 43) - temp ) / M(39, 39)
C     Upper part.
      temp = M(39, 38) * M(38, 46)
      M(39, 46) = ( M(39, 46) - temp ) / M(39, 39)
C     Upper part.
      temp = M(39, 2) * M(2, 50)
      temp = temp + M(39, 38) * M(38, 50)
      M(39, 50) = ( M(39, 50) - temp ) / M(39, 39)
C     Upper part.
      temp = M(39, 38) * M(38, 51)
      M(39, 51) = ( M(39, 51) - temp ) / M(39, 39)
C     Upper part.
      temp = M(39, 38) * M(38, 55)
      M(39, 55) = ( M(39, 55) - temp ) / M(39, 39)
C     Upper part.
      temp = M(39, 38) * M(38, 56)
      M(39, 56) = ( M(39, 56) - temp ) / M(39, 39)
C     Upper part.
      temp = M(39, 38) * M(38, 57)
      M(39, 57) = ( M(39, 57) - temp ) / M(39, 39)
C     Upper part.
      temp = M(39, 38) * M(38, 58)
      M(39, 58) = ( M(39, 58) - temp ) / M(39, 39)

C     Upper part.
      temp = M(40, 38) * M(38, 43)
      M(40, 43) = ( M(40, 43) - temp ) / M(40, 40)
C     Upper part.
      temp = M(40, 38) * M(38, 46)
      M(40, 46) = ( M(40, 46) - temp ) / M(40, 40)
C     Upper part.
      temp = M(40, 38) * M(38, 50)
      M(40, 50) = ( M(40, 50) - temp ) / M(40, 40)
C     Upper part.
      temp = M(40, 38) * M(38, 51)
      M(40, 51) = ( M(40, 51) - temp ) / M(40, 40)
C     Upper part.
      temp = M(40, 38) * M(38, 55)
      M(40, 55) = ( M(40, 55) - temp ) / M(40, 40)
C     Upper part.
      temp = M(40, 38) * M(38, 56)
      M(40, 56) = ( M(40, 56) - temp ) / M(40, 40)
C     Upper part.
      temp = M(40, 38) * M(38, 57)
      M(40, 57) = ( M(40, 57) - temp ) / M(40, 40)
C     Upper part.
      temp = M(40, 38) * M(38, 58)
      M(40, 58) = ( M(40, 58) - temp ) / M(40, 40)

C     Upper part.
      temp = M(41, 39) * M(39, 43)
      temp = temp + M(41, 40) * M(40, 43)
      M(41, 43) = ( M(41, 43) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 27) * M(27, 46)
      temp = temp + M(41, 28) * M(28, 46)
      temp = temp + M(41, 29) * M(29, 46)
      temp = temp + M(41, 30) * M(30, 46)
      temp = temp + M(41, 34) * M(34, 46)
      temp = temp + M(41, 35) * M(35, 46)
      temp = temp + M(41, 39) * M(39, 46)
      temp = temp + M(41, 40) * M(40, 46)
      M(41, 46) = ( M(41, 46) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 15) * M(15, 50)
      temp = temp + M(41, 16) * M(16, 50)
      temp = temp + M(41, 18) * M(18, 50)
      temp = temp + M(41, 26) * M(26, 50)
      temp = temp + M(41, 27) * M(27, 50)
      temp = temp + M(41, 28) * M(28, 50)
      temp = temp + M(41, 29) * M(29, 50)
      temp = temp + M(41, 30) * M(30, 50)
      temp = temp + M(41, 34) * M(34, 50)
      temp = temp + M(41, 35) * M(35, 50)
      temp = temp + M(41, 39) * M(39, 50)
      temp = temp + M(41, 40) * M(40, 50)
      M(41, 50) = ( M(41, 50) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 15) * M(15, 51)
      temp = temp + M(41, 16) * M(16, 51)
      temp = temp + M(41, 18) * M(18, 51)
      temp = temp + M(41, 26) * M(26, 51)
      temp = temp + M(41, 29) * M(29, 51)
      temp = temp + M(41, 30) * M(30, 51)
      temp = temp + M(41, 34) * M(34, 51)
      temp = temp + M(41, 35) * M(35, 51)
      temp = temp + M(41, 39) * M(39, 51)
      temp = temp + M(41, 40) * M(40, 51)
      M(41, 51) = ( M(41, 51) - temp ) / M(41, 41)
C     Upper part.
      M(41, 54) = M(41, 54) / M(41, 41)
C     Upper part.
      temp = M(41, 26) * M(26, 55)
      temp = temp + M(41, 29) * M(29, 55)
      temp = temp + M(41, 30) * M(30, 55)
      temp = temp + M(41, 34) * M(34, 55)
      temp = temp + M(41, 35) * M(35, 55)
      temp = temp + M(41, 39) * M(39, 55)
      temp = temp + M(41, 40) * M(40, 55)
      M(41, 55) = ( M(41, 55) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 26) * M(26, 56)
      temp = temp + M(41, 27) * M(27, 56)
      temp = temp + M(41, 28) * M(28, 56)
      temp = temp + M(41, 29) * M(29, 56)
      temp = temp + M(41, 30) * M(30, 56)
      temp = temp + M(41, 34) * M(34, 56)
      temp = temp + M(41, 35) * M(35, 56)
      temp = temp + M(41, 39) * M(39, 56)
      temp = temp + M(41, 40) * M(40, 56)
      M(41, 56) = ( M(41, 56) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 26) * M(26, 57)
      temp = temp + M(41, 27) * M(27, 57)
      temp = temp + M(41, 28) * M(28, 57)
      temp = temp + M(41, 29) * M(29, 57)
      temp = temp + M(41, 30) * M(30, 57)
      temp = temp + M(41, 34) * M(34, 57)
      temp = temp + M(41, 35) * M(35, 57)
      temp = temp + M(41, 39) * M(39, 57)
      temp = temp + M(41, 40) * M(40, 57)
      M(41, 57) = ( M(41, 57) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 27) * M(27, 58)
      temp = temp + M(41, 28) * M(28, 58)
      temp = temp + M(41, 29) * M(29, 58)
      temp = temp + M(41, 30) * M(30, 58)
      temp = temp + M(41, 34) * M(34, 58)
      temp = temp + M(41, 35) * M(35, 58)
      temp = temp + M(41, 39) * M(39, 58)
      temp = temp + M(41, 40) * M(40, 58)
      M(41, 58) = ( M(41, 58) - temp ) / M(41, 41)

C     Upper part.
      temp = M(42, 39) * M(39, 43)
      temp = temp + M(42, 40) * M(40, 43)
      M(42, 43) = ( M(42, 43) - temp ) / M(42, 42)
C     Upper part.
      M(42, 45) = M(42, 45) / M(42, 42)
C     Upper part.
      temp = M(42, 27) * M(27, 46)
      temp = temp + M(42, 28) * M(28, 46)
      temp = temp + M(42, 29) * M(29, 46)
      temp = temp + M(42, 30) * M(30, 46)
      temp = temp + M(42, 31) * M(31, 46)
      temp = temp + M(42, 32) * M(32, 46)
      temp = temp + M(42, 34) * M(34, 46)
      temp = temp + M(42, 36) * M(36, 46)
      temp = temp + M(42, 39) * M(39, 46)
      temp = temp + M(42, 40) * M(40, 46)
      M(42, 46) = ( M(42, 46) - temp ) / M(42, 42)
C     Upper part.
      temp = M(42, 27) * M(27, 50)
      temp = temp + M(42, 28) * M(28, 50)
      temp = temp + M(42, 29) * M(29, 50)
      temp = temp + M(42, 30) * M(30, 50)
      temp = temp + M(42, 31) * M(31, 50)
      temp = temp + M(42, 32) * M(32, 50)
      temp = temp + M(42, 34) * M(34, 50)
      temp = temp + M(42, 36) * M(36, 50)
      temp = temp + M(42, 39) * M(39, 50)
      temp = temp + M(42, 40) * M(40, 50)
      M(42, 50) = ( M(42, 50) - temp ) / M(42, 42)
C     Upper part.
      temp = M(42, 29) * M(29, 51)
      temp = temp + M(42, 30) * M(30, 51)
      temp = temp + M(42, 34) * M(34, 51)
      temp = temp + M(42, 36) * M(36, 51)
      temp = temp + M(42, 39) * M(39, 51)
      temp = temp + M(42, 40) * M(40, 51)
      M(42, 51) = ( M(42, 51) - temp ) / M(42, 42)
C     Upper part.
      M(42, 54) = M(42, 54) / M(42, 42)
C     Upper part.
      temp = M(42, 29) * M(29, 55)
      temp = temp + M(42, 30) * M(30, 55)
      temp = temp + M(42, 34) * M(34, 55)
      temp = temp + M(42, 36) * M(36, 55)
      temp = temp + M(42, 39) * M(39, 55)
      temp = temp + M(42, 40) * M(40, 55)
      M(42, 55) = ( M(42, 55) - temp ) / M(42, 42)
C     Upper part.
      temp = M(42, 27) * M(27, 56)
      temp = temp + M(42, 28) * M(28, 56)
      temp = temp + M(42, 29) * M(29, 56)
      temp = temp + M(42, 30) * M(30, 56)
      temp = temp + M(42, 31) * M(31, 56)
      temp = temp + M(42, 32) * M(32, 56)
      temp = temp + M(42, 34) * M(34, 56)
      temp = temp + M(42, 39) * M(39, 56)
      temp = temp + M(42, 40) * M(40, 56)
      M(42, 56) = ( M(42, 56) - temp ) / M(42, 42)
C     Upper part.
      temp = M(42, 27) * M(27, 57)
      temp = temp + M(42, 28) * M(28, 57)
      temp = temp + M(42, 29) * M(29, 57)
      temp = temp + M(42, 30) * M(30, 57)
      temp = temp + M(42, 31) * M(31, 57)
      temp = temp + M(42, 32) * M(32, 57)
      temp = temp + M(42, 34) * M(34, 57)
      temp = temp + M(42, 36) * M(36, 57)
      temp = temp + M(42, 39) * M(39, 57)
      temp = temp + M(42, 40) * M(40, 57)
      M(42, 57) = ( M(42, 57) - temp ) / M(42, 42)
C     Upper part.
      temp = M(42, 27) * M(27, 58)
      temp = temp + M(42, 28) * M(28, 58)
      temp = temp + M(42, 29) * M(29, 58)
      temp = temp + M(42, 30) * M(30, 58)
      temp = temp + M(42, 31) * M(31, 58)
      temp = temp + M(42, 32) * M(32, 58)
      temp = temp + M(42, 34) * M(34, 58)
      temp = temp + M(42, 36) * M(36, 58)
      temp = temp + M(42, 39) * M(39, 58)
      temp = temp + M(42, 40) * M(40, 58)
      M(42, 58) = ( M(42, 58) - temp ) / M(42, 42)

C     Lower part.
      temp = M(43, 37) * M(37, 43)
      temp = temp + M(43, 42) * M(42, 43)
      M(43, 43) = M(43, 43) - temp
C     Lower part.
      temp = M(44, 37) * M(37, 43)
      temp = temp + M(44, 39) * M(39, 43)
      temp = temp + M(44, 42) * M(42, 43)
      M(44, 43) = M(44, 43) - temp
C     Lower part.
      temp = M(46, 39) * M(39, 43)
      temp = temp + M(46, 40) * M(40, 43)
      M(46, 43) = M(46, 43) - temp
C     Lower part.
      temp = M(48, 39) * M(39, 43)
      temp = temp + M(48, 40) * M(40, 43)
      M(48, 43) = M(48, 43) - temp
C     Lower part.
      temp = M(50, 37) * M(37, 43)
      temp = temp + M(50, 38) * M(38, 43)
      temp = temp + M(50, 42) * M(42, 43)
      M(50, 43) = M(50, 43) - temp
C     Lower part.
      temp = M(52, 40) * M(40, 43)
      M(52, 43) = M(52, 43) - temp
C     Lower part.
      temp = M(55, 37) * M(37, 43)
      temp = temp + M(55, 39) * M(39, 43)
      temp = temp + M(55, 40) * M(40, 43)
      M(55, 43) = M(55, 43) - temp
C     Lower part.
      temp = M(56, 39) * M(39, 43)
      temp = temp + M(56, 40) * M(40, 43)
      M(56, 43) = M(56, 43) - temp
C     Lower part.
      temp = M(57, 37) * M(37, 43)
      temp = temp + M(57, 39) * M(39, 43)
      temp = temp + M(57, 40) * M(40, 43)
      temp = temp + M(57, 42) * M(42, 43)
      M(57, 43) = M(57, 43) - temp
C     Lower part.
      temp = M(58, 38) * M(38, 43)
      temp = temp + M(58, 39) * M(39, 43)
      temp = temp + M(58, 40) * M(40, 43)
      M(58, 43) = M(58, 43) - temp
C     Upper part.
      temp = M(43, 42) * M(42, 45)
      M(43, 45) = ( M(43, 45) - temp ) / M(43, 43)
C     Upper part.
      temp = M(43, 37) * M(37, 46)
      temp = temp + M(43, 42) * M(42, 46)
      M(43, 46) = ( M(43, 46) - temp ) / M(43, 43)
C     Upper part.
      temp = M(43, 3) * M(3, 50)
      temp = temp + M(43, 37) * M(37, 50)
      temp = temp + M(43, 42) * M(42, 50)
      M(43, 50) = ( M(43, 50) - temp ) / M(43, 43)
C     Upper part.
      temp = M(43, 37) * M(37, 51)
      temp = temp + M(43, 42) * M(42, 51)
      M(43, 51) = ( M(43, 51) - temp ) / M(43, 43)
C     Upper part.
      temp = M(43, 42) * M(42, 54)
      M(43, 54) = ( M(43, 54) - temp ) / M(43, 43)
C     Upper part.
      temp = M(43, 37) * M(37, 55)
      temp = temp + M(43, 42) * M(42, 55)
      M(43, 55) = ( M(43, 55) - temp ) / M(43, 43)
C     Upper part.
      temp = M(43, 37) * M(37, 56)
      temp = temp + M(43, 42) * M(42, 56)
      M(43, 56) = ( M(43, 56) - temp ) / M(43, 43)
C     Upper part.
      temp = M(43, 37) * M(37, 57)
      temp = temp + M(43, 42) * M(42, 57)
      M(43, 57) = ( M(43, 57) - temp ) / M(43, 43)
C     Upper part.
      temp = M(43, 37) * M(37, 58)
      temp = temp + M(43, 42) * M(42, 58)
      M(43, 58) = ( M(43, 58) - temp ) / M(43, 43)

C     Upper part.
      temp = M(44, 42) * M(42, 45)
      temp = temp + M(44, 43) * M(43, 45)
      M(44, 45) = ( M(44, 45) - temp ) / M(44, 44)
C     Upper part.
      temp = M(44, 27) * M(27, 46)
      temp = temp + M(44, 28) * M(28, 46)
      temp = temp + M(44, 29) * M(29, 46)
      temp = temp + M(44, 30) * M(30, 46)
      temp = temp + M(44, 34) * M(34, 46)
      temp = temp + M(44, 35) * M(35, 46)
      temp = temp + M(44, 37) * M(37, 46)
      temp = temp + M(44, 39) * M(39, 46)
      temp = temp + M(44, 42) * M(42, 46)
      temp = temp + M(44, 43) * M(43, 46)
      M(44, 46) = ( M(44, 46) - temp ) / M(44, 44)
C     Upper part.
      temp = M(44, 3) * M(3, 50)
      temp = temp + M(44, 15) * M(15, 50)
      temp = temp + M(44, 16) * M(16, 50)
      temp = temp + M(44, 18) * M(18, 50)
      temp = temp + M(44, 26) * M(26, 50)
      temp = temp + M(44, 27) * M(27, 50)
      temp = temp + M(44, 28) * M(28, 50)
      temp = temp + M(44, 29) * M(29, 50)
      temp = temp + M(44, 30) * M(30, 50)
      temp = temp + M(44, 34) * M(34, 50)
      temp = temp + M(44, 35) * M(35, 50)
      temp = temp + M(44, 37) * M(37, 50)
      temp = temp + M(44, 39) * M(39, 50)
      temp = temp + M(44, 42) * M(42, 50)
      temp = temp + M(44, 43) * M(43, 50)
      M(44, 50) = ( M(44, 50) - temp ) / M(44, 44)
C     Upper part.
      temp = M(44, 15) * M(15, 51)
      temp = temp + M(44, 16) * M(16, 51)
      temp = temp + M(44, 18) * M(18, 51)
      temp = temp + M(44, 26) * M(26, 51)
      temp = temp + M(44, 29) * M(29, 51)
      temp = temp + M(44, 30) * M(30, 51)
      temp = temp + M(44, 34) * M(34, 51)
      temp = temp + M(44, 35) * M(35, 51)
      temp = temp + M(44, 37) * M(37, 51)
      temp = temp + M(44, 39) * M(39, 51)
      temp = temp + M(44, 42) * M(42, 51)
      temp = temp + M(44, 43) * M(43, 51)
      M(44, 51) = ( M(44, 51) - temp ) / M(44, 44)
C     Upper part.
      temp = M(44, 42) * M(42, 54)
      temp = temp + M(44, 43) * M(43, 54)
      M(44, 54) = ( M(44, 54) - temp ) / M(44, 44)
C     Upper part.
      temp = M(44, 26) * M(26, 55)
      temp = temp + M(44, 29) * M(29, 55)
      temp = temp + M(44, 30) * M(30, 55)
      temp = temp + M(44, 34) * M(34, 55)
      temp = temp + M(44, 35) * M(35, 55)
      temp = temp + M(44, 37) * M(37, 55)
      temp = temp + M(44, 39) * M(39, 55)
      temp = temp + M(44, 42) * M(42, 55)
      temp = temp + M(44, 43) * M(43, 55)
      M(44, 55) = ( M(44, 55) - temp ) / M(44, 44)
C     Upper part.
      temp = M(44, 26) * M(26, 56)
      temp = temp + M(44, 27) * M(27, 56)
      temp = temp + M(44, 28) * M(28, 56)
      temp = temp + M(44, 29) * M(29, 56)
      temp = temp + M(44, 30) * M(30, 56)
      temp = temp + M(44, 34) * M(34, 56)
      temp = temp + M(44, 35) * M(35, 56)
      temp = temp + M(44, 37) * M(37, 56)
      temp = temp + M(44, 39) * M(39, 56)
      temp = temp + M(44, 42) * M(42, 56)
      temp = temp + M(44, 43) * M(43, 56)
      M(44, 56) = ( M(44, 56) - temp ) / M(44, 44)
C     Upper part.
      temp = M(44, 26) * M(26, 57)
      temp = temp + M(44, 27) * M(27, 57)
      temp = temp + M(44, 28) * M(28, 57)
      temp = temp + M(44, 29) * M(29, 57)
      temp = temp + M(44, 30) * M(30, 57)
      temp = temp + M(44, 34) * M(34, 57)
      temp = temp + M(44, 35) * M(35, 57)
      temp = temp + M(44, 37) * M(37, 57)
      temp = temp + M(44, 39) * M(39, 57)
      temp = temp + M(44, 42) * M(42, 57)
      temp = temp + M(44, 43) * M(43, 57)
      M(44, 57) = ( M(44, 57) - temp ) / M(44, 44)
C     Upper part.
      temp = M(44, 27) * M(27, 58)
      temp = temp + M(44, 28) * M(28, 58)
      temp = temp + M(44, 29) * M(29, 58)
      temp = temp + M(44, 30) * M(30, 58)
      temp = temp + M(44, 34) * M(34, 58)
      temp = temp + M(44, 35) * M(35, 58)
      temp = temp + M(44, 37) * M(37, 58)
      temp = temp + M(44, 39) * M(39, 58)
      temp = temp + M(44, 42) * M(42, 58)
      temp = temp + M(44, 43) * M(43, 58)
      M(44, 58) = ( M(44, 58) - temp ) / M(44, 44)

C     Lower part.
      temp = M(46, 43) * M(43, 45)
      temp = temp + M(46, 44) * M(44, 45)
      M(46, 45) = M(46, 45) - temp
C     Lower part.
      temp = M(48, 43) * M(43, 45)
      M(48, 45) = M(48, 45) - temp
C     Lower part.
      temp = M(49, 44) * M(44, 45)
      M(49, 45) = M(49, 45) - temp
C     Lower part.
      temp = M(50, 42) * M(42, 45)
      temp = temp + M(50, 43) * M(43, 45)
      temp = temp + M(50, 44) * M(44, 45)
      M(50, 45) = M(50, 45) - temp
C     Lower part.
      temp = M(51, 44) * M(44, 45)
      M(51, 45) = M(51, 45) - temp
C     Lower part.
      temp = M(52, 43) * M(43, 45)
      M(52, 45) = M(52, 45) - temp
C     Lower part.
      temp = M(53, 44) * M(44, 45)
      M(53, 45) = M(53, 45) - temp
C     Lower part.
      temp = M(55, 43) * M(43, 45)
      M(55, 45) = M(55, 45) - temp
C     Lower part.
      temp = M(56, 43) * M(43, 45)
      M(56, 45) = M(56, 45) - temp
C     Lower part.
      temp = M(57, 42) * M(42, 45)
      temp = temp + M(57, 43) * M(43, 45)
      temp = temp + M(57, 44) * M(44, 45)
      M(57, 45) = M(57, 45) - temp
C     Lower part.
      temp = M(58, 43) * M(43, 45)
      temp = temp + M(58, 44) * M(44, 45)
      M(58, 45) = M(58, 45) - temp
C     Upper part.
      M(45, 46) = M(45, 46) / M(45, 45)
C     Upper part.
      temp = M(45, 4) * M(4, 50)
      temp = temp + M(45, 5) * M(5, 50)
      temp = temp + M(45, 13) * M(13, 50)
      temp = temp + M(45, 20) * M(20, 50)
      M(45, 50) = ( M(45, 50) - temp ) / M(45, 45)
C     Upper part.
      temp = M(45, 13) * M(13, 51)
      M(45, 51) = ( M(45, 51) - temp ) / M(45, 45)
C     Upper part.
      M(45, 54) = M(45, 54) / M(45, 45)
C     Upper part.
      temp = M(45, 20) * M(20, 55)
      M(45, 55) = ( M(45, 55) - temp ) / M(45, 45)
C     Upper part.
      M(45, 56) = M(45, 56) / M(45, 45)
C     Upper part.
      M(45, 57) = M(45, 57) / M(45, 45)
C     Upper part.
      temp = M(45, 20) * M(20, 58)
      M(45, 58) = ( M(45, 58) - temp ) / M(45, 45)

C     Lower part.
      temp = M(46, 21) * M(21, 46)
      temp = temp + M(46, 27) * M(27, 46)
      temp = temp + M(46, 28) * M(28, 46)
      temp = temp + M(46, 29) * M(29, 46)
      temp = temp + M(46, 30) * M(30, 46)
      temp = temp + M(46, 31) * M(31, 46)
      temp = temp + M(46, 32) * M(32, 46)
      temp = temp + M(46, 34) * M(34, 46)
      temp = temp + M(46, 35) * M(35, 46)
      temp = temp + M(46, 36) * M(36, 46)
      temp = temp + M(46, 39) * M(39, 46)
      temp = temp + M(46, 40) * M(40, 46)
      temp = temp + M(46, 43) * M(43, 46)
      temp = temp + M(46, 44) * M(44, 46)
      temp = temp + M(46, 45) * M(45, 46)
      M(46, 46) = M(46, 46) - temp
C     Lower part.
      temp = M(47, 31) * M(31, 46)
      M(47, 46) = M(47, 46) - temp
C     Lower part.
      temp = M(48, 21) * M(21, 46)
      temp = temp + M(48, 27) * M(27, 46)
      temp = temp + M(48, 28) * M(28, 46)
      temp = temp + M(48, 29) * M(29, 46)
      temp = temp + M(48, 30) * M(30, 46)
      temp = temp + M(48, 31) * M(31, 46)
      temp = temp + M(48, 32) * M(32, 46)
      temp = temp + M(48, 34) * M(34, 46)
      temp = temp + M(48, 35) * M(35, 46)
      temp = temp + M(48, 36) * M(36, 46)
      temp = temp + M(48, 39) * M(39, 46)
      temp = temp + M(48, 40) * M(40, 46)
      temp = temp + M(48, 43) * M(43, 46)
      temp = temp + M(48, 45) * M(45, 46)
      M(48, 46) = M(48, 46) - temp
C     Lower part.
      temp = M(49, 33) * M(33, 46)
      temp = temp + M(49, 44) * M(44, 46)
      temp = temp + M(49, 45) * M(45, 46)
      M(49, 46) = M(49, 46) - temp
C     Lower part.
      temp = M(50, 21) * M(21, 46)
      temp = temp + M(50, 33) * M(33, 46)
      temp = temp + M(50, 37) * M(37, 46)
      temp = temp + M(50, 38) * M(38, 46)
      temp = temp + M(50, 42) * M(42, 46)
      temp = temp + M(50, 43) * M(43, 46)
      temp = temp + M(50, 44) * M(44, 46)
      temp = temp + M(50, 45) * M(45, 46)
      M(50, 46) = M(50, 46) - temp
C     Lower part.
      temp = M(51, 33) * M(33, 46)
      temp = temp + M(51, 44) * M(44, 46)
      temp = temp + M(51, 45) * M(45, 46)
      M(51, 46) = M(51, 46) - temp
C     Lower part.
      temp = M(52, 31) * M(31, 46)
      temp = temp + M(52, 32) * M(32, 46)
      temp = temp + M(52, 40) * M(40, 46)
      temp = temp + M(52, 43) * M(43, 46)
      temp = temp + M(52, 45) * M(45, 46)
      M(52, 46) = M(52, 46) - temp
C     Lower part.
      temp = M(53, 44) * M(44, 46)
      temp = temp + M(53, 45) * M(45, 46)
      M(53, 46) = M(53, 46) - temp
C     Lower part.
      temp = M(54, 33) * M(33, 46)
      M(54, 46) = M(54, 46) - temp
C     Lower part.
      temp = M(55, 27) * M(27, 46)
      temp = temp + M(55, 28) * M(28, 46)
      temp = temp + M(55, 29) * M(29, 46)
      temp = temp + M(55, 30) * M(30, 46)
      temp = temp + M(55, 31) * M(31, 46)
      temp = temp + M(55, 32) * M(32, 46)
      temp = temp + M(55, 34) * M(34, 46)
      temp = temp + M(55, 35) * M(35, 46)
      temp = temp + M(55, 36) * M(36, 46)
      temp = temp + M(55, 37) * M(37, 46)
      temp = temp + M(55, 39) * M(39, 46)
      temp = temp + M(55, 40) * M(40, 46)
      temp = temp + M(55, 43) * M(43, 46)
      temp = temp + M(55, 45) * M(45, 46)
      M(55, 46) = M(55, 46) - temp
C     Lower part.
      temp = M(56, 27) * M(27, 46)
      temp = temp + M(56, 28) * M(28, 46)
      temp = temp + M(56, 29) * M(29, 46)
      temp = temp + M(56, 30) * M(30, 46)
      temp = temp + M(56, 31) * M(31, 46)
      temp = temp + M(56, 32) * M(32, 46)
      temp = temp + M(56, 34) * M(34, 46)
      temp = temp + M(56, 35) * M(35, 46)
      temp = temp + M(56, 39) * M(39, 46)
      temp = temp + M(56, 40) * M(40, 46)
      temp = temp + M(56, 43) * M(43, 46)
      temp = temp + M(56, 45) * M(45, 46)
      M(56, 46) = M(56, 46) - temp
C     Lower part.
      temp = M(57, 21) * M(21, 46)
      temp = temp + M(57, 27) * M(27, 46)
      temp = temp + M(57, 28) * M(28, 46)
      temp = temp + M(57, 29) * M(29, 46)
      temp = temp + M(57, 30) * M(30, 46)
      temp = temp + M(57, 31) * M(31, 46)
      temp = temp + M(57, 32) * M(32, 46)
      temp = temp + M(57, 33) * M(33, 46)
      temp = temp + M(57, 34) * M(34, 46)
      temp = temp + M(57, 35) * M(35, 46)
      temp = temp + M(57, 36) * M(36, 46)
      temp = temp + M(57, 37) * M(37, 46)
      temp = temp + M(57, 39) * M(39, 46)
      temp = temp + M(57, 40) * M(40, 46)
      temp = temp + M(57, 42) * M(42, 46)
      temp = temp + M(57, 43) * M(43, 46)
      temp = temp + M(57, 44) * M(44, 46)
      temp = temp + M(57, 45) * M(45, 46)
      M(57, 46) = M(57, 46) - temp
C     Lower part.
      temp = M(58, 27) * M(27, 46)
      temp = temp + M(58, 28) * M(28, 46)
      temp = temp + M(58, 29) * M(29, 46)
      temp = temp + M(58, 30) * M(30, 46)
      temp = temp + M(58, 31) * M(31, 46)
      temp = temp + M(58, 32) * M(32, 46)
      temp = temp + M(58, 34) * M(34, 46)
      temp = temp + M(58, 35) * M(35, 46)
      temp = temp + M(58, 36) * M(36, 46)
      temp = temp + M(58, 38) * M(38, 46)
      temp = temp + M(58, 39) * M(39, 46)
      temp = temp + M(58, 40) * M(40, 46)
      temp = temp + M(58, 43) * M(43, 46)
      temp = temp + M(58, 44) * M(44, 46)
      temp = temp + M(58, 45) * M(45, 46)
      M(58, 46) = M(58, 46) - temp
C     Upper part.
      temp = M(46, 15) * M(15, 50)
      temp = temp + M(46, 16) * M(16, 50)
      temp = temp + M(46, 17) * M(17, 50)
      temp = temp + M(46, 18) * M(18, 50)
      temp = temp + M(46, 21) * M(21, 50)
      temp = temp + M(46, 22) * M(22, 50)
      temp = temp + M(46, 26) * M(26, 50)
      temp = temp + M(46, 27) * M(27, 50)
      temp = temp + M(46, 28) * M(28, 50)
      temp = temp + M(46, 29) * M(29, 50)
      temp = temp + M(46, 30) * M(30, 50)
      temp = temp + M(46, 31) * M(31, 50)
      temp = temp + M(46, 32) * M(32, 50)
      temp = temp + M(46, 34) * M(34, 50)
      temp = temp + M(46, 35) * M(35, 50)
      temp = temp + M(46, 36) * M(36, 50)
      temp = temp + M(46, 39) * M(39, 50)
      temp = temp + M(46, 40) * M(40, 50)
      temp = temp + M(46, 43) * M(43, 50)
      temp = temp + M(46, 44) * M(44, 50)
      temp = temp + M(46, 45) * M(45, 50)
      M(46, 50) = ( M(46, 50) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 15) * M(15, 51)
      temp = temp + M(46, 16) * M(16, 51)
      temp = temp + M(46, 17) * M(17, 51)
      temp = temp + M(46, 18) * M(18, 51)
      temp = temp + M(46, 26) * M(26, 51)
      temp = temp + M(46, 29) * M(29, 51)
      temp = temp + M(46, 30) * M(30, 51)
      temp = temp + M(46, 34) * M(34, 51)
      temp = temp + M(46, 35) * M(35, 51)
      temp = temp + M(46, 36) * M(36, 51)
      temp = temp + M(46, 39) * M(39, 51)
      temp = temp + M(46, 40) * M(40, 51)
      temp = temp + M(46, 43) * M(43, 51)
      temp = temp + M(46, 44) * M(44, 51)
      temp = temp + M(46, 45) * M(45, 51)
      M(46, 51) = ( M(46, 51) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 43) * M(43, 54)
      temp = temp + M(46, 44) * M(44, 54)
      temp = temp + M(46, 45) * M(45, 54)
      M(46, 54) = ( M(46, 54) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 26) * M(26, 55)
      temp = temp + M(46, 29) * M(29, 55)
      temp = temp + M(46, 30) * M(30, 55)
      temp = temp + M(46, 34) * M(34, 55)
      temp = temp + M(46, 35) * M(35, 55)
      temp = temp + M(46, 36) * M(36, 55)
      temp = temp + M(46, 39) * M(39, 55)
      temp = temp + M(46, 40) * M(40, 55)
      temp = temp + M(46, 43) * M(43, 55)
      temp = temp + M(46, 44) * M(44, 55)
      temp = temp + M(46, 45) * M(45, 55)
      M(46, 55) = ( M(46, 55) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 26) * M(26, 56)
      temp = temp + M(46, 27) * M(27, 56)
      temp = temp + M(46, 28) * M(28, 56)
      temp = temp + M(46, 29) * M(29, 56)
      temp = temp + M(46, 30) * M(30, 56)
      temp = temp + M(46, 31) * M(31, 56)
      temp = temp + M(46, 32) * M(32, 56)
      temp = temp + M(46, 34) * M(34, 56)
      temp = temp + M(46, 35) * M(35, 56)
      temp = temp + M(46, 39) * M(39, 56)
      temp = temp + M(46, 40) * M(40, 56)
      temp = temp + M(46, 43) * M(43, 56)
      temp = temp + M(46, 44) * M(44, 56)
      temp = temp + M(46, 45) * M(45, 56)
      M(46, 56) = ( M(46, 56) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 21) * M(21, 57)
      temp = temp + M(46, 22) * M(22, 57)
      temp = temp + M(46, 26) * M(26, 57)
      temp = temp + M(46, 27) * M(27, 57)
      temp = temp + M(46, 28) * M(28, 57)
      temp = temp + M(46, 29) * M(29, 57)
      temp = temp + M(46, 30) * M(30, 57)
      temp = temp + M(46, 31) * M(31, 57)
      temp = temp + M(46, 32) * M(32, 57)
      temp = temp + M(46, 34) * M(34, 57)
      temp = temp + M(46, 35) * M(35, 57)
      temp = temp + M(46, 36) * M(36, 57)
      temp = temp + M(46, 39) * M(39, 57)
      temp = temp + M(46, 40) * M(40, 57)
      temp = temp + M(46, 43) * M(43, 57)
      temp = temp + M(46, 44) * M(44, 57)
      temp = temp + M(46, 45) * M(45, 57)
      M(46, 57) = ( M(46, 57) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 22) * M(22, 58)
      temp = temp + M(46, 27) * M(27, 58)
      temp = temp + M(46, 28) * M(28, 58)
      temp = temp + M(46, 29) * M(29, 58)
      temp = temp + M(46, 30) * M(30, 58)
      temp = temp + M(46, 31) * M(31, 58)
      temp = temp + M(46, 32) * M(32, 58)
      temp = temp + M(46, 34) * M(34, 58)
      temp = temp + M(46, 35) * M(35, 58)
      temp = temp + M(46, 36) * M(36, 58)
      temp = temp + M(46, 39) * M(39, 58)
      temp = temp + M(46, 40) * M(40, 58)
      temp = temp + M(46, 43) * M(43, 58)
      temp = temp + M(46, 44) * M(44, 58)
      temp = temp + M(46, 45) * M(45, 58)
      M(46, 58) = ( M(46, 58) - temp ) / M(46, 46)

C     Upper part.
      temp = M(47, 31) * M(31, 50)
      temp = temp + M(47, 46) * M(46, 50)
      M(47, 50) = ( M(47, 50) - temp ) / M(47, 47)
C     Upper part.
      temp = M(47, 46) * M(46, 51)
      M(47, 51) = ( M(47, 51) - temp ) / M(47, 47)
C     Upper part.
      temp = M(47, 46) * M(46, 54)
      M(47, 54) = ( M(47, 54) - temp ) / M(47, 47)
C     Upper part.
      temp = M(47, 46) * M(46, 55)
      M(47, 55) = ( M(47, 55) - temp ) / M(47, 47)
C     Upper part.
      temp = M(47, 31) * M(31, 56)
      temp = temp + M(47, 46) * M(46, 56)
      M(47, 56) = ( M(47, 56) - temp ) / M(47, 47)
C     Upper part.
      temp = M(47, 31) * M(31, 57)
      temp = temp + M(47, 46) * M(46, 57)
      M(47, 57) = ( M(47, 57) - temp ) / M(47, 47)
C     Upper part.
      temp = M(47, 31) * M(31, 58)
      temp = temp + M(47, 46) * M(46, 58)
      M(47, 58) = ( M(47, 58) - temp ) / M(47, 47)

C     Upper part.
      temp = M(48, 3) * M(3, 50)
      temp = temp + M(48, 15) * M(15, 50)
      temp = temp + M(48, 16) * M(16, 50)
      temp = temp + M(48, 18) * M(18, 50)
      temp = temp + M(48, 20) * M(20, 50)
      temp = temp + M(48, 21) * M(21, 50)
      temp = temp + M(48, 25) * M(25, 50)
      temp = temp + M(48, 26) * M(26, 50)
      temp = temp + M(48, 27) * M(27, 50)
      temp = temp + M(48, 28) * M(28, 50)
      temp = temp + M(48, 29) * M(29, 50)
      temp = temp + M(48, 30) * M(30, 50)
      temp = temp + M(48, 31) * M(31, 50)
      temp = temp + M(48, 32) * M(32, 50)
      temp = temp + M(48, 34) * M(34, 50)
      temp = temp + M(48, 35) * M(35, 50)
      temp = temp + M(48, 36) * M(36, 50)
      temp = temp + M(48, 39) * M(39, 50)
      temp = temp + M(48, 40) * M(40, 50)
      temp = temp + M(48, 43) * M(43, 50)
      temp = temp + M(48, 45) * M(45, 50)
      temp = temp + M(48, 46) * M(46, 50)
      temp = temp + M(48, 47) * M(47, 50)
      M(48, 50) = ( M(48, 50) - temp ) / M(48, 48)
C     Upper part.
      temp = M(48, 15) * M(15, 51)
      temp = temp + M(48, 16) * M(16, 51)
      temp = temp + M(48, 18) * M(18, 51)
      temp = temp + M(48, 25) * M(25, 51)
      temp = temp + M(48, 26) * M(26, 51)
      temp = temp + M(48, 29) * M(29, 51)
      temp = temp + M(48, 30) * M(30, 51)
      temp = temp + M(48, 34) * M(34, 51)
      temp = temp + M(48, 35) * M(35, 51)
      temp = temp + M(48, 36) * M(36, 51)
      temp = temp + M(48, 39) * M(39, 51)
      temp = temp + M(48, 40) * M(40, 51)
      temp = temp + M(48, 43) * M(43, 51)
      temp = temp + M(48, 45) * M(45, 51)
      temp = temp + M(48, 46) * M(46, 51)
      temp = temp + M(48, 47) * M(47, 51)
      M(48, 51) = ( M(48, 51) - temp ) / M(48, 48)
C     Upper part.
      temp = M(48, 43) * M(43, 54)
      temp = temp + M(48, 45) * M(45, 54)
      temp = temp + M(48, 46) * M(46, 54)
      temp = temp + M(48, 47) * M(47, 54)
      M(48, 54) = ( M(48, 54) - temp ) / M(48, 48)
C     Upper part.
      temp = M(48, 20) * M(20, 55)
      temp = temp + M(48, 26) * M(26, 55)
      temp = temp + M(48, 29) * M(29, 55)
      temp = temp + M(48, 30) * M(30, 55)
      temp = temp + M(48, 34) * M(34, 55)
      temp = temp + M(48, 35) * M(35, 55)
      temp = temp + M(48, 36) * M(36, 55)
      temp = temp + M(48, 39) * M(39, 55)
      temp = temp + M(48, 40) * M(40, 55)
      temp = temp + M(48, 43) * M(43, 55)
      temp = temp + M(48, 45) * M(45, 55)
      temp = temp + M(48, 46) * M(46, 55)
      temp = temp + M(48, 47) * M(47, 55)
      M(48, 55) = ( M(48, 55) - temp ) / M(48, 48)
C     Upper part.
      temp = M(48, 26) * M(26, 56)
      temp = temp + M(48, 27) * M(27, 56)
      temp = temp + M(48, 28) * M(28, 56)
      temp = temp + M(48, 29) * M(29, 56)
      temp = temp + M(48, 30) * M(30, 56)
      temp = temp + M(48, 31) * M(31, 56)
      temp = temp + M(48, 32) * M(32, 56)
      temp = temp + M(48, 34) * M(34, 56)
      temp = temp + M(48, 35) * M(35, 56)
      temp = temp + M(48, 39) * M(39, 56)
      temp = temp + M(48, 40) * M(40, 56)
      temp = temp + M(48, 43) * M(43, 56)
      temp = temp + M(48, 45) * M(45, 56)
      temp = temp + M(48, 46) * M(46, 56)
      temp = temp + M(48, 47) * M(47, 56)
      M(48, 56) = ( M(48, 56) - temp ) / M(48, 48)
C     Upper part.
      temp = M(48, 21) * M(21, 57)
      temp = temp + M(48, 26) * M(26, 57)
      temp = temp + M(48, 27) * M(27, 57)
      temp = temp + M(48, 28) * M(28, 57)
      temp = temp + M(48, 29) * M(29, 57)
      temp = temp + M(48, 30) * M(30, 57)
      temp = temp + M(48, 31) * M(31, 57)
      temp = temp + M(48, 32) * M(32, 57)
      temp = temp + M(48, 34) * M(34, 57)
      temp = temp + M(48, 35) * M(35, 57)
      temp = temp + M(48, 36) * M(36, 57)
      temp = temp + M(48, 39) * M(39, 57)
      temp = temp + M(48, 40) * M(40, 57)
      temp = temp + M(48, 43) * M(43, 57)
      temp = temp + M(48, 45) * M(45, 57)
      temp = temp + M(48, 46) * M(46, 57)
      temp = temp + M(48, 47) * M(47, 57)
      M(48, 57) = ( M(48, 57) - temp ) / M(48, 48)
C     Upper part.
      temp = M(48, 20) * M(20, 58)
      temp = temp + M(48, 27) * M(27, 58)
      temp = temp + M(48, 28) * M(28, 58)
      temp = temp + M(48, 29) * M(29, 58)
      temp = temp + M(48, 30) * M(30, 58)
      temp = temp + M(48, 31) * M(31, 58)
      temp = temp + M(48, 32) * M(32, 58)
      temp = temp + M(48, 34) * M(34, 58)
      temp = temp + M(48, 35) * M(35, 58)
      temp = temp + M(48, 36) * M(36, 58)
      temp = temp + M(48, 39) * M(39, 58)
      temp = temp + M(48, 40) * M(40, 58)
      temp = temp + M(48, 43) * M(43, 58)
      temp = temp + M(48, 45) * M(45, 58)
      temp = temp + M(48, 46) * M(46, 58)
      temp = temp + M(48, 47) * M(47, 58)
      M(48, 58) = ( M(48, 58) - temp ) / M(48, 48)

C     Upper part.
      temp = M(49, 13) * M(13, 50)
      temp = temp + M(49, 33) * M(33, 50)
      temp = temp + M(49, 44) * M(44, 50)
      temp = temp + M(49, 45) * M(45, 50)
      temp = temp + M(49, 46) * M(46, 50)
      temp = temp + M(49, 47) * M(47, 50)
      temp = temp + M(49, 48) * M(48, 50)
      M(49, 50) = ( M(49, 50) - temp ) / M(49, 49)
C     Upper part.
      temp = M(49, 11) * M(11, 51)
      temp = temp + M(49, 13) * M(13, 51)
      temp = temp + M(49, 33) * M(33, 51)
      temp = temp + M(49, 44) * M(44, 51)
      temp = temp + M(49, 45) * M(45, 51)
      temp = temp + M(49, 46) * M(46, 51)
      temp = temp + M(49, 47) * M(47, 51)
      temp = temp + M(49, 48) * M(48, 51)
      M(49, 51) = ( M(49, 51) - temp ) / M(49, 49)
C     Upper part.
      M(49, 52) = M(49, 52) / M(49, 49)
C     Upper part.
      temp = M(49, 44) * M(44, 54)
      temp = temp + M(49, 45) * M(45, 54)
      temp = temp + M(49, 46) * M(46, 54)
      temp = temp + M(49, 47) * M(47, 54)
      temp = temp + M(49, 48) * M(48, 54)
      M(49, 54) = ( M(49, 54) - temp ) / M(49, 49)
C     Upper part.
      temp = M(49, 11) * M(11, 55)
      temp = temp + M(49, 44) * M(44, 55)
      temp = temp + M(49, 45) * M(45, 55)
      temp = temp + M(49, 46) * M(46, 55)
      temp = temp + M(49, 47) * M(47, 55)
      temp = temp + M(49, 48) * M(48, 55)
      M(49, 55) = ( M(49, 55) - temp ) / M(49, 49)
C     Upper part.
      temp = M(49, 33) * M(33, 56)
      temp = temp + M(49, 44) * M(44, 56)
      temp = temp + M(49, 45) * M(45, 56)
      temp = temp + M(49, 46) * M(46, 56)
      temp = temp + M(49, 47) * M(47, 56)
      temp = temp + M(49, 48) * M(48, 56)
      M(49, 56) = ( M(49, 56) - temp ) / M(49, 49)
C     Upper part.
      temp = M(49, 33) * M(33, 57)
      temp = temp + M(49, 44) * M(44, 57)
      temp = temp + M(49, 45) * M(45, 57)
      temp = temp + M(49, 46) * M(46, 57)
      temp = temp + M(49, 47) * M(47, 57)
      temp = temp + M(49, 48) * M(48, 57)
      M(49, 57) = ( M(49, 57) - temp ) / M(49, 49)
C     Upper part.
      temp = M(49, 33) * M(33, 58)
      temp = temp + M(49, 44) * M(44, 58)
      temp = temp + M(49, 45) * M(45, 58)
      temp = temp + M(49, 46) * M(46, 58)
      temp = temp + M(49, 47) * M(47, 58)
      temp = temp + M(49, 48) * M(48, 58)
      M(49, 58) = ( M(49, 58) - temp ) / M(49, 49)

C     Lower part.
      temp = M(50, 1) * M(1, 50)
      temp = temp + M(50, 2) * M(2, 50)
      temp = temp + M(50, 3) * M(3, 50)
      temp = temp + M(50, 4) * M(4, 50)
      temp = temp + M(50, 5) * M(5, 50)
      temp = temp + M(50, 6) * M(6, 50)
      temp = temp + M(50, 7) * M(7, 50)
      temp = temp + M(50, 10) * M(10, 50)
      temp = temp + M(50, 12) * M(12, 50)
      temp = temp + M(50, 13) * M(13, 50)
      temp = temp + M(50, 15) * M(15, 50)
      temp = temp + M(50, 16) * M(16, 50)
      temp = temp + M(50, 17) * M(17, 50)
      temp = temp + M(50, 18) * M(18, 50)
      temp = temp + M(50, 20) * M(20, 50)
      temp = temp + M(50, 21) * M(21, 50)
      temp = temp + M(50, 22) * M(22, 50)
      temp = temp + M(50, 24) * M(24, 50)
      temp = temp + M(50, 25) * M(25, 50)
      temp = temp + M(50, 26) * M(26, 50)
      temp = temp + M(50, 33) * M(33, 50)
      temp = temp + M(50, 37) * M(37, 50)
      temp = temp + M(50, 38) * M(38, 50)
      temp = temp + M(50, 42) * M(42, 50)
      temp = temp + M(50, 43) * M(43, 50)
      temp = temp + M(50, 44) * M(44, 50)
      temp = temp + M(50, 45) * M(45, 50)
      temp = temp + M(50, 46) * M(46, 50)
      temp = temp + M(50, 47) * M(47, 50)
      temp = temp + M(50, 48) * M(48, 50)
      temp = temp + M(50, 49) * M(49, 50)
      M(50, 50) = M(50, 50) - temp
C     Lower part.
      temp = M(51, 13) * M(13, 50)
      temp = temp + M(51, 15) * M(15, 50)
      temp = temp + M(51, 16) * M(16, 50)
      temp = temp + M(51, 18) * M(18, 50)
      temp = temp + M(51, 20) * M(20, 50)
      temp = temp + M(51, 24) * M(24, 50)
      temp = temp + M(51, 25) * M(25, 50)
      temp = temp + M(51, 26) * M(26, 50)
      temp = temp + M(51, 33) * M(33, 50)
      temp = temp + M(51, 44) * M(44, 50)
      temp = temp + M(51, 45) * M(45, 50)
      temp = temp + M(51, 46) * M(46, 50)
      temp = temp + M(51, 47) * M(47, 50)
      temp = temp + M(51, 48) * M(48, 50)
      temp = temp + M(51, 49) * M(49, 50)
      M(51, 50) = M(51, 50) - temp
C     Lower part.
      temp = M(52, 31) * M(31, 50)
      temp = temp + M(52, 32) * M(32, 50)
      temp = temp + M(52, 40) * M(40, 50)
      temp = temp + M(52, 43) * M(43, 50)
      temp = temp + M(52, 45) * M(45, 50)
      temp = temp + M(52, 46) * M(46, 50)
      M(52, 50) = M(52, 50) - temp
C     Lower part.
      temp = M(53, 15) * M(15, 50)
      temp = temp + M(53, 16) * M(16, 50)
      temp = temp + M(53, 18) * M(18, 50)
      temp = temp + M(53, 25) * M(25, 50)
      temp = temp + M(53, 26) * M(26, 50)
      temp = temp + M(53, 44) * M(44, 50)
      temp = temp + M(53, 45) * M(45, 50)
      temp = temp + M(53, 46) * M(46, 50)
      temp = temp + M(53, 47) * M(47, 50)
      temp = temp + M(53, 48) * M(48, 50)
      M(53, 50) = M(53, 50) - temp
C     Lower part.
      temp = M(54, 13) * M(13, 50)
      temp = temp + M(54, 33) * M(33, 50)
      temp = temp + M(54, 46) * M(46, 50)
      M(54, 50) = M(54, 50) - temp
C     Lower part.
      temp = M(55, 20) * M(20, 50)
      temp = temp + M(55, 24) * M(24, 50)
      temp = temp + M(55, 26) * M(26, 50)
      temp = temp + M(55, 27) * M(27, 50)
      temp = temp + M(55, 28) * M(28, 50)
      temp = temp + M(55, 29) * M(29, 50)
      temp = temp + M(55, 30) * M(30, 50)
      temp = temp + M(55, 31) * M(31, 50)
      temp = temp + M(55, 32) * M(32, 50)
      temp = temp + M(55, 34) * M(34, 50)
      temp = temp + M(55, 35) * M(35, 50)
      temp = temp + M(55, 36) * M(36, 50)
      temp = temp + M(55, 37) * M(37, 50)
      temp = temp + M(55, 39) * M(39, 50)
      temp = temp + M(55, 40) * M(40, 50)
      temp = temp + M(55, 43) * M(43, 50)
      temp = temp + M(55, 45) * M(45, 50)
      temp = temp + M(55, 46) * M(46, 50)
      temp = temp + M(55, 49) * M(49, 50)
      M(55, 50) = M(55, 50) - temp
C     Lower part.
      temp = M(56, 12) * M(12, 50)
      temp = temp + M(56, 26) * M(26, 50)
      temp = temp + M(56, 27) * M(27, 50)
      temp = temp + M(56, 28) * M(28, 50)
      temp = temp + M(56, 29) * M(29, 50)
      temp = temp + M(56, 30) * M(30, 50)
      temp = temp + M(56, 31) * M(31, 50)
      temp = temp + M(56, 32) * M(32, 50)
      temp = temp + M(56, 34) * M(34, 50)
      temp = temp + M(56, 35) * M(35, 50)
      temp = temp + M(56, 39) * M(39, 50)
      temp = temp + M(56, 40) * M(40, 50)
      temp = temp + M(56, 43) * M(43, 50)
      temp = temp + M(56, 45) * M(45, 50)
      temp = temp + M(56, 46) * M(46, 50)
      M(56, 50) = M(56, 50) - temp
C     Lower part.
      temp = M(57, 1) * M(1, 50)
      temp = temp + M(57, 3) * M(3, 50)
      temp = temp + M(57, 6) * M(6, 50)
      temp = temp + M(57, 7) * M(7, 50)
      temp = temp + M(57, 10) * M(10, 50)
      temp = temp + M(57, 13) * M(13, 50)
      temp = temp + M(57, 15) * M(15, 50)
      temp = temp + M(57, 16) * M(16, 50)
      temp = temp + M(57, 18) * M(18, 50)
      temp = temp + M(57, 21) * M(21, 50)
      temp = temp + M(57, 24) * M(24, 50)
      temp = temp + M(57, 25) * M(25, 50)
      temp = temp + M(57, 26) * M(26, 50)
      temp = temp + M(57, 27) * M(27, 50)
      temp = temp + M(57, 28) * M(28, 50)
      temp = temp + M(57, 29) * M(29, 50)
      temp = temp + M(57, 30) * M(30, 50)
      temp = temp + M(57, 31) * M(31, 50)
      temp = temp + M(57, 32) * M(32, 50)
      temp = temp + M(57, 33) * M(33, 50)
      temp = temp + M(57, 34) * M(34, 50)
      temp = temp + M(57, 35) * M(35, 50)
      temp = temp + M(57, 36) * M(36, 50)
      temp = temp + M(57, 37) * M(37, 50)
      temp = temp + M(57, 39) * M(39, 50)
      temp = temp + M(57, 40) * M(40, 50)
      temp = temp + M(57, 42) * M(42, 50)
      temp = temp + M(57, 43) * M(43, 50)
      temp = temp + M(57, 44) * M(44, 50)
      temp = temp + M(57, 45) * M(45, 50)
      temp = temp + M(57, 46) * M(46, 50)
      temp = temp + M(57, 47) * M(47, 50)
      temp = temp + M(57, 48) * M(48, 50)
      M(57, 50) = M(57, 50) - temp
C     Lower part.
      temp = M(58, 20) * M(20, 50)
      temp = temp + M(58, 22) * M(22, 50)
      temp = temp + M(58, 27) * M(27, 50)
      temp = temp + M(58, 28) * M(28, 50)
      temp = temp + M(58, 29) * M(29, 50)
      temp = temp + M(58, 30) * M(30, 50)
      temp = temp + M(58, 31) * M(31, 50)
      temp = temp + M(58, 32) * M(32, 50)
      temp = temp + M(58, 34) * M(34, 50)
      temp = temp + M(58, 35) * M(35, 50)
      temp = temp + M(58, 36) * M(36, 50)
      temp = temp + M(58, 38) * M(38, 50)
      temp = temp + M(58, 39) * M(39, 50)
      temp = temp + M(58, 40) * M(40, 50)
      temp = temp + M(58, 43) * M(43, 50)
      temp = temp + M(58, 44) * M(44, 50)
      temp = temp + M(58, 45) * M(45, 50)
      temp = temp + M(58, 46) * M(46, 50)
      M(58, 50) = M(58, 50) - temp
C     Upper part.
      temp = M(50, 13) * M(13, 51)
      temp = temp + M(50, 15) * M(15, 51)
      temp = temp + M(50, 16) * M(16, 51)
      temp = temp + M(50, 17) * M(17, 51)
      temp = temp + M(50, 18) * M(18, 51)
      temp = temp + M(50, 25) * M(25, 51)
      temp = temp + M(50, 26) * M(26, 51)
      temp = temp + M(50, 33) * M(33, 51)
      temp = temp + M(50, 37) * M(37, 51)
      temp = temp + M(50, 38) * M(38, 51)
      temp = temp + M(50, 42) * M(42, 51)
      temp = temp + M(50, 43) * M(43, 51)
      temp = temp + M(50, 44) * M(44, 51)
      temp = temp + M(50, 45) * M(45, 51)
      temp = temp + M(50, 46) * M(46, 51)
      temp = temp + M(50, 47) * M(47, 51)
      temp = temp + M(50, 48) * M(48, 51)
      temp = temp + M(50, 49) * M(49, 51)
      M(50, 51) = ( M(50, 51) - temp ) / M(50, 50)
C     Upper part.
      temp = M(50, 49) * M(49, 52)
      M(50, 52) = ( M(50, 52) - temp ) / M(50, 50)
C     Upper part.
      M(50, 53) = M(50, 53) / M(50, 50)
C     Upper part.
      temp = M(50, 42) * M(42, 54)
      temp = temp + M(50, 43) * M(43, 54)
      temp = temp + M(50, 44) * M(44, 54)
      temp = temp + M(50, 45) * M(45, 54)
      temp = temp + M(50, 46) * M(46, 54)
      temp = temp + M(50, 47) * M(47, 54)
      temp = temp + M(50, 48) * M(48, 54)
      temp = temp + M(50, 49) * M(49, 54)
      M(50, 54) = ( M(50, 54) - temp ) / M(50, 50)
C     Upper part.
      temp = M(50, 20) * M(20, 55)
      temp = temp + M(50, 24) * M(24, 55)
      temp = temp + M(50, 26) * M(26, 55)
      temp = temp + M(50, 37) * M(37, 55)
      temp = temp + M(50, 38) * M(38, 55)
      temp = temp + M(50, 42) * M(42, 55)
      temp = temp + M(50, 43) * M(43, 55)
      temp = temp + M(50, 44) * M(44, 55)
      temp = temp + M(50, 45) * M(45, 55)
      temp = temp + M(50, 46) * M(46, 55)
      temp = temp + M(50, 47) * M(47, 55)
      temp = temp + M(50, 48) * M(48, 55)
      temp = temp + M(50, 49) * M(49, 55)
      M(50, 55) = ( M(50, 55) - temp ) / M(50, 50)
C     Upper part.
      temp = M(50, 12) * M(12, 56)
      temp = temp + M(50, 26) * M(26, 56)
      temp = temp + M(50, 33) * M(33, 56)
      temp = temp + M(50, 37) * M(37, 56)
      temp = temp + M(50, 38) * M(38, 56)
      temp = temp + M(50, 42) * M(42, 56)
      temp = temp + M(50, 43) * M(43, 56)
      temp = temp + M(50, 44) * M(44, 56)
      temp = temp + M(50, 45) * M(45, 56)
      temp = temp + M(50, 46) * M(46, 56)
      temp = temp + M(50, 47) * M(47, 56)
      temp = temp + M(50, 48) * M(48, 56)
      temp = temp + M(50, 49) * M(49, 56)
      M(50, 56) = ( M(50, 56) - temp ) / M(50, 50)
C     Upper part.
      temp = M(50, 10) * M(10, 57)
      temp = temp + M(50, 21) * M(21, 57)
      temp = temp + M(50, 22) * M(22, 57)
      temp = temp + M(50, 24) * M(24, 57)
      temp = temp + M(50, 26) * M(26, 57)
      temp = temp + M(50, 33) * M(33, 57)
      temp = temp + M(50, 37) * M(37, 57)
      temp = temp + M(50, 38) * M(38, 57)
      temp = temp + M(50, 42) * M(42, 57)
      temp = temp + M(50, 43) * M(43, 57)
      temp = temp + M(50, 44) * M(44, 57)
      temp = temp + M(50, 45) * M(45, 57)
      temp = temp + M(50, 46) * M(46, 57)
      temp = temp + M(50, 47) * M(47, 57)
      temp = temp + M(50, 48) * M(48, 57)
      temp = temp + M(50, 49) * M(49, 57)
      M(50, 57) = ( M(50, 57) - temp ) / M(50, 50)
C     Upper part.
      temp = M(50, 20) * M(20, 58)
      temp = temp + M(50, 22) * M(22, 58)
      temp = temp + M(50, 33) * M(33, 58)
      temp = temp + M(50, 37) * M(37, 58)
      temp = temp + M(50, 38) * M(38, 58)
      temp = temp + M(50, 42) * M(42, 58)
      temp = temp + M(50, 43) * M(43, 58)
      temp = temp + M(50, 44) * M(44, 58)
      temp = temp + M(50, 45) * M(45, 58)
      temp = temp + M(50, 46) * M(46, 58)
      temp = temp + M(50, 47) * M(47, 58)
      temp = temp + M(50, 48) * M(48, 58)
      temp = temp + M(50, 49) * M(49, 58)
      M(50, 58) = ( M(50, 58) - temp ) / M(50, 50)

C     Lower part.
      temp = M(51, 11) * M(11, 51)
      temp = temp + M(51, 13) * M(13, 51)
      temp = temp + M(51, 15) * M(15, 51)
      temp = temp + M(51, 16) * M(16, 51)
      temp = temp + M(51, 18) * M(18, 51)
      temp = temp + M(51, 25) * M(25, 51)
      temp = temp + M(51, 26) * M(26, 51)
      temp = temp + M(51, 33) * M(33, 51)
      temp = temp + M(51, 44) * M(44, 51)
      temp = temp + M(51, 45) * M(45, 51)
      temp = temp + M(51, 46) * M(46, 51)
      temp = temp + M(51, 47) * M(47, 51)
      temp = temp + M(51, 48) * M(48, 51)
      temp = temp + M(51, 49) * M(49, 51)
      temp = temp + M(51, 50) * M(50, 51)
      M(51, 51) = M(51, 51) - temp
C     Lower part.
      temp = M(52, 40) * M(40, 51)
      temp = temp + M(52, 43) * M(43, 51)
      temp = temp + M(52, 45) * M(45, 51)
      temp = temp + M(52, 46) * M(46, 51)
      temp = temp + M(52, 50) * M(50, 51)
      M(52, 51) = M(52, 51) - temp
C     Lower part.
      temp = M(53, 15) * M(15, 51)
      temp = temp + M(53, 16) * M(16, 51)
      temp = temp + M(53, 18) * M(18, 51)
      temp = temp + M(53, 25) * M(25, 51)
      temp = temp + M(53, 26) * M(26, 51)
      temp = temp + M(53, 44) * M(44, 51)
      temp = temp + M(53, 45) * M(45, 51)
      temp = temp + M(53, 46) * M(46, 51)
      temp = temp + M(53, 47) * M(47, 51)
      temp = temp + M(53, 48) * M(48, 51)
      temp = temp + M(53, 50) * M(50, 51)
      M(53, 51) = M(53, 51) - temp
C     Lower part.
      temp = M(54, 13) * M(13, 51)
      temp = temp + M(54, 33) * M(33, 51)
      temp = temp + M(54, 46) * M(46, 51)
      temp = temp + M(54, 50) * M(50, 51)
      M(54, 51) = M(54, 51) - temp
C     Lower part.
      temp = M(55, 11) * M(11, 51)
      temp = temp + M(55, 23) * M(23, 51)
      temp = temp + M(55, 26) * M(26, 51)
      temp = temp + M(55, 29) * M(29, 51)
      temp = temp + M(55, 30) * M(30, 51)
      temp = temp + M(55, 34) * M(34, 51)
      temp = temp + M(55, 35) * M(35, 51)
      temp = temp + M(55, 36) * M(36, 51)
      temp = temp + M(55, 37) * M(37, 51)
      temp = temp + M(55, 39) * M(39, 51)
      temp = temp + M(55, 40) * M(40, 51)
      temp = temp + M(55, 43) * M(43, 51)
      temp = temp + M(55, 45) * M(45, 51)
      temp = temp + M(55, 46) * M(46, 51)
      temp = temp + M(55, 49) * M(49, 51)
      temp = temp + M(55, 50) * M(50, 51)
      M(55, 51) = M(55, 51) - temp
C     Lower part.
      temp = M(56, 23) * M(23, 51)
      temp = temp + M(56, 26) * M(26, 51)
      temp = temp + M(56, 29) * M(29, 51)
      temp = temp + M(56, 30) * M(30, 51)
      temp = temp + M(56, 34) * M(34, 51)
      temp = temp + M(56, 35) * M(35, 51)
      temp = temp + M(56, 39) * M(39, 51)
      temp = temp + M(56, 40) * M(40, 51)
      temp = temp + M(56, 43) * M(43, 51)
      temp = temp + M(56, 45) * M(45, 51)
      temp = temp + M(56, 46) * M(46, 51)
      temp = temp + M(56, 50) * M(50, 51)
      M(56, 51) = M(56, 51) - temp
C     Lower part.
      temp = M(57, 13) * M(13, 51)
      temp = temp + M(57, 15) * M(15, 51)
      temp = temp + M(57, 16) * M(16, 51)
      temp = temp + M(57, 18) * M(18, 51)
      temp = temp + M(57, 25) * M(25, 51)
      temp = temp + M(57, 26) * M(26, 51)
      temp = temp + M(57, 29) * M(29, 51)
      temp = temp + M(57, 30) * M(30, 51)
      temp = temp + M(57, 33) * M(33, 51)
      temp = temp + M(57, 34) * M(34, 51)
      temp = temp + M(57, 35) * M(35, 51)
      temp = temp + M(57, 36) * M(36, 51)
      temp = temp + M(57, 37) * M(37, 51)
      temp = temp + M(57, 39) * M(39, 51)
      temp = temp + M(57, 40) * M(40, 51)
      temp = temp + M(57, 42) * M(42, 51)
      temp = temp + M(57, 43) * M(43, 51)
      temp = temp + M(57, 44) * M(44, 51)
      temp = temp + M(57, 45) * M(45, 51)
      temp = temp + M(57, 46) * M(46, 51)
      temp = temp + M(57, 47) * M(47, 51)
      temp = temp + M(57, 48) * M(48, 51)
      temp = temp + M(57, 50) * M(50, 51)
      M(57, 51) = M(57, 51) - temp
C     Lower part.
      temp = M(58, 29) * M(29, 51)
      temp = temp + M(58, 30) * M(30, 51)
      temp = temp + M(58, 34) * M(34, 51)
      temp = temp + M(58, 35) * M(35, 51)
      temp = temp + M(58, 36) * M(36, 51)
      temp = temp + M(58, 38) * M(38, 51)
      temp = temp + M(58, 39) * M(39, 51)
      temp = temp + M(58, 40) * M(40, 51)
      temp = temp + M(58, 43) * M(43, 51)
      temp = temp + M(58, 44) * M(44, 51)
      temp = temp + M(58, 45) * M(45, 51)
      temp = temp + M(58, 46) * M(46, 51)
      temp = temp + M(58, 50) * M(50, 51)
      M(58, 51) = M(58, 51) - temp
C     Upper part.
      temp = M(51, 49) * M(49, 52)
      temp = temp + M(51, 50) * M(50, 52)
      M(51, 52) = ( M(51, 52) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 50) * M(50, 53)
      M(51, 53) = ( M(51, 53) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 44) * M(44, 54)
      temp = temp + M(51, 45) * M(45, 54)
      temp = temp + M(51, 46) * M(46, 54)
      temp = temp + M(51, 47) * M(47, 54)
      temp = temp + M(51, 48) * M(48, 54)
      temp = temp + M(51, 49) * M(49, 54)
      temp = temp + M(51, 50) * M(50, 54)
      M(51, 54) = ( M(51, 54) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 11) * M(11, 55)
      temp = temp + M(51, 20) * M(20, 55)
      temp = temp + M(51, 24) * M(24, 55)
      temp = temp + M(51, 26) * M(26, 55)
      temp = temp + M(51, 44) * M(44, 55)
      temp = temp + M(51, 45) * M(45, 55)
      temp = temp + M(51, 46) * M(46, 55)
      temp = temp + M(51, 47) * M(47, 55)
      temp = temp + M(51, 48) * M(48, 55)
      temp = temp + M(51, 49) * M(49, 55)
      temp = temp + M(51, 50) * M(50, 55)
      M(51, 55) = ( M(51, 55) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 26) * M(26, 56)
      temp = temp + M(51, 33) * M(33, 56)
      temp = temp + M(51, 44) * M(44, 56)
      temp = temp + M(51, 45) * M(45, 56)
      temp = temp + M(51, 46) * M(46, 56)
      temp = temp + M(51, 47) * M(47, 56)
      temp = temp + M(51, 48) * M(48, 56)
      temp = temp + M(51, 49) * M(49, 56)
      temp = temp + M(51, 50) * M(50, 56)
      M(51, 56) = ( M(51, 56) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 24) * M(24, 57)
      temp = temp + M(51, 26) * M(26, 57)
      temp = temp + M(51, 33) * M(33, 57)
      temp = temp + M(51, 44) * M(44, 57)
      temp = temp + M(51, 45) * M(45, 57)
      temp = temp + M(51, 46) * M(46, 57)
      temp = temp + M(51, 47) * M(47, 57)
      temp = temp + M(51, 48) * M(48, 57)
      temp = temp + M(51, 49) * M(49, 57)
      temp = temp + M(51, 50) * M(50, 57)
      M(51, 57) = ( M(51, 57) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 20) * M(20, 58)
      temp = temp + M(51, 33) * M(33, 58)
      temp = temp + M(51, 44) * M(44, 58)
      temp = temp + M(51, 45) * M(45, 58)
      temp = temp + M(51, 46) * M(46, 58)
      temp = temp + M(51, 47) * M(47, 58)
      temp = temp + M(51, 48) * M(48, 58)
      temp = temp + M(51, 49) * M(49, 58)
      temp = temp + M(51, 50) * M(50, 58)
      M(51, 58) = ( M(51, 58) - temp ) / M(51, 51)

C     Lower part.
      temp = M(52, 50) * M(50, 52)
      temp = temp + M(52, 51) * M(51, 52)
      M(52, 52) = M(52, 52) - temp
C     Lower part.
      temp = M(53, 50) * M(50, 52)
      temp = temp + M(53, 51) * M(51, 52)
      M(53, 52) = M(53, 52) - temp
C     Lower part.
      temp = M(54, 50) * M(50, 52)
      temp = temp + M(54, 51) * M(51, 52)
      M(54, 52) = M(54, 52) - temp
C     Lower part.
      temp = M(55, 49) * M(49, 52)
      temp = temp + M(55, 50) * M(50, 52)
      temp = temp + M(55, 51) * M(51, 52)
      M(55, 52) = M(55, 52) - temp
C     Lower part.
      temp = M(56, 50) * M(50, 52)
      temp = temp + M(56, 51) * M(51, 52)
      M(56, 52) = M(56, 52) - temp
C     Lower part.
      temp = M(57, 50) * M(50, 52)
      temp = temp + M(57, 51) * M(51, 52)
      M(57, 52) = M(57, 52) - temp
C     Lower part.
      temp = M(58, 50) * M(50, 52)
      temp = temp + M(58, 51) * M(51, 52)
      M(58, 52) = M(58, 52) - temp
C     Upper part.
      temp = M(52, 50) * M(50, 53)
      temp = temp + M(52, 51) * M(51, 53)
      M(52, 53) = ( M(52, 53) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 43) * M(43, 54)
      temp = temp + M(52, 45) * M(45, 54)
      temp = temp + M(52, 46) * M(46, 54)
      temp = temp + M(52, 50) * M(50, 54)
      temp = temp + M(52, 51) * M(51, 54)
      M(52, 54) = ( M(52, 54) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 40) * M(40, 55)
      temp = temp + M(52, 43) * M(43, 55)
      temp = temp + M(52, 45) * M(45, 55)
      temp = temp + M(52, 46) * M(46, 55)
      temp = temp + M(52, 50) * M(50, 55)
      temp = temp + M(52, 51) * M(51, 55)
      M(52, 55) = ( M(52, 55) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 31) * M(31, 56)
      temp = temp + M(52, 32) * M(32, 56)
      temp = temp + M(52, 40) * M(40, 56)
      temp = temp + M(52, 43) * M(43, 56)
      temp = temp + M(52, 45) * M(45, 56)
      temp = temp + M(52, 46) * M(46, 56)
      temp = temp + M(52, 50) * M(50, 56)
      temp = temp + M(52, 51) * M(51, 56)
      M(52, 56) = ( M(52, 56) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 31) * M(31, 57)
      temp = temp + M(52, 32) * M(32, 57)
      temp = temp + M(52, 40) * M(40, 57)
      temp = temp + M(52, 43) * M(43, 57)
      temp = temp + M(52, 45) * M(45, 57)
      temp = temp + M(52, 46) * M(46, 57)
      temp = temp + M(52, 50) * M(50, 57)
      temp = temp + M(52, 51) * M(51, 57)
      M(52, 57) = ( M(52, 57) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 31) * M(31, 58)
      temp = temp + M(52, 32) * M(32, 58)
      temp = temp + M(52, 40) * M(40, 58)
      temp = temp + M(52, 43) * M(43, 58)
      temp = temp + M(52, 45) * M(45, 58)
      temp = temp + M(52, 46) * M(46, 58)
      temp = temp + M(52, 50) * M(50, 58)
      temp = temp + M(52, 51) * M(51, 58)
      M(52, 58) = ( M(52, 58) - temp ) / M(52, 52)

C     Lower part.
      temp = M(53, 50) * M(50, 53)
      temp = temp + M(53, 51) * M(51, 53)
      temp = temp + M(53, 52) * M(52, 53)
      M(53, 53) = M(53, 53) - temp
C     Lower part.
      temp = M(54, 50) * M(50, 53)
      temp = temp + M(54, 51) * M(51, 53)
      temp = temp + M(54, 52) * M(52, 53)
      M(54, 53) = M(54, 53) - temp
C     Lower part.
      temp = M(55, 50) * M(50, 53)
      temp = temp + M(55, 51) * M(51, 53)
      temp = temp + M(55, 52) * M(52, 53)
      M(55, 53) = M(55, 53) - temp
C     Lower part.
      temp = M(56, 50) * M(50, 53)
      temp = temp + M(56, 51) * M(51, 53)
      temp = temp + M(56, 52) * M(52, 53)
      M(56, 53) = M(56, 53) - temp
C     Lower part.
      temp = M(57, 50) * M(50, 53)
      temp = temp + M(57, 51) * M(51, 53)
      temp = temp + M(57, 52) * M(52, 53)
      M(57, 53) = M(57, 53) - temp
C     Lower part.
      temp = M(58, 50) * M(50, 53)
      temp = temp + M(58, 51) * M(51, 53)
      temp = temp + M(58, 52) * M(52, 53)
      M(58, 53) = M(58, 53) - temp
C     Upper part.
      temp = M(53, 44) * M(44, 54)
      temp = temp + M(53, 45) * M(45, 54)
      temp = temp + M(53, 46) * M(46, 54)
      temp = temp + M(53, 47) * M(47, 54)
      temp = temp + M(53, 48) * M(48, 54)
      temp = temp + M(53, 50) * M(50, 54)
      temp = temp + M(53, 51) * M(51, 54)
      temp = temp + M(53, 52) * M(52, 54)
      M(53, 54) = ( M(53, 54) - temp ) / M(53, 53)
C     Upper part.
      temp = M(53, 26) * M(26, 55)
      temp = temp + M(53, 44) * M(44, 55)
      temp = temp + M(53, 45) * M(45, 55)
      temp = temp + M(53, 46) * M(46, 55)
      temp = temp + M(53, 47) * M(47, 55)
      temp = temp + M(53, 48) * M(48, 55)
      temp = temp + M(53, 50) * M(50, 55)
      temp = temp + M(53, 51) * M(51, 55)
      temp = temp + M(53, 52) * M(52, 55)
      M(53, 55) = ( M(53, 55) - temp ) / M(53, 53)
C     Upper part.
      temp = M(53, 26) * M(26, 56)
      temp = temp + M(53, 44) * M(44, 56)
      temp = temp + M(53, 45) * M(45, 56)
      temp = temp + M(53, 46) * M(46, 56)
      temp = temp + M(53, 47) * M(47, 56)
      temp = temp + M(53, 48) * M(48, 56)
      temp = temp + M(53, 50) * M(50, 56)
      temp = temp + M(53, 51) * M(51, 56)
      temp = temp + M(53, 52) * M(52, 56)
      M(53, 56) = ( M(53, 56) - temp ) / M(53, 53)
C     Upper part.
      temp = M(53, 26) * M(26, 57)
      temp = temp + M(53, 44) * M(44, 57)
      temp = temp + M(53, 45) * M(45, 57)
      temp = temp + M(53, 46) * M(46, 57)
      temp = temp + M(53, 47) * M(47, 57)
      temp = temp + M(53, 48) * M(48, 57)
      temp = temp + M(53, 50) * M(50, 57)
      temp = temp + M(53, 51) * M(51, 57)
      temp = temp + M(53, 52) * M(52, 57)
      M(53, 57) = ( M(53, 57) - temp ) / M(53, 53)
C     Upper part.
      temp = M(53, 44) * M(44, 58)
      temp = temp + M(53, 45) * M(45, 58)
      temp = temp + M(53, 46) * M(46, 58)
      temp = temp + M(53, 47) * M(47, 58)
      temp = temp + M(53, 48) * M(48, 58)
      temp = temp + M(53, 50) * M(50, 58)
      temp = temp + M(53, 51) * M(51, 58)
      temp = temp + M(53, 52) * M(52, 58)
      M(53, 58) = ( M(53, 58) - temp ) / M(53, 53)

C     Lower part.
      temp = M(54, 14) * M(14, 54)
      temp = temp + M(54, 46) * M(46, 54)
      temp = temp + M(54, 50) * M(50, 54)
      temp = temp + M(54, 51) * M(51, 54)
      temp = temp + M(54, 52) * M(52, 54)
      temp = temp + M(54, 53) * M(53, 54)
      M(54, 54) = M(54, 54) - temp
C     Lower part.
      temp = M(55, 14) * M(14, 54)
      temp = temp + M(55, 43) * M(43, 54)
      temp = temp + M(55, 45) * M(45, 54)
      temp = temp + M(55, 46) * M(46, 54)
      temp = temp + M(55, 49) * M(49, 54)
      temp = temp + M(55, 50) * M(50, 54)
      temp = temp + M(55, 51) * M(51, 54)
      temp = temp + M(55, 52) * M(52, 54)
      temp = temp + M(55, 53) * M(53, 54)
      M(55, 54) = M(55, 54) - temp
C     Lower part.
      temp = M(56, 43) * M(43, 54)
      temp = temp + M(56, 45) * M(45, 54)
      temp = temp + M(56, 46) * M(46, 54)
      temp = temp + M(56, 50) * M(50, 54)
      temp = temp + M(56, 51) * M(51, 54)
      temp = temp + M(56, 52) * M(52, 54)
      temp = temp + M(56, 53) * M(53, 54)
      M(56, 54) = M(56, 54) - temp
C     Lower part.
      temp = M(57, 42) * M(42, 54)
      temp = temp + M(57, 43) * M(43, 54)
      temp = temp + M(57, 44) * M(44, 54)
      temp = temp + M(57, 45) * M(45, 54)
      temp = temp + M(57, 46) * M(46, 54)
      temp = temp + M(57, 47) * M(47, 54)
      temp = temp + M(57, 48) * M(48, 54)
      temp = temp + M(57, 50) * M(50, 54)
      temp = temp + M(57, 51) * M(51, 54)
      temp = temp + M(57, 52) * M(52, 54)
      temp = temp + M(57, 53) * M(53, 54)
      M(57, 54) = M(57, 54) - temp
C     Lower part.
      temp = M(58, 43) * M(43, 54)
      temp = temp + M(58, 44) * M(44, 54)
      temp = temp + M(58, 45) * M(45, 54)
      temp = temp + M(58, 46) * M(46, 54)
      temp = temp + M(58, 50) * M(50, 54)
      temp = temp + M(58, 51) * M(51, 54)
      temp = temp + M(58, 52) * M(52, 54)
      temp = temp + M(58, 53) * M(53, 54)
      M(58, 54) = M(58, 54) - temp
C     Upper part.
      temp = M(54, 14) * M(14, 55)
      temp = temp + M(54, 46) * M(46, 55)
      temp = temp + M(54, 50) * M(50, 55)
      temp = temp + M(54, 51) * M(51, 55)
      temp = temp + M(54, 52) * M(52, 55)
      temp = temp + M(54, 53) * M(53, 55)
      M(54, 55) = ( M(54, 55) - temp ) / M(54, 54)
C     Upper part.
      temp = M(54, 33) * M(33, 56)
      temp = temp + M(54, 46) * M(46, 56)
      temp = temp + M(54, 50) * M(50, 56)
      temp = temp + M(54, 51) * M(51, 56)
      temp = temp + M(54, 52) * M(52, 56)
      temp = temp + M(54, 53) * M(53, 56)
      M(54, 56) = ( M(54, 56) - temp ) / M(54, 54)
C     Upper part.
      temp = M(54, 33) * M(33, 57)
      temp = temp + M(54, 46) * M(46, 57)
      temp = temp + M(54, 50) * M(50, 57)
      temp = temp + M(54, 51) * M(51, 57)
      temp = temp + M(54, 52) * M(52, 57)
      temp = temp + M(54, 53) * M(53, 57)
      M(54, 57) = ( M(54, 57) - temp ) / M(54, 54)
C     Upper part.
      temp = M(54, 33) * M(33, 58)
      temp = temp + M(54, 46) * M(46, 58)
      temp = temp + M(54, 50) * M(50, 58)
      temp = temp + M(54, 51) * M(51, 58)
      temp = temp + M(54, 52) * M(52, 58)
      temp = temp + M(54, 53) * M(53, 58)
      M(54, 58) = ( M(54, 58) - temp ) / M(54, 54)

C     Lower part.
      temp = M(55, 11) * M(11, 55)
      temp = temp + M(55, 14) * M(14, 55)
      temp = temp + M(55, 20) * M(20, 55)
      temp = temp + M(55, 23) * M(23, 55)
      temp = temp + M(55, 24) * M(24, 55)
      temp = temp + M(55, 26) * M(26, 55)
      temp = temp + M(55, 29) * M(29, 55)
      temp = temp + M(55, 30) * M(30, 55)
      temp = temp + M(55, 34) * M(34, 55)
      temp = temp + M(55, 35) * M(35, 55)
      temp = temp + M(55, 36) * M(36, 55)
      temp = temp + M(55, 37) * M(37, 55)
      temp = temp + M(55, 39) * M(39, 55)
      temp = temp + M(55, 40) * M(40, 55)
      temp = temp + M(55, 43) * M(43, 55)
      temp = temp + M(55, 45) * M(45, 55)
      temp = temp + M(55, 46) * M(46, 55)
      temp = temp + M(55, 49) * M(49, 55)
      temp = temp + M(55, 50) * M(50, 55)
      temp = temp + M(55, 51) * M(51, 55)
      temp = temp + M(55, 52) * M(52, 55)
      temp = temp + M(55, 53) * M(53, 55)
      temp = temp + M(55, 54) * M(54, 55)
      M(55, 55) = M(55, 55) - temp
C     Lower part.
      temp = M(56, 23) * M(23, 55)
      temp = temp + M(56, 26) * M(26, 55)
      temp = temp + M(56, 29) * M(29, 55)
      temp = temp + M(56, 30) * M(30, 55)
      temp = temp + M(56, 34) * M(34, 55)
      temp = temp + M(56, 35) * M(35, 55)
      temp = temp + M(56, 39) * M(39, 55)
      temp = temp + M(56, 40) * M(40, 55)
      temp = temp + M(56, 43) * M(43, 55)
      temp = temp + M(56, 45) * M(45, 55)
      temp = temp + M(56, 46) * M(46, 55)
      temp = temp + M(56, 50) * M(50, 55)
      temp = temp + M(56, 51) * M(51, 55)
      temp = temp + M(56, 52) * M(52, 55)
      temp = temp + M(56, 53) * M(53, 55)
      temp = temp + M(56, 54) * M(54, 55)
      M(56, 55) = M(56, 55) - temp
C     Lower part.
      temp = M(57, 24) * M(24, 55)
      temp = temp + M(57, 26) * M(26, 55)
      temp = temp + M(57, 29) * M(29, 55)
      temp = temp + M(57, 30) * M(30, 55)
      temp = temp + M(57, 34) * M(34, 55)
      temp = temp + M(57, 35) * M(35, 55)
      temp = temp + M(57, 36) * M(36, 55)
      temp = temp + M(57, 37) * M(37, 55)
      temp = temp + M(57, 39) * M(39, 55)
      temp = temp + M(57, 40) * M(40, 55)
      temp = temp + M(57, 42) * M(42, 55)
      temp = temp + M(57, 43) * M(43, 55)
      temp = temp + M(57, 44) * M(44, 55)
      temp = temp + M(57, 45) * M(45, 55)
      temp = temp + M(57, 46) * M(46, 55)
      temp = temp + M(57, 47) * M(47, 55)
      temp = temp + M(57, 48) * M(48, 55)
      temp = temp + M(57, 50) * M(50, 55)
      temp = temp + M(57, 51) * M(51, 55)
      temp = temp + M(57, 52) * M(52, 55)
      temp = temp + M(57, 53) * M(53, 55)
      temp = temp + M(57, 54) * M(54, 55)
      M(57, 55) = M(57, 55) - temp
C     Lower part.
      temp = M(58, 20) * M(20, 55)
      temp = temp + M(58, 29) * M(29, 55)
      temp = temp + M(58, 30) * M(30, 55)
      temp = temp + M(58, 34) * M(34, 55)
      temp = temp + M(58, 35) * M(35, 55)
      temp = temp + M(58, 36) * M(36, 55)
      temp = temp + M(58, 38) * M(38, 55)
      temp = temp + M(58, 39) * M(39, 55)
      temp = temp + M(58, 40) * M(40, 55)
      temp = temp + M(58, 43) * M(43, 55)
      temp = temp + M(58, 44) * M(44, 55)
      temp = temp + M(58, 45) * M(45, 55)
      temp = temp + M(58, 46) * M(46, 55)
      temp = temp + M(58, 50) * M(50, 55)
      temp = temp + M(58, 51) * M(51, 55)
      temp = temp + M(58, 52) * M(52, 55)
      temp = temp + M(58, 53) * M(53, 55)
      temp = temp + M(58, 54) * M(54, 55)
      M(58, 55) = M(58, 55) - temp
C     Upper part.
      temp = M(55, 26) * M(26, 56)
      temp = temp + M(55, 27) * M(27, 56)
      temp = temp + M(55, 28) * M(28, 56)
      temp = temp + M(55, 29) * M(29, 56)
      temp = temp + M(55, 30) * M(30, 56)
      temp = temp + M(55, 31) * M(31, 56)
      temp = temp + M(55, 32) * M(32, 56)
      temp = temp + M(55, 34) * M(34, 56)
      temp = temp + M(55, 35) * M(35, 56)
      temp = temp + M(55, 37) * M(37, 56)
      temp = temp + M(55, 39) * M(39, 56)
      temp = temp + M(55, 40) * M(40, 56)
      temp = temp + M(55, 43) * M(43, 56)
      temp = temp + M(55, 45) * M(45, 56)
      temp = temp + M(55, 46) * M(46, 56)
      temp = temp + M(55, 49) * M(49, 56)
      temp = temp + M(55, 50) * M(50, 56)
      temp = temp + M(55, 51) * M(51, 56)
      temp = temp + M(55, 52) * M(52, 56)
      temp = temp + M(55, 53) * M(53, 56)
      temp = temp + M(55, 54) * M(54, 56)
      M(55, 56) = ( M(55, 56) - temp ) / M(55, 55)
C     Upper part.
      temp = M(55, 24) * M(24, 57)
      temp = temp + M(55, 26) * M(26, 57)
      temp = temp + M(55, 27) * M(27, 57)
      temp = temp + M(55, 28) * M(28, 57)
      temp = temp + M(55, 29) * M(29, 57)
      temp = temp + M(55, 30) * M(30, 57)
      temp = temp + M(55, 31) * M(31, 57)
      temp = temp + M(55, 32) * M(32, 57)
      temp = temp + M(55, 34) * M(34, 57)
      temp = temp + M(55, 35) * M(35, 57)
      temp = temp + M(55, 36) * M(36, 57)
      temp = temp + M(55, 37) * M(37, 57)
      temp = temp + M(55, 39) * M(39, 57)
      temp = temp + M(55, 40) * M(40, 57)
      temp = temp + M(55, 43) * M(43, 57)
      temp = temp + M(55, 45) * M(45, 57)
      temp = temp + M(55, 46) * M(46, 57)
      temp = temp + M(55, 49) * M(49, 57)
      temp = temp + M(55, 50) * M(50, 57)
      temp = temp + M(55, 51) * M(51, 57)
      temp = temp + M(55, 52) * M(52, 57)
      temp = temp + M(55, 53) * M(53, 57)
      temp = temp + M(55, 54) * M(54, 57)
      M(55, 57) = ( M(55, 57) - temp ) / M(55, 55)
C     Upper part.
      temp = M(55, 20) * M(20, 58)
      temp = temp + M(55, 27) * M(27, 58)
      temp = temp + M(55, 28) * M(28, 58)
      temp = temp + M(55, 29) * M(29, 58)
      temp = temp + M(55, 30) * M(30, 58)
      temp = temp + M(55, 31) * M(31, 58)
      temp = temp + M(55, 32) * M(32, 58)
      temp = temp + M(55, 34) * M(34, 58)
      temp = temp + M(55, 35) * M(35, 58)
      temp = temp + M(55, 36) * M(36, 58)
      temp = temp + M(55, 37) * M(37, 58)
      temp = temp + M(55, 39) * M(39, 58)
      temp = temp + M(55, 40) * M(40, 58)
      temp = temp + M(55, 43) * M(43, 58)
      temp = temp + M(55, 45) * M(45, 58)
      temp = temp + M(55, 46) * M(46, 58)
      temp = temp + M(55, 49) * M(49, 58)
      temp = temp + M(55, 50) * M(50, 58)
      temp = temp + M(55, 51) * M(51, 58)
      temp = temp + M(55, 52) * M(52, 58)
      temp = temp + M(55, 53) * M(53, 58)
      temp = temp + M(55, 54) * M(54, 58)
      M(55, 58) = ( M(55, 58) - temp ) / M(55, 55)

C     Lower part.
      temp = M(56, 12) * M(12, 56)
      temp = temp + M(56, 26) * M(26, 56)
      temp = temp + M(56, 27) * M(27, 56)
      temp = temp + M(56, 28) * M(28, 56)
      temp = temp + M(56, 29) * M(29, 56)
      temp = temp + M(56, 30) * M(30, 56)
      temp = temp + M(56, 31) * M(31, 56)
      temp = temp + M(56, 32) * M(32, 56)
      temp = temp + M(56, 34) * M(34, 56)
      temp = temp + M(56, 35) * M(35, 56)
      temp = temp + M(56, 39) * M(39, 56)
      temp = temp + M(56, 40) * M(40, 56)
      temp = temp + M(56, 43) * M(43, 56)
      temp = temp + M(56, 45) * M(45, 56)
      temp = temp + M(56, 46) * M(46, 56)
      temp = temp + M(56, 50) * M(50, 56)
      temp = temp + M(56, 51) * M(51, 56)
      temp = temp + M(56, 52) * M(52, 56)
      temp = temp + M(56, 53) * M(53, 56)
      temp = temp + M(56, 54) * M(54, 56)
      temp = temp + M(56, 55) * M(55, 56)
      M(56, 56) = M(56, 56) - temp
C     Lower part.
      temp = M(57, 26) * M(26, 56)
      temp = temp + M(57, 27) * M(27, 56)
      temp = temp + M(57, 28) * M(28, 56)
      temp = temp + M(57, 29) * M(29, 56)
      temp = temp + M(57, 30) * M(30, 56)
      temp = temp + M(57, 31) * M(31, 56)
      temp = temp + M(57, 32) * M(32, 56)
      temp = temp + M(57, 33) * M(33, 56)
      temp = temp + M(57, 34) * M(34, 56)
      temp = temp + M(57, 35) * M(35, 56)
      temp = temp + M(57, 37) * M(37, 56)
      temp = temp + M(57, 39) * M(39, 56)
      temp = temp + M(57, 40) * M(40, 56)
      temp = temp + M(57, 42) * M(42, 56)
      temp = temp + M(57, 43) * M(43, 56)
      temp = temp + M(57, 44) * M(44, 56)
      temp = temp + M(57, 45) * M(45, 56)
      temp = temp + M(57, 46) * M(46, 56)
      temp = temp + M(57, 47) * M(47, 56)
      temp = temp + M(57, 48) * M(48, 56)
      temp = temp + M(57, 50) * M(50, 56)
      temp = temp + M(57, 51) * M(51, 56)
      temp = temp + M(57, 52) * M(52, 56)
      temp = temp + M(57, 53) * M(53, 56)
      temp = temp + M(57, 54) * M(54, 56)
      temp = temp + M(57, 55) * M(55, 56)
      M(57, 56) = M(57, 56) - temp
C     Lower part.
      temp = M(58, 27) * M(27, 56)
      temp = temp + M(58, 28) * M(28, 56)
      temp = temp + M(58, 29) * M(29, 56)
      temp = temp + M(58, 30) * M(30, 56)
      temp = temp + M(58, 31) * M(31, 56)
      temp = temp + M(58, 32) * M(32, 56)
      temp = temp + M(58, 34) * M(34, 56)
      temp = temp + M(58, 35) * M(35, 56)
      temp = temp + M(58, 38) * M(38, 56)
      temp = temp + M(58, 39) * M(39, 56)
      temp = temp + M(58, 40) * M(40, 56)
      temp = temp + M(58, 43) * M(43, 56)
      temp = temp + M(58, 44) * M(44, 56)
      temp = temp + M(58, 45) * M(45, 56)
      temp = temp + M(58, 46) * M(46, 56)
      temp = temp + M(58, 50) * M(50, 56)
      temp = temp + M(58, 51) * M(51, 56)
      temp = temp + M(58, 52) * M(52, 56)
      temp = temp + M(58, 53) * M(53, 56)
      temp = temp + M(58, 54) * M(54, 56)
      temp = temp + M(58, 55) * M(55, 56)
      M(58, 56) = M(58, 56) - temp
C     Upper part.
      temp = M(56, 26) * M(26, 57)
      temp = temp + M(56, 27) * M(27, 57)
      temp = temp + M(56, 28) * M(28, 57)
      temp = temp + M(56, 29) * M(29, 57)
      temp = temp + M(56, 30) * M(30, 57)
      temp = temp + M(56, 31) * M(31, 57)
      temp = temp + M(56, 32) * M(32, 57)
      temp = temp + M(56, 34) * M(34, 57)
      temp = temp + M(56, 35) * M(35, 57)
      temp = temp + M(56, 39) * M(39, 57)
      temp = temp + M(56, 40) * M(40, 57)
      temp = temp + M(56, 43) * M(43, 57)
      temp = temp + M(56, 45) * M(45, 57)
      temp = temp + M(56, 46) * M(46, 57)
      temp = temp + M(56, 50) * M(50, 57)
      temp = temp + M(56, 51) * M(51, 57)
      temp = temp + M(56, 52) * M(52, 57)
      temp = temp + M(56, 53) * M(53, 57)
      temp = temp + M(56, 54) * M(54, 57)
      temp = temp + M(56, 55) * M(55, 57)
      M(56, 57) = ( M(56, 57) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 27) * M(27, 58)
      temp = temp + M(56, 28) * M(28, 58)
      temp = temp + M(56, 29) * M(29, 58)
      temp = temp + M(56, 30) * M(30, 58)
      temp = temp + M(56, 31) * M(31, 58)
      temp = temp + M(56, 32) * M(32, 58)
      temp = temp + M(56, 34) * M(34, 58)
      temp = temp + M(56, 35) * M(35, 58)
      temp = temp + M(56, 39) * M(39, 58)
      temp = temp + M(56, 40) * M(40, 58)
      temp = temp + M(56, 43) * M(43, 58)
      temp = temp + M(56, 45) * M(45, 58)
      temp = temp + M(56, 46) * M(46, 58)
      temp = temp + M(56, 50) * M(50, 58)
      temp = temp + M(56, 51) * M(51, 58)
      temp = temp + M(56, 52) * M(52, 58)
      temp = temp + M(56, 53) * M(53, 58)
      temp = temp + M(56, 54) * M(54, 58)
      temp = temp + M(56, 55) * M(55, 58)
      M(56, 58) = ( M(56, 58) - temp ) / M(56, 56)

C     Lower part.
      temp = M(57, 10) * M(10, 57)
      temp = temp + M(57, 21) * M(21, 57)
      temp = temp + M(57, 24) * M(24, 57)
      temp = temp + M(57, 26) * M(26, 57)
      temp = temp + M(57, 27) * M(27, 57)
      temp = temp + M(57, 28) * M(28, 57)
      temp = temp + M(57, 29) * M(29, 57)
      temp = temp + M(57, 30) * M(30, 57)
      temp = temp + M(57, 31) * M(31, 57)
      temp = temp + M(57, 32) * M(32, 57)
      temp = temp + M(57, 33) * M(33, 57)
      temp = temp + M(57, 34) * M(34, 57)
      temp = temp + M(57, 35) * M(35, 57)
      temp = temp + M(57, 36) * M(36, 57)
      temp = temp + M(57, 37) * M(37, 57)
      temp = temp + M(57, 39) * M(39, 57)
      temp = temp + M(57, 40) * M(40, 57)
      temp = temp + M(57, 42) * M(42, 57)
      temp = temp + M(57, 43) * M(43, 57)
      temp = temp + M(57, 44) * M(44, 57)
      temp = temp + M(57, 45) * M(45, 57)
      temp = temp + M(57, 46) * M(46, 57)
      temp = temp + M(57, 47) * M(47, 57)
      temp = temp + M(57, 48) * M(48, 57)
      temp = temp + M(57, 50) * M(50, 57)
      temp = temp + M(57, 51) * M(51, 57)
      temp = temp + M(57, 52) * M(52, 57)
      temp = temp + M(57, 53) * M(53, 57)
      temp = temp + M(57, 54) * M(54, 57)
      temp = temp + M(57, 55) * M(55, 57)
      temp = temp + M(57, 56) * M(56, 57)
      M(57, 57) = M(57, 57) - temp
C     Lower part.
      temp = M(58, 22) * M(22, 57)
      temp = temp + M(58, 27) * M(27, 57)
      temp = temp + M(58, 28) * M(28, 57)
      temp = temp + M(58, 29) * M(29, 57)
      temp = temp + M(58, 30) * M(30, 57)
      temp = temp + M(58, 31) * M(31, 57)
      temp = temp + M(58, 32) * M(32, 57)
      temp = temp + M(58, 34) * M(34, 57)
      temp = temp + M(58, 35) * M(35, 57)
      temp = temp + M(58, 36) * M(36, 57)
      temp = temp + M(58, 38) * M(38, 57)
      temp = temp + M(58, 39) * M(39, 57)
      temp = temp + M(58, 40) * M(40, 57)
      temp = temp + M(58, 43) * M(43, 57)
      temp = temp + M(58, 44) * M(44, 57)
      temp = temp + M(58, 45) * M(45, 57)
      temp = temp + M(58, 46) * M(46, 57)
      temp = temp + M(58, 50) * M(50, 57)
      temp = temp + M(58, 51) * M(51, 57)
      temp = temp + M(58, 52) * M(52, 57)
      temp = temp + M(58, 53) * M(53, 57)
      temp = temp + M(58, 54) * M(54, 57)
      temp = temp + M(58, 55) * M(55, 57)
      temp = temp + M(58, 56) * M(56, 57)
      M(58, 57) = M(58, 57) - temp
C     Upper part.
      temp = M(57, 27) * M(27, 58)
      temp = temp + M(57, 28) * M(28, 58)
      temp = temp + M(57, 29) * M(29, 58)
      temp = temp + M(57, 30) * M(30, 58)
      temp = temp + M(57, 31) * M(31, 58)
      temp = temp + M(57, 32) * M(32, 58)
      temp = temp + M(57, 33) * M(33, 58)
      temp = temp + M(57, 34) * M(34, 58)
      temp = temp + M(57, 35) * M(35, 58)
      temp = temp + M(57, 36) * M(36, 58)
      temp = temp + M(57, 37) * M(37, 58)
      temp = temp + M(57, 39) * M(39, 58)
      temp = temp + M(57, 40) * M(40, 58)
      temp = temp + M(57, 42) * M(42, 58)
      temp = temp + M(57, 43) * M(43, 58)
      temp = temp + M(57, 44) * M(44, 58)
      temp = temp + M(57, 45) * M(45, 58)
      temp = temp + M(57, 46) * M(46, 58)
      temp = temp + M(57, 47) * M(47, 58)
      temp = temp + M(57, 48) * M(48, 58)
      temp = temp + M(57, 50) * M(50, 58)
      temp = temp + M(57, 51) * M(51, 58)
      temp = temp + M(57, 52) * M(52, 58)
      temp = temp + M(57, 53) * M(53, 58)
      temp = temp + M(57, 54) * M(54, 58)
      temp = temp + M(57, 55) * M(55, 58)
      temp = temp + M(57, 56) * M(56, 58)
      M(57, 58) = ( M(57, 58) - temp ) / M(57, 57)

C     Lower part.
      temp = M(58, 20) * M(20, 58)
      temp = temp + M(58, 22) * M(22, 58)
      temp = temp + M(58, 27) * M(27, 58)
      temp = temp + M(58, 28) * M(28, 58)
      temp = temp + M(58, 29) * M(29, 58)
      temp = temp + M(58, 30) * M(30, 58)
      temp = temp + M(58, 31) * M(31, 58)
      temp = temp + M(58, 32) * M(32, 58)
      temp = temp + M(58, 34) * M(34, 58)
      temp = temp + M(58, 35) * M(35, 58)
      temp = temp + M(58, 36) * M(36, 58)
      temp = temp + M(58, 38) * M(38, 58)
      temp = temp + M(58, 39) * M(39, 58)
      temp = temp + M(58, 40) * M(40, 58)
      temp = temp + M(58, 43) * M(43, 58)
      temp = temp + M(58, 44) * M(44, 58)
      temp = temp + M(58, 45) * M(45, 58)
      temp = temp + M(58, 46) * M(46, 58)
      temp = temp + M(58, 50) * M(50, 58)
      temp = temp + M(58, 51) * M(51, 58)
      temp = temp + M(58, 52) * M(52, 58)
      temp = temp + M(58, 53) * M(53, 58)
      temp = temp + M(58, 54) * M(54, 58)
      temp = temp + M(58, 55) * M(55, 58)
      temp = temp + M(58, 56) * M(56, 58)
      temp = temp + M(58, 57) * M(57, 58)
      M(58, 58) = M(58, 58) - temp


      END
