C------------------------------------------------------------------------
C     Copyright (C) 2001-2008, ENPC - INRIA - EDF R&D
C
C     This file is part of the air quality modeling system Polyphemus.
C
C     Polyphemus is developed in the INRIA - ENPC joint project-team
C     CLIME and in the ENPC - EDF R&D joint laboratory CEREA.
C
C     Polyphemus is free software; you can redistribute i and/or modify
C     it under the terms of the GNU General Public License as published
C     by the Free Software Foundation; either version 2 of the License,
C     or (at your option) any later version.
C
C     Polyphemus is distributed in the hope that it will be useful, but
C     WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
C     General Public License for more details.
C
C     For more information, visit the Polyphemus web site:
C     http://cerea.enpc.fr/polyphemus/
C------------------------------------------------------------------------
 
      subroutine dratedc_radm(ns,nr,rk,y,dw)
 
C------------------------------------------------------------------------
C
C     -- DESCRIPTION
C
C     This routine computes the derivative of reaction rates.
C     This routine is automatically generated by SPACK.
C     Mechanism: RADM                
C     Species: _ciRADM             
C
C------------------------------------------------------------------------
C
C     -- INPUT VARIABLES
C
C     Ns: chemical species number.
C     NR: reaction number.
C     RK: kinetic rates.
C     Y: chemical concentrations.
C
C     -- INPUT/OUTPUT VARIABLES
C
C     -- OUTPUT VARIABLES
C
C     DW: derivative of reaction rates wrt Y.
C
C------------------------------------------------------------------------
C
C     -- REMARKS
C
C------------------------------------------------------------------------
C
C     -- MODIFICATIONS
C
C------------------------------------------------------------------------
C
C     -- AUTHOR(S)
C
C     SPACK.
C
C------------------------------------------------------------------------
 
      implicit none
 
      integer nr,ns
      double precision rk(nr),y(ns),dw(nr,ns)
 
 
 
      dw(  1, 55) =  rk(  1)
      dw(  2, 26) =  rk(  2)
      dw(  3, 26) =  rk(  3)
      dw(  4, 12) =  rk(  4)
      dw(  5, 49) =  rk(  5)
      dw(  6, 24) =  rk(  6)
      dw(  7, 51) =  rk(  7)
      dw(  8, 51) =  rk(  8)
      dw(  9, 10) =  rk(  9)
      dw( 10, 48) =  rk( 10)
      dw( 11, 48) =  rk( 11)
      dw( 12, 44) =  rk( 12)
      dw( 13, 21) =  rk( 13)
      dw( 14, 42) =  rk( 14)
      dw( 15, 22) =  rk( 15)
      dw( 16, 38) =  rk( 16)
      dw( 17, 47) =  rk( 17)
      dw( 18, 47) =  rk( 18)
      dw( 19, 52) =  rk( 19)
      dw( 20, 33) =  rk( 20)
      dw( 21, 37) =  rk( 21)
      dw( 22, 23) =  rk( 22) * Y( 55)
      dw( 22, 55) =  rk( 22) * Y( 23)
      dw( 23,  8) =  rk( 23)
      dw( 24,  8) =  rk( 24)
      dw( 25,  8) =  rk( 25)
      dw( 26, 26) =  rk( 26) * Y( 56)
      dw( 26, 56) =  rk( 26) * Y( 26)
      dw( 27, 26) =  rk( 27) * Y( 50)
      dw( 27, 50) =  rk( 27) * Y( 26)
      dw( 28, 26) =  rk( 28) * Y( 57)
      dw( 28, 57) =  rk( 28) * Y( 26)
      dw( 29, 57) =  rk( 29) * Y( 56)
      dw( 29, 56) =  rk( 29) * Y( 57)
      dw( 30, 10) =  rk( 30) * Y( 50)
      dw( 30, 50) =  rk( 30) * Y( 10)
      dw( 31, 56) =  rk( 31) * Y( 56)
      dw( 31, 56) =  rk( 31) * Y( 56)
      dw( 32, 26) =  rk( 32) * Y( 55)
      dw( 32, 55) =  rk( 32) * Y( 26)
      dw( 33, 51) =  rk( 33) * Y( 56)
      dw( 33, 56) =  rk( 33) * Y( 51)
      dw( 34, 51) =  rk( 34) * Y( 55)
      dw( 34, 55) =  rk( 34) * Y( 51)
      dw( 35, 51) =  rk( 35) * Y( 57)
      dw( 35, 57) =  rk( 35) * Y( 51)
      dw( 36, 11) =  rk( 36)
      dw( 37, 50) =  rk( 37) * Y( 24)
      dw( 37, 24) =  rk( 37) * Y( 50)
      dw( 38, 50) =  rk( 38) * Y( 57)
      dw( 38, 57) =  rk( 38) * Y( 50)
      dw( 39, 17) =  rk( 39) * Y( 50)
      dw( 39, 50) =  rk( 39) * Y( 17)
      dw( 40,  2) =  rk( 40) * Y( 50)
      dw( 40, 50) =  rk( 40) * Y(  2)
      dw( 41,  3) =  rk( 41) * Y( 50)
      dw( 41, 50) =  rk( 41) * Y(  3)
      dw( 42,  4) =  rk( 42) * Y( 50)
      dw( 42, 50) =  rk( 42) * Y(  4)
      dw( 43,  5) =  rk( 43) * Y( 50)
      dw( 43, 50) =  rk( 43) * Y(  5)
      dw( 44, 25) =  rk( 44) * Y( 50)
      dw( 44, 50) =  rk( 44) * Y( 25)
      dw( 45, 15) =  rk( 45) * Y( 50)
      dw( 45, 50) =  rk( 45) * Y( 15)
      dw( 46, 16) =  rk( 46) * Y( 50)
      dw( 46, 50) =  rk( 46) * Y( 16)
      dw( 47,  6) =  rk( 47) * Y( 50)
      dw( 47, 50) =  rk( 47) * Y(  6)
      dw( 48,  7) =  rk( 48) * Y( 50)
      dw( 48, 50) =  rk( 48) * Y(  7)
      dw( 49, 13) =  rk( 49) * Y( 50)
      dw( 49, 50) =  rk( 49) * Y( 13)
      dw( 50, 48) =  rk( 50) * Y( 50)
      dw( 50, 50) =  rk( 50) * Y( 48)
      dw( 51, 44) =  rk( 51) * Y( 50)
      dw( 51, 50) =  rk( 51) * Y( 44)
      dw( 52, 38) =  rk( 52) * Y( 50)
      dw( 52, 50) =  rk( 52) * Y( 38)
      dw( 53, 47) =  rk( 53) * Y( 50)
      dw( 53, 50) =  rk( 53) * Y( 47)
      dw( 54, 52) =  rk( 54) * Y( 50)
      dw( 54, 50) =  rk( 54) * Y( 52)
      dw( 55, 33) =  rk( 55) * Y( 50)
      dw( 55, 50) =  rk( 55) * Y( 33)
      dw( 56, 21) =  rk( 56) * Y( 50)
      dw( 56, 50) =  rk( 56) * Y( 21)
      dw( 57, 42) =  rk( 57) * Y( 50)
      dw( 57, 50) =  rk( 57) * Y( 42)
      dw( 58, 22) =  rk( 58) * Y( 50)
      dw( 58, 50) =  rk( 58) * Y( 22)
      dw( 59, 20) =  rk( 59) * Y( 50)
      dw( 59, 50) =  rk( 59) * Y( 20)
      dw( 60, 37) =  rk( 60) * Y( 50)
      dw( 60, 50) =  rk( 60) * Y( 37)
      dw( 61, 18) =  rk( 61) * Y( 50)
      dw( 61, 50) =  rk( 61) * Y( 18)
      dw( 62, 58) =  rk( 62) * Y( 55)
      dw( 62, 55) =  rk( 62) * Y( 58)
      dw( 63, 20) =  rk( 63)
      dw( 64, 54) =  rk( 64) * Y( 55)
      dw( 64, 55) =  rk( 64) * Y( 54)
      dw( 65, 14) =  rk( 65)
      dw( 66, 46) =  rk( 66) * Y( 56)
      dw( 66, 56) =  rk( 66) * Y( 46)
      dw( 67, 43) =  rk( 67) * Y( 56)
      dw( 67, 56) =  rk( 67) * Y( 43)
      dw( 68, 27) =  rk( 68) * Y( 56)
      dw( 68, 56) =  rk( 68) * Y( 27)
      dw( 69, 28) =  rk( 69) * Y( 56)
      dw( 69, 56) =  rk( 69) * Y( 28)
      dw( 70, 34) =  rk( 70) * Y( 56)
      dw( 70, 56) =  rk( 70) * Y( 34)
      dw( 71, 29) =  rk( 71) * Y( 56)
      dw( 71, 56) =  rk( 71) * Y( 29)
      dw( 72, 30) =  rk( 72) * Y( 56)
      dw( 72, 56) =  rk( 72) * Y( 30)
      dw( 73, 58) =  rk( 73) * Y( 56)
      dw( 73, 56) =  rk( 73) * Y( 58)
      dw( 74, 54) =  rk( 74) * Y( 56)
      dw( 74, 56) =  rk( 74) * Y( 54)
      dw( 75, 31) =  rk( 75) * Y( 56)
      dw( 75, 56) =  rk( 75) * Y( 31)
      dw( 76, 32) =  rk( 76) * Y( 56)
      dw( 76, 56) =  rk( 76) * Y( 32)
      dw( 77, 39) =  rk( 77) * Y( 56)
      dw( 77, 56) =  rk( 77) * Y( 39)
      dw( 78, 40) =  rk( 78) * Y( 56)
      dw( 78, 56) =  rk( 78) * Y( 40)
      dw( 79, 35) =  rk( 79) * Y( 56)
      dw( 79, 56) =  rk( 79) * Y( 35)
      dw( 80, 48) =  rk( 80) * Y( 51)
      dw( 80, 51) =  rk( 80) * Y( 48)
      dw( 81, 44) =  rk( 81) * Y( 51)
      dw( 81, 51) =  rk( 81) * Y( 44)
      dw( 82, 47) =  rk( 82) * Y( 51)
      dw( 82, 51) =  rk( 82) * Y( 47)
      dw( 83, 52) =  rk( 83) * Y( 51)
      dw( 83, 51) =  rk( 83) * Y( 52)
      dw( 84, 33) =  rk( 84) * Y( 51)
      dw( 84, 51) =  rk( 84) * Y( 33)
      dw( 85, 13) =  rk( 85) * Y( 51)
      dw( 85, 51) =  rk( 85) * Y( 13)
      dw( 86, 25) =  rk( 86) * Y( 51)
      dw( 86, 51) =  rk( 86) * Y( 25)
      dw( 87, 15) =  rk( 87) * Y( 51)
      dw( 87, 51) =  rk( 87) * Y( 15)
      dw( 88, 16) =  rk( 88) * Y( 51)
      dw( 88, 51) =  rk( 88) * Y( 16)
      dw( 89, 18) =  rk( 89) * Y( 51)
      dw( 89, 51) =  rk( 89) * Y( 18)
      dw( 90, 25) =  rk( 90) * Y( 26)
      dw( 90, 26) =  rk( 90) * Y( 25)
      dw( 91, 15) =  rk( 91) * Y( 26)
      dw( 91, 26) =  rk( 91) * Y( 15)
      dw( 92, 16) =  rk( 92) * Y( 26)
      dw( 92, 26) =  rk( 92) * Y( 16)
      dw( 93, 18) =  rk( 93) * Y( 26)
      dw( 93, 26) =  rk( 93) * Y( 18)
      dw( 94, 57) =  rk( 94) * Y( 46)
      dw( 94, 46) =  rk( 94) * Y( 57)
      dw( 95, 57) =  rk( 95) * Y( 39)
      dw( 95, 39) =  rk( 95) * Y( 57)
      dw( 96, 57) =  rk( 96) * Y( 43)
      dw( 96, 43) =  rk( 96) * Y( 57)
      dw( 97, 57) =  rk( 97) * Y( 27)
      dw( 97, 27) =  rk( 97) * Y( 57)
      dw( 98, 57) =  rk( 98) * Y( 28)
      dw( 98, 28) =  rk( 98) * Y( 57)
      dw( 99, 57) =  rk( 99) * Y( 34)
      dw( 99, 34) =  rk( 99) * Y( 57)
      dw(100, 57) =  rk(100) * Y( 29)
      dw(100, 29) =  rk(100) * Y( 57)
      dw(101, 57) =  rk(101) * Y( 30)
      dw(101, 30) =  rk(101) * Y( 57)
      dw(102, 57) =  rk(102) * Y( 40)
      dw(102, 40) =  rk(102) * Y( 57)
      dw(103, 57) =  rk(103) * Y( 58)
      dw(103, 58) =  rk(103) * Y( 57)
      dw(104, 57) =  rk(104) * Y( 31)
      dw(104, 31) =  rk(104) * Y( 57)
      dw(105, 57) =  rk(105) * Y( 32)
      dw(105, 32) =  rk(105) * Y( 57)
      dw(106, 57) =  rk(106) * Y( 54)
      dw(106, 54) =  rk(106) * Y( 57)
      dw(107, 57) =  rk(107) * Y( 35)
      dw(107, 35) =  rk(107) * Y( 57)
      dw(108, 46) =  rk(108) * Y( 46)
      dw(108, 46) =  rk(108) * Y( 46)
      dw(109, 46) =  rk(109) * Y( 39)
      dw(109, 39) =  rk(109) * Y( 46)
      dw(110, 46) =  rk(110) * Y( 43)
      dw(110, 43) =  rk(110) * Y( 46)
      dw(111, 46) =  rk(111) * Y( 27)
      dw(111, 27) =  rk(111) * Y( 46)
      dw(112, 46) =  rk(112) * Y( 28)
      dw(112, 28) =  rk(112) * Y( 46)
      dw(113, 46) =  rk(113) * Y( 34)
      dw(113, 34) =  rk(113) * Y( 46)
      dw(114, 46) =  rk(114) * Y( 29)
      dw(114, 29) =  rk(114) * Y( 46)
      dw(115, 46) =  rk(115) * Y( 30)
      dw(115, 30) =  rk(115) * Y( 46)
      dw(116, 46) =  rk(116) * Y( 40)
      dw(116, 40) =  rk(116) * Y( 46)
      dw(117, 46) =  rk(117) * Y( 58)
      dw(117, 58) =  rk(117) * Y( 46)
      dw(118, 46) =  rk(118) * Y( 31)
      dw(118, 31) =  rk(118) * Y( 46)
      dw(119, 46) =  rk(119) * Y( 32)
      dw(119, 32) =  rk(119) * Y( 46)
      dw(120, 46) =  rk(120) * Y( 54)
      dw(120, 54) =  rk(120) * Y( 46)
      dw(121, 46) =  rk(121) * Y( 35)
      dw(121, 35) =  rk(121) * Y( 46)
      dw(122, 39) =  rk(122) * Y( 58)
      dw(122, 58) =  rk(122) * Y( 39)
      dw(123, 43) =  rk(123) * Y( 58)
      dw(123, 58) =  rk(123) * Y( 43)
      dw(124, 27) =  rk(124) * Y( 58)
      dw(124, 58) =  rk(124) * Y( 27)
      dw(125, 28) =  rk(125) * Y( 58)
      dw(125, 58) =  rk(125) * Y( 28)
      dw(126, 34) =  rk(126) * Y( 58)
      dw(126, 58) =  rk(126) * Y( 34)
      dw(127, 29) =  rk(127) * Y( 58)
      dw(127, 58) =  rk(127) * Y( 29)
      dw(128, 30) =  rk(128) * Y( 58)
      dw(128, 58) =  rk(128) * Y( 30)
      dw(129, 40) =  rk(129) * Y( 58)
      dw(129, 58) =  rk(129) * Y( 40)
      dw(130, 58) =  rk(130) * Y( 58)
      dw(130, 58) =  rk(130) * Y( 58)
      dw(131, 58) =  rk(131) * Y( 31)
      dw(131, 31) =  rk(131) * Y( 58)
      dw(132, 58) =  rk(132) * Y( 32)
      dw(132, 32) =  rk(132) * Y( 58)
      dw(133, 58) =  rk(133) * Y( 54)
      dw(133, 54) =  rk(133) * Y( 58)
      dw(134, 58) =  rk(134) * Y( 35)
      dw(134, 35) =  rk(134) * Y( 58)
      dw(135, 35) =  rk(135) * Y( 35)
      dw(135, 35) =  rk(135) * Y( 35)
      dw(136, 45) =  rk(136) * Y( 57)
      dw(136, 57) =  rk(136) * Y( 45)
      dw(137, 45) =  rk(137) * Y( 46)
      dw(137, 46) =  rk(137) * Y( 45)
      dw(138, 45) =  rk(138) * Y( 58)
      dw(138, 58) =  rk(138) * Y( 45)
      dw(139, 45) =  rk(139) * Y( 45)
      dw(139, 45) =  rk(139) * Y( 45)
      dw(140, 45) =  rk(140) * Y( 56)
      dw(140, 56) =  rk(140) * Y( 45)
      dw(141, 36) =  rk(141) * Y( 55)
      dw(141, 55) =  rk(141) * Y( 36)
      dw(142, 36) =  rk(142) * Y( 57)
      dw(142, 57) =  rk(142) * Y( 36)
      dw(143, 36) =  rk(143) * Y( 46)
      dw(143, 46) =  rk(143) * Y( 36)
      dw(144, 36) =  rk(144) * Y( 58)
      dw(144, 58) =  rk(144) * Y( 36)
      dw(145, 36) =  rk(145) * Y( 36)
      dw(145, 36) =  rk(145) * Y( 36)
      dw(146, 57) =  rk(146) * Y( 55)
      dw(146, 55) =  rk(146) * Y( 57)
      dw(147, 56) =  rk(147) * Y( 50)
      dw(147, 50) =  rk(147) * Y( 56)
      dw(148, 51) =  rk(148) * Y( 55)
      dw(148, 55) =  rk(148) * Y( 51)
      dw(149, 50) =  rk(149) * Y( 55)
      dw(149, 55) =  rk(149) * Y( 50)
      dw(150, 50) =  rk(150) * Y(  1)
      dw(150,  1) =  rk(150) * Y( 50)
      dw(151, 24) =  rk(151)
      dw(152, 11) =  rk(152)
      dw(153, 23) =  rk(153)
      dw(154, 57) =  rk(154) * Y( 57)
      dw(154, 57) =  rk(154) * Y( 57)
      dw(155, 57) =  rk(155) * Y( 57)
      dw(155, 57) =  rk(155) * Y( 57)
      dw(156, 50) =  rk(156) * Y( 49)
      dw(156, 49) =  rk(156) * Y( 50)
      dw(157, 53) =  rk(157) * Y( 50)
      dw(157, 50) =  rk(157) * Y( 53)
 
      RETURN
      END
 
