C------------------------------------------------------------------------
C     Copyright (C) 2001-2008, ENPC - INRIA - EDF R&D
C     
C     This file is part of the air quality modeling system Polyphemus.
C    
C     Polyphemus is developed in the INRIA - ENPC joint project-team
C     CLIME and in the ENPC - EDF R&D joint laboratory CEREA.
C    
C     Polyphemus is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published
C     by the Free Software Foundation; either version 2 of the License,
C     or (at your option) any later version.
C     
C     Polyphemus is distributed in the hope that it will be useful, but
C     WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
C     General Public License for more details.
C     
C     For more information, visit the Polyphemus web site:
C     http://cerea.enpc.fr/polyphemus/
C
C------------------------------------------------------------------------

      SUBROUTINE LU_decompose (ns,M)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine computes an LU factorization of M.
C	  This routine is automatically generated by LU.cpp
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C
C	  nesp: matrix row number from the chemical species number
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     M: on entry, an invertible matrix. On exit, an LU factorization
C     of M.
C     
C     -- OUTPUT VARIABLES
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C------------------------------------------------------------------------

      IMPLICIT NONE


      INTEGER ns
      DOUBLE PRECISION M(ns,ns)
      DOUBLE PRECISION temp




C     Upper part.
      M(3, 75) = M(3, 75) / M(3, 3)

C     Upper part.
      M(4, 75) = M(4, 75) / M(4, 4)

C     Upper part.
      M(5, 75) = M(5, 75) / M(5, 5)

C     Upper part.
      M(6, 75) = M(6, 75) / M(6, 6)

C     Upper part.
      M(7, 59) = M(7, 59) / M(7, 7)

C     Upper part.
      temp = M(8, 4) * M(4, 75)
      M(8, 75) = ( M(8, 75) - temp ) / M(8, 8)

C     Upper part.
      M(9, 75) = M(9, 75) / M(9, 9)

C     Upper part.
      temp = M(10, 9) * M(9, 75)
      M(10, 75) = ( M(10, 75) - temp ) / M(10, 10)

C     Upper part.
      M(11, 75) = M(11, 75) / M(11, 11)

C     Upper part.
      M(12, 46) = M(12, 46) / M(12, 12)
C     Upper part.
      M(12, 75) = M(12, 75) / M(12, 12)

C     Upper part.
      M(13, 77) = M(13, 77) / M(13, 13)
C     Upper part.
      M(13, 80) = M(13, 80) / M(13, 13)

C     Upper part.
      M(14, 59) = M(14, 59) / M(14, 14)
C     Upper part.
      M(14, 75) = M(14, 75) / M(14, 14)
C     Upper part.
      M(14, 77) = M(14, 77) / M(14, 14)

C     Upper part.
      temp = M(15, 14) * M(14, 59)
      M(15, 59) = ( M(15, 59) - temp ) / M(15, 15)
C     Upper part.
      temp = M(15, 14) * M(14, 75)
      M(15, 75) = ( M(15, 75) - temp ) / M(15, 15)
C     Upper part.
      temp = M(15, 14) * M(14, 77)
      M(15, 77) = ( M(15, 77) - temp ) / M(15, 15)

C     Upper part.
      temp = M(16, 14) * M(14, 59)
      M(16, 59) = ( M(16, 59) - temp ) / M(16, 16)
C     Upper part.
      temp = M(16, 14) * M(14, 75)
      M(16, 75) = ( M(16, 75) - temp ) / M(16, 16)
C     Upper part.
      temp = M(16, 14) * M(14, 77)
      M(16, 77) = ( M(16, 77) - temp ) / M(16, 16)

C     Upper part.
      M(17, 59) = M(17, 59) / M(17, 17)
C     Upper part.
      temp = M(17, 5) * M(5, 75)
      M(17, 75) = ( M(17, 75) - temp ) / M(17, 17)
C     Upper part.
      M(17, 80) = M(17, 80) / M(17, 17)

C     Upper part.
      M(18, 59) = M(18, 59) / M(18, 18)
C     Upper part.
      temp = M(18, 6) * M(6, 75)
      M(18, 75) = ( M(18, 75) - temp ) / M(18, 18)
C     Upper part.
      M(18, 80) = M(18, 80) / M(18, 18)

C     Upper part.
      M(19, 37) = M(19, 37) / M(19, 19)
C     Upper part.
      temp = M(19, 5) * M(5, 75)
      temp = temp + M(19, 6) * M(6, 75)
      M(19, 75) = ( M(19, 75) - temp ) / M(19, 19)
C     Upper part.
      M(19, 77) = M(19, 77) / M(19, 19)

C     Upper part.
      M(20, 37) = M(20, 37) / M(20, 20)
C     Upper part.
      temp = M(20, 5) * M(5, 75)
      temp = temp + M(20, 6) * M(6, 75)
      M(20, 75) = ( M(20, 75) - temp ) / M(20, 20)
C     Upper part.
      M(20, 77) = M(20, 77) / M(20, 20)

C     Upper part.
      M(21, 59) = M(21, 59) / M(21, 21)
C     Upper part.
      M(21, 75) = M(21, 75) / M(21, 21)
C     Upper part.
      M(21, 77) = M(21, 77) / M(21, 21)

C     Upper part.
      M(22, 26) = M(22, 26) / M(22, 22)
C     Upper part.
      M(22, 59) = M(22, 59) / M(22, 22)
C     Upper part.
      M(22, 75) = M(22, 75) / M(22, 22)

C     Upper part.
      M(23, 26) = M(23, 26) / M(23, 23)
C     Upper part.
      M(23, 59) = M(23, 59) / M(23, 23)
C     Upper part.
      M(23, 75) = M(23, 75) / M(23, 23)

C     Upper part.
      M(24, 75) = M(24, 75) / M(24, 24)
C     Upper part.
      M(24, 80) = M(24, 80) / M(24, 24)
C     Upper part.
      M(24, 81) = M(24, 81) / M(24, 24)

C     Upper part.
      M(25, 73) = M(25, 73) / M(25, 25)
C     Upper part.
      M(25, 75) = M(25, 75) / M(25, 25)
C     Upper part.
      M(25, 81) = M(25, 81) / M(25, 25)

C     Upper part.
      M(26, 59) = M(26, 59) / M(26, 26)
C     Upper part.
      M(26, 75) = M(26, 75) / M(26, 26)
C     Upper part.
      M(26, 77) = M(26, 77) / M(26, 26)

C     Upper part.
      M(27, 59) = M(27, 59) / M(27, 27)
C     Upper part.
      M(27, 75) = M(27, 75) / M(27, 27)
C     Upper part.
      M(27, 77) = M(27, 77) / M(27, 27)

C     Upper part.
      M(28, 34) = M(28, 34) / M(28, 28)
C     Upper part.
      M(28, 59) = M(28, 59) / M(28, 28)
C     Upper part.
      M(28, 75) = M(28, 75) / M(28, 28)
C     Upper part.
      M(28, 77) = M(28, 77) / M(28, 28)

C     Upper part.
      M(29, 53) = M(29, 53) / M(29, 29)
C     Upper part.
      M(29, 56) = M(29, 56) / M(29, 29)
C     Upper part.
      M(29, 59) = M(29, 59) / M(29, 29)
C     Upper part.
      M(29, 75) = M(29, 75) / M(29, 29)

C     Upper part.
      M(30, 53) = M(30, 53) / M(30, 30)
C     Upper part.
      M(30, 56) = M(30, 56) / M(30, 30)
C     Upper part.
      M(30, 59) = M(30, 59) / M(30, 30)
C     Upper part.
      M(30, 75) = M(30, 75) / M(30, 30)

C     Upper part.
      M(31, 37) = M(31, 37) / M(31, 31)
C     Upper part.
      M(31, 59) = M(31, 59) / M(31, 31)
C     Upper part.
      M(31, 75) = M(31, 75) / M(31, 31)
C     Upper part.
      M(31, 80) = M(31, 80) / M(31, 31)

C     Upper part.
      temp = M(32, 31) * M(31, 37)
      M(32, 37) = ( M(32, 37) - temp ) / M(32, 32)
C     Upper part.
      temp = M(32, 17) * M(17, 59)
      temp = temp + M(32, 18) * M(18, 59)
      temp = temp + M(32, 31) * M(31, 59)
      M(32, 59) = ( M(32, 59) - temp ) / M(32, 32)
C     Upper part.
      temp = M(32, 17) * M(17, 75)
      temp = temp + M(32, 18) * M(18, 75)
      temp = temp + M(32, 31) * M(31, 75)
      M(32, 75) = ( M(32, 75) - temp ) / M(32, 32)
C     Upper part.
      M(32, 78) = M(32, 78) / M(32, 32)
C     Upper part.
      temp = M(32, 17) * M(17, 80)
      temp = temp + M(32, 18) * M(18, 80)
      temp = temp + M(32, 31) * M(31, 80)
      M(32, 80) = ( M(32, 80) - temp ) / M(32, 32)

C     Upper part.
      temp = M(33, 31) * M(31, 37)
      M(33, 37) = ( M(33, 37) - temp ) / M(33, 33)
C     Upper part.
      temp = M(33, 31) * M(31, 59)
      M(33, 59) = ( M(33, 59) - temp ) / M(33, 33)
C     Upper part.
      M(33, 73) = M(33, 73) / M(33, 33)
C     Upper part.
      temp = M(33, 31) * M(31, 75)
      M(33, 75) = ( M(33, 75) - temp ) / M(33, 33)
C     Upper part.
      M(33, 76) = M(33, 76) / M(33, 33)
C     Upper part.
      M(33, 77) = M(33, 77) / M(33, 33)
C     Upper part.
      M(33, 78) = M(33, 78) / M(33, 33)
C     Upper part.
      temp = M(33, 31) * M(31, 80)
      M(33, 80) = ( M(33, 80) - temp ) / M(33, 33)
C     Upper part.
      M(33, 81) = M(33, 81) / M(33, 33)

C     Lower part.
      temp = M(34, 28) * M(28, 34)
      M(34, 34) = M(34, 34) - temp
C     Lower part.
      temp = M(43, 28) * M(28, 34)
      M(43, 34) = M(43, 34) - temp
C     Lower part.
      temp = M(45, 28) * M(28, 34)
      M(45, 34) = M(45, 34) - temp
C     Lower part.
      temp = M(46, 28) * M(28, 34)
      M(46, 34) = M(46, 34) - temp
C     Lower part.
      temp = M(51, 28) * M(28, 34)
      M(51, 34) = M(51, 34) - temp
C     Lower part.
      temp = M(52, 28) * M(28, 34)
      M(52, 34) = M(52, 34) - temp
C     Lower part.
      temp = M(53, 28) * M(28, 34)
      M(53, 34) = M(53, 34) - temp
C     Lower part.
      temp = M(57, 28) * M(28, 34)
      M(57, 34) = M(57, 34) - temp
C     Lower part.
      temp = M(58, 28) * M(28, 34)
      M(58, 34) = M(58, 34) - temp
C     Lower part.
      temp = M(59, 28) * M(28, 34)
      M(59, 34) = M(59, 34) - temp
C     Lower part.
      temp = M(60, 28) * M(28, 34)
      M(60, 34) = M(60, 34) - temp
C     Lower part.
      temp = M(64, 28) * M(28, 34)
      M(64, 34) = M(64, 34) - temp
C     Lower part.
      temp = M(72, 28) * M(28, 34)
      M(72, 34) = M(72, 34) - temp
C     Lower part.
      temp = M(73, 28) * M(28, 34)
      M(73, 34) = M(73, 34) - temp
C     Lower part.
      temp = M(74, 28) * M(28, 34)
      M(74, 34) = M(74, 34) - temp
C     Lower part.
      temp = M(75, 28) * M(28, 34)
      M(75, 34) = M(75, 34) - temp
C     Lower part.
      temp = M(76, 28) * M(28, 34)
      M(76, 34) = M(76, 34) - temp
C     Lower part.
      temp = M(77, 28) * M(28, 34)
      M(77, 34) = M(77, 34) - temp
C     Lower part.
      temp = M(81, 28) * M(28, 34)
      M(81, 34) = M(81, 34) - temp
C     Upper part.
      M(34, 52) = M(34, 52) / M(34, 34)
C     Upper part.
      temp = M(34, 7) * M(7, 59)
      temp = temp + M(34, 21) * M(21, 59)
      temp = temp + M(34, 28) * M(28, 59)
      M(34, 59) = ( M(34, 59) - temp ) / M(34, 34)
C     Upper part.
      temp = M(34, 21) * M(21, 75)
      temp = temp + M(34, 28) * M(28, 75)
      M(34, 75) = ( M(34, 75) - temp ) / M(34, 34)
C     Upper part.
      temp = M(34, 21) * M(21, 77)
      temp = temp + M(34, 28) * M(28, 77)
      M(34, 77) = ( M(34, 77) - temp ) / M(34, 34)
C     Upper part.
      M(34, 78) = M(34, 78) / M(34, 34)
C     Upper part.
      M(34, 80) = M(34, 80) / M(34, 34)

C     Upper part.
      M(35, 46) = M(35, 46) / M(35, 35)
C     Upper part.
      M(35, 59) = M(35, 59) / M(35, 35)
C     Upper part.
      M(35, 75) = M(35, 75) / M(35, 35)
C     Upper part.
      M(35, 76) = M(35, 76) / M(35, 35)
C     Upper part.
      M(35, 81) = M(35, 81) / M(35, 35)

C     Upper part.
      M(36, 37) = M(36, 37) / M(36, 36)
C     Upper part.
      M(36, 75) = M(36, 75) / M(36, 36)
C     Upper part.
      M(36, 77) = M(36, 77) / M(36, 36)
C     Upper part.
      M(36, 80) = M(36, 80) / M(36, 36)
C     Upper part.
      M(36, 81) = M(36, 81) / M(36, 36)

C     Lower part.
      temp = M(37, 31) * M(31, 37)
      temp = temp + M(37, 36) * M(36, 37)
      M(37, 37) = M(37, 37) - temp
C     Lower part.
      temp = M(59, 31) * M(31, 37)
      M(59, 37) = M(59, 37) - temp
C     Lower part.
      temp = M(61, 33) * M(33, 37)
      M(61, 37) = M(61, 37) - temp
C     Lower part.
      temp = M(65, 33) * M(33, 37)
      M(65, 37) = M(65, 37) - temp
C     Lower part.
      temp = M(66, 33) * M(33, 37)
      M(66, 37) = M(66, 37) - temp
C     Lower part.
      temp = M(73, 33) * M(33, 37)
      M(73, 37) = M(73, 37) - temp
C     Lower part.
      temp = M(74, 33) * M(33, 37)
      M(74, 37) = M(74, 37) - temp
C     Lower part.
      temp = M(75, 31) * M(31, 37)
      temp = temp + M(75, 32) * M(32, 37)
      M(75, 37) = M(75, 37) - temp
C     Lower part.
      temp = M(76, 33) * M(33, 37)
      M(76, 37) = M(76, 37) - temp
C     Lower part.
      temp = M(77, 33) * M(33, 37)
      M(77, 37) = M(77, 37) - temp
C     Lower part.
      temp = M(78, 32) * M(32, 37)
      temp = temp + M(78, 33) * M(33, 37)
      M(78, 37) = M(78, 37) - temp
C     Lower part.
      temp = M(80, 31) * M(31, 37)
      temp = temp + M(80, 32) * M(32, 37)
      temp = temp + M(80, 33) * M(33, 37)
      temp = temp + M(80, 36) * M(36, 37)
      M(80, 37) = M(80, 37) - temp
C     Lower part.
      temp = M(81, 31) * M(31, 37)
      temp = temp + M(81, 33) * M(33, 37)
      temp = temp + M(81, 36) * M(36, 37)
      M(81, 37) = M(81, 37) - temp
C     Lower part.
      temp = M(82, 36) * M(36, 37)
      M(82, 37) = M(82, 37) - temp
C     Upper part.
      temp = M(37, 17) * M(17, 59)
      temp = temp + M(37, 18) * M(18, 59)
      temp = temp + M(37, 31) * M(31, 59)
      M(37, 59) = ( M(37, 59) - temp ) / M(37, 37)
C     Upper part.
      temp = M(37, 17) * M(17, 75)
      temp = temp + M(37, 18) * M(18, 75)
      temp = temp + M(37, 31) * M(31, 75)
      temp = temp + M(37, 36) * M(36, 75)
      M(37, 75) = ( M(37, 75) - temp ) / M(37, 37)
C     Upper part.
      temp = M(37, 36) * M(36, 77)
      M(37, 77) = ( M(37, 77) - temp ) / M(37, 37)
C     Upper part.
      temp = M(37, 17) * M(17, 80)
      temp = temp + M(37, 18) * M(18, 80)
      temp = temp + M(37, 31) * M(31, 80)
      temp = temp + M(37, 36) * M(36, 80)
      M(37, 80) = ( M(37, 80) - temp ) / M(37, 37)
C     Upper part.
      temp = M(37, 36) * M(36, 81)
      M(37, 81) = ( M(37, 81) - temp ) / M(37, 37)

C     Upper part.
      M(38, 53) = M(38, 53) / M(38, 38)
C     Upper part.
      M(38, 56) = M(38, 56) / M(38, 38)
C     Upper part.
      M(38, 59) = M(38, 59) / M(38, 38)
C     Upper part.
      M(38, 75) = M(38, 75) / M(38, 38)
C     Upper part.
      M(38, 77) = M(38, 77) / M(38, 38)

C     Upper part.
      temp = M(39, 17) * M(17, 59)
      M(39, 59) = ( M(39, 59) - temp ) / M(39, 39)
C     Upper part.
      M(39, 73) = M(39, 73) / M(39, 39)
C     Upper part.
      temp = M(39, 17) * M(17, 75)
      M(39, 75) = ( M(39, 75) - temp ) / M(39, 39)
C     Upper part.
      M(39, 76) = M(39, 76) / M(39, 39)
C     Upper part.
      M(39, 77) = M(39, 77) / M(39, 39)
C     Upper part.
      M(39, 78) = M(39, 78) / M(39, 39)
C     Upper part.
      temp = M(39, 17) * M(17, 80)
      M(39, 80) = ( M(39, 80) - temp ) / M(39, 39)
C     Upper part.
      M(39, 81) = M(39, 81) / M(39, 39)

C     Upper part.
      temp = M(40, 18) * M(18, 59)
      M(40, 59) = ( M(40, 59) - temp ) / M(40, 40)
C     Upper part.
      M(40, 73) = M(40, 73) / M(40, 40)
C     Upper part.
      temp = M(40, 18) * M(18, 75)
      M(40, 75) = ( M(40, 75) - temp ) / M(40, 40)
C     Upper part.
      M(40, 76) = M(40, 76) / M(40, 40)
C     Upper part.
      M(40, 77) = M(40, 77) / M(40, 40)
C     Upper part.
      M(40, 78) = M(40, 78) / M(40, 40)
C     Upper part.
      temp = M(40, 18) * M(18, 80)
      M(40, 80) = ( M(40, 80) - temp ) / M(40, 40)
C     Upper part.
      M(40, 81) = M(40, 81) / M(40, 40)

C     Upper part.
      M(41, 42) = M(41, 42) / M(41, 41)
C     Upper part.
      M(41, 52) = M(41, 52) / M(41, 41)
C     Upper part.
      M(41, 64) = M(41, 64) / M(41, 41)
C     Upper part.
      M(41, 73) = M(41, 73) / M(41, 41)
C     Upper part.
      temp = M(41, 4) * M(4, 75)
      M(41, 75) = ( M(41, 75) - temp ) / M(41, 41)

C     Lower part.
      temp = M(66, 41) * M(41, 42)
      M(66, 42) = M(66, 42) - temp
C     Lower part.
      temp = M(74, 41) * M(41, 42)
      M(74, 42) = M(74, 42) - temp
C     Lower part.
      temp = M(75, 41) * M(41, 42)
      M(75, 42) = M(75, 42) - temp
C     Lower part.
      temp = M(76, 41) * M(41, 42)
      M(76, 42) = M(76, 42) - temp
C     Lower part.
      temp = M(81, 41) * M(41, 42)
      M(81, 42) = M(81, 42) - temp
C     Upper part.
      M(42, 59) = M(42, 59) / M(42, 42)
C     Upper part.
      M(42, 75) = M(42, 75) / M(42, 42)
C     Upper part.
      M(42, 77) = M(42, 77) / M(42, 42)
C     Upper part.
      M(42, 79) = M(42, 79) / M(42, 42)
C     Upper part.
      M(42, 80) = M(42, 80) / M(42, 42)

C     Upper part.
      M(43, 46) = M(43, 46) / M(43, 43)
C     Upper part.
      temp = M(43, 34) * M(34, 52)
      M(43, 52) = ( M(43, 52) - temp ) / M(43, 43)
C     Upper part.
      M(43, 53) = M(43, 53) / M(43, 43)
C     Upper part.
      temp = M(43, 14) * M(14, 59)
      temp = temp + M(43, 21) * M(21, 59)
      temp = temp + M(43, 27) * M(27, 59)
      temp = temp + M(43, 28) * M(28, 59)
      temp = temp + M(43, 34) * M(34, 59)
      temp = temp + M(43, 42) * M(42, 59)
      M(43, 59) = ( M(43, 59) - temp ) / M(43, 43)
C     Upper part.
      temp = M(43, 11) * M(11, 75)
      temp = temp + M(43, 14) * M(14, 75)
      temp = temp + M(43, 21) * M(21, 75)
      temp = temp + M(43, 27) * M(27, 75)
      temp = temp + M(43, 28) * M(28, 75)
      temp = temp + M(43, 34) * M(34, 75)
      temp = temp + M(43, 42) * M(42, 75)
      M(43, 75) = ( M(43, 75) - temp ) / M(43, 43)
C     Upper part.
      temp = M(43, 14) * M(14, 77)
      temp = temp + M(43, 21) * M(21, 77)
      temp = temp + M(43, 27) * M(27, 77)
      temp = temp + M(43, 28) * M(28, 77)
      temp = temp + M(43, 34) * M(34, 77)
      temp = temp + M(43, 42) * M(42, 77)
      M(43, 77) = ( M(43, 77) - temp ) / M(43, 43)
C     Upper part.
      temp = M(43, 34) * M(34, 78)
      M(43, 78) = ( M(43, 78) - temp ) / M(43, 43)
C     Upper part.
      temp = M(43, 42) * M(42, 79)
      M(43, 79) = ( M(43, 79) - temp ) / M(43, 43)
C     Upper part.
      temp = M(43, 34) * M(34, 80)
      temp = temp + M(43, 42) * M(42, 80)
      M(43, 80) = ( M(43, 80) - temp ) / M(43, 43)

C     Upper part.
      temp = M(44, 42) * M(42, 59)
      M(44, 59) = ( M(44, 59) - temp ) / M(44, 44)
C     Upper part.
      temp = M(44, 42) * M(42, 75)
      M(44, 75) = ( M(44, 75) - temp ) / M(44, 44)
C     Upper part.
      M(44, 76) = M(44, 76) / M(44, 44)
C     Upper part.
      temp = M(44, 42) * M(42, 77)
      M(44, 77) = ( M(44, 77) - temp ) / M(44, 44)
C     Upper part.
      temp = M(44, 42) * M(42, 79)
      M(44, 79) = ( M(44, 79) - temp ) / M(44, 44)
C     Upper part.
      temp = M(44, 42) * M(42, 80)
      M(44, 80) = ( M(44, 80) - temp ) / M(44, 44)

C     Upper part.
      temp = M(45, 34) * M(34, 52)
      M(45, 52) = ( M(45, 52) - temp ) / M(45, 45)
C     Upper part.
      M(45, 53) = M(45, 53) / M(45, 45)
C     Upper part.
      M(45, 56) = M(45, 56) / M(45, 45)
C     Upper part.
      temp = M(45, 14) * M(14, 59)
      temp = temp + M(45, 21) * M(21, 59)
      temp = temp + M(45, 26) * M(26, 59)
      temp = temp + M(45, 28) * M(28, 59)
      temp = temp + M(45, 34) * M(34, 59)
      M(45, 59) = ( M(45, 59) - temp ) / M(45, 45)
C     Upper part.
      temp = M(45, 14) * M(14, 75)
      temp = temp + M(45, 21) * M(21, 75)
      temp = temp + M(45, 26) * M(26, 75)
      temp = temp + M(45, 28) * M(28, 75)
      temp = temp + M(45, 34) * M(34, 75)
      M(45, 75) = ( M(45, 75) - temp ) / M(45, 45)
C     Upper part.
      temp = M(45, 14) * M(14, 77)
      temp = temp + M(45, 21) * M(21, 77)
      temp = temp + M(45, 26) * M(26, 77)
      temp = temp + M(45, 28) * M(28, 77)
      temp = temp + M(45, 34) * M(34, 77)
      M(45, 77) = ( M(45, 77) - temp ) / M(45, 45)
C     Upper part.
      temp = M(45, 34) * M(34, 78)
      M(45, 78) = ( M(45, 78) - temp ) / M(45, 45)
C     Upper part.
      temp = M(45, 34) * M(34, 80)
      M(45, 80) = ( M(45, 80) - temp ) / M(45, 45)
C     Upper part.
      M(45, 81) = M(45, 81) / M(45, 45)

C     Lower part.
      temp = M(69, 12) * M(12, 46)
      M(69, 46) = M(69, 46) - temp
C     Lower part.
      temp = M(71, 12) * M(12, 46)
      M(71, 46) = M(71, 46) - temp
C     Lower part.
      temp = M(72, 35) * M(35, 46)
      M(72, 46) = M(72, 46) - temp
C     Lower part.
      temp = M(73, 35) * M(35, 46)
      M(73, 46) = M(73, 46) - temp
C     Lower part.
      temp = M(74, 35) * M(35, 46)
      M(74, 46) = M(74, 46) - temp
C     Lower part.
      temp = M(75, 12) * M(12, 46)
      temp = temp + M(75, 35) * M(35, 46)
      M(75, 46) = M(75, 46) - temp
C     Lower part.
      temp = M(76, 35) * M(35, 46)
      M(76, 46) = M(76, 46) - temp
C     Lower part.
      temp = M(81, 12) * M(12, 46)
      temp = temp + M(81, 35) * M(35, 46)
      M(81, 46) = M(81, 46) - temp
C     Upper part.
      temp = M(46, 34) * M(34, 52)
      M(46, 52) = ( M(46, 52) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 28) * M(28, 59)
      temp = temp + M(46, 34) * M(34, 59)
      temp = temp + M(46, 39) * M(39, 59)
      temp = temp + M(46, 40) * M(40, 59)
      M(46, 59) = ( M(46, 59) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 39) * M(39, 73)
      temp = temp + M(46, 40) * M(40, 73)
      M(46, 73) = ( M(46, 73) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 28) * M(28, 75)
      temp = temp + M(46, 34) * M(34, 75)
      temp = temp + M(46, 39) * M(39, 75)
      temp = temp + M(46, 40) * M(40, 75)
      M(46, 75) = ( M(46, 75) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 39) * M(39, 76)
      temp = temp + M(46, 40) * M(40, 76)
      M(46, 76) = ( M(46, 76) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 28) * M(28, 77)
      temp = temp + M(46, 34) * M(34, 77)
      temp = temp + M(46, 39) * M(39, 77)
      temp = temp + M(46, 40) * M(40, 77)
      M(46, 77) = ( M(46, 77) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 34) * M(34, 78)
      temp = temp + M(46, 39) * M(39, 78)
      temp = temp + M(46, 40) * M(40, 78)
      M(46, 78) = ( M(46, 78) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 34) * M(34, 80)
      temp = temp + M(46, 39) * M(39, 80)
      temp = temp + M(46, 40) * M(40, 80)
      M(46, 80) = ( M(46, 80) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 39) * M(39, 81)
      temp = temp + M(46, 40) * M(40, 81)
      M(46, 81) = ( M(46, 81) - temp ) / M(46, 46)

C     Upper part.
      temp = M(47, 14) * M(14, 59)
      M(47, 59) = ( M(47, 59) - temp ) / M(47, 47)
C     Upper part.
      M(47, 73) = M(47, 73) / M(47, 47)
C     Upper part.
      temp = M(47, 14) * M(14, 75)
      M(47, 75) = ( M(47, 75) - temp ) / M(47, 47)
C     Upper part.
      M(47, 76) = M(47, 76) / M(47, 47)
C     Upper part.
      temp = M(47, 14) * M(14, 77)
      M(47, 77) = ( M(47, 77) - temp ) / M(47, 47)
C     Upper part.
      M(47, 78) = M(47, 78) / M(47, 47)
C     Upper part.
      M(47, 81) = M(47, 81) / M(47, 47)

C     Upper part.
      M(48, 73) = M(48, 73) / M(48, 48)
C     Upper part.
      temp = M(48, 3) * M(3, 75)
      M(48, 75) = ( M(48, 75) - temp ) / M(48, 48)
C     Upper part.
      M(48, 76) = M(48, 76) / M(48, 48)
C     Upper part.
      M(48, 77) = M(48, 77) / M(48, 48)
C     Upper part.
      M(48, 78) = M(48, 78) / M(48, 48)
C     Upper part.
      M(48, 81) = M(48, 81) / M(48, 48)

C     Upper part.
      M(49, 73) = M(49, 73) / M(49, 49)
C     Upper part.
      temp = M(49, 4) * M(4, 75)
      M(49, 75) = ( M(49, 75) - temp ) / M(49, 49)
C     Upper part.
      M(49, 76) = M(49, 76) / M(49, 49)
C     Upper part.
      M(49, 77) = M(49, 77) / M(49, 49)
C     Upper part.
      M(49, 78) = M(49, 78) / M(49, 49)
C     Upper part.
      M(49, 81) = M(49, 81) / M(49, 49)

C     Upper part.
      temp = M(50, 27) * M(27, 59)
      M(50, 59) = ( M(50, 59) - temp ) / M(50, 50)
C     Upper part.
      M(50, 73) = M(50, 73) / M(50, 50)
C     Upper part.
      temp = M(50, 27) * M(27, 75)
      M(50, 75) = ( M(50, 75) - temp ) / M(50, 50)
C     Upper part.
      M(50, 76) = M(50, 76) / M(50, 50)
C     Upper part.
      temp = M(50, 27) * M(27, 77)
      M(50, 77) = ( M(50, 77) - temp ) / M(50, 50)
C     Upper part.
      M(50, 78) = M(50, 78) / M(50, 50)
C     Upper part.
      M(50, 81) = M(50, 81) / M(50, 50)

C     Upper part.
      temp = M(51, 34) * M(34, 52)
      M(51, 52) = ( M(51, 52) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 21) * M(21, 59)
      temp = temp + M(51, 28) * M(28, 59)
      temp = temp + M(51, 34) * M(34, 59)
      M(51, 59) = ( M(51, 59) - temp ) / M(51, 51)
C     Upper part.
      M(51, 73) = M(51, 73) / M(51, 51)
C     Upper part.
      temp = M(51, 21) * M(21, 75)
      temp = temp + M(51, 28) * M(28, 75)
      temp = temp + M(51, 34) * M(34, 75)
      M(51, 75) = ( M(51, 75) - temp ) / M(51, 51)
C     Upper part.
      M(51, 76) = M(51, 76) / M(51, 51)
C     Upper part.
      temp = M(51, 21) * M(21, 77)
      temp = temp + M(51, 28) * M(28, 77)
      temp = temp + M(51, 34) * M(34, 77)
      M(51, 77) = ( M(51, 77) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 34) * M(34, 78)
      M(51, 78) = ( M(51, 78) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 34) * M(34, 80)
      M(51, 80) = ( M(51, 80) - temp ) / M(51, 51)
C     Upper part.
      M(51, 81) = M(51, 81) / M(51, 51)

C     Lower part.
      temp = M(52, 34) * M(34, 52)
      temp = temp + M(52, 51) * M(51, 52)
      M(52, 52) = M(52, 52) - temp
C     Lower part.
      temp = M(53, 34) * M(34, 52)
      temp = temp + M(53, 51) * M(51, 52)
      M(53, 52) = M(53, 52) - temp
C     Lower part.
      temp = M(56, 51) * M(51, 52)
      M(56, 52) = M(56, 52) - temp
C     Lower part.
      temp = M(57, 34) * M(34, 52)
      M(57, 52) = M(57, 52) - temp
C     Lower part.
      temp = M(58, 34) * M(34, 52)
      M(58, 52) = M(58, 52) - temp
C     Lower part.
      temp = M(59, 34) * M(34, 52)
      temp = temp + M(59, 46) * M(46, 52)
      M(59, 52) = M(59, 52) - temp
C     Lower part.
      temp = M(60, 34) * M(34, 52)
      temp = temp + M(60, 46) * M(46, 52)
      M(60, 52) = M(60, 52) - temp
C     Lower part.
      temp = M(61, 46) * M(46, 52)
      M(61, 52) = M(61, 52) - temp
C     Lower part.
      temp = M(63, 46) * M(46, 52)
      temp = temp + M(63, 51) * M(51, 52)
      M(63, 52) = M(63, 52) - temp
C     Lower part.
      temp = M(64, 34) * M(34, 52)
      M(64, 52) = M(64, 52) - temp
C     Lower part.
      temp = M(65, 51) * M(51, 52)
      M(65, 52) = M(65, 52) - temp
C     Lower part.
      temp = M(66, 41) * M(41, 52)
      temp = temp + M(66, 46) * M(46, 52)
      M(66, 52) = M(66, 52) - temp
C     Lower part.
      temp = M(67, 46) * M(46, 52)
      M(67, 52) = M(67, 52) - temp
C     Lower part.
      temp = M(69, 46) * M(46, 52)
      M(69, 52) = M(69, 52) - temp
C     Lower part.
      temp = M(71, 34) * M(34, 52)
      temp = temp + M(71, 46) * M(46, 52)
      M(71, 52) = M(71, 52) - temp
C     Lower part.
      temp = M(72, 34) * M(34, 52)
      temp = temp + M(72, 46) * M(46, 52)
      M(72, 52) = M(72, 52) - temp
C     Lower part.
      temp = M(73, 34) * M(34, 52)
      temp = temp + M(73, 46) * M(46, 52)
      temp = temp + M(73, 51) * M(51, 52)
      M(73, 52) = M(73, 52) - temp
C     Lower part.
      temp = M(74, 34) * M(34, 52)
      temp = temp + M(74, 41) * M(41, 52)
      temp = temp + M(74, 46) * M(46, 52)
      temp = temp + M(74, 51) * M(51, 52)
      M(74, 52) = M(74, 52) - temp
C     Lower part.
      temp = M(75, 34) * M(34, 52)
      temp = temp + M(75, 41) * M(41, 52)
      temp = temp + M(75, 45) * M(45, 52)
      temp = temp + M(75, 46) * M(46, 52)
      M(75, 52) = M(75, 52) - temp
C     Lower part.
      temp = M(76, 34) * M(34, 52)
      temp = temp + M(76, 41) * M(41, 52)
      temp = temp + M(76, 46) * M(46, 52)
      temp = temp + M(76, 51) * M(51, 52)
      M(76, 52) = M(76, 52) - temp
C     Lower part.
      temp = M(77, 34) * M(34, 52)
      temp = temp + M(77, 46) * M(46, 52)
      temp = temp + M(77, 51) * M(51, 52)
      M(77, 52) = M(77, 52) - temp
C     Lower part.
      temp = M(78, 34) * M(34, 52)
      temp = temp + M(78, 51) * M(51, 52)
      M(78, 52) = M(78, 52) - temp
C     Lower part.
      temp = M(79, 46) * M(46, 52)
      M(79, 52) = M(79, 52) - temp
C     Lower part.
      temp = M(80, 34) * M(34, 52)
      temp = temp + M(80, 46) * M(46, 52)
      temp = temp + M(80, 51) * M(51, 52)
      M(80, 52) = M(80, 52) - temp
C     Lower part.
      temp = M(81, 34) * M(34, 52)
      temp = temp + M(81, 41) * M(41, 52)
      temp = temp + M(81, 45) * M(45, 52)
      temp = temp + M(81, 46) * M(46, 52)
      temp = temp + M(81, 51) * M(51, 52)
      M(81, 52) = M(81, 52) - temp
C     Lower part.
      temp = M(82, 51) * M(51, 52)
      M(82, 52) = M(82, 52) - temp
C     Upper part.
      temp = M(52, 14) * M(14, 59)
      temp = temp + M(52, 21) * M(21, 59)
      temp = temp + M(52, 28) * M(28, 59)
      temp = temp + M(52, 34) * M(34, 59)
      temp = temp + M(52, 47) * M(47, 59)
      temp = temp + M(52, 51) * M(51, 59)
      M(52, 59) = ( M(52, 59) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 47) * M(47, 73)
      temp = temp + M(52, 51) * M(51, 73)
      M(52, 73) = ( M(52, 73) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 14) * M(14, 75)
      temp = temp + M(52, 21) * M(21, 75)
      temp = temp + M(52, 28) * M(28, 75)
      temp = temp + M(52, 34) * M(34, 75)
      temp = temp + M(52, 47) * M(47, 75)
      temp = temp + M(52, 51) * M(51, 75)
      M(52, 75) = ( M(52, 75) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 47) * M(47, 76)
      temp = temp + M(52, 51) * M(51, 76)
      M(52, 76) = ( M(52, 76) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 14) * M(14, 77)
      temp = temp + M(52, 21) * M(21, 77)
      temp = temp + M(52, 28) * M(28, 77)
      temp = temp + M(52, 34) * M(34, 77)
      temp = temp + M(52, 47) * M(47, 77)
      temp = temp + M(52, 51) * M(51, 77)
      M(52, 77) = ( M(52, 77) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 34) * M(34, 78)
      temp = temp + M(52, 47) * M(47, 78)
      temp = temp + M(52, 51) * M(51, 78)
      M(52, 78) = ( M(52, 78) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 34) * M(34, 80)
      temp = temp + M(52, 51) * M(51, 80)
      M(52, 80) = ( M(52, 80) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 47) * M(47, 81)
      temp = temp + M(52, 51) * M(51, 81)
      M(52, 81) = ( M(52, 81) - temp ) / M(52, 52)

C     Lower part.
      temp = M(70, 30) * M(30, 53)
      M(70, 53) = M(70, 53) - temp
C     Lower part.
      temp = M(73, 29) * M(29, 53)
      M(73, 53) = M(73, 53) - temp
C     Lower part.
      temp = M(75, 29) * M(29, 53)
      temp = temp + M(75, 30) * M(30, 53)
      temp = temp + M(75, 45) * M(45, 53)
      M(75, 53) = M(75, 53) - temp
C     Lower part.
      temp = M(81, 45) * M(45, 53)
      M(81, 53) = M(81, 53) - temp
C     Upper part.
      temp = M(53, 14) * M(14, 59)
      temp = temp + M(53, 21) * M(21, 59)
      temp = temp + M(53, 28) * M(28, 59)
      temp = temp + M(53, 34) * M(34, 59)
      temp = temp + M(53, 51) * M(51, 59)
      temp = temp + M(53, 52) * M(52, 59)
      M(53, 59) = ( M(53, 59) - temp ) / M(53, 53)
C     Upper part.
      temp = M(53, 51) * M(51, 73)
      temp = temp + M(53, 52) * M(52, 73)
      M(53, 73) = ( M(53, 73) - temp ) / M(53, 53)
C     Upper part.
      temp = M(53, 14) * M(14, 75)
      temp = temp + M(53, 21) * M(21, 75)
      temp = temp + M(53, 28) * M(28, 75)
      temp = temp + M(53, 34) * M(34, 75)
      temp = temp + M(53, 51) * M(51, 75)
      temp = temp + M(53, 52) * M(52, 75)
      M(53, 75) = ( M(53, 75) - temp ) / M(53, 53)
C     Upper part.
      temp = M(53, 51) * M(51, 76)
      temp = temp + M(53, 52) * M(52, 76)
      M(53, 76) = ( M(53, 76) - temp ) / M(53, 53)
C     Upper part.
      temp = M(53, 14) * M(14, 77)
      temp = temp + M(53, 21) * M(21, 77)
      temp = temp + M(53, 28) * M(28, 77)
      temp = temp + M(53, 34) * M(34, 77)
      temp = temp + M(53, 51) * M(51, 77)
      temp = temp + M(53, 52) * M(52, 77)
      M(53, 77) = ( M(53, 77) - temp ) / M(53, 53)
C     Upper part.
      temp = M(53, 34) * M(34, 78)
      temp = temp + M(53, 51) * M(51, 78)
      temp = temp + M(53, 52) * M(52, 78)
      M(53, 78) = ( M(53, 78) - temp ) / M(53, 53)
C     Upper part.
      temp = M(53, 34) * M(34, 80)
      temp = temp + M(53, 51) * M(51, 80)
      temp = temp + M(53, 52) * M(52, 80)
      M(53, 80) = ( M(53, 80) - temp ) / M(53, 53)
C     Upper part.
      temp = M(53, 51) * M(51, 81)
      temp = temp + M(53, 52) * M(52, 81)
      M(53, 81) = ( M(53, 81) - temp ) / M(53, 53)

C     Upper part.
      temp = M(54, 53) * M(53, 59)
      M(54, 59) = ( M(54, 59) - temp ) / M(54, 54)
C     Upper part.
      temp = M(54, 53) * M(53, 73)
      M(54, 73) = ( M(54, 73) - temp ) / M(54, 54)
C     Upper part.
      temp = M(54, 53) * M(53, 75)
      M(54, 75) = ( M(54, 75) - temp ) / M(54, 54)
C     Upper part.
      temp = M(54, 53) * M(53, 76)
      M(54, 76) = ( M(54, 76) - temp ) / M(54, 54)
C     Upper part.
      temp = M(54, 53) * M(53, 77)
      M(54, 77) = ( M(54, 77) - temp ) / M(54, 54)
C     Upper part.
      temp = M(54, 53) * M(53, 78)
      M(54, 78) = ( M(54, 78) - temp ) / M(54, 54)
C     Upper part.
      temp = M(54, 53) * M(53, 80)
      M(54, 80) = ( M(54, 80) - temp ) / M(54, 54)
C     Upper part.
      temp = M(54, 53) * M(53, 81)
      M(54, 81) = ( M(54, 81) - temp ) / M(54, 54)

C     Upper part.
      temp = M(55, 26) * M(26, 59)
      M(55, 59) = ( M(55, 59) - temp ) / M(55, 55)
C     Upper part.
      M(55, 73) = M(55, 73) / M(55, 55)
C     Upper part.
      temp = M(55, 26) * M(26, 75)
      M(55, 75) = ( M(55, 75) - temp ) / M(55, 55)
C     Upper part.
      M(55, 76) = M(55, 76) / M(55, 55)
C     Upper part.
      temp = M(55, 26) * M(26, 77)
      M(55, 77) = ( M(55, 77) - temp ) / M(55, 55)
C     Upper part.
      M(55, 78) = M(55, 78) / M(55, 55)
C     Upper part.
      M(55, 81) = M(55, 81) / M(55, 55)

C     Lower part.
      temp = M(70, 30) * M(30, 56)
      M(70, 56) = M(70, 56) - temp
C     Lower part.
      temp = M(73, 29) * M(29, 56)
      M(73, 56) = M(73, 56) - temp
C     Lower part.
      temp = M(75, 29) * M(29, 56)
      temp = temp + M(75, 30) * M(30, 56)
      temp = temp + M(75, 45) * M(45, 56)
      M(75, 56) = M(75, 56) - temp
C     Lower part.
      temp = M(81, 45) * M(45, 56)
      M(81, 56) = M(81, 56) - temp
C     Upper part.
      temp = M(56, 47) * M(47, 59)
      temp = temp + M(56, 51) * M(51, 59)
      temp = temp + M(56, 52) * M(52, 59)
      M(56, 59) = ( M(56, 59) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 47) * M(47, 73)
      temp = temp + M(56, 51) * M(51, 73)
      temp = temp + M(56, 52) * M(52, 73)
      M(56, 73) = ( M(56, 73) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 47) * M(47, 75)
      temp = temp + M(56, 51) * M(51, 75)
      temp = temp + M(56, 52) * M(52, 75)
      M(56, 75) = ( M(56, 75) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 47) * M(47, 76)
      temp = temp + M(56, 51) * M(51, 76)
      temp = temp + M(56, 52) * M(52, 76)
      M(56, 76) = ( M(56, 76) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 47) * M(47, 77)
      temp = temp + M(56, 51) * M(51, 77)
      temp = temp + M(56, 52) * M(52, 77)
      M(56, 77) = ( M(56, 77) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 47) * M(47, 78)
      temp = temp + M(56, 51) * M(51, 78)
      temp = temp + M(56, 52) * M(52, 78)
      M(56, 78) = ( M(56, 78) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 51) * M(51, 80)
      temp = temp + M(56, 52) * M(52, 80)
      M(56, 80) = ( M(56, 80) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 47) * M(47, 81)
      temp = temp + M(56, 51) * M(51, 81)
      temp = temp + M(56, 52) * M(52, 81)
      M(56, 81) = ( M(56, 81) - temp ) / M(56, 56)

C     Upper part.
      M(57, 58) = M(57, 58) / M(57, 57)
C     Upper part.
      temp = M(57, 14) * M(14, 59)
      temp = temp + M(57, 21) * M(21, 59)
      temp = temp + M(57, 26) * M(26, 59)
      temp = temp + M(57, 27) * M(27, 59)
      temp = temp + M(57, 28) * M(28, 59)
      temp = temp + M(57, 34) * M(34, 59)
      temp = temp + M(57, 52) * M(52, 59)
      temp = temp + M(57, 53) * M(53, 59)
      temp = temp + M(57, 56) * M(56, 59)
      M(57, 59) = ( M(57, 59) - temp ) / M(57, 57)
C     Upper part.
      temp = M(57, 52) * M(52, 73)
      temp = temp + M(57, 53) * M(53, 73)
      temp = temp + M(57, 56) * M(56, 73)
      M(57, 73) = ( M(57, 73) - temp ) / M(57, 57)
C     Upper part.
      temp = M(57, 14) * M(14, 75)
      temp = temp + M(57, 21) * M(21, 75)
      temp = temp + M(57, 26) * M(26, 75)
      temp = temp + M(57, 27) * M(27, 75)
      temp = temp + M(57, 28) * M(28, 75)
      temp = temp + M(57, 34) * M(34, 75)
      temp = temp + M(57, 52) * M(52, 75)
      temp = temp + M(57, 53) * M(53, 75)
      temp = temp + M(57, 56) * M(56, 75)
      M(57, 75) = ( M(57, 75) - temp ) / M(57, 57)
C     Upper part.
      temp = M(57, 52) * M(52, 76)
      temp = temp + M(57, 53) * M(53, 76)
      temp = temp + M(57, 56) * M(56, 76)
      M(57, 76) = ( M(57, 76) - temp ) / M(57, 57)
C     Upper part.
      temp = M(57, 14) * M(14, 77)
      temp = temp + M(57, 21) * M(21, 77)
      temp = temp + M(57, 26) * M(26, 77)
      temp = temp + M(57, 27) * M(27, 77)
      temp = temp + M(57, 28) * M(28, 77)
      temp = temp + M(57, 34) * M(34, 77)
      temp = temp + M(57, 52) * M(52, 77)
      temp = temp + M(57, 53) * M(53, 77)
      temp = temp + M(57, 56) * M(56, 77)
      M(57, 77) = ( M(57, 77) - temp ) / M(57, 57)
C     Upper part.
      temp = M(57, 34) * M(34, 78)
      temp = temp + M(57, 52) * M(52, 78)
      temp = temp + M(57, 53) * M(53, 78)
      temp = temp + M(57, 56) * M(56, 78)
      M(57, 78) = ( M(57, 78) - temp ) / M(57, 57)
C     Upper part.
      temp = M(57, 34) * M(34, 80)
      temp = temp + M(57, 52) * M(52, 80)
      temp = temp + M(57, 53) * M(53, 80)
      temp = temp + M(57, 56) * M(56, 80)
      M(57, 80) = ( M(57, 80) - temp ) / M(57, 57)
C     Upper part.
      temp = M(57, 52) * M(52, 81)
      temp = temp + M(57, 53) * M(53, 81)
      temp = temp + M(57, 56) * M(56, 81)
      M(57, 81) = ( M(57, 81) - temp ) / M(57, 57)

C     Lower part.
      temp = M(58, 57) * M(57, 58)
      M(58, 58) = M(58, 58) - temp
C     Lower part.
      temp = M(63, 57) * M(57, 58)
      M(63, 58) = M(63, 58) - temp
C     Lower part.
      temp = M(69, 57) * M(57, 58)
      M(69, 58) = M(69, 58) - temp
C     Lower part.
      temp = M(71, 57) * M(57, 58)
      M(71, 58) = M(71, 58) - temp
C     Lower part.
      temp = M(73, 57) * M(57, 58)
      M(73, 58) = M(73, 58) - temp
C     Lower part.
      temp = M(74, 57) * M(57, 58)
      M(74, 58) = M(74, 58) - temp
C     Lower part.
      temp = M(76, 57) * M(57, 58)
      M(76, 58) = M(76, 58) - temp
C     Lower part.
      temp = M(77, 57) * M(57, 58)
      M(77, 58) = M(77, 58) - temp
C     Lower part.
      temp = M(78, 57) * M(57, 58)
      M(78, 58) = M(78, 58) - temp
C     Lower part.
      temp = M(80, 57) * M(57, 58)
      M(80, 58) = M(80, 58) - temp
C     Lower part.
      temp = M(81, 57) * M(57, 58)
      M(81, 58) = M(81, 58) - temp
C     Lower part.
      temp = M(82, 57) * M(57, 58)
      M(82, 58) = M(82, 58) - temp
C     Upper part.
      temp = M(58, 14) * M(14, 59)
      temp = temp + M(58, 21) * M(21, 59)
      temp = temp + M(58, 26) * M(26, 59)
      temp = temp + M(58, 27) * M(27, 59)
      temp = temp + M(58, 28) * M(28, 59)
      temp = temp + M(58, 34) * M(34, 59)
      temp = temp + M(58, 52) * M(52, 59)
      temp = temp + M(58, 53) * M(53, 59)
      temp = temp + M(58, 56) * M(56, 59)
      temp = temp + M(58, 57) * M(57, 59)
      M(58, 59) = ( M(58, 59) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 52) * M(52, 73)
      temp = temp + M(58, 53) * M(53, 73)
      temp = temp + M(58, 56) * M(56, 73)
      temp = temp + M(58, 57) * M(57, 73)
      M(58, 73) = ( M(58, 73) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 14) * M(14, 75)
      temp = temp + M(58, 21) * M(21, 75)
      temp = temp + M(58, 26) * M(26, 75)
      temp = temp + M(58, 27) * M(27, 75)
      temp = temp + M(58, 28) * M(28, 75)
      temp = temp + M(58, 34) * M(34, 75)
      temp = temp + M(58, 52) * M(52, 75)
      temp = temp + M(58, 53) * M(53, 75)
      temp = temp + M(58, 56) * M(56, 75)
      temp = temp + M(58, 57) * M(57, 75)
      M(58, 75) = ( M(58, 75) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 52) * M(52, 76)
      temp = temp + M(58, 53) * M(53, 76)
      temp = temp + M(58, 56) * M(56, 76)
      temp = temp + M(58, 57) * M(57, 76)
      M(58, 76) = ( M(58, 76) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 14) * M(14, 77)
      temp = temp + M(58, 21) * M(21, 77)
      temp = temp + M(58, 26) * M(26, 77)
      temp = temp + M(58, 27) * M(27, 77)
      temp = temp + M(58, 28) * M(28, 77)
      temp = temp + M(58, 34) * M(34, 77)
      temp = temp + M(58, 52) * M(52, 77)
      temp = temp + M(58, 53) * M(53, 77)
      temp = temp + M(58, 56) * M(56, 77)
      temp = temp + M(58, 57) * M(57, 77)
      M(58, 77) = ( M(58, 77) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 34) * M(34, 78)
      temp = temp + M(58, 52) * M(52, 78)
      temp = temp + M(58, 53) * M(53, 78)
      temp = temp + M(58, 56) * M(56, 78)
      temp = temp + M(58, 57) * M(57, 78)
      M(58, 78) = ( M(58, 78) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 34) * M(34, 80)
      temp = temp + M(58, 52) * M(52, 80)
      temp = temp + M(58, 53) * M(53, 80)
      temp = temp + M(58, 56) * M(56, 80)
      temp = temp + M(58, 57) * M(57, 80)
      M(58, 80) = ( M(58, 80) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 52) * M(52, 81)
      temp = temp + M(58, 53) * M(53, 81)
      temp = temp + M(58, 56) * M(56, 81)
      temp = temp + M(58, 57) * M(57, 81)
      M(58, 81) = ( M(58, 81) - temp ) / M(58, 58)

C     Lower part.
      temp = M(59, 14) * M(14, 59)
      temp = temp + M(59, 17) * M(17, 59)
      temp = temp + M(59, 18) * M(18, 59)
      temp = temp + M(59, 21) * M(21, 59)
      temp = temp + M(59, 26) * M(26, 59)
      temp = temp + M(59, 27) * M(27, 59)
      temp = temp + M(59, 28) * M(28, 59)
      temp = temp + M(59, 31) * M(31, 59)
      temp = temp + M(59, 34) * M(34, 59)
      temp = temp + M(59, 37) * M(37, 59)
      temp = temp + M(59, 42) * M(42, 59)
      temp = temp + M(59, 46) * M(46, 59)
      temp = temp + M(59, 52) * M(52, 59)
      temp = temp + M(59, 53) * M(53, 59)
      temp = temp + M(59, 56) * M(56, 59)
      M(59, 59) = M(59, 59) - temp
C     Lower part.
      temp = M(60, 14) * M(14, 59)
      temp = temp + M(60, 21) * M(21, 59)
      temp = temp + M(60, 26) * M(26, 59)
      temp = temp + M(60, 27) * M(27, 59)
      temp = temp + M(60, 28) * M(28, 59)
      temp = temp + M(60, 34) * M(34, 59)
      temp = temp + M(60, 42) * M(42, 59)
      temp = temp + M(60, 46) * M(46, 59)
      temp = temp + M(60, 52) * M(52, 59)
      temp = temp + M(60, 53) * M(53, 59)
      temp = temp + M(60, 56) * M(56, 59)
      M(60, 59) = M(60, 59) - temp
C     Lower part.
      temp = M(61, 33) * M(33, 59)
      temp = temp + M(61, 37) * M(37, 59)
      temp = temp + M(61, 39) * M(39, 59)
      temp = temp + M(61, 40) * M(40, 59)
      temp = temp + M(61, 46) * M(46, 59)
      temp = temp + M(61, 52) * M(52, 59)
      M(61, 59) = M(61, 59) - temp
C     Lower part.
      temp = M(62, 56) * M(56, 59)
      M(62, 59) = M(62, 59) - temp
C     Lower part.
      temp = M(63, 14) * M(14, 59)
      temp = temp + M(63, 46) * M(46, 59)
      temp = temp + M(63, 50) * M(50, 59)
      temp = temp + M(63, 51) * M(51, 59)
      temp = temp + M(63, 52) * M(52, 59)
      temp = temp + M(63, 53) * M(53, 59)
      temp = temp + M(63, 54) * M(54, 59)
      temp = temp + M(63, 56) * M(56, 59)
      temp = temp + M(63, 57) * M(57, 59)
      temp = temp + M(63, 58) * M(58, 59)
      M(63, 59) = M(63, 59) - temp
C     Lower part.
      temp = M(64, 14) * M(14, 59)
      temp = temp + M(64, 21) * M(21, 59)
      temp = temp + M(64, 26) * M(26, 59)
      temp = temp + M(64, 28) * M(28, 59)
      temp = temp + M(64, 34) * M(34, 59)
      temp = temp + M(64, 52) * M(52, 59)
      temp = temp + M(64, 53) * M(53, 59)
      temp = temp + M(64, 56) * M(56, 59)
      M(64, 59) = M(64, 59) - temp
C     Lower part.
      temp = M(65, 33) * M(33, 59)
      temp = temp + M(65, 37) * M(37, 59)
      temp = temp + M(65, 39) * M(39, 59)
      temp = temp + M(65, 40) * M(40, 59)
      temp = temp + M(65, 47) * M(47, 59)
      temp = temp + M(65, 50) * M(50, 59)
      temp = temp + M(65, 51) * M(51, 59)
      temp = temp + M(65, 52) * M(52, 59)
      temp = temp + M(65, 54) * M(54, 59)
      temp = temp + M(65, 55) * M(55, 59)
      M(65, 59) = M(65, 59) - temp
C     Lower part.
      temp = M(66, 33) * M(33, 59)
      temp = temp + M(66, 37) * M(37, 59)
      temp = temp + M(66, 39) * M(39, 59)
      temp = temp + M(66, 40) * M(40, 59)
      temp = temp + M(66, 42) * M(42, 59)
      temp = temp + M(66, 46) * M(46, 59)
      temp = temp + M(66, 52) * M(52, 59)
      M(66, 59) = M(66, 59) - temp
C     Lower part.
      temp = M(67, 37) * M(37, 59)
      temp = temp + M(67, 46) * M(46, 59)
      temp = temp + M(67, 52) * M(52, 59)
      M(67, 59) = M(67, 59) - temp
C     Lower part.
      temp = M(69, 26) * M(26, 59)
      temp = temp + M(69, 46) * M(46, 59)
      temp = temp + M(69, 52) * M(52, 59)
      temp = temp + M(69, 53) * M(53, 59)
      temp = temp + M(69, 54) * M(54, 59)
      temp = temp + M(69, 55) * M(55, 59)
      temp = temp + M(69, 56) * M(56, 59)
      temp = temp + M(69, 57) * M(57, 59)
      temp = temp + M(69, 58) * M(58, 59)
      M(69, 59) = M(69, 59) - temp
C     Lower part.
      temp = M(70, 14) * M(14, 59)
      temp = temp + M(70, 26) * M(26, 59)
      temp = temp + M(70, 30) * M(30, 59)
      temp = temp + M(70, 53) * M(53, 59)
      temp = temp + M(70, 56) * M(56, 59)
      M(70, 59) = M(70, 59) - temp
C     Lower part.
      temp = M(71, 26) * M(26, 59)
      temp = temp + M(71, 34) * M(34, 59)
      temp = temp + M(71, 46) * M(46, 59)
      temp = temp + M(71, 50) * M(50, 59)
      temp = temp + M(71, 52) * M(52, 59)
      temp = temp + M(71, 53) * M(53, 59)
      temp = temp + M(71, 54) * M(54, 59)
      temp = temp + M(71, 55) * M(55, 59)
      temp = temp + M(71, 56) * M(56, 59)
      temp = temp + M(71, 57) * M(57, 59)
      temp = temp + M(71, 58) * M(58, 59)
      M(71, 59) = M(71, 59) - temp
C     Lower part.
      temp = M(72, 21) * M(21, 59)
      temp = temp + M(72, 28) * M(28, 59)
      temp = temp + M(72, 34) * M(34, 59)
      temp = temp + M(72, 35) * M(35, 59)
      temp = temp + M(72, 37) * M(37, 59)
      temp = temp + M(72, 42) * M(42, 59)
      temp = temp + M(72, 44) * M(44, 59)
      temp = temp + M(72, 46) * M(46, 59)
      temp = temp + M(72, 52) * M(52, 59)
      M(72, 59) = M(72, 59) - temp
C     Lower part.
      temp = M(73, 21) * M(21, 59)
      temp = temp + M(73, 28) * M(28, 59)
      temp = temp + M(73, 29) * M(29, 59)
      temp = temp + M(73, 33) * M(33, 59)
      temp = temp + M(73, 34) * M(34, 59)
      temp = temp + M(73, 35) * M(35, 59)
      temp = temp + M(73, 37) * M(37, 59)
      temp = temp + M(73, 39) * M(39, 59)
      temp = temp + M(73, 40) * M(40, 59)
      temp = temp + M(73, 46) * M(46, 59)
      temp = temp + M(73, 47) * M(47, 59)
      temp = temp + M(73, 50) * M(50, 59)
      temp = temp + M(73, 51) * M(51, 59)
      temp = temp + M(73, 52) * M(52, 59)
      temp = temp + M(73, 53) * M(53, 59)
      temp = temp + M(73, 54) * M(54, 59)
      temp = temp + M(73, 55) * M(55, 59)
      temp = temp + M(73, 56) * M(56, 59)
      temp = temp + M(73, 57) * M(57, 59)
      temp = temp + M(73, 58) * M(58, 59)
      M(73, 59) = M(73, 59) - temp
C     Lower part.
      temp = M(74, 14) * M(14, 59)
      temp = temp + M(74, 21) * M(21, 59)
      temp = temp + M(74, 27) * M(27, 59)
      temp = temp + M(74, 28) * M(28, 59)
      temp = temp + M(74, 33) * M(33, 59)
      temp = temp + M(74, 34) * M(34, 59)
      temp = temp + M(74, 35) * M(35, 59)
      temp = temp + M(74, 37) * M(37, 59)
      temp = temp + M(74, 39) * M(39, 59)
      temp = temp + M(74, 40) * M(40, 59)
      temp = temp + M(74, 42) * M(42, 59)
      temp = temp + M(74, 44) * M(44, 59)
      temp = temp + M(74, 46) * M(46, 59)
      temp = temp + M(74, 47) * M(47, 59)
      temp = temp + M(74, 50) * M(50, 59)
      temp = temp + M(74, 51) * M(51, 59)
      temp = temp + M(74, 52) * M(52, 59)
      temp = temp + M(74, 53) * M(53, 59)
      temp = temp + M(74, 54) * M(54, 59)
      temp = temp + M(74, 55) * M(55, 59)
      temp = temp + M(74, 56) * M(56, 59)
      temp = temp + M(74, 57) * M(57, 59)
      temp = temp + M(74, 58) * M(58, 59)
      M(74, 59) = M(74, 59) - temp
C     Lower part.
      temp = M(75, 7) * M(7, 59)
      temp = temp + M(75, 14) * M(14, 59)
      temp = temp + M(75, 17) * M(17, 59)
      temp = temp + M(75, 18) * M(18, 59)
      temp = temp + M(75, 21) * M(21, 59)
      temp = temp + M(75, 26) * M(26, 59)
      temp = temp + M(75, 27) * M(27, 59)
      temp = temp + M(75, 28) * M(28, 59)
      temp = temp + M(75, 29) * M(29, 59)
      temp = temp + M(75, 30) * M(30, 59)
      temp = temp + M(75, 31) * M(31, 59)
      temp = temp + M(75, 32) * M(32, 59)
      temp = temp + M(75, 34) * M(34, 59)
      temp = temp + M(75, 35) * M(35, 59)
      temp = temp + M(75, 37) * M(37, 59)
      temp = temp + M(75, 42) * M(42, 59)
      temp = temp + M(75, 44) * M(44, 59)
      temp = temp + M(75, 45) * M(45, 59)
      temp = temp + M(75, 46) * M(46, 59)
      temp = temp + M(75, 52) * M(52, 59)
      temp = temp + M(75, 53) * M(53, 59)
      temp = temp + M(75, 56) * M(56, 59)
      M(75, 59) = M(75, 59) - temp
C     Lower part.
      temp = M(76, 21) * M(21, 59)
      temp = temp + M(76, 28) * M(28, 59)
      temp = temp + M(76, 33) * M(33, 59)
      temp = temp + M(76, 34) * M(34, 59)
      temp = temp + M(76, 35) * M(35, 59)
      temp = temp + M(76, 37) * M(37, 59)
      temp = temp + M(76, 39) * M(39, 59)
      temp = temp + M(76, 40) * M(40, 59)
      temp = temp + M(76, 42) * M(42, 59)
      temp = temp + M(76, 44) * M(44, 59)
      temp = temp + M(76, 46) * M(46, 59)
      temp = temp + M(76, 47) * M(47, 59)
      temp = temp + M(76, 50) * M(50, 59)
      temp = temp + M(76, 51) * M(51, 59)
      temp = temp + M(76, 52) * M(52, 59)
      temp = temp + M(76, 54) * M(54, 59)
      temp = temp + M(76, 55) * M(55, 59)
      temp = temp + M(76, 57) * M(57, 59)
      temp = temp + M(76, 58) * M(58, 59)
      M(76, 59) = M(76, 59) - temp
C     Lower part.
      temp = M(77, 14) * M(14, 59)
      temp = temp + M(77, 21) * M(21, 59)
      temp = temp + M(77, 26) * M(26, 59)
      temp = temp + M(77, 27) * M(27, 59)
      temp = temp + M(77, 28) * M(28, 59)
      temp = temp + M(77, 33) * M(33, 59)
      temp = temp + M(77, 34) * M(34, 59)
      temp = temp + M(77, 37) * M(37, 59)
      temp = temp + M(77, 39) * M(39, 59)
      temp = temp + M(77, 40) * M(40, 59)
      temp = temp + M(77, 42) * M(42, 59)
      temp = temp + M(77, 44) * M(44, 59)
      temp = temp + M(77, 46) * M(46, 59)
      temp = temp + M(77, 47) * M(47, 59)
      temp = temp + M(77, 50) * M(50, 59)
      temp = temp + M(77, 51) * M(51, 59)
      temp = temp + M(77, 52) * M(52, 59)
      temp = temp + M(77, 53) * M(53, 59)
      temp = temp + M(77, 54) * M(54, 59)
      temp = temp + M(77, 55) * M(55, 59)
      temp = temp + M(77, 56) * M(56, 59)
      temp = temp + M(77, 57) * M(57, 59)
      temp = temp + M(77, 58) * M(58, 59)
      M(77, 59) = M(77, 59) - temp
C     Lower part.
      temp = M(78, 32) * M(32, 59)
      temp = temp + M(78, 33) * M(33, 59)
      temp = temp + M(78, 34) * M(34, 59)
      temp = temp + M(78, 37) * M(37, 59)
      temp = temp + M(78, 39) * M(39, 59)
      temp = temp + M(78, 40) * M(40, 59)
      temp = temp + M(78, 47) * M(47, 59)
      temp = temp + M(78, 50) * M(50, 59)
      temp = temp + M(78, 51) * M(51, 59)
      temp = temp + M(78, 52) * M(52, 59)
      temp = temp + M(78, 54) * M(54, 59)
      temp = temp + M(78, 55) * M(55, 59)
      temp = temp + M(78, 57) * M(57, 59)
      temp = temp + M(78, 58) * M(58, 59)
      M(78, 59) = M(78, 59) - temp
C     Lower part.
      temp = M(79, 42) * M(42, 59)
      temp = temp + M(79, 46) * M(46, 59)
      temp = temp + M(79, 52) * M(52, 59)
      M(79, 59) = M(79, 59) - temp
C     Lower part.
      temp = M(80, 17) * M(17, 59)
      temp = temp + M(80, 18) * M(18, 59)
      temp = temp + M(80, 31) * M(31, 59)
      temp = temp + M(80, 32) * M(32, 59)
      temp = temp + M(80, 33) * M(33, 59)
      temp = temp + M(80, 34) * M(34, 59)
      temp = temp + M(80, 37) * M(37, 59)
      temp = temp + M(80, 39) * M(39, 59)
      temp = temp + M(80, 40) * M(40, 59)
      temp = temp + M(80, 42) * M(42, 59)
      temp = temp + M(80, 44) * M(44, 59)
      temp = temp + M(80, 46) * M(46, 59)
      temp = temp + M(80, 47) * M(47, 59)
      temp = temp + M(80, 50) * M(50, 59)
      temp = temp + M(80, 51) * M(51, 59)
      temp = temp + M(80, 52) * M(52, 59)
      temp = temp + M(80, 54) * M(54, 59)
      temp = temp + M(80, 55) * M(55, 59)
      temp = temp + M(80, 57) * M(57, 59)
      temp = temp + M(80, 58) * M(58, 59)
      M(80, 59) = M(80, 59) - temp
C     Lower part.
      temp = M(81, 14) * M(14, 59)
      temp = temp + M(81, 17) * M(17, 59)
      temp = temp + M(81, 18) * M(18, 59)
      temp = temp + M(81, 21) * M(21, 59)
      temp = temp + M(81, 26) * M(26, 59)
      temp = temp + M(81, 27) * M(27, 59)
      temp = temp + M(81, 28) * M(28, 59)
      temp = temp + M(81, 31) * M(31, 59)
      temp = temp + M(81, 33) * M(33, 59)
      temp = temp + M(81, 34) * M(34, 59)
      temp = temp + M(81, 35) * M(35, 59)
      temp = temp + M(81, 37) * M(37, 59)
      temp = temp + M(81, 39) * M(39, 59)
      temp = temp + M(81, 40) * M(40, 59)
      temp = temp + M(81, 42) * M(42, 59)
      temp = temp + M(81, 45) * M(45, 59)
      temp = temp + M(81, 46) * M(46, 59)
      temp = temp + M(81, 47) * M(47, 59)
      temp = temp + M(81, 50) * M(50, 59)
      temp = temp + M(81, 51) * M(51, 59)
      temp = temp + M(81, 52) * M(52, 59)
      temp = temp + M(81, 53) * M(53, 59)
      temp = temp + M(81, 54) * M(54, 59)
      temp = temp + M(81, 55) * M(55, 59)
      temp = temp + M(81, 56) * M(56, 59)
      temp = temp + M(81, 57) * M(57, 59)
      temp = temp + M(81, 58) * M(58, 59)
      M(81, 59) = M(81, 59) - temp
C     Lower part.
      temp = M(82, 37) * M(37, 59)
      temp = temp + M(82, 39) * M(39, 59)
      temp = temp + M(82, 40) * M(40, 59)
      temp = temp + M(82, 42) * M(42, 59)
      temp = temp + M(82, 47) * M(47, 59)
      temp = temp + M(82, 51) * M(51, 59)
      temp = temp + M(82, 52) * M(52, 59)
      temp = temp + M(82, 55) * M(55, 59)
      temp = temp + M(82, 57) * M(57, 59)
      temp = temp + M(82, 58) * M(58, 59)
      M(82, 59) = M(82, 59) - temp
C     Upper part.
      temp = M(59, 46) * M(46, 73)
      temp = temp + M(59, 52) * M(52, 73)
      temp = temp + M(59, 53) * M(53, 73)
      temp = temp + M(59, 56) * M(56, 73)
      M(59, 73) = ( M(59, 73) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 14) * M(14, 75)
      temp = temp + M(59, 17) * M(17, 75)
      temp = temp + M(59, 18) * M(18, 75)
      temp = temp + M(59, 21) * M(21, 75)
      temp = temp + M(59, 26) * M(26, 75)
      temp = temp + M(59, 27) * M(27, 75)
      temp = temp + M(59, 28) * M(28, 75)
      temp = temp + M(59, 31) * M(31, 75)
      temp = temp + M(59, 34) * M(34, 75)
      temp = temp + M(59, 37) * M(37, 75)
      temp = temp + M(59, 42) * M(42, 75)
      temp = temp + M(59, 46) * M(46, 75)
      temp = temp + M(59, 52) * M(52, 75)
      temp = temp + M(59, 53) * M(53, 75)
      temp = temp + M(59, 56) * M(56, 75)
      M(59, 75) = ( M(59, 75) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 46) * M(46, 76)
      temp = temp + M(59, 52) * M(52, 76)
      temp = temp + M(59, 53) * M(53, 76)
      temp = temp + M(59, 56) * M(56, 76)
      M(59, 76) = ( M(59, 76) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 14) * M(14, 77)
      temp = temp + M(59, 21) * M(21, 77)
      temp = temp + M(59, 26) * M(26, 77)
      temp = temp + M(59, 27) * M(27, 77)
      temp = temp + M(59, 28) * M(28, 77)
      temp = temp + M(59, 34) * M(34, 77)
      temp = temp + M(59, 37) * M(37, 77)
      temp = temp + M(59, 42) * M(42, 77)
      temp = temp + M(59, 46) * M(46, 77)
      temp = temp + M(59, 52) * M(52, 77)
      temp = temp + M(59, 53) * M(53, 77)
      temp = temp + M(59, 56) * M(56, 77)
      M(59, 77) = ( M(59, 77) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 34) * M(34, 78)
      temp = temp + M(59, 46) * M(46, 78)
      temp = temp + M(59, 52) * M(52, 78)
      temp = temp + M(59, 53) * M(53, 78)
      temp = temp + M(59, 56) * M(56, 78)
      M(59, 78) = ( M(59, 78) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 42) * M(42, 79)
      M(59, 79) = ( M(59, 79) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 17) * M(17, 80)
      temp = temp + M(59, 18) * M(18, 80)
      temp = temp + M(59, 31) * M(31, 80)
      temp = temp + M(59, 34) * M(34, 80)
      temp = temp + M(59, 37) * M(37, 80)
      temp = temp + M(59, 42) * M(42, 80)
      temp = temp + M(59, 46) * M(46, 80)
      temp = temp + M(59, 52) * M(52, 80)
      temp = temp + M(59, 53) * M(53, 80)
      temp = temp + M(59, 56) * M(56, 80)
      M(59, 80) = ( M(59, 80) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 37) * M(37, 81)
      temp = temp + M(59, 46) * M(46, 81)
      temp = temp + M(59, 52) * M(52, 81)
      temp = temp + M(59, 53) * M(53, 81)
      temp = temp + M(59, 56) * M(56, 81)
      M(59, 81) = ( M(59, 81) - temp ) / M(59, 59)

C     Upper part.
      M(60, 61) = M(60, 61) / M(60, 60)
C     Upper part.
      M(60, 66) = M(60, 66) / M(60, 60)
C     Upper part.
      M(60, 71) = M(60, 71) / M(60, 60)
C     Upper part.
      temp = M(60, 46) * M(46, 73)
      temp = temp + M(60, 52) * M(52, 73)
      temp = temp + M(60, 53) * M(53, 73)
      temp = temp + M(60, 56) * M(56, 73)
      temp = temp + M(60, 59) * M(59, 73)
      M(60, 73) = ( M(60, 73) - temp ) / M(60, 60)
C     Upper part.
      M(60, 74) = M(60, 74) / M(60, 60)
C     Upper part.
      temp = M(60, 11) * M(11, 75)
      temp = temp + M(60, 14) * M(14, 75)
      temp = temp + M(60, 21) * M(21, 75)
      temp = temp + M(60, 26) * M(26, 75)
      temp = temp + M(60, 27) * M(27, 75)
      temp = temp + M(60, 28) * M(28, 75)
      temp = temp + M(60, 34) * M(34, 75)
      temp = temp + M(60, 42) * M(42, 75)
      temp = temp + M(60, 46) * M(46, 75)
      temp = temp + M(60, 52) * M(52, 75)
      temp = temp + M(60, 53) * M(53, 75)
      temp = temp + M(60, 56) * M(56, 75)
      temp = temp + M(60, 59) * M(59, 75)
      M(60, 75) = ( M(60, 75) - temp ) / M(60, 60)
C     Upper part.
      temp = M(60, 46) * M(46, 76)
      temp = temp + M(60, 52) * M(52, 76)
      temp = temp + M(60, 53) * M(53, 76)
      temp = temp + M(60, 56) * M(56, 76)
      temp = temp + M(60, 59) * M(59, 76)
      M(60, 76) = ( M(60, 76) - temp ) / M(60, 60)
C     Upper part.
      temp = M(60, 14) * M(14, 77)
      temp = temp + M(60, 21) * M(21, 77)
      temp = temp + M(60, 26) * M(26, 77)
      temp = temp + M(60, 27) * M(27, 77)
      temp = temp + M(60, 28) * M(28, 77)
      temp = temp + M(60, 34) * M(34, 77)
      temp = temp + M(60, 42) * M(42, 77)
      temp = temp + M(60, 46) * M(46, 77)
      temp = temp + M(60, 52) * M(52, 77)
      temp = temp + M(60, 53) * M(53, 77)
      temp = temp + M(60, 56) * M(56, 77)
      temp = temp + M(60, 59) * M(59, 77)
      M(60, 77) = ( M(60, 77) - temp ) / M(60, 60)
C     Upper part.
      temp = M(60, 34) * M(34, 78)
      temp = temp + M(60, 46) * M(46, 78)
      temp = temp + M(60, 52) * M(52, 78)
      temp = temp + M(60, 53) * M(53, 78)
      temp = temp + M(60, 56) * M(56, 78)
      temp = temp + M(60, 59) * M(59, 78)
      M(60, 78) = ( M(60, 78) - temp ) / M(60, 60)
C     Upper part.
      temp = M(60, 42) * M(42, 79)
      temp = temp + M(60, 59) * M(59, 79)
      M(60, 79) = ( M(60, 79) - temp ) / M(60, 60)
C     Upper part.
      temp = M(60, 34) * M(34, 80)
      temp = temp + M(60, 42) * M(42, 80)
      temp = temp + M(60, 46) * M(46, 80)
      temp = temp + M(60, 52) * M(52, 80)
      temp = temp + M(60, 53) * M(53, 80)
      temp = temp + M(60, 56) * M(56, 80)
      temp = temp + M(60, 59) * M(59, 80)
      M(60, 80) = ( M(60, 80) - temp ) / M(60, 60)
C     Upper part.
      temp = M(60, 46) * M(46, 81)
      temp = temp + M(60, 52) * M(52, 81)
      temp = temp + M(60, 53) * M(53, 81)
      temp = temp + M(60, 56) * M(56, 81)
      temp = temp + M(60, 59) * M(59, 81)
      M(60, 81) = ( M(60, 81) - temp ) / M(60, 60)

C     Lower part.
      temp = M(75, 60) * M(60, 61)
      M(75, 61) = M(75, 61) - temp
C     Lower part.
      temp = M(81, 60) * M(60, 61)
      M(81, 61) = M(81, 61) - temp
C     Upper part.
      M(61, 68) = M(61, 68) / M(61, 61)
C     Upper part.
      temp = M(61, 33) * M(33, 73)
      temp = temp + M(61, 39) * M(39, 73)
      temp = temp + M(61, 40) * M(40, 73)
      temp = temp + M(61, 46) * M(46, 73)
      temp = temp + M(61, 52) * M(52, 73)
      temp = temp + M(61, 59) * M(59, 73)
      M(61, 73) = ( M(61, 73) - temp ) / M(61, 61)
C     Upper part.
      temp = M(61, 11) * M(11, 75)
      temp = temp + M(61, 33) * M(33, 75)
      temp = temp + M(61, 37) * M(37, 75)
      temp = temp + M(61, 39) * M(39, 75)
      temp = temp + M(61, 40) * M(40, 75)
      temp = temp + M(61, 46) * M(46, 75)
      temp = temp + M(61, 52) * M(52, 75)
      temp = temp + M(61, 59) * M(59, 75)
      M(61, 75) = ( M(61, 75) - temp ) / M(61, 61)
C     Upper part.
      temp = M(61, 33) * M(33, 76)
      temp = temp + M(61, 39) * M(39, 76)
      temp = temp + M(61, 40) * M(40, 76)
      temp = temp + M(61, 46) * M(46, 76)
      temp = temp + M(61, 52) * M(52, 76)
      temp = temp + M(61, 59) * M(59, 76)
      M(61, 76) = ( M(61, 76) - temp ) / M(61, 61)
C     Upper part.
      temp = M(61, 33) * M(33, 77)
      temp = temp + M(61, 37) * M(37, 77)
      temp = temp + M(61, 39) * M(39, 77)
      temp = temp + M(61, 40) * M(40, 77)
      temp = temp + M(61, 46) * M(46, 77)
      temp = temp + M(61, 52) * M(52, 77)
      temp = temp + M(61, 59) * M(59, 77)
      M(61, 77) = ( M(61, 77) - temp ) / M(61, 61)
C     Upper part.
      temp = M(61, 33) * M(33, 78)
      temp = temp + M(61, 39) * M(39, 78)
      temp = temp + M(61, 40) * M(40, 78)
      temp = temp + M(61, 46) * M(46, 78)
      temp = temp + M(61, 52) * M(52, 78)
      temp = temp + M(61, 59) * M(59, 78)
      M(61, 78) = ( M(61, 78) - temp ) / M(61, 61)
C     Upper part.
      temp = M(61, 59) * M(59, 79)
      M(61, 79) = ( M(61, 79) - temp ) / M(61, 61)
C     Upper part.
      temp = M(61, 33) * M(33, 80)
      temp = temp + M(61, 37) * M(37, 80)
      temp = temp + M(61, 39) * M(39, 80)
      temp = temp + M(61, 40) * M(40, 80)
      temp = temp + M(61, 46) * M(46, 80)
      temp = temp + M(61, 52) * M(52, 80)
      temp = temp + M(61, 59) * M(59, 80)
      M(61, 80) = ( M(61, 80) - temp ) / M(61, 61)
C     Upper part.
      temp = M(61, 33) * M(33, 81)
      temp = temp + M(61, 37) * M(37, 81)
      temp = temp + M(61, 39) * M(39, 81)
      temp = temp + M(61, 40) * M(40, 81)
      temp = temp + M(61, 46) * M(46, 81)
      temp = temp + M(61, 52) * M(52, 81)
      temp = temp + M(61, 59) * M(59, 81)
      M(61, 81) = ( M(61, 81) - temp ) / M(61, 61)

C     Upper part.
      temp = M(62, 56) * M(56, 73)
      temp = temp + M(62, 59) * M(59, 73)
      M(62, 73) = ( M(62, 73) - temp ) / M(62, 62)
C     Upper part.
      temp = M(62, 56) * M(56, 75)
      temp = temp + M(62, 59) * M(59, 75)
      M(62, 75) = ( M(62, 75) - temp ) / M(62, 62)
C     Upper part.
      temp = M(62, 56) * M(56, 76)
      temp = temp + M(62, 59) * M(59, 76)
      M(62, 76) = ( M(62, 76) - temp ) / M(62, 62)
C     Upper part.
      temp = M(62, 56) * M(56, 77)
      temp = temp + M(62, 59) * M(59, 77)
      M(62, 77) = ( M(62, 77) - temp ) / M(62, 62)
C     Upper part.
      temp = M(62, 56) * M(56, 78)
      temp = temp + M(62, 59) * M(59, 78)
      M(62, 78) = ( M(62, 78) - temp ) / M(62, 62)
C     Upper part.
      temp = M(62, 59) * M(59, 79)
      M(62, 79) = ( M(62, 79) - temp ) / M(62, 62)
C     Upper part.
      temp = M(62, 56) * M(56, 80)
      temp = temp + M(62, 59) * M(59, 80)
      M(62, 80) = ( M(62, 80) - temp ) / M(62, 62)
C     Upper part.
      temp = M(62, 56) * M(56, 81)
      temp = temp + M(62, 59) * M(59, 81)
      M(62, 81) = ( M(62, 81) - temp ) / M(62, 62)

C     Upper part.
      M(63, 64) = M(63, 64) / M(63, 63)
C     Upper part.
      M(63, 68) = M(63, 68) / M(63, 63)
C     Upper part.
      M(63, 70) = M(63, 70) / M(63, 63)
C     Upper part.
      temp = M(63, 46) * M(46, 73)
      temp = temp + M(63, 48) * M(48, 73)
      temp = temp + M(63, 49) * M(49, 73)
      temp = temp + M(63, 50) * M(50, 73)
      temp = temp + M(63, 51) * M(51, 73)
      temp = temp + M(63, 52) * M(52, 73)
      temp = temp + M(63, 53) * M(53, 73)
      temp = temp + M(63, 54) * M(54, 73)
      temp = temp + M(63, 56) * M(56, 73)
      temp = temp + M(63, 57) * M(57, 73)
      temp = temp + M(63, 58) * M(58, 73)
      temp = temp + M(63, 59) * M(59, 73)
      temp = temp + M(63, 62) * M(62, 73)
      M(63, 73) = ( M(63, 73) - temp ) / M(63, 63)
C     Upper part.
      temp = M(63, 14) * M(14, 75)
      temp = temp + M(63, 46) * M(46, 75)
      temp = temp + M(63, 48) * M(48, 75)
      temp = temp + M(63, 49) * M(49, 75)
      temp = temp + M(63, 50) * M(50, 75)
      temp = temp + M(63, 51) * M(51, 75)
      temp = temp + M(63, 52) * M(52, 75)
      temp = temp + M(63, 53) * M(53, 75)
      temp = temp + M(63, 54) * M(54, 75)
      temp = temp + M(63, 56) * M(56, 75)
      temp = temp + M(63, 57) * M(57, 75)
      temp = temp + M(63, 58) * M(58, 75)
      temp = temp + M(63, 59) * M(59, 75)
      temp = temp + M(63, 62) * M(62, 75)
      M(63, 75) = ( M(63, 75) - temp ) / M(63, 63)
C     Upper part.
      temp = M(63, 46) * M(46, 76)
      temp = temp + M(63, 48) * M(48, 76)
      temp = temp + M(63, 49) * M(49, 76)
      temp = temp + M(63, 50) * M(50, 76)
      temp = temp + M(63, 51) * M(51, 76)
      temp = temp + M(63, 52) * M(52, 76)
      temp = temp + M(63, 53) * M(53, 76)
      temp = temp + M(63, 54) * M(54, 76)
      temp = temp + M(63, 56) * M(56, 76)
      temp = temp + M(63, 57) * M(57, 76)
      temp = temp + M(63, 58) * M(58, 76)
      temp = temp + M(63, 59) * M(59, 76)
      temp = temp + M(63, 62) * M(62, 76)
      M(63, 76) = ( M(63, 76) - temp ) / M(63, 63)
C     Upper part.
      temp = M(63, 14) * M(14, 77)
      temp = temp + M(63, 46) * M(46, 77)
      temp = temp + M(63, 48) * M(48, 77)
      temp = temp + M(63, 49) * M(49, 77)
      temp = temp + M(63, 50) * M(50, 77)
      temp = temp + M(63, 51) * M(51, 77)
      temp = temp + M(63, 52) * M(52, 77)
      temp = temp + M(63, 53) * M(53, 77)
      temp = temp + M(63, 54) * M(54, 77)
      temp = temp + M(63, 56) * M(56, 77)
      temp = temp + M(63, 57) * M(57, 77)
      temp = temp + M(63, 58) * M(58, 77)
      temp = temp + M(63, 59) * M(59, 77)
      temp = temp + M(63, 62) * M(62, 77)
      M(63, 77) = ( M(63, 77) - temp ) / M(63, 63)
C     Upper part.
      temp = M(63, 46) * M(46, 78)
      temp = temp + M(63, 48) * M(48, 78)
      temp = temp + M(63, 49) * M(49, 78)
      temp = temp + M(63, 50) * M(50, 78)
      temp = temp + M(63, 51) * M(51, 78)
      temp = temp + M(63, 52) * M(52, 78)
      temp = temp + M(63, 53) * M(53, 78)
      temp = temp + M(63, 54) * M(54, 78)
      temp = temp + M(63, 56) * M(56, 78)
      temp = temp + M(63, 57) * M(57, 78)
      temp = temp + M(63, 58) * M(58, 78)
      temp = temp + M(63, 59) * M(59, 78)
      temp = temp + M(63, 62) * M(62, 78)
      M(63, 78) = ( M(63, 78) - temp ) / M(63, 63)
C     Upper part.
      temp = M(63, 59) * M(59, 79)
      temp = temp + M(63, 62) * M(62, 79)
      M(63, 79) = ( M(63, 79) - temp ) / M(63, 63)
C     Upper part.
      temp = M(63, 46) * M(46, 80)
      temp = temp + M(63, 51) * M(51, 80)
      temp = temp + M(63, 52) * M(52, 80)
      temp = temp + M(63, 53) * M(53, 80)
      temp = temp + M(63, 54) * M(54, 80)
      temp = temp + M(63, 56) * M(56, 80)
      temp = temp + M(63, 57) * M(57, 80)
      temp = temp + M(63, 58) * M(58, 80)
      temp = temp + M(63, 59) * M(59, 80)
      temp = temp + M(63, 62) * M(62, 80)
      M(63, 80) = ( M(63, 80) - temp ) / M(63, 63)
C     Upper part.
      temp = M(63, 46) * M(46, 81)
      temp = temp + M(63, 48) * M(48, 81)
      temp = temp + M(63, 49) * M(49, 81)
      temp = temp + M(63, 50) * M(50, 81)
      temp = temp + M(63, 51) * M(51, 81)
      temp = temp + M(63, 52) * M(52, 81)
      temp = temp + M(63, 53) * M(53, 81)
      temp = temp + M(63, 54) * M(54, 81)
      temp = temp + M(63, 56) * M(56, 81)
      temp = temp + M(63, 57) * M(57, 81)
      temp = temp + M(63, 58) * M(58, 81)
      temp = temp + M(63, 59) * M(59, 81)
      temp = temp + M(63, 62) * M(62, 81)
      M(63, 81) = ( M(63, 81) - temp ) / M(63, 63)

C     Lower part.
      temp = M(66, 41) * M(41, 64)
      M(66, 64) = M(66, 64) - temp
C     Lower part.
      temp = M(74, 41) * M(41, 64)
      M(74, 64) = M(74, 64) - temp
C     Lower part.
      temp = M(75, 41) * M(41, 64)
      M(75, 64) = M(75, 64) - temp
C     Lower part.
      temp = M(76, 41) * M(41, 64)
      M(76, 64) = M(76, 64) - temp
C     Lower part.
      temp = M(81, 41) * M(41, 64)
      M(81, 64) = M(81, 64) - temp
C     Upper part.
      M(64, 69) = M(64, 69) / M(64, 64)
C     Upper part.
      temp = M(64, 52) * M(52, 73)
      temp = temp + M(64, 53) * M(53, 73)
      temp = temp + M(64, 56) * M(56, 73)
      temp = temp + M(64, 59) * M(59, 73)
      M(64, 73) = ( M(64, 73) - temp ) / M(64, 64)
C     Upper part.
      temp = M(64, 14) * M(14, 75)
      temp = temp + M(64, 21) * M(21, 75)
      temp = temp + M(64, 26) * M(26, 75)
      temp = temp + M(64, 28) * M(28, 75)
      temp = temp + M(64, 34) * M(34, 75)
      temp = temp + M(64, 52) * M(52, 75)
      temp = temp + M(64, 53) * M(53, 75)
      temp = temp + M(64, 56) * M(56, 75)
      temp = temp + M(64, 59) * M(59, 75)
      M(64, 75) = ( M(64, 75) - temp ) / M(64, 64)
C     Upper part.
      temp = M(64, 52) * M(52, 76)
      temp = temp + M(64, 53) * M(53, 76)
      temp = temp + M(64, 56) * M(56, 76)
      temp = temp + M(64, 59) * M(59, 76)
      M(64, 76) = ( M(64, 76) - temp ) / M(64, 64)
C     Upper part.
      temp = M(64, 14) * M(14, 77)
      temp = temp + M(64, 21) * M(21, 77)
      temp = temp + M(64, 26) * M(26, 77)
      temp = temp + M(64, 28) * M(28, 77)
      temp = temp + M(64, 34) * M(34, 77)
      temp = temp + M(64, 52) * M(52, 77)
      temp = temp + M(64, 53) * M(53, 77)
      temp = temp + M(64, 56) * M(56, 77)
      temp = temp + M(64, 59) * M(59, 77)
      M(64, 77) = ( M(64, 77) - temp ) / M(64, 64)
C     Upper part.
      temp = M(64, 34) * M(34, 78)
      temp = temp + M(64, 52) * M(52, 78)
      temp = temp + M(64, 53) * M(53, 78)
      temp = temp + M(64, 56) * M(56, 78)
      temp = temp + M(64, 59) * M(59, 78)
      M(64, 78) = ( M(64, 78) - temp ) / M(64, 64)
C     Upper part.
      temp = M(64, 59) * M(59, 79)
      M(64, 79) = ( M(64, 79) - temp ) / M(64, 64)
C     Upper part.
      temp = M(64, 34) * M(34, 80)
      temp = temp + M(64, 52) * M(52, 80)
      temp = temp + M(64, 53) * M(53, 80)
      temp = temp + M(64, 56) * M(56, 80)
      temp = temp + M(64, 59) * M(59, 80)
      M(64, 80) = ( M(64, 80) - temp ) / M(64, 64)
C     Upper part.
      temp = M(64, 52) * M(52, 81)
      temp = temp + M(64, 53) * M(53, 81)
      temp = temp + M(64, 56) * M(56, 81)
      temp = temp + M(64, 59) * M(59, 81)
      M(64, 81) = ( M(64, 81) - temp ) / M(64, 64)

C     Upper part.
      M(65, 68) = M(65, 68) / M(65, 65)
C     Upper part.
      temp = M(65, 64) * M(64, 69)
      M(65, 69) = ( M(65, 69) - temp ) / M(65, 65)
C     Upper part.
      M(65, 70) = M(65, 70) / M(65, 65)
C     Upper part.
      M(65, 72) = M(65, 72) / M(65, 65)
C     Upper part.
      temp = M(65, 33) * M(33, 73)
      temp = temp + M(65, 39) * M(39, 73)
      temp = temp + M(65, 40) * M(40, 73)
      temp = temp + M(65, 47) * M(47, 73)
      temp = temp + M(65, 48) * M(48, 73)
      temp = temp + M(65, 49) * M(49, 73)
      temp = temp + M(65, 50) * M(50, 73)
      temp = temp + M(65, 51) * M(51, 73)
      temp = temp + M(65, 52) * M(52, 73)
      temp = temp + M(65, 54) * M(54, 73)
      temp = temp + M(65, 55) * M(55, 73)
      temp = temp + M(65, 59) * M(59, 73)
      temp = temp + M(65, 62) * M(62, 73)
      temp = temp + M(65, 64) * M(64, 73)
      M(65, 73) = ( M(65, 73) - temp ) / M(65, 65)
C     Upper part.
      temp = M(65, 33) * M(33, 75)
      temp = temp + M(65, 37) * M(37, 75)
      temp = temp + M(65, 39) * M(39, 75)
      temp = temp + M(65, 40) * M(40, 75)
      temp = temp + M(65, 47) * M(47, 75)
      temp = temp + M(65, 48) * M(48, 75)
      temp = temp + M(65, 49) * M(49, 75)
      temp = temp + M(65, 50) * M(50, 75)
      temp = temp + M(65, 51) * M(51, 75)
      temp = temp + M(65, 52) * M(52, 75)
      temp = temp + M(65, 54) * M(54, 75)
      temp = temp + M(65, 55) * M(55, 75)
      temp = temp + M(65, 59) * M(59, 75)
      temp = temp + M(65, 62) * M(62, 75)
      temp = temp + M(65, 64) * M(64, 75)
      M(65, 75) = ( M(65, 75) - temp ) / M(65, 65)
C     Upper part.
      temp = M(65, 33) * M(33, 76)
      temp = temp + M(65, 39) * M(39, 76)
      temp = temp + M(65, 40) * M(40, 76)
      temp = temp + M(65, 47) * M(47, 76)
      temp = temp + M(65, 48) * M(48, 76)
      temp = temp + M(65, 49) * M(49, 76)
      temp = temp + M(65, 50) * M(50, 76)
      temp = temp + M(65, 51) * M(51, 76)
      temp = temp + M(65, 52) * M(52, 76)
      temp = temp + M(65, 54) * M(54, 76)
      temp = temp + M(65, 55) * M(55, 76)
      temp = temp + M(65, 59) * M(59, 76)
      temp = temp + M(65, 62) * M(62, 76)
      temp = temp + M(65, 64) * M(64, 76)
      M(65, 76) = ( M(65, 76) - temp ) / M(65, 65)
C     Upper part.
      temp = M(65, 33) * M(33, 77)
      temp = temp + M(65, 37) * M(37, 77)
      temp = temp + M(65, 39) * M(39, 77)
      temp = temp + M(65, 40) * M(40, 77)
      temp = temp + M(65, 47) * M(47, 77)
      temp = temp + M(65, 48) * M(48, 77)
      temp = temp + M(65, 49) * M(49, 77)
      temp = temp + M(65, 50) * M(50, 77)
      temp = temp + M(65, 51) * M(51, 77)
      temp = temp + M(65, 52) * M(52, 77)
      temp = temp + M(65, 54) * M(54, 77)
      temp = temp + M(65, 55) * M(55, 77)
      temp = temp + M(65, 59) * M(59, 77)
      temp = temp + M(65, 62) * M(62, 77)
      temp = temp + M(65, 64) * M(64, 77)
      M(65, 77) = ( M(65, 77) - temp ) / M(65, 65)
C     Upper part.
      temp = M(65, 33) * M(33, 78)
      temp = temp + M(65, 39) * M(39, 78)
      temp = temp + M(65, 40) * M(40, 78)
      temp = temp + M(65, 47) * M(47, 78)
      temp = temp + M(65, 48) * M(48, 78)
      temp = temp + M(65, 49) * M(49, 78)
      temp = temp + M(65, 50) * M(50, 78)
      temp = temp + M(65, 51) * M(51, 78)
      temp = temp + M(65, 52) * M(52, 78)
      temp = temp + M(65, 54) * M(54, 78)
      temp = temp + M(65, 55) * M(55, 78)
      temp = temp + M(65, 59) * M(59, 78)
      temp = temp + M(65, 62) * M(62, 78)
      temp = temp + M(65, 64) * M(64, 78)
      M(65, 78) = ( M(65, 78) - temp ) / M(65, 65)
C     Upper part.
      temp = M(65, 59) * M(59, 79)
      temp = temp + M(65, 62) * M(62, 79)
      temp = temp + M(65, 64) * M(64, 79)
      M(65, 79) = ( M(65, 79) - temp ) / M(65, 65)
C     Upper part.
      temp = M(65, 33) * M(33, 80)
      temp = temp + M(65, 37) * M(37, 80)
      temp = temp + M(65, 39) * M(39, 80)
      temp = temp + M(65, 40) * M(40, 80)
      temp = temp + M(65, 51) * M(51, 80)
      temp = temp + M(65, 52) * M(52, 80)
      temp = temp + M(65, 54) * M(54, 80)
      temp = temp + M(65, 59) * M(59, 80)
      temp = temp + M(65, 62) * M(62, 80)
      temp = temp + M(65, 64) * M(64, 80)
      M(65, 80) = ( M(65, 80) - temp ) / M(65, 65)
C     Upper part.
      temp = M(65, 33) * M(33, 81)
      temp = temp + M(65, 37) * M(37, 81)
      temp = temp + M(65, 39) * M(39, 81)
      temp = temp + M(65, 40) * M(40, 81)
      temp = temp + M(65, 47) * M(47, 81)
      temp = temp + M(65, 48) * M(48, 81)
      temp = temp + M(65, 49) * M(49, 81)
      temp = temp + M(65, 50) * M(50, 81)
      temp = temp + M(65, 51) * M(51, 81)
      temp = temp + M(65, 52) * M(52, 81)
      temp = temp + M(65, 54) * M(54, 81)
      temp = temp + M(65, 55) * M(55, 81)
      temp = temp + M(65, 59) * M(59, 81)
      temp = temp + M(65, 62) * M(62, 81)
      temp = temp + M(65, 64) * M(64, 81)
      M(65, 81) = ( M(65, 81) - temp ) / M(65, 65)

C     Lower part.
      temp = M(75, 60) * M(60, 66)
      M(75, 66) = M(75, 66) - temp
C     Lower part.
      temp = M(81, 60) * M(60, 66)
      M(81, 66) = M(81, 66) - temp
C     Upper part.
      M(66, 68) = M(66, 68) / M(66, 66)
C     Upper part.
      temp = M(66, 64) * M(64, 69)
      M(66, 69) = ( M(66, 69) - temp ) / M(66, 66)
C     Upper part.
      temp = M(66, 33) * M(33, 73)
      temp = temp + M(66, 39) * M(39, 73)
      temp = temp + M(66, 40) * M(40, 73)
      temp = temp + M(66, 41) * M(41, 73)
      temp = temp + M(66, 46) * M(46, 73)
      temp = temp + M(66, 52) * M(52, 73)
      temp = temp + M(66, 59) * M(59, 73)
      temp = temp + M(66, 64) * M(64, 73)
      M(66, 73) = ( M(66, 73) - temp ) / M(66, 66)
C     Upper part.
      temp = M(66, 33) * M(33, 75)
      temp = temp + M(66, 37) * M(37, 75)
      temp = temp + M(66, 39) * M(39, 75)
      temp = temp + M(66, 40) * M(40, 75)
      temp = temp + M(66, 41) * M(41, 75)
      temp = temp + M(66, 42) * M(42, 75)
      temp = temp + M(66, 46) * M(46, 75)
      temp = temp + M(66, 52) * M(52, 75)
      temp = temp + M(66, 59) * M(59, 75)
      temp = temp + M(66, 64) * M(64, 75)
      M(66, 75) = ( M(66, 75) - temp ) / M(66, 66)
C     Upper part.
      temp = M(66, 33) * M(33, 76)
      temp = temp + M(66, 39) * M(39, 76)
      temp = temp + M(66, 40) * M(40, 76)
      temp = temp + M(66, 46) * M(46, 76)
      temp = temp + M(66, 52) * M(52, 76)
      temp = temp + M(66, 59) * M(59, 76)
      temp = temp + M(66, 64) * M(64, 76)
      M(66, 76) = ( M(66, 76) - temp ) / M(66, 66)
C     Upper part.
      temp = M(66, 33) * M(33, 77)
      temp = temp + M(66, 37) * M(37, 77)
      temp = temp + M(66, 39) * M(39, 77)
      temp = temp + M(66, 40) * M(40, 77)
      temp = temp + M(66, 42) * M(42, 77)
      temp = temp + M(66, 46) * M(46, 77)
      temp = temp + M(66, 52) * M(52, 77)
      temp = temp + M(66, 59) * M(59, 77)
      temp = temp + M(66, 64) * M(64, 77)
      M(66, 77) = ( M(66, 77) - temp ) / M(66, 66)
C     Upper part.
      temp = M(66, 33) * M(33, 78)
      temp = temp + M(66, 39) * M(39, 78)
      temp = temp + M(66, 40) * M(40, 78)
      temp = temp + M(66, 46) * M(46, 78)
      temp = temp + M(66, 52) * M(52, 78)
      temp = temp + M(66, 59) * M(59, 78)
      temp = temp + M(66, 64) * M(64, 78)
      M(66, 78) = ( M(66, 78) - temp ) / M(66, 66)
C     Upper part.
      temp = M(66, 42) * M(42, 79)
      temp = temp + M(66, 59) * M(59, 79)
      temp = temp + M(66, 64) * M(64, 79)
      M(66, 79) = ( M(66, 79) - temp ) / M(66, 66)
C     Upper part.
      temp = M(66, 33) * M(33, 80)
      temp = temp + M(66, 37) * M(37, 80)
      temp = temp + M(66, 39) * M(39, 80)
      temp = temp + M(66, 40) * M(40, 80)
      temp = temp + M(66, 42) * M(42, 80)
      temp = temp + M(66, 46) * M(46, 80)
      temp = temp + M(66, 52) * M(52, 80)
      temp = temp + M(66, 59) * M(59, 80)
      temp = temp + M(66, 64) * M(64, 80)
      M(66, 80) = ( M(66, 80) - temp ) / M(66, 66)
C     Upper part.
      temp = M(66, 33) * M(33, 81)
      temp = temp + M(66, 37) * M(37, 81)
      temp = temp + M(66, 39) * M(39, 81)
      temp = temp + M(66, 40) * M(40, 81)
      temp = temp + M(66, 46) * M(46, 81)
      temp = temp + M(66, 52) * M(52, 81)
      temp = temp + M(66, 59) * M(59, 81)
      temp = temp + M(66, 64) * M(64, 81)
      M(66, 81) = ( M(66, 81) - temp ) / M(66, 66)

C     Upper part.
      temp = M(67, 61) * M(61, 68)
      temp = temp + M(67, 66) * M(66, 68)
      M(67, 68) = ( M(67, 68) - temp ) / M(67, 67)
C     Upper part.
      temp = M(67, 66) * M(66, 69)
      M(67, 69) = ( M(67, 69) - temp ) / M(67, 67)
C     Upper part.
      M(67, 71) = M(67, 71) / M(67, 67)
C     Upper part.
      temp = M(67, 46) * M(46, 73)
      temp = temp + M(67, 52) * M(52, 73)
      temp = temp + M(67, 59) * M(59, 73)
      temp = temp + M(67, 61) * M(61, 73)
      temp = temp + M(67, 66) * M(66, 73)
      M(67, 73) = ( M(67, 73) - temp ) / M(67, 67)
C     Upper part.
      M(67, 74) = M(67, 74) / M(67, 67)
C     Upper part.
      temp = M(67, 37) * M(37, 75)
      temp = temp + M(67, 46) * M(46, 75)
      temp = temp + M(67, 52) * M(52, 75)
      temp = temp + M(67, 59) * M(59, 75)
      temp = temp + M(67, 61) * M(61, 75)
      temp = temp + M(67, 66) * M(66, 75)
      M(67, 75) = ( M(67, 75) - temp ) / M(67, 67)
C     Upper part.
      temp = M(67, 46) * M(46, 76)
      temp = temp + M(67, 52) * M(52, 76)
      temp = temp + M(67, 59) * M(59, 76)
      temp = temp + M(67, 61) * M(61, 76)
      temp = temp + M(67, 66) * M(66, 76)
      M(67, 76) = ( M(67, 76) - temp ) / M(67, 67)
C     Upper part.
      temp = M(67, 13) * M(13, 77)
      temp = temp + M(67, 37) * M(37, 77)
      temp = temp + M(67, 46) * M(46, 77)
      temp = temp + M(67, 52) * M(52, 77)
      temp = temp + M(67, 59) * M(59, 77)
      temp = temp + M(67, 61) * M(61, 77)
      temp = temp + M(67, 66) * M(66, 77)
      M(67, 77) = ( M(67, 77) - temp ) / M(67, 67)
C     Upper part.
      temp = M(67, 46) * M(46, 78)
      temp = temp + M(67, 52) * M(52, 78)
      temp = temp + M(67, 59) * M(59, 78)
      temp = temp + M(67, 61) * M(61, 78)
      temp = temp + M(67, 66) * M(66, 78)
      M(67, 78) = ( M(67, 78) - temp ) / M(67, 67)
C     Upper part.
      temp = M(67, 59) * M(59, 79)
      temp = temp + M(67, 61) * M(61, 79)
      temp = temp + M(67, 66) * M(66, 79)
      M(67, 79) = ( M(67, 79) - temp ) / M(67, 67)
C     Upper part.
      temp = M(67, 13) * M(13, 80)
      temp = temp + M(67, 37) * M(37, 80)
      temp = temp + M(67, 46) * M(46, 80)
      temp = temp + M(67, 52) * M(52, 80)
      temp = temp + M(67, 59) * M(59, 80)
      temp = temp + M(67, 61) * M(61, 80)
      temp = temp + M(67, 66) * M(66, 80)
      M(67, 80) = ( M(67, 80) - temp ) / M(67, 67)
C     Upper part.
      temp = M(67, 37) * M(37, 81)
      temp = temp + M(67, 46) * M(46, 81)
      temp = temp + M(67, 52) * M(52, 81)
      temp = temp + M(67, 59) * M(59, 81)
      temp = temp + M(67, 61) * M(61, 81)
      temp = temp + M(67, 66) * M(66, 81)
      M(67, 81) = ( M(67, 81) - temp ) / M(67, 67)

C     Lower part.
      temp = M(68, 65) * M(65, 68)
      M(68, 68) = M(68, 68) - temp
C     Lower part.
      temp = M(69, 65) * M(65, 68)
      M(69, 68) = M(69, 68) - temp
C     Lower part.
      temp = M(71, 65) * M(65, 68)
      M(71, 68) = M(71, 68) - temp
C     Lower part.
      temp = M(72, 65) * M(65, 68)
      M(72, 68) = M(72, 68) - temp
C     Lower part.
      temp = M(74, 61) * M(61, 68)
      M(74, 68) = M(74, 68) - temp
C     Lower part.
      temp = M(75, 61) * M(61, 68)
      temp = temp + M(75, 65) * M(65, 68)
      temp = temp + M(75, 66) * M(66, 68)
      temp = temp + M(75, 67) * M(67, 68)
      M(75, 68) = M(75, 68) - temp
C     Lower part.
      temp = M(76, 66) * M(66, 68)
      M(76, 68) = M(76, 68) - temp
C     Lower part.
      temp = M(77, 61) * M(61, 68)
      temp = temp + M(77, 66) * M(66, 68)
      temp = temp + M(77, 67) * M(67, 68)
      M(77, 68) = M(77, 68) - temp
C     Lower part.
      temp = M(80, 67) * M(67, 68)
      M(80, 68) = M(80, 68) - temp
C     Lower part.
      temp = M(81, 61) * M(61, 68)
      temp = temp + M(81, 65) * M(65, 68)
      temp = temp + M(81, 66) * M(66, 68)
      M(81, 68) = M(81, 68) - temp
C     Upper part.
      temp = M(68, 65) * M(65, 69)
      M(68, 69) = ( M(68, 69) - temp ) / M(68, 68)
C     Upper part.
      temp = M(68, 65) * M(65, 70)
      M(68, 70) = ( M(68, 70) - temp ) / M(68, 68)
C     Upper part.
      temp = M(68, 65) * M(65, 72)
      M(68, 72) = ( M(68, 72) - temp ) / M(68, 68)
C     Upper part.
      temp = M(68, 65) * M(65, 73)
      M(68, 73) = ( M(68, 73) - temp ) / M(68, 68)
C     Upper part.
      temp = M(68, 11) * M(11, 75)
      temp = temp + M(68, 65) * M(65, 75)
      M(68, 75) = ( M(68, 75) - temp ) / M(68, 68)
C     Upper part.
      temp = M(68, 65) * M(65, 76)
      M(68, 76) = ( M(68, 76) - temp ) / M(68, 68)
C     Upper part.
      temp = M(68, 65) * M(65, 77)
      M(68, 77) = ( M(68, 77) - temp ) / M(68, 68)
C     Upper part.
      temp = M(68, 65) * M(65, 78)
      M(68, 78) = ( M(68, 78) - temp ) / M(68, 68)
C     Upper part.
      temp = M(68, 65) * M(65, 79)
      M(68, 79) = ( M(68, 79) - temp ) / M(68, 68)
C     Upper part.
      temp = M(68, 65) * M(65, 80)
      M(68, 80) = ( M(68, 80) - temp ) / M(68, 68)
C     Upper part.
      temp = M(68, 65) * M(65, 81)
      M(68, 81) = ( M(68, 81) - temp ) / M(68, 68)
C     Upper part.
      M(68, 82) = M(68, 82) / M(68, 68)

C     Lower part.
      temp = M(69, 64) * M(64, 69)
      temp = temp + M(69, 65) * M(65, 69)
      temp = temp + M(69, 68) * M(68, 69)
      M(69, 69) = M(69, 69) - temp
C     Lower part.
      temp = M(70, 68) * M(68, 69)
      M(70, 69) = M(70, 69) - temp
C     Lower part.
      temp = M(71, 64) * M(64, 69)
      temp = temp + M(71, 65) * M(65, 69)
      temp = temp + M(71, 68) * M(68, 69)
      M(71, 69) = M(71, 69) - temp
C     Lower part.
      temp = M(72, 64) * M(64, 69)
      temp = temp + M(72, 65) * M(65, 69)
      temp = temp + M(72, 68) * M(68, 69)
      M(72, 69) = M(72, 69) - temp
C     Lower part.
      temp = M(73, 64) * M(64, 69)
      temp = temp + M(73, 68) * M(68, 69)
      M(73, 69) = M(73, 69) - temp
C     Lower part.
      temp = M(74, 64) * M(64, 69)
      temp = temp + M(74, 68) * M(68, 69)
      M(74, 69) = M(74, 69) - temp
C     Lower part.
      temp = M(75, 64) * M(64, 69)
      temp = temp + M(75, 65) * M(65, 69)
      temp = temp + M(75, 66) * M(66, 69)
      temp = temp + M(75, 67) * M(67, 69)
      temp = temp + M(75, 68) * M(68, 69)
      M(75, 69) = M(75, 69) - temp
C     Lower part.
      temp = M(76, 64) * M(64, 69)
      temp = temp + M(76, 66) * M(66, 69)
      temp = temp + M(76, 68) * M(68, 69)
      M(76, 69) = M(76, 69) - temp
C     Lower part.
      temp = M(77, 64) * M(64, 69)
      temp = temp + M(77, 66) * M(66, 69)
      temp = temp + M(77, 67) * M(67, 69)
      temp = temp + M(77, 68) * M(68, 69)
      M(77, 69) = M(77, 69) - temp
C     Lower part.
      temp = M(78, 64) * M(64, 69)
      temp = temp + M(78, 68) * M(68, 69)
      M(78, 69) = M(78, 69) - temp
C     Lower part.
      temp = M(80, 64) * M(64, 69)
      temp = temp + M(80, 67) * M(67, 69)
      temp = temp + M(80, 68) * M(68, 69)
      M(80, 69) = M(80, 69) - temp
C     Lower part.
      temp = M(81, 64) * M(64, 69)
      temp = temp + M(81, 65) * M(65, 69)
      temp = temp + M(81, 66) * M(66, 69)
      temp = temp + M(81, 68) * M(68, 69)
      M(81, 69) = M(81, 69) - temp
C     Lower part.
      temp = M(82, 68) * M(68, 69)
      M(82, 69) = M(82, 69) - temp
C     Upper part.
      temp = M(69, 65) * M(65, 70)
      temp = temp + M(69, 68) * M(68, 70)
      M(69, 70) = ( M(69, 70) - temp ) / M(69, 69)
C     Upper part.
      temp = M(69, 65) * M(65, 72)
      temp = temp + M(69, 68) * M(68, 72)
      M(69, 72) = ( M(69, 72) - temp ) / M(69, 69)
C     Upper part.
      temp = M(69, 46) * M(46, 73)
      temp = temp + M(69, 48) * M(48, 73)
      temp = temp + M(69, 49) * M(49, 73)
      temp = temp + M(69, 52) * M(52, 73)
      temp = temp + M(69, 53) * M(53, 73)
      temp = temp + M(69, 54) * M(54, 73)
      temp = temp + M(69, 55) * M(55, 73)
      temp = temp + M(69, 56) * M(56, 73)
      temp = temp + M(69, 57) * M(57, 73)
      temp = temp + M(69, 58) * M(58, 73)
      temp = temp + M(69, 59) * M(59, 73)
      temp = temp + M(69, 62) * M(62, 73)
      temp = temp + M(69, 64) * M(64, 73)
      temp = temp + M(69, 65) * M(65, 73)
      temp = temp + M(69, 68) * M(68, 73)
      M(69, 73) = ( M(69, 73) - temp ) / M(69, 69)
C     Upper part.
      temp = M(69, 3) * M(3, 75)
      temp = temp + M(69, 12) * M(12, 75)
      temp = temp + M(69, 26) * M(26, 75)
      temp = temp + M(69, 46) * M(46, 75)
      temp = temp + M(69, 48) * M(48, 75)
      temp = temp + M(69, 49) * M(49, 75)
      temp = temp + M(69, 52) * M(52, 75)
      temp = temp + M(69, 53) * M(53, 75)
      temp = temp + M(69, 54) * M(54, 75)
      temp = temp + M(69, 55) * M(55, 75)
      temp = temp + M(69, 56) * M(56, 75)
      temp = temp + M(69, 57) * M(57, 75)
      temp = temp + M(69, 58) * M(58, 75)
      temp = temp + M(69, 59) * M(59, 75)
      temp = temp + M(69, 62) * M(62, 75)
      temp = temp + M(69, 64) * M(64, 75)
      temp = temp + M(69, 65) * M(65, 75)
      temp = temp + M(69, 68) * M(68, 75)
      M(69, 75) = ( M(69, 75) - temp ) / M(69, 69)
C     Upper part.
      temp = M(69, 46) * M(46, 76)
      temp = temp + M(69, 48) * M(48, 76)
      temp = temp + M(69, 49) * M(49, 76)
      temp = temp + M(69, 52) * M(52, 76)
      temp = temp + M(69, 53) * M(53, 76)
      temp = temp + M(69, 54) * M(54, 76)
      temp = temp + M(69, 55) * M(55, 76)
      temp = temp + M(69, 56) * M(56, 76)
      temp = temp + M(69, 57) * M(57, 76)
      temp = temp + M(69, 58) * M(58, 76)
      temp = temp + M(69, 59) * M(59, 76)
      temp = temp + M(69, 62) * M(62, 76)
      temp = temp + M(69, 64) * M(64, 76)
      temp = temp + M(69, 65) * M(65, 76)
      temp = temp + M(69, 68) * M(68, 76)
      M(69, 76) = ( M(69, 76) - temp ) / M(69, 69)
C     Upper part.
      temp = M(69, 26) * M(26, 77)
      temp = temp + M(69, 46) * M(46, 77)
      temp = temp + M(69, 48) * M(48, 77)
      temp = temp + M(69, 49) * M(49, 77)
      temp = temp + M(69, 52) * M(52, 77)
      temp = temp + M(69, 53) * M(53, 77)
      temp = temp + M(69, 54) * M(54, 77)
      temp = temp + M(69, 55) * M(55, 77)
      temp = temp + M(69, 56) * M(56, 77)
      temp = temp + M(69, 57) * M(57, 77)
      temp = temp + M(69, 58) * M(58, 77)
      temp = temp + M(69, 59) * M(59, 77)
      temp = temp + M(69, 62) * M(62, 77)
      temp = temp + M(69, 64) * M(64, 77)
      temp = temp + M(69, 65) * M(65, 77)
      temp = temp + M(69, 68) * M(68, 77)
      M(69, 77) = ( M(69, 77) - temp ) / M(69, 69)
C     Upper part.
      temp = M(69, 46) * M(46, 78)
      temp = temp + M(69, 48) * M(48, 78)
      temp = temp + M(69, 49) * M(49, 78)
      temp = temp + M(69, 52) * M(52, 78)
      temp = temp + M(69, 53) * M(53, 78)
      temp = temp + M(69, 54) * M(54, 78)
      temp = temp + M(69, 55) * M(55, 78)
      temp = temp + M(69, 56) * M(56, 78)
      temp = temp + M(69, 57) * M(57, 78)
      temp = temp + M(69, 58) * M(58, 78)
      temp = temp + M(69, 59) * M(59, 78)
      temp = temp + M(69, 62) * M(62, 78)
      temp = temp + M(69, 64) * M(64, 78)
      temp = temp + M(69, 65) * M(65, 78)
      temp = temp + M(69, 68) * M(68, 78)
      M(69, 78) = ( M(69, 78) - temp ) / M(69, 69)
C     Upper part.
      temp = M(69, 59) * M(59, 79)
      temp = temp + M(69, 62) * M(62, 79)
      temp = temp + M(69, 64) * M(64, 79)
      temp = temp + M(69, 65) * M(65, 79)
      temp = temp + M(69, 68) * M(68, 79)
      M(69, 79) = ( M(69, 79) - temp ) / M(69, 69)
C     Upper part.
      temp = M(69, 46) * M(46, 80)
      temp = temp + M(69, 52) * M(52, 80)
      temp = temp + M(69, 53) * M(53, 80)
      temp = temp + M(69, 54) * M(54, 80)
      temp = temp + M(69, 56) * M(56, 80)
      temp = temp + M(69, 57) * M(57, 80)
      temp = temp + M(69, 58) * M(58, 80)
      temp = temp + M(69, 59) * M(59, 80)
      temp = temp + M(69, 62) * M(62, 80)
      temp = temp + M(69, 64) * M(64, 80)
      temp = temp + M(69, 65) * M(65, 80)
      temp = temp + M(69, 68) * M(68, 80)
      M(69, 80) = ( M(69, 80) - temp ) / M(69, 69)
C     Upper part.
      temp = M(69, 46) * M(46, 81)
      temp = temp + M(69, 48) * M(48, 81)
      temp = temp + M(69, 49) * M(49, 81)
      temp = temp + M(69, 52) * M(52, 81)
      temp = temp + M(69, 53) * M(53, 81)
      temp = temp + M(69, 54) * M(54, 81)
      temp = temp + M(69, 55) * M(55, 81)
      temp = temp + M(69, 56) * M(56, 81)
      temp = temp + M(69, 57) * M(57, 81)
      temp = temp + M(69, 58) * M(58, 81)
      temp = temp + M(69, 59) * M(59, 81)
      temp = temp + M(69, 62) * M(62, 81)
      temp = temp + M(69, 64) * M(64, 81)
      temp = temp + M(69, 65) * M(65, 81)
      temp = temp + M(69, 68) * M(68, 81)
      M(69, 81) = ( M(69, 81) - temp ) / M(69, 69)
C     Upper part.
      temp = M(69, 68) * M(68, 82)
      M(69, 82) = ( M(69, 82) - temp ) / M(69, 69)

C     Lower part.
      temp = M(70, 68) * M(68, 70)
      temp = temp + M(70, 69) * M(69, 70)
      M(70, 70) = M(70, 70) - temp
C     Lower part.
      temp = M(71, 65) * M(65, 70)
      temp = temp + M(71, 68) * M(68, 70)
      temp = temp + M(71, 69) * M(69, 70)
      M(71, 70) = M(71, 70) - temp
C     Lower part.
      temp = M(72, 65) * M(65, 70)
      temp = temp + M(72, 68) * M(68, 70)
      temp = temp + M(72, 69) * M(69, 70)
      M(72, 70) = M(72, 70) - temp
C     Lower part.
      temp = M(73, 68) * M(68, 70)
      temp = temp + M(73, 69) * M(69, 70)
      M(73, 70) = M(73, 70) - temp
C     Lower part.
      temp = M(74, 68) * M(68, 70)
      temp = temp + M(74, 69) * M(69, 70)
      M(74, 70) = M(74, 70) - temp
C     Lower part.
      temp = M(75, 65) * M(65, 70)
      temp = temp + M(75, 68) * M(68, 70)
      temp = temp + M(75, 69) * M(69, 70)
      M(75, 70) = M(75, 70) - temp
C     Lower part.
      temp = M(76, 68) * M(68, 70)
      temp = temp + M(76, 69) * M(69, 70)
      M(76, 70) = M(76, 70) - temp
C     Lower part.
      temp = M(77, 68) * M(68, 70)
      temp = temp + M(77, 69) * M(69, 70)
      M(77, 70) = M(77, 70) - temp
C     Lower part.
      temp = M(78, 68) * M(68, 70)
      temp = temp + M(78, 69) * M(69, 70)
      M(78, 70) = M(78, 70) - temp
C     Lower part.
      temp = M(80, 68) * M(68, 70)
      temp = temp + M(80, 69) * M(69, 70)
      M(80, 70) = M(80, 70) - temp
C     Lower part.
      temp = M(81, 65) * M(65, 70)
      temp = temp + M(81, 68) * M(68, 70)
      temp = temp + M(81, 69) * M(69, 70)
      M(81, 70) = M(81, 70) - temp
C     Lower part.
      temp = M(82, 68) * M(68, 70)
      temp = temp + M(82, 69) * M(69, 70)
      M(82, 70) = M(82, 70) - temp
C     Upper part.
      temp = M(70, 68) * M(68, 72)
      temp = temp + M(70, 69) * M(69, 72)
      M(70, 72) = ( M(70, 72) - temp ) / M(70, 70)
C     Upper part.
      temp = M(70, 48) * M(48, 73)
      temp = temp + M(70, 49) * M(49, 73)
      temp = temp + M(70, 53) * M(53, 73)
      temp = temp + M(70, 56) * M(56, 73)
      temp = temp + M(70, 59) * M(59, 73)
      temp = temp + M(70, 68) * M(68, 73)
      temp = temp + M(70, 69) * M(69, 73)
      M(70, 73) = ( M(70, 73) - temp ) / M(70, 70)
C     Upper part.
      temp = M(70, 14) * M(14, 75)
      temp = temp + M(70, 26) * M(26, 75)
      temp = temp + M(70, 30) * M(30, 75)
      temp = temp + M(70, 48) * M(48, 75)
      temp = temp + M(70, 49) * M(49, 75)
      temp = temp + M(70, 53) * M(53, 75)
      temp = temp + M(70, 56) * M(56, 75)
      temp = temp + M(70, 59) * M(59, 75)
      temp = temp + M(70, 68) * M(68, 75)
      temp = temp + M(70, 69) * M(69, 75)
      M(70, 75) = ( M(70, 75) - temp ) / M(70, 70)
C     Upper part.
      temp = M(70, 48) * M(48, 76)
      temp = temp + M(70, 49) * M(49, 76)
      temp = temp + M(70, 53) * M(53, 76)
      temp = temp + M(70, 56) * M(56, 76)
      temp = temp + M(70, 59) * M(59, 76)
      temp = temp + M(70, 68) * M(68, 76)
      temp = temp + M(70, 69) * M(69, 76)
      M(70, 76) = ( M(70, 76) - temp ) / M(70, 70)
C     Upper part.
      temp = M(70, 14) * M(14, 77)
      temp = temp + M(70, 26) * M(26, 77)
      temp = temp + M(70, 48) * M(48, 77)
      temp = temp + M(70, 49) * M(49, 77)
      temp = temp + M(70, 53) * M(53, 77)
      temp = temp + M(70, 56) * M(56, 77)
      temp = temp + M(70, 59) * M(59, 77)
      temp = temp + M(70, 68) * M(68, 77)
      temp = temp + M(70, 69) * M(69, 77)
      M(70, 77) = ( M(70, 77) - temp ) / M(70, 70)
C     Upper part.
      temp = M(70, 48) * M(48, 78)
      temp = temp + M(70, 49) * M(49, 78)
      temp = temp + M(70, 53) * M(53, 78)
      temp = temp + M(70, 56) * M(56, 78)
      temp = temp + M(70, 59) * M(59, 78)
      temp = temp + M(70, 68) * M(68, 78)
      temp = temp + M(70, 69) * M(69, 78)
      M(70, 78) = ( M(70, 78) - temp ) / M(70, 70)
C     Upper part.
      temp = M(70, 59) * M(59, 79)
      temp = temp + M(70, 68) * M(68, 79)
      temp = temp + M(70, 69) * M(69, 79)
      M(70, 79) = ( M(70, 79) - temp ) / M(70, 70)
C     Upper part.
      temp = M(70, 53) * M(53, 80)
      temp = temp + M(70, 56) * M(56, 80)
      temp = temp + M(70, 59) * M(59, 80)
      temp = temp + M(70, 68) * M(68, 80)
      temp = temp + M(70, 69) * M(69, 80)
      M(70, 80) = ( M(70, 80) - temp ) / M(70, 70)
C     Upper part.
      temp = M(70, 48) * M(48, 81)
      temp = temp + M(70, 49) * M(49, 81)
      temp = temp + M(70, 53) * M(53, 81)
      temp = temp + M(70, 56) * M(56, 81)
      temp = temp + M(70, 59) * M(59, 81)
      temp = temp + M(70, 68) * M(68, 81)
      temp = temp + M(70, 69) * M(69, 81)
      M(70, 81) = ( M(70, 81) - temp ) / M(70, 70)
C     Upper part.
      temp = M(70, 68) * M(68, 82)
      temp = temp + M(70, 69) * M(69, 82)
      M(70, 82) = ( M(70, 82) - temp ) / M(70, 70)

C     Lower part.
      temp = M(75, 60) * M(60, 71)
      temp = temp + M(75, 67) * M(67, 71)
      M(75, 71) = M(75, 71) - temp
C     Lower part.
      temp = M(77, 67) * M(67, 71)
      M(77, 71) = M(77, 71) - temp
C     Lower part.
      temp = M(80, 67) * M(67, 71)
      M(80, 71) = M(80, 71) - temp
C     Lower part.
      temp = M(81, 60) * M(60, 71)
      M(81, 71) = M(81, 71) - temp
C     Upper part.
      temp = M(71, 65) * M(65, 72)
      temp = temp + M(71, 68) * M(68, 72)
      temp = temp + M(71, 69) * M(69, 72)
      temp = temp + M(71, 70) * M(70, 72)
      M(71, 72) = ( M(71, 72) - temp ) / M(71, 71)
C     Upper part.
      temp = M(71, 46) * M(46, 73)
      temp = temp + M(71, 48) * M(48, 73)
      temp = temp + M(71, 49) * M(49, 73)
      temp = temp + M(71, 50) * M(50, 73)
      temp = temp + M(71, 52) * M(52, 73)
      temp = temp + M(71, 53) * M(53, 73)
      temp = temp + M(71, 54) * M(54, 73)
      temp = temp + M(71, 55) * M(55, 73)
      temp = temp + M(71, 56) * M(56, 73)
      temp = temp + M(71, 57) * M(57, 73)
      temp = temp + M(71, 58) * M(58, 73)
      temp = temp + M(71, 59) * M(59, 73)
      temp = temp + M(71, 62) * M(62, 73)
      temp = temp + M(71, 64) * M(64, 73)
      temp = temp + M(71, 65) * M(65, 73)
      temp = temp + M(71, 68) * M(68, 73)
      temp = temp + M(71, 69) * M(69, 73)
      temp = temp + M(71, 70) * M(70, 73)
      M(71, 73) = ( M(71, 73) - temp ) / M(71, 71)
C     Upper part.
      temp = M(71, 4) * M(4, 75)
      temp = temp + M(71, 11) * M(11, 75)
      temp = temp + M(71, 12) * M(12, 75)
      temp = temp + M(71, 26) * M(26, 75)
      temp = temp + M(71, 34) * M(34, 75)
      temp = temp + M(71, 46) * M(46, 75)
      temp = temp + M(71, 48) * M(48, 75)
      temp = temp + M(71, 49) * M(49, 75)
      temp = temp + M(71, 50) * M(50, 75)
      temp = temp + M(71, 52) * M(52, 75)
      temp = temp + M(71, 53) * M(53, 75)
      temp = temp + M(71, 54) * M(54, 75)
      temp = temp + M(71, 55) * M(55, 75)
      temp = temp + M(71, 56) * M(56, 75)
      temp = temp + M(71, 57) * M(57, 75)
      temp = temp + M(71, 58) * M(58, 75)
      temp = temp + M(71, 59) * M(59, 75)
      temp = temp + M(71, 62) * M(62, 75)
      temp = temp + M(71, 64) * M(64, 75)
      temp = temp + M(71, 65) * M(65, 75)
      temp = temp + M(71, 68) * M(68, 75)
      temp = temp + M(71, 69) * M(69, 75)
      temp = temp + M(71, 70) * M(70, 75)
      M(71, 75) = ( M(71, 75) - temp ) / M(71, 71)
C     Upper part.
      temp = M(71, 46) * M(46, 76)
      temp = temp + M(71, 48) * M(48, 76)
      temp = temp + M(71, 49) * M(49, 76)
      temp = temp + M(71, 50) * M(50, 76)
      temp = temp + M(71, 52) * M(52, 76)
      temp = temp + M(71, 53) * M(53, 76)
      temp = temp + M(71, 54) * M(54, 76)
      temp = temp + M(71, 55) * M(55, 76)
      temp = temp + M(71, 56) * M(56, 76)
      temp = temp + M(71, 57) * M(57, 76)
      temp = temp + M(71, 58) * M(58, 76)
      temp = temp + M(71, 59) * M(59, 76)
      temp = temp + M(71, 62) * M(62, 76)
      temp = temp + M(71, 64) * M(64, 76)
      temp = temp + M(71, 65) * M(65, 76)
      temp = temp + M(71, 68) * M(68, 76)
      temp = temp + M(71, 69) * M(69, 76)
      temp = temp + M(71, 70) * M(70, 76)
      M(71, 76) = ( M(71, 76) - temp ) / M(71, 71)
C     Upper part.
      temp = M(71, 26) * M(26, 77)
      temp = temp + M(71, 34) * M(34, 77)
      temp = temp + M(71, 46) * M(46, 77)
      temp = temp + M(71, 48) * M(48, 77)
      temp = temp + M(71, 49) * M(49, 77)
      temp = temp + M(71, 50) * M(50, 77)
      temp = temp + M(71, 52) * M(52, 77)
      temp = temp + M(71, 53) * M(53, 77)
      temp = temp + M(71, 54) * M(54, 77)
      temp = temp + M(71, 55) * M(55, 77)
      temp = temp + M(71, 56) * M(56, 77)
      temp = temp + M(71, 57) * M(57, 77)
      temp = temp + M(71, 58) * M(58, 77)
      temp = temp + M(71, 59) * M(59, 77)
      temp = temp + M(71, 62) * M(62, 77)
      temp = temp + M(71, 64) * M(64, 77)
      temp = temp + M(71, 65) * M(65, 77)
      temp = temp + M(71, 68) * M(68, 77)
      temp = temp + M(71, 69) * M(69, 77)
      temp = temp + M(71, 70) * M(70, 77)
      M(71, 77) = ( M(71, 77) - temp ) / M(71, 71)
C     Upper part.
      temp = M(71, 34) * M(34, 78)
      temp = temp + M(71, 46) * M(46, 78)
      temp = temp + M(71, 48) * M(48, 78)
      temp = temp + M(71, 49) * M(49, 78)
      temp = temp + M(71, 50) * M(50, 78)
      temp = temp + M(71, 52) * M(52, 78)
      temp = temp + M(71, 53) * M(53, 78)
      temp = temp + M(71, 54) * M(54, 78)
      temp = temp + M(71, 55) * M(55, 78)
      temp = temp + M(71, 56) * M(56, 78)
      temp = temp + M(71, 57) * M(57, 78)
      temp = temp + M(71, 58) * M(58, 78)
      temp = temp + M(71, 59) * M(59, 78)
      temp = temp + M(71, 62) * M(62, 78)
      temp = temp + M(71, 64) * M(64, 78)
      temp = temp + M(71, 65) * M(65, 78)
      temp = temp + M(71, 68) * M(68, 78)
      temp = temp + M(71, 69) * M(69, 78)
      temp = temp + M(71, 70) * M(70, 78)
      M(71, 78) = ( M(71, 78) - temp ) / M(71, 71)
C     Upper part.
      temp = M(71, 59) * M(59, 79)
      temp = temp + M(71, 62) * M(62, 79)
      temp = temp + M(71, 64) * M(64, 79)
      temp = temp + M(71, 65) * M(65, 79)
      temp = temp + M(71, 68) * M(68, 79)
      temp = temp + M(71, 69) * M(69, 79)
      temp = temp + M(71, 70) * M(70, 79)
      M(71, 79) = ( M(71, 79) - temp ) / M(71, 71)
C     Upper part.
      temp = M(71, 34) * M(34, 80)
      temp = temp + M(71, 46) * M(46, 80)
      temp = temp + M(71, 52) * M(52, 80)
      temp = temp + M(71, 53) * M(53, 80)
      temp = temp + M(71, 54) * M(54, 80)
      temp = temp + M(71, 56) * M(56, 80)
      temp = temp + M(71, 57) * M(57, 80)
      temp = temp + M(71, 58) * M(58, 80)
      temp = temp + M(71, 59) * M(59, 80)
      temp = temp + M(71, 62) * M(62, 80)
      temp = temp + M(71, 64) * M(64, 80)
      temp = temp + M(71, 65) * M(65, 80)
      temp = temp + M(71, 68) * M(68, 80)
      temp = temp + M(71, 69) * M(69, 80)
      temp = temp + M(71, 70) * M(70, 80)
      M(71, 80) = ( M(71, 80) - temp ) / M(71, 71)
C     Upper part.
      temp = M(71, 46) * M(46, 81)
      temp = temp + M(71, 48) * M(48, 81)
      temp = temp + M(71, 49) * M(49, 81)
      temp = temp + M(71, 50) * M(50, 81)
      temp = temp + M(71, 52) * M(52, 81)
      temp = temp + M(71, 53) * M(53, 81)
      temp = temp + M(71, 54) * M(54, 81)
      temp = temp + M(71, 55) * M(55, 81)
      temp = temp + M(71, 56) * M(56, 81)
      temp = temp + M(71, 57) * M(57, 81)
      temp = temp + M(71, 58) * M(58, 81)
      temp = temp + M(71, 59) * M(59, 81)
      temp = temp + M(71, 62) * M(62, 81)
      temp = temp + M(71, 64) * M(64, 81)
      temp = temp + M(71, 65) * M(65, 81)
      temp = temp + M(71, 68) * M(68, 81)
      temp = temp + M(71, 69) * M(69, 81)
      temp = temp + M(71, 70) * M(70, 81)
      M(71, 81) = ( M(71, 81) - temp ) / M(71, 71)
C     Upper part.
      temp = M(71, 68) * M(68, 82)
      temp = temp + M(71, 69) * M(69, 82)
      temp = temp + M(71, 70) * M(70, 82)
      M(71, 82) = ( M(71, 82) - temp ) / M(71, 71)

C     Lower part.
      temp = M(72, 65) * M(65, 72)
      temp = temp + M(72, 68) * M(68, 72)
      temp = temp + M(72, 69) * M(69, 72)
      temp = temp + M(72, 70) * M(70, 72)
      M(72, 72) = M(72, 72) - temp
C     Lower part.
      temp = M(73, 68) * M(68, 72)
      temp = temp + M(73, 69) * M(69, 72)
      temp = temp + M(73, 70) * M(70, 72)
      temp = temp + M(73, 71) * M(71, 72)
      M(73, 72) = M(73, 72) - temp
C     Lower part.
      temp = M(74, 68) * M(68, 72)
      temp = temp + M(74, 69) * M(69, 72)
      temp = temp + M(74, 70) * M(70, 72)
      M(74, 72) = M(74, 72) - temp
C     Lower part.
      temp = M(75, 65) * M(65, 72)
      temp = temp + M(75, 68) * M(68, 72)
      temp = temp + M(75, 69) * M(69, 72)
      temp = temp + M(75, 70) * M(70, 72)
      temp = temp + M(75, 71) * M(71, 72)
      M(75, 72) = M(75, 72) - temp
C     Lower part.
      temp = M(76, 68) * M(68, 72)
      temp = temp + M(76, 69) * M(69, 72)
      temp = temp + M(76, 70) * M(70, 72)
      temp = temp + M(76, 71) * M(71, 72)
      M(76, 72) = M(76, 72) - temp
C     Lower part.
      temp = M(77, 68) * M(68, 72)
      temp = temp + M(77, 69) * M(69, 72)
      temp = temp + M(77, 70) * M(70, 72)
      temp = temp + M(77, 71) * M(71, 72)
      M(77, 72) = M(77, 72) - temp
C     Lower part.
      temp = M(78, 68) * M(68, 72)
      temp = temp + M(78, 69) * M(69, 72)
      temp = temp + M(78, 70) * M(70, 72)
      M(78, 72) = M(78, 72) - temp
C     Lower part.
      temp = M(80, 68) * M(68, 72)
      temp = temp + M(80, 69) * M(69, 72)
      temp = temp + M(80, 70) * M(70, 72)
      temp = temp + M(80, 71) * M(71, 72)
      M(80, 72) = M(80, 72) - temp
C     Lower part.
      temp = M(81, 65) * M(65, 72)
      temp = temp + M(81, 68) * M(68, 72)
      temp = temp + M(81, 69) * M(69, 72)
      temp = temp + M(81, 70) * M(70, 72)
      temp = temp + M(81, 71) * M(71, 72)
      M(81, 72) = M(81, 72) - temp
C     Lower part.
      temp = M(82, 68) * M(68, 72)
      temp = temp + M(82, 69) * M(69, 72)
      temp = temp + M(82, 70) * M(70, 72)
      M(82, 72) = M(82, 72) - temp
C     Upper part.
      temp = M(72, 46) * M(46, 73)
      temp = temp + M(72, 48) * M(48, 73)
      temp = temp + M(72, 49) * M(49, 73)
      temp = temp + M(72, 52) * M(52, 73)
      temp = temp + M(72, 59) * M(59, 73)
      temp = temp + M(72, 64) * M(64, 73)
      temp = temp + M(72, 65) * M(65, 73)
      temp = temp + M(72, 68) * M(68, 73)
      temp = temp + M(72, 69) * M(69, 73)
      temp = temp + M(72, 70) * M(70, 73)
      M(72, 73) = ( M(72, 73) - temp ) / M(72, 72)
C     Upper part.
      temp = M(72, 5) * M(5, 75)
      temp = temp + M(72, 6) * M(6, 75)
      temp = temp + M(72, 21) * M(21, 75)
      temp = temp + M(72, 28) * M(28, 75)
      temp = temp + M(72, 34) * M(34, 75)
      temp = temp + M(72, 35) * M(35, 75)
      temp = temp + M(72, 37) * M(37, 75)
      temp = temp + M(72, 42) * M(42, 75)
      temp = temp + M(72, 44) * M(44, 75)
      temp = temp + M(72, 46) * M(46, 75)
      temp = temp + M(72, 48) * M(48, 75)
      temp = temp + M(72, 49) * M(49, 75)
      temp = temp + M(72, 52) * M(52, 75)
      temp = temp + M(72, 59) * M(59, 75)
      temp = temp + M(72, 64) * M(64, 75)
      temp = temp + M(72, 65) * M(65, 75)
      temp = temp + M(72, 68) * M(68, 75)
      temp = temp + M(72, 69) * M(69, 75)
      temp = temp + M(72, 70) * M(70, 75)
      M(72, 75) = ( M(72, 75) - temp ) / M(72, 72)
C     Upper part.
      temp = M(72, 35) * M(35, 76)
      temp = temp + M(72, 44) * M(44, 76)
      temp = temp + M(72, 46) * M(46, 76)
      temp = temp + M(72, 48) * M(48, 76)
      temp = temp + M(72, 49) * M(49, 76)
      temp = temp + M(72, 52) * M(52, 76)
      temp = temp + M(72, 59) * M(59, 76)
      temp = temp + M(72, 64) * M(64, 76)
      temp = temp + M(72, 65) * M(65, 76)
      temp = temp + M(72, 68) * M(68, 76)
      temp = temp + M(72, 69) * M(69, 76)
      temp = temp + M(72, 70) * M(70, 76)
      M(72, 76) = ( M(72, 76) - temp ) / M(72, 72)
C     Upper part.
      temp = M(72, 21) * M(21, 77)
      temp = temp + M(72, 28) * M(28, 77)
      temp = temp + M(72, 34) * M(34, 77)
      temp = temp + M(72, 37) * M(37, 77)
      temp = temp + M(72, 42) * M(42, 77)
      temp = temp + M(72, 44) * M(44, 77)
      temp = temp + M(72, 46) * M(46, 77)
      temp = temp + M(72, 48) * M(48, 77)
      temp = temp + M(72, 49) * M(49, 77)
      temp = temp + M(72, 52) * M(52, 77)
      temp = temp + M(72, 59) * M(59, 77)
      temp = temp + M(72, 64) * M(64, 77)
      temp = temp + M(72, 65) * M(65, 77)
      temp = temp + M(72, 68) * M(68, 77)
      temp = temp + M(72, 69) * M(69, 77)
      temp = temp + M(72, 70) * M(70, 77)
      M(72, 77) = ( M(72, 77) - temp ) / M(72, 72)
C     Upper part.
      temp = M(72, 34) * M(34, 78)
      temp = temp + M(72, 46) * M(46, 78)
      temp = temp + M(72, 48) * M(48, 78)
      temp = temp + M(72, 49) * M(49, 78)
      temp = temp + M(72, 52) * M(52, 78)
      temp = temp + M(72, 59) * M(59, 78)
      temp = temp + M(72, 64) * M(64, 78)
      temp = temp + M(72, 65) * M(65, 78)
      temp = temp + M(72, 68) * M(68, 78)
      temp = temp + M(72, 69) * M(69, 78)
      temp = temp + M(72, 70) * M(70, 78)
      M(72, 78) = ( M(72, 78) - temp ) / M(72, 72)
C     Upper part.
      temp = M(72, 42) * M(42, 79)
      temp = temp + M(72, 44) * M(44, 79)
      temp = temp + M(72, 59) * M(59, 79)
      temp = temp + M(72, 64) * M(64, 79)
      temp = temp + M(72, 65) * M(65, 79)
      temp = temp + M(72, 68) * M(68, 79)
      temp = temp + M(72, 69) * M(69, 79)
      temp = temp + M(72, 70) * M(70, 79)
      M(72, 79) = ( M(72, 79) - temp ) / M(72, 72)
C     Upper part.
      temp = M(72, 34) * M(34, 80)
      temp = temp + M(72, 37) * M(37, 80)
      temp = temp + M(72, 42) * M(42, 80)
      temp = temp + M(72, 44) * M(44, 80)
      temp = temp + M(72, 46) * M(46, 80)
      temp = temp + M(72, 52) * M(52, 80)
      temp = temp + M(72, 59) * M(59, 80)
      temp = temp + M(72, 64) * M(64, 80)
      temp = temp + M(72, 65) * M(65, 80)
      temp = temp + M(72, 68) * M(68, 80)
      temp = temp + M(72, 69) * M(69, 80)
      temp = temp + M(72, 70) * M(70, 80)
      M(72, 80) = ( M(72, 80) - temp ) / M(72, 72)
C     Upper part.
      temp = M(72, 35) * M(35, 81)
      temp = temp + M(72, 37) * M(37, 81)
      temp = temp + M(72, 46) * M(46, 81)
      temp = temp + M(72, 48) * M(48, 81)
      temp = temp + M(72, 49) * M(49, 81)
      temp = temp + M(72, 52) * M(52, 81)
      temp = temp + M(72, 59) * M(59, 81)
      temp = temp + M(72, 64) * M(64, 81)
      temp = temp + M(72, 65) * M(65, 81)
      temp = temp + M(72, 68) * M(68, 81)
      temp = temp + M(72, 69) * M(69, 81)
      temp = temp + M(72, 70) * M(70, 81)
      M(72, 81) = ( M(72, 81) - temp ) / M(72, 72)
C     Upper part.
      temp = M(72, 68) * M(68, 82)
      temp = temp + M(72, 69) * M(69, 82)
      temp = temp + M(72, 70) * M(70, 82)
      M(72, 82) = ( M(72, 82) - temp ) / M(72, 72)

C     Lower part.
      temp = M(73, 25) * M(25, 73)
      temp = temp + M(73, 33) * M(33, 73)
      temp = temp + M(73, 39) * M(39, 73)
      temp = temp + M(73, 40) * M(40, 73)
      temp = temp + M(73, 46) * M(46, 73)
      temp = temp + M(73, 47) * M(47, 73)
      temp = temp + M(73, 48) * M(48, 73)
      temp = temp + M(73, 49) * M(49, 73)
      temp = temp + M(73, 50) * M(50, 73)
      temp = temp + M(73, 51) * M(51, 73)
      temp = temp + M(73, 52) * M(52, 73)
      temp = temp + M(73, 53) * M(53, 73)
      temp = temp + M(73, 54) * M(54, 73)
      temp = temp + M(73, 55) * M(55, 73)
      temp = temp + M(73, 56) * M(56, 73)
      temp = temp + M(73, 57) * M(57, 73)
      temp = temp + M(73, 58) * M(58, 73)
      temp = temp + M(73, 59) * M(59, 73)
      temp = temp + M(73, 62) * M(62, 73)
      temp = temp + M(73, 64) * M(64, 73)
      temp = temp + M(73, 68) * M(68, 73)
      temp = temp + M(73, 69) * M(69, 73)
      temp = temp + M(73, 70) * M(70, 73)
      temp = temp + M(73, 71) * M(71, 73)
      temp = temp + M(73, 72) * M(72, 73)
      M(73, 73) = M(73, 73) - temp
C     Lower part.
      temp = M(74, 25) * M(25, 73)
      temp = temp + M(74, 33) * M(33, 73)
      temp = temp + M(74, 39) * M(39, 73)
      temp = temp + M(74, 40) * M(40, 73)
      temp = temp + M(74, 41) * M(41, 73)
      temp = temp + M(74, 46) * M(46, 73)
      temp = temp + M(74, 47) * M(47, 73)
      temp = temp + M(74, 48) * M(48, 73)
      temp = temp + M(74, 49) * M(49, 73)
      temp = temp + M(74, 50) * M(50, 73)
      temp = temp + M(74, 51) * M(51, 73)
      temp = temp + M(74, 52) * M(52, 73)
      temp = temp + M(74, 53) * M(53, 73)
      temp = temp + M(74, 54) * M(54, 73)
      temp = temp + M(74, 55) * M(55, 73)
      temp = temp + M(74, 56) * M(56, 73)
      temp = temp + M(74, 57) * M(57, 73)
      temp = temp + M(74, 58) * M(58, 73)
      temp = temp + M(74, 59) * M(59, 73)
      temp = temp + M(74, 61) * M(61, 73)
      temp = temp + M(74, 62) * M(62, 73)
      temp = temp + M(74, 64) * M(64, 73)
      temp = temp + M(74, 68) * M(68, 73)
      temp = temp + M(74, 69) * M(69, 73)
      temp = temp + M(74, 70) * M(70, 73)
      temp = temp + M(74, 72) * M(72, 73)
      M(74, 73) = M(74, 73) - temp
C     Lower part.
      temp = M(75, 25) * M(25, 73)
      temp = temp + M(75, 41) * M(41, 73)
      temp = temp + M(75, 46) * M(46, 73)
      temp = temp + M(75, 52) * M(52, 73)
      temp = temp + M(75, 53) * M(53, 73)
      temp = temp + M(75, 56) * M(56, 73)
      temp = temp + M(75, 59) * M(59, 73)
      temp = temp + M(75, 60) * M(60, 73)
      temp = temp + M(75, 61) * M(61, 73)
      temp = temp + M(75, 64) * M(64, 73)
      temp = temp + M(75, 65) * M(65, 73)
      temp = temp + M(75, 66) * M(66, 73)
      temp = temp + M(75, 67) * M(67, 73)
      temp = temp + M(75, 68) * M(68, 73)
      temp = temp + M(75, 69) * M(69, 73)
      temp = temp + M(75, 70) * M(70, 73)
      temp = temp + M(75, 71) * M(71, 73)
      temp = temp + M(75, 72) * M(72, 73)
      M(75, 73) = M(75, 73) - temp
C     Lower part.
      temp = M(76, 33) * M(33, 73)
      temp = temp + M(76, 39) * M(39, 73)
      temp = temp + M(76, 40) * M(40, 73)
      temp = temp + M(76, 41) * M(41, 73)
      temp = temp + M(76, 46) * M(46, 73)
      temp = temp + M(76, 47) * M(47, 73)
      temp = temp + M(76, 48) * M(48, 73)
      temp = temp + M(76, 49) * M(49, 73)
      temp = temp + M(76, 50) * M(50, 73)
      temp = temp + M(76, 51) * M(51, 73)
      temp = temp + M(76, 52) * M(52, 73)
      temp = temp + M(76, 54) * M(54, 73)
      temp = temp + M(76, 55) * M(55, 73)
      temp = temp + M(76, 57) * M(57, 73)
      temp = temp + M(76, 58) * M(58, 73)
      temp = temp + M(76, 59) * M(59, 73)
      temp = temp + M(76, 62) * M(62, 73)
      temp = temp + M(76, 64) * M(64, 73)
      temp = temp + M(76, 66) * M(66, 73)
      temp = temp + M(76, 68) * M(68, 73)
      temp = temp + M(76, 69) * M(69, 73)
      temp = temp + M(76, 70) * M(70, 73)
      temp = temp + M(76, 71) * M(71, 73)
      temp = temp + M(76, 72) * M(72, 73)
      M(76, 73) = M(76, 73) - temp
C     Lower part.
      temp = M(77, 33) * M(33, 73)
      temp = temp + M(77, 39) * M(39, 73)
      temp = temp + M(77, 40) * M(40, 73)
      temp = temp + M(77, 46) * M(46, 73)
      temp = temp + M(77, 47) * M(47, 73)
      temp = temp + M(77, 48) * M(48, 73)
      temp = temp + M(77, 49) * M(49, 73)
      temp = temp + M(77, 50) * M(50, 73)
      temp = temp + M(77, 51) * M(51, 73)
      temp = temp + M(77, 52) * M(52, 73)
      temp = temp + M(77, 53) * M(53, 73)
      temp = temp + M(77, 54) * M(54, 73)
      temp = temp + M(77, 55) * M(55, 73)
      temp = temp + M(77, 56) * M(56, 73)
      temp = temp + M(77, 57) * M(57, 73)
      temp = temp + M(77, 58) * M(58, 73)
      temp = temp + M(77, 59) * M(59, 73)
      temp = temp + M(77, 61) * M(61, 73)
      temp = temp + M(77, 62) * M(62, 73)
      temp = temp + M(77, 64) * M(64, 73)
      temp = temp + M(77, 66) * M(66, 73)
      temp = temp + M(77, 67) * M(67, 73)
      temp = temp + M(77, 68) * M(68, 73)
      temp = temp + M(77, 69) * M(69, 73)
      temp = temp + M(77, 70) * M(70, 73)
      temp = temp + M(77, 71) * M(71, 73)
      temp = temp + M(77, 72) * M(72, 73)
      M(77, 73) = M(77, 73) - temp
C     Lower part.
      temp = M(78, 33) * M(33, 73)
      temp = temp + M(78, 39) * M(39, 73)
      temp = temp + M(78, 40) * M(40, 73)
      temp = temp + M(78, 47) * M(47, 73)
      temp = temp + M(78, 48) * M(48, 73)
      temp = temp + M(78, 49) * M(49, 73)
      temp = temp + M(78, 50) * M(50, 73)
      temp = temp + M(78, 51) * M(51, 73)
      temp = temp + M(78, 52) * M(52, 73)
      temp = temp + M(78, 54) * M(54, 73)
      temp = temp + M(78, 55) * M(55, 73)
      temp = temp + M(78, 57) * M(57, 73)
      temp = temp + M(78, 58) * M(58, 73)
      temp = temp + M(78, 59) * M(59, 73)
      temp = temp + M(78, 62) * M(62, 73)
      temp = temp + M(78, 64) * M(64, 73)
      temp = temp + M(78, 68) * M(68, 73)
      temp = temp + M(78, 69) * M(69, 73)
      temp = temp + M(78, 70) * M(70, 73)
      temp = temp + M(78, 72) * M(72, 73)
      M(78, 73) = M(78, 73) - temp
C     Lower part.
      temp = M(79, 46) * M(46, 73)
      temp = temp + M(79, 52) * M(52, 73)
      temp = temp + M(79, 59) * M(59, 73)
      M(79, 73) = M(79, 73) - temp
C     Lower part.
      temp = M(80, 33) * M(33, 73)
      temp = temp + M(80, 39) * M(39, 73)
      temp = temp + M(80, 40) * M(40, 73)
      temp = temp + M(80, 46) * M(46, 73)
      temp = temp + M(80, 47) * M(47, 73)
      temp = temp + M(80, 48) * M(48, 73)
      temp = temp + M(80, 49) * M(49, 73)
      temp = temp + M(80, 50) * M(50, 73)
      temp = temp + M(80, 51) * M(51, 73)
      temp = temp + M(80, 52) * M(52, 73)
      temp = temp + M(80, 54) * M(54, 73)
      temp = temp + M(80, 55) * M(55, 73)
      temp = temp + M(80, 57) * M(57, 73)
      temp = temp + M(80, 58) * M(58, 73)
      temp = temp + M(80, 59) * M(59, 73)
      temp = temp + M(80, 62) * M(62, 73)
      temp = temp + M(80, 64) * M(64, 73)
      temp = temp + M(80, 67) * M(67, 73)
      temp = temp + M(80, 68) * M(68, 73)
      temp = temp + M(80, 69) * M(69, 73)
      temp = temp + M(80, 70) * M(70, 73)
      temp = temp + M(80, 71) * M(71, 73)
      temp = temp + M(80, 72) * M(72, 73)
      M(80, 73) = M(80, 73) - temp
C     Lower part.
      temp = M(81, 25) * M(25, 73)
      temp = temp + M(81, 33) * M(33, 73)
      temp = temp + M(81, 39) * M(39, 73)
      temp = temp + M(81, 40) * M(40, 73)
      temp = temp + M(81, 41) * M(41, 73)
      temp = temp + M(81, 46) * M(46, 73)
      temp = temp + M(81, 47) * M(47, 73)
      temp = temp + M(81, 48) * M(48, 73)
      temp = temp + M(81, 49) * M(49, 73)
      temp = temp + M(81, 50) * M(50, 73)
      temp = temp + M(81, 51) * M(51, 73)
      temp = temp + M(81, 52) * M(52, 73)
      temp = temp + M(81, 53) * M(53, 73)
      temp = temp + M(81, 54) * M(54, 73)
      temp = temp + M(81, 55) * M(55, 73)
      temp = temp + M(81, 56) * M(56, 73)
      temp = temp + M(81, 57) * M(57, 73)
      temp = temp + M(81, 58) * M(58, 73)
      temp = temp + M(81, 59) * M(59, 73)
      temp = temp + M(81, 60) * M(60, 73)
      temp = temp + M(81, 61) * M(61, 73)
      temp = temp + M(81, 62) * M(62, 73)
      temp = temp + M(81, 64) * M(64, 73)
      temp = temp + M(81, 65) * M(65, 73)
      temp = temp + M(81, 66) * M(66, 73)
      temp = temp + M(81, 68) * M(68, 73)
      temp = temp + M(81, 69) * M(69, 73)
      temp = temp + M(81, 70) * M(70, 73)
      temp = temp + M(81, 71) * M(71, 73)
      temp = temp + M(81, 72) * M(72, 73)
      M(81, 73) = M(81, 73) - temp
C     Lower part.
      temp = M(82, 39) * M(39, 73)
      temp = temp + M(82, 40) * M(40, 73)
      temp = temp + M(82, 47) * M(47, 73)
      temp = temp + M(82, 48) * M(48, 73)
      temp = temp + M(82, 49) * M(49, 73)
      temp = temp + M(82, 51) * M(51, 73)
      temp = temp + M(82, 52) * M(52, 73)
      temp = temp + M(82, 55) * M(55, 73)
      temp = temp + M(82, 57) * M(57, 73)
      temp = temp + M(82, 58) * M(58, 73)
      temp = temp + M(82, 59) * M(59, 73)
      temp = temp + M(82, 68) * M(68, 73)
      temp = temp + M(82, 69) * M(69, 73)
      temp = temp + M(82, 70) * M(70, 73)
      temp = temp + M(82, 72) * M(72, 73)
      M(82, 73) = M(82, 73) - temp
C     Upper part.
      temp = M(73, 21) * M(21, 75)
      temp = temp + M(73, 25) * M(25, 75)
      temp = temp + M(73, 28) * M(28, 75)
      temp = temp + M(73, 29) * M(29, 75)
      temp = temp + M(73, 33) * M(33, 75)
      temp = temp + M(73, 34) * M(34, 75)
      temp = temp + M(73, 35) * M(35, 75)
      temp = temp + M(73, 37) * M(37, 75)
      temp = temp + M(73, 39) * M(39, 75)
      temp = temp + M(73, 40) * M(40, 75)
      temp = temp + M(73, 46) * M(46, 75)
      temp = temp + M(73, 47) * M(47, 75)
      temp = temp + M(73, 48) * M(48, 75)
      temp = temp + M(73, 49) * M(49, 75)
      temp = temp + M(73, 50) * M(50, 75)
      temp = temp + M(73, 51) * M(51, 75)
      temp = temp + M(73, 52) * M(52, 75)
      temp = temp + M(73, 53) * M(53, 75)
      temp = temp + M(73, 54) * M(54, 75)
      temp = temp + M(73, 55) * M(55, 75)
      temp = temp + M(73, 56) * M(56, 75)
      temp = temp + M(73, 57) * M(57, 75)
      temp = temp + M(73, 58) * M(58, 75)
      temp = temp + M(73, 59) * M(59, 75)
      temp = temp + M(73, 62) * M(62, 75)
      temp = temp + M(73, 64) * M(64, 75)
      temp = temp + M(73, 68) * M(68, 75)
      temp = temp + M(73, 69) * M(69, 75)
      temp = temp + M(73, 70) * M(70, 75)
      temp = temp + M(73, 71) * M(71, 75)
      temp = temp + M(73, 72) * M(72, 75)
      M(73, 75) = ( M(73, 75) - temp ) / M(73, 73)
C     Upper part.
      temp = M(73, 33) * M(33, 76)
      temp = temp + M(73, 35) * M(35, 76)
      temp = temp + M(73, 39) * M(39, 76)
      temp = temp + M(73, 40) * M(40, 76)
      temp = temp + M(73, 46) * M(46, 76)
      temp = temp + M(73, 47) * M(47, 76)
      temp = temp + M(73, 48) * M(48, 76)
      temp = temp + M(73, 49) * M(49, 76)
      temp = temp + M(73, 50) * M(50, 76)
      temp = temp + M(73, 51) * M(51, 76)
      temp = temp + M(73, 52) * M(52, 76)
      temp = temp + M(73, 53) * M(53, 76)
      temp = temp + M(73, 54) * M(54, 76)
      temp = temp + M(73, 55) * M(55, 76)
      temp = temp + M(73, 56) * M(56, 76)
      temp = temp + M(73, 57) * M(57, 76)
      temp = temp + M(73, 58) * M(58, 76)
      temp = temp + M(73, 59) * M(59, 76)
      temp = temp + M(73, 62) * M(62, 76)
      temp = temp + M(73, 64) * M(64, 76)
      temp = temp + M(73, 68) * M(68, 76)
      temp = temp + M(73, 69) * M(69, 76)
      temp = temp + M(73, 70) * M(70, 76)
      temp = temp + M(73, 71) * M(71, 76)
      temp = temp + M(73, 72) * M(72, 76)
      M(73, 76) = ( M(73, 76) - temp ) / M(73, 73)
C     Upper part.
      temp = M(73, 21) * M(21, 77)
      temp = temp + M(73, 28) * M(28, 77)
      temp = temp + M(73, 33) * M(33, 77)
      temp = temp + M(73, 34) * M(34, 77)
      temp = temp + M(73, 37) * M(37, 77)
      temp = temp + M(73, 39) * M(39, 77)
      temp = temp + M(73, 40) * M(40, 77)
      temp = temp + M(73, 46) * M(46, 77)
      temp = temp + M(73, 47) * M(47, 77)
      temp = temp + M(73, 48) * M(48, 77)
      temp = temp + M(73, 49) * M(49, 77)
      temp = temp + M(73, 50) * M(50, 77)
      temp = temp + M(73, 51) * M(51, 77)
      temp = temp + M(73, 52) * M(52, 77)
      temp = temp + M(73, 53) * M(53, 77)
      temp = temp + M(73, 54) * M(54, 77)
      temp = temp + M(73, 55) * M(55, 77)
      temp = temp + M(73, 56) * M(56, 77)
      temp = temp + M(73, 57) * M(57, 77)
      temp = temp + M(73, 58) * M(58, 77)
      temp = temp + M(73, 59) * M(59, 77)
      temp = temp + M(73, 62) * M(62, 77)
      temp = temp + M(73, 64) * M(64, 77)
      temp = temp + M(73, 68) * M(68, 77)
      temp = temp + M(73, 69) * M(69, 77)
      temp = temp + M(73, 70) * M(70, 77)
      temp = temp + M(73, 71) * M(71, 77)
      temp = temp + M(73, 72) * M(72, 77)
      M(73, 77) = ( M(73, 77) - temp ) / M(73, 73)
C     Upper part.
      temp = M(73, 33) * M(33, 78)
      temp = temp + M(73, 34) * M(34, 78)
      temp = temp + M(73, 39) * M(39, 78)
      temp = temp + M(73, 40) * M(40, 78)
      temp = temp + M(73, 46) * M(46, 78)
      temp = temp + M(73, 47) * M(47, 78)
      temp = temp + M(73, 48) * M(48, 78)
      temp = temp + M(73, 49) * M(49, 78)
      temp = temp + M(73, 50) * M(50, 78)
      temp = temp + M(73, 51) * M(51, 78)
      temp = temp + M(73, 52) * M(52, 78)
      temp = temp + M(73, 53) * M(53, 78)
      temp = temp + M(73, 54) * M(54, 78)
      temp = temp + M(73, 55) * M(55, 78)
      temp = temp + M(73, 56) * M(56, 78)
      temp = temp + M(73, 57) * M(57, 78)
      temp = temp + M(73, 58) * M(58, 78)
      temp = temp + M(73, 59) * M(59, 78)
      temp = temp + M(73, 62) * M(62, 78)
      temp = temp + M(73, 64) * M(64, 78)
      temp = temp + M(73, 68) * M(68, 78)
      temp = temp + M(73, 69) * M(69, 78)
      temp = temp + M(73, 70) * M(70, 78)
      temp = temp + M(73, 71) * M(71, 78)
      temp = temp + M(73, 72) * M(72, 78)
      M(73, 78) = ( M(73, 78) - temp ) / M(73, 73)
C     Upper part.
      temp = M(73, 59) * M(59, 79)
      temp = temp + M(73, 62) * M(62, 79)
      temp = temp + M(73, 64) * M(64, 79)
      temp = temp + M(73, 68) * M(68, 79)
      temp = temp + M(73, 69) * M(69, 79)
      temp = temp + M(73, 70) * M(70, 79)
      temp = temp + M(73, 71) * M(71, 79)
      temp = temp + M(73, 72) * M(72, 79)
      M(73, 79) = ( M(73, 79) - temp ) / M(73, 73)
C     Upper part.
      temp = M(73, 33) * M(33, 80)
      temp = temp + M(73, 34) * M(34, 80)
      temp = temp + M(73, 37) * M(37, 80)
      temp = temp + M(73, 39) * M(39, 80)
      temp = temp + M(73, 40) * M(40, 80)
      temp = temp + M(73, 46) * M(46, 80)
      temp = temp + M(73, 51) * M(51, 80)
      temp = temp + M(73, 52) * M(52, 80)
      temp = temp + M(73, 53) * M(53, 80)
      temp = temp + M(73, 54) * M(54, 80)
      temp = temp + M(73, 56) * M(56, 80)
      temp = temp + M(73, 57) * M(57, 80)
      temp = temp + M(73, 58) * M(58, 80)
      temp = temp + M(73, 59) * M(59, 80)
      temp = temp + M(73, 62) * M(62, 80)
      temp = temp + M(73, 64) * M(64, 80)
      temp = temp + M(73, 68) * M(68, 80)
      temp = temp + M(73, 69) * M(69, 80)
      temp = temp + M(73, 70) * M(70, 80)
      temp = temp + M(73, 71) * M(71, 80)
      temp = temp + M(73, 72) * M(72, 80)
      M(73, 80) = ( M(73, 80) - temp ) / M(73, 73)
C     Upper part.
      temp = M(73, 25) * M(25, 81)
      temp = temp + M(73, 33) * M(33, 81)
      temp = temp + M(73, 35) * M(35, 81)
      temp = temp + M(73, 37) * M(37, 81)
      temp = temp + M(73, 39) * M(39, 81)
      temp = temp + M(73, 40) * M(40, 81)
      temp = temp + M(73, 46) * M(46, 81)
      temp = temp + M(73, 47) * M(47, 81)
      temp = temp + M(73, 48) * M(48, 81)
      temp = temp + M(73, 49) * M(49, 81)
      temp = temp + M(73, 50) * M(50, 81)
      temp = temp + M(73, 51) * M(51, 81)
      temp = temp + M(73, 52) * M(52, 81)
      temp = temp + M(73, 53) * M(53, 81)
      temp = temp + M(73, 54) * M(54, 81)
      temp = temp + M(73, 55) * M(55, 81)
      temp = temp + M(73, 56) * M(56, 81)
      temp = temp + M(73, 57) * M(57, 81)
      temp = temp + M(73, 58) * M(58, 81)
      temp = temp + M(73, 59) * M(59, 81)
      temp = temp + M(73, 62) * M(62, 81)
      temp = temp + M(73, 64) * M(64, 81)
      temp = temp + M(73, 68) * M(68, 81)
      temp = temp + M(73, 69) * M(69, 81)
      temp = temp + M(73, 70) * M(70, 81)
      temp = temp + M(73, 71) * M(71, 81)
      temp = temp + M(73, 72) * M(72, 81)
      M(73, 81) = ( M(73, 81) - temp ) / M(73, 73)
C     Upper part.
      temp = M(73, 68) * M(68, 82)
      temp = temp + M(73, 69) * M(69, 82)
      temp = temp + M(73, 70) * M(70, 82)
      temp = temp + M(73, 71) * M(71, 82)
      temp = temp + M(73, 72) * M(72, 82)
      M(73, 82) = ( M(73, 82) - temp ) / M(73, 73)

C     Lower part.
      temp = M(75, 60) * M(60, 74)
      temp = temp + M(75, 67) * M(67, 74)
      M(75, 74) = M(75, 74) - temp
C     Lower part.
      temp = M(77, 67) * M(67, 74)
      M(77, 74) = M(77, 74) - temp
C     Lower part.
      temp = M(80, 67) * M(67, 74)
      M(80, 74) = M(80, 74) - temp
C     Lower part.
      temp = M(81, 60) * M(60, 74)
      M(81, 74) = M(81, 74) - temp
C     Upper part.
      temp = M(74, 11) * M(11, 75)
      temp = temp + M(74, 14) * M(14, 75)
      temp = temp + M(74, 21) * M(21, 75)
      temp = temp + M(74, 25) * M(25, 75)
      temp = temp + M(74, 27) * M(27, 75)
      temp = temp + M(74, 28) * M(28, 75)
      temp = temp + M(74, 33) * M(33, 75)
      temp = temp + M(74, 34) * M(34, 75)
      temp = temp + M(74, 35) * M(35, 75)
      temp = temp + M(74, 37) * M(37, 75)
      temp = temp + M(74, 39) * M(39, 75)
      temp = temp + M(74, 40) * M(40, 75)
      temp = temp + M(74, 41) * M(41, 75)
      temp = temp + M(74, 42) * M(42, 75)
      temp = temp + M(74, 44) * M(44, 75)
      temp = temp + M(74, 46) * M(46, 75)
      temp = temp + M(74, 47) * M(47, 75)
      temp = temp + M(74, 48) * M(48, 75)
      temp = temp + M(74, 49) * M(49, 75)
      temp = temp + M(74, 50) * M(50, 75)
      temp = temp + M(74, 51) * M(51, 75)
      temp = temp + M(74, 52) * M(52, 75)
      temp = temp + M(74, 53) * M(53, 75)
      temp = temp + M(74, 54) * M(54, 75)
      temp = temp + M(74, 55) * M(55, 75)
      temp = temp + M(74, 56) * M(56, 75)
      temp = temp + M(74, 57) * M(57, 75)
      temp = temp + M(74, 58) * M(58, 75)
      temp = temp + M(74, 59) * M(59, 75)
      temp = temp + M(74, 61) * M(61, 75)
      temp = temp + M(74, 62) * M(62, 75)
      temp = temp + M(74, 64) * M(64, 75)
      temp = temp + M(74, 68) * M(68, 75)
      temp = temp + M(74, 69) * M(69, 75)
      temp = temp + M(74, 70) * M(70, 75)
      temp = temp + M(74, 72) * M(72, 75)
      temp = temp + M(74, 73) * M(73, 75)
      M(74, 75) = ( M(74, 75) - temp ) / M(74, 74)
C     Upper part.
      temp = M(74, 33) * M(33, 76)
      temp = temp + M(74, 35) * M(35, 76)
      temp = temp + M(74, 39) * M(39, 76)
      temp = temp + M(74, 40) * M(40, 76)
      temp = temp + M(74, 44) * M(44, 76)
      temp = temp + M(74, 46) * M(46, 76)
      temp = temp + M(74, 47) * M(47, 76)
      temp = temp + M(74, 48) * M(48, 76)
      temp = temp + M(74, 49) * M(49, 76)
      temp = temp + M(74, 50) * M(50, 76)
      temp = temp + M(74, 51) * M(51, 76)
      temp = temp + M(74, 52) * M(52, 76)
      temp = temp + M(74, 53) * M(53, 76)
      temp = temp + M(74, 54) * M(54, 76)
      temp = temp + M(74, 55) * M(55, 76)
      temp = temp + M(74, 56) * M(56, 76)
      temp = temp + M(74, 57) * M(57, 76)
      temp = temp + M(74, 58) * M(58, 76)
      temp = temp + M(74, 59) * M(59, 76)
      temp = temp + M(74, 61) * M(61, 76)
      temp = temp + M(74, 62) * M(62, 76)
      temp = temp + M(74, 64) * M(64, 76)
      temp = temp + M(74, 68) * M(68, 76)
      temp = temp + M(74, 69) * M(69, 76)
      temp = temp + M(74, 70) * M(70, 76)
      temp = temp + M(74, 72) * M(72, 76)
      temp = temp + M(74, 73) * M(73, 76)
      M(74, 76) = ( M(74, 76) - temp ) / M(74, 74)
C     Upper part.
      temp = M(74, 14) * M(14, 77)
      temp = temp + M(74, 21) * M(21, 77)
      temp = temp + M(74, 27) * M(27, 77)
      temp = temp + M(74, 28) * M(28, 77)
      temp = temp + M(74, 33) * M(33, 77)
      temp = temp + M(74, 34) * M(34, 77)
      temp = temp + M(74, 37) * M(37, 77)
      temp = temp + M(74, 39) * M(39, 77)
      temp = temp + M(74, 40) * M(40, 77)
      temp = temp + M(74, 42) * M(42, 77)
      temp = temp + M(74, 44) * M(44, 77)
      temp = temp + M(74, 46) * M(46, 77)
      temp = temp + M(74, 47) * M(47, 77)
      temp = temp + M(74, 48) * M(48, 77)
      temp = temp + M(74, 49) * M(49, 77)
      temp = temp + M(74, 50) * M(50, 77)
      temp = temp + M(74, 51) * M(51, 77)
      temp = temp + M(74, 52) * M(52, 77)
      temp = temp + M(74, 53) * M(53, 77)
      temp = temp + M(74, 54) * M(54, 77)
      temp = temp + M(74, 55) * M(55, 77)
      temp = temp + M(74, 56) * M(56, 77)
      temp = temp + M(74, 57) * M(57, 77)
      temp = temp + M(74, 58) * M(58, 77)
      temp = temp + M(74, 59) * M(59, 77)
      temp = temp + M(74, 61) * M(61, 77)
      temp = temp + M(74, 62) * M(62, 77)
      temp = temp + M(74, 64) * M(64, 77)
      temp = temp + M(74, 68) * M(68, 77)
      temp = temp + M(74, 69) * M(69, 77)
      temp = temp + M(74, 70) * M(70, 77)
      temp = temp + M(74, 72) * M(72, 77)
      temp = temp + M(74, 73) * M(73, 77)
      M(74, 77) = ( M(74, 77) - temp ) / M(74, 74)
C     Upper part.
      temp = M(74, 33) * M(33, 78)
      temp = temp + M(74, 34) * M(34, 78)
      temp = temp + M(74, 39) * M(39, 78)
      temp = temp + M(74, 40) * M(40, 78)
      temp = temp + M(74, 46) * M(46, 78)
      temp = temp + M(74, 47) * M(47, 78)
      temp = temp + M(74, 48) * M(48, 78)
      temp = temp + M(74, 49) * M(49, 78)
      temp = temp + M(74, 50) * M(50, 78)
      temp = temp + M(74, 51) * M(51, 78)
      temp = temp + M(74, 52) * M(52, 78)
      temp = temp + M(74, 53) * M(53, 78)
      temp = temp + M(74, 54) * M(54, 78)
      temp = temp + M(74, 55) * M(55, 78)
      temp = temp + M(74, 56) * M(56, 78)
      temp = temp + M(74, 57) * M(57, 78)
      temp = temp + M(74, 58) * M(58, 78)
      temp = temp + M(74, 59) * M(59, 78)
      temp = temp + M(74, 61) * M(61, 78)
      temp = temp + M(74, 62) * M(62, 78)
      temp = temp + M(74, 64) * M(64, 78)
      temp = temp + M(74, 68) * M(68, 78)
      temp = temp + M(74, 69) * M(69, 78)
      temp = temp + M(74, 70) * M(70, 78)
      temp = temp + M(74, 72) * M(72, 78)
      temp = temp + M(74, 73) * M(73, 78)
      M(74, 78) = ( M(74, 78) - temp ) / M(74, 74)
C     Upper part.
      temp = M(74, 42) * M(42, 79)
      temp = temp + M(74, 44) * M(44, 79)
      temp = temp + M(74, 59) * M(59, 79)
      temp = temp + M(74, 61) * M(61, 79)
      temp = temp + M(74, 62) * M(62, 79)
      temp = temp + M(74, 64) * M(64, 79)
      temp = temp + M(74, 68) * M(68, 79)
      temp = temp + M(74, 69) * M(69, 79)
      temp = temp + M(74, 70) * M(70, 79)
      temp = temp + M(74, 72) * M(72, 79)
      temp = temp + M(74, 73) * M(73, 79)
      M(74, 79) = ( M(74, 79) - temp ) / M(74, 74)
C     Upper part.
      temp = M(74, 33) * M(33, 80)
      temp = temp + M(74, 34) * M(34, 80)
      temp = temp + M(74, 37) * M(37, 80)
      temp = temp + M(74, 39) * M(39, 80)
      temp = temp + M(74, 40) * M(40, 80)
      temp = temp + M(74, 42) * M(42, 80)
      temp = temp + M(74, 44) * M(44, 80)
      temp = temp + M(74, 46) * M(46, 80)
      temp = temp + M(74, 51) * M(51, 80)
      temp = temp + M(74, 52) * M(52, 80)
      temp = temp + M(74, 53) * M(53, 80)
      temp = temp + M(74, 54) * M(54, 80)
      temp = temp + M(74, 56) * M(56, 80)
      temp = temp + M(74, 57) * M(57, 80)
      temp = temp + M(74, 58) * M(58, 80)
      temp = temp + M(74, 59) * M(59, 80)
      temp = temp + M(74, 61) * M(61, 80)
      temp = temp + M(74, 62) * M(62, 80)
      temp = temp + M(74, 64) * M(64, 80)
      temp = temp + M(74, 68) * M(68, 80)
      temp = temp + M(74, 69) * M(69, 80)
      temp = temp + M(74, 70) * M(70, 80)
      temp = temp + M(74, 72) * M(72, 80)
      temp = temp + M(74, 73) * M(73, 80)
      M(74, 80) = ( M(74, 80) - temp ) / M(74, 74)
C     Upper part.
      temp = M(74, 25) * M(25, 81)
      temp = temp + M(74, 33) * M(33, 81)
      temp = temp + M(74, 35) * M(35, 81)
      temp = temp + M(74, 37) * M(37, 81)
      temp = temp + M(74, 39) * M(39, 81)
      temp = temp + M(74, 40) * M(40, 81)
      temp = temp + M(74, 46) * M(46, 81)
      temp = temp + M(74, 47) * M(47, 81)
      temp = temp + M(74, 48) * M(48, 81)
      temp = temp + M(74, 49) * M(49, 81)
      temp = temp + M(74, 50) * M(50, 81)
      temp = temp + M(74, 51) * M(51, 81)
      temp = temp + M(74, 52) * M(52, 81)
      temp = temp + M(74, 53) * M(53, 81)
      temp = temp + M(74, 54) * M(54, 81)
      temp = temp + M(74, 55) * M(55, 81)
      temp = temp + M(74, 56) * M(56, 81)
      temp = temp + M(74, 57) * M(57, 81)
      temp = temp + M(74, 58) * M(58, 81)
      temp = temp + M(74, 59) * M(59, 81)
      temp = temp + M(74, 61) * M(61, 81)
      temp = temp + M(74, 62) * M(62, 81)
      temp = temp + M(74, 64) * M(64, 81)
      temp = temp + M(74, 68) * M(68, 81)
      temp = temp + M(74, 69) * M(69, 81)
      temp = temp + M(74, 70) * M(70, 81)
      temp = temp + M(74, 72) * M(72, 81)
      temp = temp + M(74, 73) * M(73, 81)
      M(74, 81) = ( M(74, 81) - temp ) / M(74, 74)
C     Upper part.
      temp = M(74, 68) * M(68, 82)
      temp = temp + M(74, 69) * M(69, 82)
      temp = temp + M(74, 70) * M(70, 82)
      temp = temp + M(74, 72) * M(72, 82)
      temp = temp + M(74, 73) * M(73, 82)
      M(74, 82) = ( M(74, 82) - temp ) / M(74, 74)

C     Lower part.
      temp = M(75, 3) * M(3, 75)
      temp = temp + M(75, 4) * M(4, 75)
      temp = temp + M(75, 5) * M(5, 75)
      temp = temp + M(75, 6) * M(6, 75)
      temp = temp + M(75, 9) * M(9, 75)
      temp = temp + M(75, 11) * M(11, 75)
      temp = temp + M(75, 12) * M(12, 75)
      temp = temp + M(75, 14) * M(14, 75)
      temp = temp + M(75, 17) * M(17, 75)
      temp = temp + M(75, 18) * M(18, 75)
      temp = temp + M(75, 21) * M(21, 75)
      temp = temp + M(75, 24) * M(24, 75)
      temp = temp + M(75, 25) * M(25, 75)
      temp = temp + M(75, 26) * M(26, 75)
      temp = temp + M(75, 27) * M(27, 75)
      temp = temp + M(75, 28) * M(28, 75)
      temp = temp + M(75, 29) * M(29, 75)
      temp = temp + M(75, 30) * M(30, 75)
      temp = temp + M(75, 31) * M(31, 75)
      temp = temp + M(75, 32) * M(32, 75)
      temp = temp + M(75, 34) * M(34, 75)
      temp = temp + M(75, 35) * M(35, 75)
      temp = temp + M(75, 37) * M(37, 75)
      temp = temp + M(75, 41) * M(41, 75)
      temp = temp + M(75, 42) * M(42, 75)
      temp = temp + M(75, 44) * M(44, 75)
      temp = temp + M(75, 45) * M(45, 75)
      temp = temp + M(75, 46) * M(46, 75)
      temp = temp + M(75, 52) * M(52, 75)
      temp = temp + M(75, 53) * M(53, 75)
      temp = temp + M(75, 56) * M(56, 75)
      temp = temp + M(75, 59) * M(59, 75)
      temp = temp + M(75, 60) * M(60, 75)
      temp = temp + M(75, 61) * M(61, 75)
      temp = temp + M(75, 64) * M(64, 75)
      temp = temp + M(75, 65) * M(65, 75)
      temp = temp + M(75, 66) * M(66, 75)
      temp = temp + M(75, 67) * M(67, 75)
      temp = temp + M(75, 68) * M(68, 75)
      temp = temp + M(75, 69) * M(69, 75)
      temp = temp + M(75, 70) * M(70, 75)
      temp = temp + M(75, 71) * M(71, 75)
      temp = temp + M(75, 72) * M(72, 75)
      temp = temp + M(75, 73) * M(73, 75)
      temp = temp + M(75, 74) * M(74, 75)
      M(75, 75) = M(75, 75) - temp
C     Lower part.
      temp = M(76, 21) * M(21, 75)
      temp = temp + M(76, 28) * M(28, 75)
      temp = temp + M(76, 33) * M(33, 75)
      temp = temp + M(76, 34) * M(34, 75)
      temp = temp + M(76, 35) * M(35, 75)
      temp = temp + M(76, 37) * M(37, 75)
      temp = temp + M(76, 39) * M(39, 75)
      temp = temp + M(76, 40) * M(40, 75)
      temp = temp + M(76, 41) * M(41, 75)
      temp = temp + M(76, 42) * M(42, 75)
      temp = temp + M(76, 44) * M(44, 75)
      temp = temp + M(76, 46) * M(46, 75)
      temp = temp + M(76, 47) * M(47, 75)
      temp = temp + M(76, 48) * M(48, 75)
      temp = temp + M(76, 49) * M(49, 75)
      temp = temp + M(76, 50) * M(50, 75)
      temp = temp + M(76, 51) * M(51, 75)
      temp = temp + M(76, 52) * M(52, 75)
      temp = temp + M(76, 54) * M(54, 75)
      temp = temp + M(76, 55) * M(55, 75)
      temp = temp + M(76, 57) * M(57, 75)
      temp = temp + M(76, 58) * M(58, 75)
      temp = temp + M(76, 59) * M(59, 75)
      temp = temp + M(76, 62) * M(62, 75)
      temp = temp + M(76, 64) * M(64, 75)
      temp = temp + M(76, 66) * M(66, 75)
      temp = temp + M(76, 68) * M(68, 75)
      temp = temp + M(76, 69) * M(69, 75)
      temp = temp + M(76, 70) * M(70, 75)
      temp = temp + M(76, 71) * M(71, 75)
      temp = temp + M(76, 72) * M(72, 75)
      temp = temp + M(76, 73) * M(73, 75)
      M(76, 75) = M(76, 75) - temp
C     Lower part.
      temp = M(77, 14) * M(14, 75)
      temp = temp + M(77, 21) * M(21, 75)
      temp = temp + M(77, 24) * M(24, 75)
      temp = temp + M(77, 26) * M(26, 75)
      temp = temp + M(77, 27) * M(27, 75)
      temp = temp + M(77, 28) * M(28, 75)
      temp = temp + M(77, 33) * M(33, 75)
      temp = temp + M(77, 34) * M(34, 75)
      temp = temp + M(77, 37) * M(37, 75)
      temp = temp + M(77, 39) * M(39, 75)
      temp = temp + M(77, 40) * M(40, 75)
      temp = temp + M(77, 42) * M(42, 75)
      temp = temp + M(77, 44) * M(44, 75)
      temp = temp + M(77, 46) * M(46, 75)
      temp = temp + M(77, 47) * M(47, 75)
      temp = temp + M(77, 48) * M(48, 75)
      temp = temp + M(77, 49) * M(49, 75)
      temp = temp + M(77, 50) * M(50, 75)
      temp = temp + M(77, 51) * M(51, 75)
      temp = temp + M(77, 52) * M(52, 75)
      temp = temp + M(77, 53) * M(53, 75)
      temp = temp + M(77, 54) * M(54, 75)
      temp = temp + M(77, 55) * M(55, 75)
      temp = temp + M(77, 56) * M(56, 75)
      temp = temp + M(77, 57) * M(57, 75)
      temp = temp + M(77, 58) * M(58, 75)
      temp = temp + M(77, 59) * M(59, 75)
      temp = temp + M(77, 61) * M(61, 75)
      temp = temp + M(77, 62) * M(62, 75)
      temp = temp + M(77, 64) * M(64, 75)
      temp = temp + M(77, 66) * M(66, 75)
      temp = temp + M(77, 67) * M(67, 75)
      temp = temp + M(77, 68) * M(68, 75)
      temp = temp + M(77, 69) * M(69, 75)
      temp = temp + M(77, 70) * M(70, 75)
      temp = temp + M(77, 71) * M(71, 75)
      temp = temp + M(77, 72) * M(72, 75)
      temp = temp + M(77, 73) * M(73, 75)
      temp = temp + M(77, 74) * M(74, 75)
      M(77, 75) = M(77, 75) - temp
C     Lower part.
      temp = M(78, 32) * M(32, 75)
      temp = temp + M(78, 33) * M(33, 75)
      temp = temp + M(78, 34) * M(34, 75)
      temp = temp + M(78, 37) * M(37, 75)
      temp = temp + M(78, 39) * M(39, 75)
      temp = temp + M(78, 40) * M(40, 75)
      temp = temp + M(78, 47) * M(47, 75)
      temp = temp + M(78, 48) * M(48, 75)
      temp = temp + M(78, 49) * M(49, 75)
      temp = temp + M(78, 50) * M(50, 75)
      temp = temp + M(78, 51) * M(51, 75)
      temp = temp + M(78, 52) * M(52, 75)
      temp = temp + M(78, 54) * M(54, 75)
      temp = temp + M(78, 55) * M(55, 75)
      temp = temp + M(78, 57) * M(57, 75)
      temp = temp + M(78, 58) * M(58, 75)
      temp = temp + M(78, 59) * M(59, 75)
      temp = temp + M(78, 62) * M(62, 75)
      temp = temp + M(78, 64) * M(64, 75)
      temp = temp + M(78, 68) * M(68, 75)
      temp = temp + M(78, 69) * M(69, 75)
      temp = temp + M(78, 70) * M(70, 75)
      temp = temp + M(78, 72) * M(72, 75)
      temp = temp + M(78, 73) * M(73, 75)
      M(78, 75) = M(78, 75) - temp
C     Lower part.
      temp = M(79, 42) * M(42, 75)
      temp = temp + M(79, 46) * M(46, 75)
      temp = temp + M(79, 52) * M(52, 75)
      temp = temp + M(79, 59) * M(59, 75)
      temp = temp + M(79, 73) * M(73, 75)
      M(79, 75) = M(79, 75) - temp
C     Lower part.
      temp = M(80, 17) * M(17, 75)
      temp = temp + M(80, 18) * M(18, 75)
      temp = temp + M(80, 24) * M(24, 75)
      temp = temp + M(80, 31) * M(31, 75)
      temp = temp + M(80, 32) * M(32, 75)
      temp = temp + M(80, 33) * M(33, 75)
      temp = temp + M(80, 34) * M(34, 75)
      temp = temp + M(80, 36) * M(36, 75)
      temp = temp + M(80, 37) * M(37, 75)
      temp = temp + M(80, 39) * M(39, 75)
      temp = temp + M(80, 40) * M(40, 75)
      temp = temp + M(80, 42) * M(42, 75)
      temp = temp + M(80, 44) * M(44, 75)
      temp = temp + M(80, 46) * M(46, 75)
      temp = temp + M(80, 47) * M(47, 75)
      temp = temp + M(80, 48) * M(48, 75)
      temp = temp + M(80, 49) * M(49, 75)
      temp = temp + M(80, 50) * M(50, 75)
      temp = temp + M(80, 51) * M(51, 75)
      temp = temp + M(80, 52) * M(52, 75)
      temp = temp + M(80, 54) * M(54, 75)
      temp = temp + M(80, 55) * M(55, 75)
      temp = temp + M(80, 57) * M(57, 75)
      temp = temp + M(80, 58) * M(58, 75)
      temp = temp + M(80, 59) * M(59, 75)
      temp = temp + M(80, 62) * M(62, 75)
      temp = temp + M(80, 64) * M(64, 75)
      temp = temp + M(80, 67) * M(67, 75)
      temp = temp + M(80, 68) * M(68, 75)
      temp = temp + M(80, 69) * M(69, 75)
      temp = temp + M(80, 70) * M(70, 75)
      temp = temp + M(80, 71) * M(71, 75)
      temp = temp + M(80, 72) * M(72, 75)
      temp = temp + M(80, 73) * M(73, 75)
      temp = temp + M(80, 74) * M(74, 75)
      M(80, 75) = M(80, 75) - temp
C     Lower part.
      temp = M(81, 3) * M(3, 75)
      temp = temp + M(81, 4) * M(4, 75)
      temp = temp + M(81, 5) * M(5, 75)
      temp = temp + M(81, 6) * M(6, 75)
      temp = temp + M(81, 9) * M(9, 75)
      temp = temp + M(81, 11) * M(11, 75)
      temp = temp + M(81, 12) * M(12, 75)
      temp = temp + M(81, 14) * M(14, 75)
      temp = temp + M(81, 17) * M(17, 75)
      temp = temp + M(81, 18) * M(18, 75)
      temp = temp + M(81, 21) * M(21, 75)
      temp = temp + M(81, 24) * M(24, 75)
      temp = temp + M(81, 25) * M(25, 75)
      temp = temp + M(81, 26) * M(26, 75)
      temp = temp + M(81, 27) * M(27, 75)
      temp = temp + M(81, 28) * M(28, 75)
      temp = temp + M(81, 31) * M(31, 75)
      temp = temp + M(81, 33) * M(33, 75)
      temp = temp + M(81, 34) * M(34, 75)
      temp = temp + M(81, 35) * M(35, 75)
      temp = temp + M(81, 36) * M(36, 75)
      temp = temp + M(81, 37) * M(37, 75)
      temp = temp + M(81, 39) * M(39, 75)
      temp = temp + M(81, 40) * M(40, 75)
      temp = temp + M(81, 41) * M(41, 75)
      temp = temp + M(81, 42) * M(42, 75)
      temp = temp + M(81, 45) * M(45, 75)
      temp = temp + M(81, 46) * M(46, 75)
      temp = temp + M(81, 47) * M(47, 75)
      temp = temp + M(81, 48) * M(48, 75)
      temp = temp + M(81, 49) * M(49, 75)
      temp = temp + M(81, 50) * M(50, 75)
      temp = temp + M(81, 51) * M(51, 75)
      temp = temp + M(81, 52) * M(52, 75)
      temp = temp + M(81, 53) * M(53, 75)
      temp = temp + M(81, 54) * M(54, 75)
      temp = temp + M(81, 55) * M(55, 75)
      temp = temp + M(81, 56) * M(56, 75)
      temp = temp + M(81, 57) * M(57, 75)
      temp = temp + M(81, 58) * M(58, 75)
      temp = temp + M(81, 59) * M(59, 75)
      temp = temp + M(81, 60) * M(60, 75)
      temp = temp + M(81, 61) * M(61, 75)
      temp = temp + M(81, 62) * M(62, 75)
      temp = temp + M(81, 64) * M(64, 75)
      temp = temp + M(81, 65) * M(65, 75)
      temp = temp + M(81, 66) * M(66, 75)
      temp = temp + M(81, 68) * M(68, 75)
      temp = temp + M(81, 69) * M(69, 75)
      temp = temp + M(81, 70) * M(70, 75)
      temp = temp + M(81, 71) * M(71, 75)
      temp = temp + M(81, 72) * M(72, 75)
      temp = temp + M(81, 73) * M(73, 75)
      temp = temp + M(81, 74) * M(74, 75)
      M(81, 75) = M(81, 75) - temp
C     Lower part.
      temp = M(82, 36) * M(36, 75)
      temp = temp + M(82, 37) * M(37, 75)
      temp = temp + M(82, 39) * M(39, 75)
      temp = temp + M(82, 40) * M(40, 75)
      temp = temp + M(82, 42) * M(42, 75)
      temp = temp + M(82, 47) * M(47, 75)
      temp = temp + M(82, 48) * M(48, 75)
      temp = temp + M(82, 49) * M(49, 75)
      temp = temp + M(82, 51) * M(51, 75)
      temp = temp + M(82, 52) * M(52, 75)
      temp = temp + M(82, 55) * M(55, 75)
      temp = temp + M(82, 57) * M(57, 75)
      temp = temp + M(82, 58) * M(58, 75)
      temp = temp + M(82, 59) * M(59, 75)
      temp = temp + M(82, 68) * M(68, 75)
      temp = temp + M(82, 69) * M(69, 75)
      temp = temp + M(82, 70) * M(70, 75)
      temp = temp + M(82, 72) * M(72, 75)
      temp = temp + M(82, 73) * M(73, 75)
      M(82, 75) = M(82, 75) - temp
C     Upper part.
      temp = M(75, 35) * M(35, 76)
      temp = temp + M(75, 44) * M(44, 76)
      temp = temp + M(75, 46) * M(46, 76)
      temp = temp + M(75, 52) * M(52, 76)
      temp = temp + M(75, 53) * M(53, 76)
      temp = temp + M(75, 56) * M(56, 76)
      temp = temp + M(75, 59) * M(59, 76)
      temp = temp + M(75, 60) * M(60, 76)
      temp = temp + M(75, 61) * M(61, 76)
      temp = temp + M(75, 64) * M(64, 76)
      temp = temp + M(75, 65) * M(65, 76)
      temp = temp + M(75, 66) * M(66, 76)
      temp = temp + M(75, 67) * M(67, 76)
      temp = temp + M(75, 68) * M(68, 76)
      temp = temp + M(75, 69) * M(69, 76)
      temp = temp + M(75, 70) * M(70, 76)
      temp = temp + M(75, 71) * M(71, 76)
      temp = temp + M(75, 72) * M(72, 76)
      temp = temp + M(75, 73) * M(73, 76)
      temp = temp + M(75, 74) * M(74, 76)
      M(75, 76) = ( M(75, 76) - temp ) / M(75, 75)
C     Upper part.
      temp = M(75, 14) * M(14, 77)
      temp = temp + M(75, 21) * M(21, 77)
      temp = temp + M(75, 26) * M(26, 77)
      temp = temp + M(75, 27) * M(27, 77)
      temp = temp + M(75, 28) * M(28, 77)
      temp = temp + M(75, 34) * M(34, 77)
      temp = temp + M(75, 37) * M(37, 77)
      temp = temp + M(75, 42) * M(42, 77)
      temp = temp + M(75, 44) * M(44, 77)
      temp = temp + M(75, 45) * M(45, 77)
      temp = temp + M(75, 46) * M(46, 77)
      temp = temp + M(75, 52) * M(52, 77)
      temp = temp + M(75, 53) * M(53, 77)
      temp = temp + M(75, 56) * M(56, 77)
      temp = temp + M(75, 59) * M(59, 77)
      temp = temp + M(75, 60) * M(60, 77)
      temp = temp + M(75, 61) * M(61, 77)
      temp = temp + M(75, 64) * M(64, 77)
      temp = temp + M(75, 65) * M(65, 77)
      temp = temp + M(75, 66) * M(66, 77)
      temp = temp + M(75, 67) * M(67, 77)
      temp = temp + M(75, 68) * M(68, 77)
      temp = temp + M(75, 69) * M(69, 77)
      temp = temp + M(75, 70) * M(70, 77)
      temp = temp + M(75, 71) * M(71, 77)
      temp = temp + M(75, 72) * M(72, 77)
      temp = temp + M(75, 73) * M(73, 77)
      temp = temp + M(75, 74) * M(74, 77)
      M(75, 77) = ( M(75, 77) - temp ) / M(75, 75)
C     Upper part.
      temp = M(75, 32) * M(32, 78)
      temp = temp + M(75, 34) * M(34, 78)
      temp = temp + M(75, 45) * M(45, 78)
      temp = temp + M(75, 46) * M(46, 78)
      temp = temp + M(75, 52) * M(52, 78)
      temp = temp + M(75, 53) * M(53, 78)
      temp = temp + M(75, 56) * M(56, 78)
      temp = temp + M(75, 59) * M(59, 78)
      temp = temp + M(75, 60) * M(60, 78)
      temp = temp + M(75, 61) * M(61, 78)
      temp = temp + M(75, 64) * M(64, 78)
      temp = temp + M(75, 65) * M(65, 78)
      temp = temp + M(75, 66) * M(66, 78)
      temp = temp + M(75, 67) * M(67, 78)
      temp = temp + M(75, 68) * M(68, 78)
      temp = temp + M(75, 69) * M(69, 78)
      temp = temp + M(75, 70) * M(70, 78)
      temp = temp + M(75, 71) * M(71, 78)
      temp = temp + M(75, 72) * M(72, 78)
      temp = temp + M(75, 73) * M(73, 78)
      temp = temp + M(75, 74) * M(74, 78)
      M(75, 78) = ( M(75, 78) - temp ) / M(75, 75)
C     Upper part.
      temp = M(75, 42) * M(42, 79)
      temp = temp + M(75, 44) * M(44, 79)
      temp = temp + M(75, 59) * M(59, 79)
      temp = temp + M(75, 60) * M(60, 79)
      temp = temp + M(75, 61) * M(61, 79)
      temp = temp + M(75, 64) * M(64, 79)
      temp = temp + M(75, 65) * M(65, 79)
      temp = temp + M(75, 66) * M(66, 79)
      temp = temp + M(75, 67) * M(67, 79)
      temp = temp + M(75, 68) * M(68, 79)
      temp = temp + M(75, 69) * M(69, 79)
      temp = temp + M(75, 70) * M(70, 79)
      temp = temp + M(75, 71) * M(71, 79)
      temp = temp + M(75, 72) * M(72, 79)
      temp = temp + M(75, 73) * M(73, 79)
      temp = temp + M(75, 74) * M(74, 79)
      M(75, 79) = ( M(75, 79) - temp ) / M(75, 75)
C     Upper part.
      temp = M(75, 17) * M(17, 80)
      temp = temp + M(75, 18) * M(18, 80)
      temp = temp + M(75, 24) * M(24, 80)
      temp = temp + M(75, 31) * M(31, 80)
      temp = temp + M(75, 32) * M(32, 80)
      temp = temp + M(75, 34) * M(34, 80)
      temp = temp + M(75, 37) * M(37, 80)
      temp = temp + M(75, 42) * M(42, 80)
      temp = temp + M(75, 44) * M(44, 80)
      temp = temp + M(75, 45) * M(45, 80)
      temp = temp + M(75, 46) * M(46, 80)
      temp = temp + M(75, 52) * M(52, 80)
      temp = temp + M(75, 53) * M(53, 80)
      temp = temp + M(75, 56) * M(56, 80)
      temp = temp + M(75, 59) * M(59, 80)
      temp = temp + M(75, 60) * M(60, 80)
      temp = temp + M(75, 61) * M(61, 80)
      temp = temp + M(75, 64) * M(64, 80)
      temp = temp + M(75, 65) * M(65, 80)
      temp = temp + M(75, 66) * M(66, 80)
      temp = temp + M(75, 67) * M(67, 80)
      temp = temp + M(75, 68) * M(68, 80)
      temp = temp + M(75, 69) * M(69, 80)
      temp = temp + M(75, 70) * M(70, 80)
      temp = temp + M(75, 71) * M(71, 80)
      temp = temp + M(75, 72) * M(72, 80)
      temp = temp + M(75, 73) * M(73, 80)
      temp = temp + M(75, 74) * M(74, 80)
      M(75, 80) = ( M(75, 80) - temp ) / M(75, 75)
C     Upper part.
      temp = M(75, 24) * M(24, 81)
      temp = temp + M(75, 25) * M(25, 81)
      temp = temp + M(75, 35) * M(35, 81)
      temp = temp + M(75, 37) * M(37, 81)
      temp = temp + M(75, 45) * M(45, 81)
      temp = temp + M(75, 46) * M(46, 81)
      temp = temp + M(75, 52) * M(52, 81)
      temp = temp + M(75, 53) * M(53, 81)
      temp = temp + M(75, 56) * M(56, 81)
      temp = temp + M(75, 59) * M(59, 81)
      temp = temp + M(75, 60) * M(60, 81)
      temp = temp + M(75, 61) * M(61, 81)
      temp = temp + M(75, 64) * M(64, 81)
      temp = temp + M(75, 65) * M(65, 81)
      temp = temp + M(75, 66) * M(66, 81)
      temp = temp + M(75, 67) * M(67, 81)
      temp = temp + M(75, 68) * M(68, 81)
      temp = temp + M(75, 69) * M(69, 81)
      temp = temp + M(75, 70) * M(70, 81)
      temp = temp + M(75, 71) * M(71, 81)
      temp = temp + M(75, 72) * M(72, 81)
      temp = temp + M(75, 73) * M(73, 81)
      temp = temp + M(75, 74) * M(74, 81)
      M(75, 81) = ( M(75, 81) - temp ) / M(75, 75)
C     Upper part.
      temp = M(75, 68) * M(68, 82)
      temp = temp + M(75, 69) * M(69, 82)
      temp = temp + M(75, 70) * M(70, 82)
      temp = temp + M(75, 71) * M(71, 82)
      temp = temp + M(75, 72) * M(72, 82)
      temp = temp + M(75, 73) * M(73, 82)
      temp = temp + M(75, 74) * M(74, 82)
      M(75, 82) = ( M(75, 82) - temp ) / M(75, 75)

C     Lower part.
      temp = M(76, 33) * M(33, 76)
      temp = temp + M(76, 35) * M(35, 76)
      temp = temp + M(76, 39) * M(39, 76)
      temp = temp + M(76, 40) * M(40, 76)
      temp = temp + M(76, 44) * M(44, 76)
      temp = temp + M(76, 46) * M(46, 76)
      temp = temp + M(76, 47) * M(47, 76)
      temp = temp + M(76, 48) * M(48, 76)
      temp = temp + M(76, 49) * M(49, 76)
      temp = temp + M(76, 50) * M(50, 76)
      temp = temp + M(76, 51) * M(51, 76)
      temp = temp + M(76, 52) * M(52, 76)
      temp = temp + M(76, 54) * M(54, 76)
      temp = temp + M(76, 55) * M(55, 76)
      temp = temp + M(76, 57) * M(57, 76)
      temp = temp + M(76, 58) * M(58, 76)
      temp = temp + M(76, 59) * M(59, 76)
      temp = temp + M(76, 62) * M(62, 76)
      temp = temp + M(76, 64) * M(64, 76)
      temp = temp + M(76, 66) * M(66, 76)
      temp = temp + M(76, 68) * M(68, 76)
      temp = temp + M(76, 69) * M(69, 76)
      temp = temp + M(76, 70) * M(70, 76)
      temp = temp + M(76, 71) * M(71, 76)
      temp = temp + M(76, 72) * M(72, 76)
      temp = temp + M(76, 73) * M(73, 76)
      temp = temp + M(76, 75) * M(75, 76)
      M(76, 76) = M(76, 76) - temp
C     Lower part.
      temp = M(77, 33) * M(33, 76)
      temp = temp + M(77, 39) * M(39, 76)
      temp = temp + M(77, 40) * M(40, 76)
      temp = temp + M(77, 44) * M(44, 76)
      temp = temp + M(77, 46) * M(46, 76)
      temp = temp + M(77, 47) * M(47, 76)
      temp = temp + M(77, 48) * M(48, 76)
      temp = temp + M(77, 49) * M(49, 76)
      temp = temp + M(77, 50) * M(50, 76)
      temp = temp + M(77, 51) * M(51, 76)
      temp = temp + M(77, 52) * M(52, 76)
      temp = temp + M(77, 53) * M(53, 76)
      temp = temp + M(77, 54) * M(54, 76)
      temp = temp + M(77, 55) * M(55, 76)
      temp = temp + M(77, 56) * M(56, 76)
      temp = temp + M(77, 57) * M(57, 76)
      temp = temp + M(77, 58) * M(58, 76)
      temp = temp + M(77, 59) * M(59, 76)
      temp = temp + M(77, 61) * M(61, 76)
      temp = temp + M(77, 62) * M(62, 76)
      temp = temp + M(77, 64) * M(64, 76)
      temp = temp + M(77, 66) * M(66, 76)
      temp = temp + M(77, 67) * M(67, 76)
      temp = temp + M(77, 68) * M(68, 76)
      temp = temp + M(77, 69) * M(69, 76)
      temp = temp + M(77, 70) * M(70, 76)
      temp = temp + M(77, 71) * M(71, 76)
      temp = temp + M(77, 72) * M(72, 76)
      temp = temp + M(77, 73) * M(73, 76)
      temp = temp + M(77, 74) * M(74, 76)
      temp = temp + M(77, 75) * M(75, 76)
      M(77, 76) = M(77, 76) - temp
C     Lower part.
      temp = M(78, 33) * M(33, 76)
      temp = temp + M(78, 39) * M(39, 76)
      temp = temp + M(78, 40) * M(40, 76)
      temp = temp + M(78, 47) * M(47, 76)
      temp = temp + M(78, 48) * M(48, 76)
      temp = temp + M(78, 49) * M(49, 76)
      temp = temp + M(78, 50) * M(50, 76)
      temp = temp + M(78, 51) * M(51, 76)
      temp = temp + M(78, 52) * M(52, 76)
      temp = temp + M(78, 54) * M(54, 76)
      temp = temp + M(78, 55) * M(55, 76)
      temp = temp + M(78, 57) * M(57, 76)
      temp = temp + M(78, 58) * M(58, 76)
      temp = temp + M(78, 59) * M(59, 76)
      temp = temp + M(78, 62) * M(62, 76)
      temp = temp + M(78, 64) * M(64, 76)
      temp = temp + M(78, 68) * M(68, 76)
      temp = temp + M(78, 69) * M(69, 76)
      temp = temp + M(78, 70) * M(70, 76)
      temp = temp + M(78, 72) * M(72, 76)
      temp = temp + M(78, 73) * M(73, 76)
      temp = temp + M(78, 75) * M(75, 76)
      M(78, 76) = M(78, 76) - temp
C     Lower part.
      temp = M(79, 46) * M(46, 76)
      temp = temp + M(79, 52) * M(52, 76)
      temp = temp + M(79, 59) * M(59, 76)
      temp = temp + M(79, 73) * M(73, 76)
      temp = temp + M(79, 75) * M(75, 76)
      M(79, 76) = M(79, 76) - temp
C     Lower part.
      temp = M(80, 33) * M(33, 76)
      temp = temp + M(80, 39) * M(39, 76)
      temp = temp + M(80, 40) * M(40, 76)
      temp = temp + M(80, 44) * M(44, 76)
      temp = temp + M(80, 46) * M(46, 76)
      temp = temp + M(80, 47) * M(47, 76)
      temp = temp + M(80, 48) * M(48, 76)
      temp = temp + M(80, 49) * M(49, 76)
      temp = temp + M(80, 50) * M(50, 76)
      temp = temp + M(80, 51) * M(51, 76)
      temp = temp + M(80, 52) * M(52, 76)
      temp = temp + M(80, 54) * M(54, 76)
      temp = temp + M(80, 55) * M(55, 76)
      temp = temp + M(80, 57) * M(57, 76)
      temp = temp + M(80, 58) * M(58, 76)
      temp = temp + M(80, 59) * M(59, 76)
      temp = temp + M(80, 62) * M(62, 76)
      temp = temp + M(80, 64) * M(64, 76)
      temp = temp + M(80, 67) * M(67, 76)
      temp = temp + M(80, 68) * M(68, 76)
      temp = temp + M(80, 69) * M(69, 76)
      temp = temp + M(80, 70) * M(70, 76)
      temp = temp + M(80, 71) * M(71, 76)
      temp = temp + M(80, 72) * M(72, 76)
      temp = temp + M(80, 73) * M(73, 76)
      temp = temp + M(80, 74) * M(74, 76)
      temp = temp + M(80, 75) * M(75, 76)
      M(80, 76) = M(80, 76) - temp
C     Lower part.
      temp = M(81, 33) * M(33, 76)
      temp = temp + M(81, 35) * M(35, 76)
      temp = temp + M(81, 39) * M(39, 76)
      temp = temp + M(81, 40) * M(40, 76)
      temp = temp + M(81, 46) * M(46, 76)
      temp = temp + M(81, 47) * M(47, 76)
      temp = temp + M(81, 48) * M(48, 76)
      temp = temp + M(81, 49) * M(49, 76)
      temp = temp + M(81, 50) * M(50, 76)
      temp = temp + M(81, 51) * M(51, 76)
      temp = temp + M(81, 52) * M(52, 76)
      temp = temp + M(81, 53) * M(53, 76)
      temp = temp + M(81, 54) * M(54, 76)
      temp = temp + M(81, 55) * M(55, 76)
      temp = temp + M(81, 56) * M(56, 76)
      temp = temp + M(81, 57) * M(57, 76)
      temp = temp + M(81, 58) * M(58, 76)
      temp = temp + M(81, 59) * M(59, 76)
      temp = temp + M(81, 60) * M(60, 76)
      temp = temp + M(81, 61) * M(61, 76)
      temp = temp + M(81, 62) * M(62, 76)
      temp = temp + M(81, 64) * M(64, 76)
      temp = temp + M(81, 65) * M(65, 76)
      temp = temp + M(81, 66) * M(66, 76)
      temp = temp + M(81, 68) * M(68, 76)
      temp = temp + M(81, 69) * M(69, 76)
      temp = temp + M(81, 70) * M(70, 76)
      temp = temp + M(81, 71) * M(71, 76)
      temp = temp + M(81, 72) * M(72, 76)
      temp = temp + M(81, 73) * M(73, 76)
      temp = temp + M(81, 74) * M(74, 76)
      temp = temp + M(81, 75) * M(75, 76)
      M(81, 76) = M(81, 76) - temp
C     Lower part.
      temp = M(82, 39) * M(39, 76)
      temp = temp + M(82, 40) * M(40, 76)
      temp = temp + M(82, 47) * M(47, 76)
      temp = temp + M(82, 48) * M(48, 76)
      temp = temp + M(82, 49) * M(49, 76)
      temp = temp + M(82, 51) * M(51, 76)
      temp = temp + M(82, 52) * M(52, 76)
      temp = temp + M(82, 55) * M(55, 76)
      temp = temp + M(82, 57) * M(57, 76)
      temp = temp + M(82, 58) * M(58, 76)
      temp = temp + M(82, 59) * M(59, 76)
      temp = temp + M(82, 68) * M(68, 76)
      temp = temp + M(82, 69) * M(69, 76)
      temp = temp + M(82, 70) * M(70, 76)
      temp = temp + M(82, 72) * M(72, 76)
      temp = temp + M(82, 73) * M(73, 76)
      temp = temp + M(82, 75) * M(75, 76)
      M(82, 76) = M(82, 76) - temp
C     Upper part.
      temp = M(76, 21) * M(21, 77)
      temp = temp + M(76, 28) * M(28, 77)
      temp = temp + M(76, 33) * M(33, 77)
      temp = temp + M(76, 34) * M(34, 77)
      temp = temp + M(76, 37) * M(37, 77)
      temp = temp + M(76, 39) * M(39, 77)
      temp = temp + M(76, 40) * M(40, 77)
      temp = temp + M(76, 42) * M(42, 77)
      temp = temp + M(76, 44) * M(44, 77)
      temp = temp + M(76, 46) * M(46, 77)
      temp = temp + M(76, 47) * M(47, 77)
      temp = temp + M(76, 48) * M(48, 77)
      temp = temp + M(76, 49) * M(49, 77)
      temp = temp + M(76, 50) * M(50, 77)
      temp = temp + M(76, 51) * M(51, 77)
      temp = temp + M(76, 52) * M(52, 77)
      temp = temp + M(76, 54) * M(54, 77)
      temp = temp + M(76, 55) * M(55, 77)
      temp = temp + M(76, 57) * M(57, 77)
      temp = temp + M(76, 58) * M(58, 77)
      temp = temp + M(76, 59) * M(59, 77)
      temp = temp + M(76, 62) * M(62, 77)
      temp = temp + M(76, 64) * M(64, 77)
      temp = temp + M(76, 66) * M(66, 77)
      temp = temp + M(76, 68) * M(68, 77)
      temp = temp + M(76, 69) * M(69, 77)
      temp = temp + M(76, 70) * M(70, 77)
      temp = temp + M(76, 71) * M(71, 77)
      temp = temp + M(76, 72) * M(72, 77)
      temp = temp + M(76, 73) * M(73, 77)
      temp = temp + M(76, 75) * M(75, 77)
      M(76, 77) = ( M(76, 77) - temp ) / M(76, 76)
C     Upper part.
      temp = M(76, 33) * M(33, 78)
      temp = temp + M(76, 34) * M(34, 78)
      temp = temp + M(76, 39) * M(39, 78)
      temp = temp + M(76, 40) * M(40, 78)
      temp = temp + M(76, 46) * M(46, 78)
      temp = temp + M(76, 47) * M(47, 78)
      temp = temp + M(76, 48) * M(48, 78)
      temp = temp + M(76, 49) * M(49, 78)
      temp = temp + M(76, 50) * M(50, 78)
      temp = temp + M(76, 51) * M(51, 78)
      temp = temp + M(76, 52) * M(52, 78)
      temp = temp + M(76, 54) * M(54, 78)
      temp = temp + M(76, 55) * M(55, 78)
      temp = temp + M(76, 57) * M(57, 78)
      temp = temp + M(76, 58) * M(58, 78)
      temp = temp + M(76, 59) * M(59, 78)
      temp = temp + M(76, 62) * M(62, 78)
      temp = temp + M(76, 64) * M(64, 78)
      temp = temp + M(76, 66) * M(66, 78)
      temp = temp + M(76, 68) * M(68, 78)
      temp = temp + M(76, 69) * M(69, 78)
      temp = temp + M(76, 70) * M(70, 78)
      temp = temp + M(76, 71) * M(71, 78)
      temp = temp + M(76, 72) * M(72, 78)
      temp = temp + M(76, 73) * M(73, 78)
      temp = temp + M(76, 75) * M(75, 78)
      M(76, 78) = ( M(76, 78) - temp ) / M(76, 76)
C     Upper part.
      temp = M(76, 42) * M(42, 79)
      temp = temp + M(76, 44) * M(44, 79)
      temp = temp + M(76, 59) * M(59, 79)
      temp = temp + M(76, 62) * M(62, 79)
      temp = temp + M(76, 64) * M(64, 79)
      temp = temp + M(76, 66) * M(66, 79)
      temp = temp + M(76, 68) * M(68, 79)
      temp = temp + M(76, 69) * M(69, 79)
      temp = temp + M(76, 70) * M(70, 79)
      temp = temp + M(76, 71) * M(71, 79)
      temp = temp + M(76, 72) * M(72, 79)
      temp = temp + M(76, 73) * M(73, 79)
      temp = temp + M(76, 75) * M(75, 79)
      M(76, 79) = ( M(76, 79) - temp ) / M(76, 76)
C     Upper part.
      temp = M(76, 33) * M(33, 80)
      temp = temp + M(76, 34) * M(34, 80)
      temp = temp + M(76, 37) * M(37, 80)
      temp = temp + M(76, 39) * M(39, 80)
      temp = temp + M(76, 40) * M(40, 80)
      temp = temp + M(76, 42) * M(42, 80)
      temp = temp + M(76, 44) * M(44, 80)
      temp = temp + M(76, 46) * M(46, 80)
      temp = temp + M(76, 51) * M(51, 80)
      temp = temp + M(76, 52) * M(52, 80)
      temp = temp + M(76, 54) * M(54, 80)
      temp = temp + M(76, 57) * M(57, 80)
      temp = temp + M(76, 58) * M(58, 80)
      temp = temp + M(76, 59) * M(59, 80)
      temp = temp + M(76, 62) * M(62, 80)
      temp = temp + M(76, 64) * M(64, 80)
      temp = temp + M(76, 66) * M(66, 80)
      temp = temp + M(76, 68) * M(68, 80)
      temp = temp + M(76, 69) * M(69, 80)
      temp = temp + M(76, 70) * M(70, 80)
      temp = temp + M(76, 71) * M(71, 80)
      temp = temp + M(76, 72) * M(72, 80)
      temp = temp + M(76, 73) * M(73, 80)
      temp = temp + M(76, 75) * M(75, 80)
      M(76, 80) = ( M(76, 80) - temp ) / M(76, 76)
C     Upper part.
      temp = M(76, 33) * M(33, 81)
      temp = temp + M(76, 35) * M(35, 81)
      temp = temp + M(76, 37) * M(37, 81)
      temp = temp + M(76, 39) * M(39, 81)
      temp = temp + M(76, 40) * M(40, 81)
      temp = temp + M(76, 46) * M(46, 81)
      temp = temp + M(76, 47) * M(47, 81)
      temp = temp + M(76, 48) * M(48, 81)
      temp = temp + M(76, 49) * M(49, 81)
      temp = temp + M(76, 50) * M(50, 81)
      temp = temp + M(76, 51) * M(51, 81)
      temp = temp + M(76, 52) * M(52, 81)
      temp = temp + M(76, 54) * M(54, 81)
      temp = temp + M(76, 55) * M(55, 81)
      temp = temp + M(76, 57) * M(57, 81)
      temp = temp + M(76, 58) * M(58, 81)
      temp = temp + M(76, 59) * M(59, 81)
      temp = temp + M(76, 62) * M(62, 81)
      temp = temp + M(76, 64) * M(64, 81)
      temp = temp + M(76, 66) * M(66, 81)
      temp = temp + M(76, 68) * M(68, 81)
      temp = temp + M(76, 69) * M(69, 81)
      temp = temp + M(76, 70) * M(70, 81)
      temp = temp + M(76, 71) * M(71, 81)
      temp = temp + M(76, 72) * M(72, 81)
      temp = temp + M(76, 73) * M(73, 81)
      temp = temp + M(76, 75) * M(75, 81)
      M(76, 81) = ( M(76, 81) - temp ) / M(76, 76)
C     Upper part.
      temp = M(76, 68) * M(68, 82)
      temp = temp + M(76, 69) * M(69, 82)
      temp = temp + M(76, 70) * M(70, 82)
      temp = temp + M(76, 71) * M(71, 82)
      temp = temp + M(76, 72) * M(72, 82)
      temp = temp + M(76, 73) * M(73, 82)
      temp = temp + M(76, 75) * M(75, 82)
      M(76, 82) = ( M(76, 82) - temp ) / M(76, 76)

C     Lower part.
      temp = M(77, 13) * M(13, 77)
      temp = temp + M(77, 14) * M(14, 77)
      temp = temp + M(77, 21) * M(21, 77)
      temp = temp + M(77, 26) * M(26, 77)
      temp = temp + M(77, 27) * M(27, 77)
      temp = temp + M(77, 28) * M(28, 77)
      temp = temp + M(77, 33) * M(33, 77)
      temp = temp + M(77, 34) * M(34, 77)
      temp = temp + M(77, 37) * M(37, 77)
      temp = temp + M(77, 39) * M(39, 77)
      temp = temp + M(77, 40) * M(40, 77)
      temp = temp + M(77, 42) * M(42, 77)
      temp = temp + M(77, 44) * M(44, 77)
      temp = temp + M(77, 46) * M(46, 77)
      temp = temp + M(77, 47) * M(47, 77)
      temp = temp + M(77, 48) * M(48, 77)
      temp = temp + M(77, 49) * M(49, 77)
      temp = temp + M(77, 50) * M(50, 77)
      temp = temp + M(77, 51) * M(51, 77)
      temp = temp + M(77, 52) * M(52, 77)
      temp = temp + M(77, 53) * M(53, 77)
      temp = temp + M(77, 54) * M(54, 77)
      temp = temp + M(77, 55) * M(55, 77)
      temp = temp + M(77, 56) * M(56, 77)
      temp = temp + M(77, 57) * M(57, 77)
      temp = temp + M(77, 58) * M(58, 77)
      temp = temp + M(77, 59) * M(59, 77)
      temp = temp + M(77, 61) * M(61, 77)
      temp = temp + M(77, 62) * M(62, 77)
      temp = temp + M(77, 64) * M(64, 77)
      temp = temp + M(77, 66) * M(66, 77)
      temp = temp + M(77, 67) * M(67, 77)
      temp = temp + M(77, 68) * M(68, 77)
      temp = temp + M(77, 69) * M(69, 77)
      temp = temp + M(77, 70) * M(70, 77)
      temp = temp + M(77, 71) * M(71, 77)
      temp = temp + M(77, 72) * M(72, 77)
      temp = temp + M(77, 73) * M(73, 77)
      temp = temp + M(77, 74) * M(74, 77)
      temp = temp + M(77, 75) * M(75, 77)
      temp = temp + M(77, 76) * M(76, 77)
      M(77, 77) = M(77, 77) - temp
C     Lower part.
      temp = M(78, 33) * M(33, 77)
      temp = temp + M(78, 34) * M(34, 77)
      temp = temp + M(78, 37) * M(37, 77)
      temp = temp + M(78, 39) * M(39, 77)
      temp = temp + M(78, 40) * M(40, 77)
      temp = temp + M(78, 47) * M(47, 77)
      temp = temp + M(78, 48) * M(48, 77)
      temp = temp + M(78, 49) * M(49, 77)
      temp = temp + M(78, 50) * M(50, 77)
      temp = temp + M(78, 51) * M(51, 77)
      temp = temp + M(78, 52) * M(52, 77)
      temp = temp + M(78, 54) * M(54, 77)
      temp = temp + M(78, 55) * M(55, 77)
      temp = temp + M(78, 57) * M(57, 77)
      temp = temp + M(78, 58) * M(58, 77)
      temp = temp + M(78, 59) * M(59, 77)
      temp = temp + M(78, 62) * M(62, 77)
      temp = temp + M(78, 64) * M(64, 77)
      temp = temp + M(78, 68) * M(68, 77)
      temp = temp + M(78, 69) * M(69, 77)
      temp = temp + M(78, 70) * M(70, 77)
      temp = temp + M(78, 72) * M(72, 77)
      temp = temp + M(78, 73) * M(73, 77)
      temp = temp + M(78, 75) * M(75, 77)
      temp = temp + M(78, 76) * M(76, 77)
      M(78, 77) = M(78, 77) - temp
C     Lower part.
      temp = M(79, 42) * M(42, 77)
      temp = temp + M(79, 46) * M(46, 77)
      temp = temp + M(79, 52) * M(52, 77)
      temp = temp + M(79, 59) * M(59, 77)
      temp = temp + M(79, 73) * M(73, 77)
      temp = temp + M(79, 75) * M(75, 77)
      temp = temp + M(79, 76) * M(76, 77)
      M(79, 77) = M(79, 77) - temp
C     Lower part.
      temp = M(80, 13) * M(13, 77)
      temp = temp + M(80, 33) * M(33, 77)
      temp = temp + M(80, 34) * M(34, 77)
      temp = temp + M(80, 36) * M(36, 77)
      temp = temp + M(80, 37) * M(37, 77)
      temp = temp + M(80, 39) * M(39, 77)
      temp = temp + M(80, 40) * M(40, 77)
      temp = temp + M(80, 42) * M(42, 77)
      temp = temp + M(80, 44) * M(44, 77)
      temp = temp + M(80, 46) * M(46, 77)
      temp = temp + M(80, 47) * M(47, 77)
      temp = temp + M(80, 48) * M(48, 77)
      temp = temp + M(80, 49) * M(49, 77)
      temp = temp + M(80, 50) * M(50, 77)
      temp = temp + M(80, 51) * M(51, 77)
      temp = temp + M(80, 52) * M(52, 77)
      temp = temp + M(80, 54) * M(54, 77)
      temp = temp + M(80, 55) * M(55, 77)
      temp = temp + M(80, 57) * M(57, 77)
      temp = temp + M(80, 58) * M(58, 77)
      temp = temp + M(80, 59) * M(59, 77)
      temp = temp + M(80, 62) * M(62, 77)
      temp = temp + M(80, 64) * M(64, 77)
      temp = temp + M(80, 67) * M(67, 77)
      temp = temp + M(80, 68) * M(68, 77)
      temp = temp + M(80, 69) * M(69, 77)
      temp = temp + M(80, 70) * M(70, 77)
      temp = temp + M(80, 71) * M(71, 77)
      temp = temp + M(80, 72) * M(72, 77)
      temp = temp + M(80, 73) * M(73, 77)
      temp = temp + M(80, 74) * M(74, 77)
      temp = temp + M(80, 75) * M(75, 77)
      temp = temp + M(80, 76) * M(76, 77)
      M(80, 77) = M(80, 77) - temp
C     Lower part.
      temp = M(81, 14) * M(14, 77)
      temp = temp + M(81, 21) * M(21, 77)
      temp = temp + M(81, 26) * M(26, 77)
      temp = temp + M(81, 27) * M(27, 77)
      temp = temp + M(81, 28) * M(28, 77)
      temp = temp + M(81, 33) * M(33, 77)
      temp = temp + M(81, 34) * M(34, 77)
      temp = temp + M(81, 36) * M(36, 77)
      temp = temp + M(81, 37) * M(37, 77)
      temp = temp + M(81, 39) * M(39, 77)
      temp = temp + M(81, 40) * M(40, 77)
      temp = temp + M(81, 42) * M(42, 77)
      temp = temp + M(81, 45) * M(45, 77)
      temp = temp + M(81, 46) * M(46, 77)
      temp = temp + M(81, 47) * M(47, 77)
      temp = temp + M(81, 48) * M(48, 77)
      temp = temp + M(81, 49) * M(49, 77)
      temp = temp + M(81, 50) * M(50, 77)
      temp = temp + M(81, 51) * M(51, 77)
      temp = temp + M(81, 52) * M(52, 77)
      temp = temp + M(81, 53) * M(53, 77)
      temp = temp + M(81, 54) * M(54, 77)
      temp = temp + M(81, 55) * M(55, 77)
      temp = temp + M(81, 56) * M(56, 77)
      temp = temp + M(81, 57) * M(57, 77)
      temp = temp + M(81, 58) * M(58, 77)
      temp = temp + M(81, 59) * M(59, 77)
      temp = temp + M(81, 60) * M(60, 77)
      temp = temp + M(81, 61) * M(61, 77)
      temp = temp + M(81, 62) * M(62, 77)
      temp = temp + M(81, 64) * M(64, 77)
      temp = temp + M(81, 65) * M(65, 77)
      temp = temp + M(81, 66) * M(66, 77)
      temp = temp + M(81, 68) * M(68, 77)
      temp = temp + M(81, 69) * M(69, 77)
      temp = temp + M(81, 70) * M(70, 77)
      temp = temp + M(81, 71) * M(71, 77)
      temp = temp + M(81, 72) * M(72, 77)
      temp = temp + M(81, 73) * M(73, 77)
      temp = temp + M(81, 74) * M(74, 77)
      temp = temp + M(81, 75) * M(75, 77)
      temp = temp + M(81, 76) * M(76, 77)
      M(81, 77) = M(81, 77) - temp
C     Lower part.
      temp = M(82, 36) * M(36, 77)
      temp = temp + M(82, 37) * M(37, 77)
      temp = temp + M(82, 39) * M(39, 77)
      temp = temp + M(82, 40) * M(40, 77)
      temp = temp + M(82, 42) * M(42, 77)
      temp = temp + M(82, 47) * M(47, 77)
      temp = temp + M(82, 48) * M(48, 77)
      temp = temp + M(82, 49) * M(49, 77)
      temp = temp + M(82, 51) * M(51, 77)
      temp = temp + M(82, 52) * M(52, 77)
      temp = temp + M(82, 55) * M(55, 77)
      temp = temp + M(82, 57) * M(57, 77)
      temp = temp + M(82, 58) * M(58, 77)
      temp = temp + M(82, 59) * M(59, 77)
      temp = temp + M(82, 68) * M(68, 77)
      temp = temp + M(82, 69) * M(69, 77)
      temp = temp + M(82, 70) * M(70, 77)
      temp = temp + M(82, 72) * M(72, 77)
      temp = temp + M(82, 73) * M(73, 77)
      temp = temp + M(82, 75) * M(75, 77)
      temp = temp + M(82, 76) * M(76, 77)
      M(82, 77) = M(82, 77) - temp
C     Upper part.
      temp = M(77, 33) * M(33, 78)
      temp = temp + M(77, 34) * M(34, 78)
      temp = temp + M(77, 39) * M(39, 78)
      temp = temp + M(77, 40) * M(40, 78)
      temp = temp + M(77, 46) * M(46, 78)
      temp = temp + M(77, 47) * M(47, 78)
      temp = temp + M(77, 48) * M(48, 78)
      temp = temp + M(77, 49) * M(49, 78)
      temp = temp + M(77, 50) * M(50, 78)
      temp = temp + M(77, 51) * M(51, 78)
      temp = temp + M(77, 52) * M(52, 78)
      temp = temp + M(77, 53) * M(53, 78)
      temp = temp + M(77, 54) * M(54, 78)
      temp = temp + M(77, 55) * M(55, 78)
      temp = temp + M(77, 56) * M(56, 78)
      temp = temp + M(77, 57) * M(57, 78)
      temp = temp + M(77, 58) * M(58, 78)
      temp = temp + M(77, 59) * M(59, 78)
      temp = temp + M(77, 61) * M(61, 78)
      temp = temp + M(77, 62) * M(62, 78)
      temp = temp + M(77, 64) * M(64, 78)
      temp = temp + M(77, 66) * M(66, 78)
      temp = temp + M(77, 67) * M(67, 78)
      temp = temp + M(77, 68) * M(68, 78)
      temp = temp + M(77, 69) * M(69, 78)
      temp = temp + M(77, 70) * M(70, 78)
      temp = temp + M(77, 71) * M(71, 78)
      temp = temp + M(77, 72) * M(72, 78)
      temp = temp + M(77, 73) * M(73, 78)
      temp = temp + M(77, 74) * M(74, 78)
      temp = temp + M(77, 75) * M(75, 78)
      temp = temp + M(77, 76) * M(76, 78)
      M(77, 78) = ( M(77, 78) - temp ) / M(77, 77)
C     Upper part.
      temp = M(77, 42) * M(42, 79)
      temp = temp + M(77, 44) * M(44, 79)
      temp = temp + M(77, 59) * M(59, 79)
      temp = temp + M(77, 61) * M(61, 79)
      temp = temp + M(77, 62) * M(62, 79)
      temp = temp + M(77, 64) * M(64, 79)
      temp = temp + M(77, 66) * M(66, 79)
      temp = temp + M(77, 67) * M(67, 79)
      temp = temp + M(77, 68) * M(68, 79)
      temp = temp + M(77, 69) * M(69, 79)
      temp = temp + M(77, 70) * M(70, 79)
      temp = temp + M(77, 71) * M(71, 79)
      temp = temp + M(77, 72) * M(72, 79)
      temp = temp + M(77, 73) * M(73, 79)
      temp = temp + M(77, 74) * M(74, 79)
      temp = temp + M(77, 75) * M(75, 79)
      temp = temp + M(77, 76) * M(76, 79)
      M(77, 79) = ( M(77, 79) - temp ) / M(77, 77)
C     Upper part.
      temp = M(77, 13) * M(13, 80)
      temp = temp + M(77, 24) * M(24, 80)
      temp = temp + M(77, 33) * M(33, 80)
      temp = temp + M(77, 34) * M(34, 80)
      temp = temp + M(77, 37) * M(37, 80)
      temp = temp + M(77, 39) * M(39, 80)
      temp = temp + M(77, 40) * M(40, 80)
      temp = temp + M(77, 42) * M(42, 80)
      temp = temp + M(77, 44) * M(44, 80)
      temp = temp + M(77, 46) * M(46, 80)
      temp = temp + M(77, 51) * M(51, 80)
      temp = temp + M(77, 52) * M(52, 80)
      temp = temp + M(77, 53) * M(53, 80)
      temp = temp + M(77, 54) * M(54, 80)
      temp = temp + M(77, 56) * M(56, 80)
      temp = temp + M(77, 57) * M(57, 80)
      temp = temp + M(77, 58) * M(58, 80)
      temp = temp + M(77, 59) * M(59, 80)
      temp = temp + M(77, 61) * M(61, 80)
      temp = temp + M(77, 62) * M(62, 80)
      temp = temp + M(77, 64) * M(64, 80)
      temp = temp + M(77, 66) * M(66, 80)
      temp = temp + M(77, 67) * M(67, 80)
      temp = temp + M(77, 68) * M(68, 80)
      temp = temp + M(77, 69) * M(69, 80)
      temp = temp + M(77, 70) * M(70, 80)
      temp = temp + M(77, 71) * M(71, 80)
      temp = temp + M(77, 72) * M(72, 80)
      temp = temp + M(77, 73) * M(73, 80)
      temp = temp + M(77, 74) * M(74, 80)
      temp = temp + M(77, 75) * M(75, 80)
      temp = temp + M(77, 76) * M(76, 80)
      M(77, 80) = ( M(77, 80) - temp ) / M(77, 77)
C     Upper part.
      temp = M(77, 24) * M(24, 81)
      temp = temp + M(77, 33) * M(33, 81)
      temp = temp + M(77, 37) * M(37, 81)
      temp = temp + M(77, 39) * M(39, 81)
      temp = temp + M(77, 40) * M(40, 81)
      temp = temp + M(77, 46) * M(46, 81)
      temp = temp + M(77, 47) * M(47, 81)
      temp = temp + M(77, 48) * M(48, 81)
      temp = temp + M(77, 49) * M(49, 81)
      temp = temp + M(77, 50) * M(50, 81)
      temp = temp + M(77, 51) * M(51, 81)
      temp = temp + M(77, 52) * M(52, 81)
      temp = temp + M(77, 53) * M(53, 81)
      temp = temp + M(77, 54) * M(54, 81)
      temp = temp + M(77, 55) * M(55, 81)
      temp = temp + M(77, 56) * M(56, 81)
      temp = temp + M(77, 57) * M(57, 81)
      temp = temp + M(77, 58) * M(58, 81)
      temp = temp + M(77, 59) * M(59, 81)
      temp = temp + M(77, 61) * M(61, 81)
      temp = temp + M(77, 62) * M(62, 81)
      temp = temp + M(77, 64) * M(64, 81)
      temp = temp + M(77, 66) * M(66, 81)
      temp = temp + M(77, 67) * M(67, 81)
      temp = temp + M(77, 68) * M(68, 81)
      temp = temp + M(77, 69) * M(69, 81)
      temp = temp + M(77, 70) * M(70, 81)
      temp = temp + M(77, 71) * M(71, 81)
      temp = temp + M(77, 72) * M(72, 81)
      temp = temp + M(77, 73) * M(73, 81)
      temp = temp + M(77, 74) * M(74, 81)
      temp = temp + M(77, 75) * M(75, 81)
      temp = temp + M(77, 76) * M(76, 81)
      M(77, 81) = ( M(77, 81) - temp ) / M(77, 77)
C     Upper part.
      temp = M(77, 68) * M(68, 82)
      temp = temp + M(77, 69) * M(69, 82)
      temp = temp + M(77, 70) * M(70, 82)
      temp = temp + M(77, 71) * M(71, 82)
      temp = temp + M(77, 72) * M(72, 82)
      temp = temp + M(77, 73) * M(73, 82)
      temp = temp + M(77, 74) * M(74, 82)
      temp = temp + M(77, 75) * M(75, 82)
      temp = temp + M(77, 76) * M(76, 82)
      M(77, 82) = ( M(77, 82) - temp ) / M(77, 77)

C     Lower part.
      temp = M(78, 32) * M(32, 78)
      temp = temp + M(78, 33) * M(33, 78)
      temp = temp + M(78, 34) * M(34, 78)
      temp = temp + M(78, 39) * M(39, 78)
      temp = temp + M(78, 40) * M(40, 78)
      temp = temp + M(78, 47) * M(47, 78)
      temp = temp + M(78, 48) * M(48, 78)
      temp = temp + M(78, 49) * M(49, 78)
      temp = temp + M(78, 50) * M(50, 78)
      temp = temp + M(78, 51) * M(51, 78)
      temp = temp + M(78, 52) * M(52, 78)
      temp = temp + M(78, 54) * M(54, 78)
      temp = temp + M(78, 55) * M(55, 78)
      temp = temp + M(78, 57) * M(57, 78)
      temp = temp + M(78, 58) * M(58, 78)
      temp = temp + M(78, 59) * M(59, 78)
      temp = temp + M(78, 62) * M(62, 78)
      temp = temp + M(78, 64) * M(64, 78)
      temp = temp + M(78, 68) * M(68, 78)
      temp = temp + M(78, 69) * M(69, 78)
      temp = temp + M(78, 70) * M(70, 78)
      temp = temp + M(78, 72) * M(72, 78)
      temp = temp + M(78, 73) * M(73, 78)
      temp = temp + M(78, 75) * M(75, 78)
      temp = temp + M(78, 76) * M(76, 78)
      temp = temp + M(78, 77) * M(77, 78)
      M(78, 78) = M(78, 78) - temp
C     Lower part.
      temp = M(79, 46) * M(46, 78)
      temp = temp + M(79, 52) * M(52, 78)
      temp = temp + M(79, 59) * M(59, 78)
      temp = temp + M(79, 73) * M(73, 78)
      temp = temp + M(79, 75) * M(75, 78)
      temp = temp + M(79, 76) * M(76, 78)
      temp = temp + M(79, 77) * M(77, 78)
      M(79, 78) = M(79, 78) - temp
C     Lower part.
      temp = M(80, 32) * M(32, 78)
      temp = temp + M(80, 33) * M(33, 78)
      temp = temp + M(80, 34) * M(34, 78)
      temp = temp + M(80, 39) * M(39, 78)
      temp = temp + M(80, 40) * M(40, 78)
      temp = temp + M(80, 46) * M(46, 78)
      temp = temp + M(80, 47) * M(47, 78)
      temp = temp + M(80, 48) * M(48, 78)
      temp = temp + M(80, 49) * M(49, 78)
      temp = temp + M(80, 50) * M(50, 78)
      temp = temp + M(80, 51) * M(51, 78)
      temp = temp + M(80, 52) * M(52, 78)
      temp = temp + M(80, 54) * M(54, 78)
      temp = temp + M(80, 55) * M(55, 78)
      temp = temp + M(80, 57) * M(57, 78)
      temp = temp + M(80, 58) * M(58, 78)
      temp = temp + M(80, 59) * M(59, 78)
      temp = temp + M(80, 62) * M(62, 78)
      temp = temp + M(80, 64) * M(64, 78)
      temp = temp + M(80, 67) * M(67, 78)
      temp = temp + M(80, 68) * M(68, 78)
      temp = temp + M(80, 69) * M(69, 78)
      temp = temp + M(80, 70) * M(70, 78)
      temp = temp + M(80, 71) * M(71, 78)
      temp = temp + M(80, 72) * M(72, 78)
      temp = temp + M(80, 73) * M(73, 78)
      temp = temp + M(80, 74) * M(74, 78)
      temp = temp + M(80, 75) * M(75, 78)
      temp = temp + M(80, 76) * M(76, 78)
      temp = temp + M(80, 77) * M(77, 78)
      M(80, 78) = M(80, 78) - temp
C     Lower part.
      temp = M(81, 33) * M(33, 78)
      temp = temp + M(81, 34) * M(34, 78)
      temp = temp + M(81, 39) * M(39, 78)
      temp = temp + M(81, 40) * M(40, 78)
      temp = temp + M(81, 45) * M(45, 78)
      temp = temp + M(81, 46) * M(46, 78)
      temp = temp + M(81, 47) * M(47, 78)
      temp = temp + M(81, 48) * M(48, 78)
      temp = temp + M(81, 49) * M(49, 78)
      temp = temp + M(81, 50) * M(50, 78)
      temp = temp + M(81, 51) * M(51, 78)
      temp = temp + M(81, 52) * M(52, 78)
      temp = temp + M(81, 53) * M(53, 78)
      temp = temp + M(81, 54) * M(54, 78)
      temp = temp + M(81, 55) * M(55, 78)
      temp = temp + M(81, 56) * M(56, 78)
      temp = temp + M(81, 57) * M(57, 78)
      temp = temp + M(81, 58) * M(58, 78)
      temp = temp + M(81, 59) * M(59, 78)
      temp = temp + M(81, 60) * M(60, 78)
      temp = temp + M(81, 61) * M(61, 78)
      temp = temp + M(81, 62) * M(62, 78)
      temp = temp + M(81, 64) * M(64, 78)
      temp = temp + M(81, 65) * M(65, 78)
      temp = temp + M(81, 66) * M(66, 78)
      temp = temp + M(81, 68) * M(68, 78)
      temp = temp + M(81, 69) * M(69, 78)
      temp = temp + M(81, 70) * M(70, 78)
      temp = temp + M(81, 71) * M(71, 78)
      temp = temp + M(81, 72) * M(72, 78)
      temp = temp + M(81, 73) * M(73, 78)
      temp = temp + M(81, 74) * M(74, 78)
      temp = temp + M(81, 75) * M(75, 78)
      temp = temp + M(81, 76) * M(76, 78)
      temp = temp + M(81, 77) * M(77, 78)
      M(81, 78) = M(81, 78) - temp
C     Lower part.
      temp = M(82, 39) * M(39, 78)
      temp = temp + M(82, 40) * M(40, 78)
      temp = temp + M(82, 47) * M(47, 78)
      temp = temp + M(82, 48) * M(48, 78)
      temp = temp + M(82, 49) * M(49, 78)
      temp = temp + M(82, 51) * M(51, 78)
      temp = temp + M(82, 52) * M(52, 78)
      temp = temp + M(82, 55) * M(55, 78)
      temp = temp + M(82, 57) * M(57, 78)
      temp = temp + M(82, 58) * M(58, 78)
      temp = temp + M(82, 59) * M(59, 78)
      temp = temp + M(82, 68) * M(68, 78)
      temp = temp + M(82, 69) * M(69, 78)
      temp = temp + M(82, 70) * M(70, 78)
      temp = temp + M(82, 72) * M(72, 78)
      temp = temp + M(82, 73) * M(73, 78)
      temp = temp + M(82, 75) * M(75, 78)
      temp = temp + M(82, 76) * M(76, 78)
      temp = temp + M(82, 77) * M(77, 78)
      M(82, 78) = M(82, 78) - temp
C     Upper part.
      temp = M(78, 59) * M(59, 79)
      temp = temp + M(78, 62) * M(62, 79)
      temp = temp + M(78, 64) * M(64, 79)
      temp = temp + M(78, 68) * M(68, 79)
      temp = temp + M(78, 69) * M(69, 79)
      temp = temp + M(78, 70) * M(70, 79)
      temp = temp + M(78, 72) * M(72, 79)
      temp = temp + M(78, 73) * M(73, 79)
      temp = temp + M(78, 75) * M(75, 79)
      temp = temp + M(78, 76) * M(76, 79)
      temp = temp + M(78, 77) * M(77, 79)
      M(78, 79) = ( M(78, 79) - temp ) / M(78, 78)
C     Upper part.
      temp = M(78, 32) * M(32, 80)
      temp = temp + M(78, 33) * M(33, 80)
      temp = temp + M(78, 34) * M(34, 80)
      temp = temp + M(78, 37) * M(37, 80)
      temp = temp + M(78, 39) * M(39, 80)
      temp = temp + M(78, 40) * M(40, 80)
      temp = temp + M(78, 51) * M(51, 80)
      temp = temp + M(78, 52) * M(52, 80)
      temp = temp + M(78, 54) * M(54, 80)
      temp = temp + M(78, 57) * M(57, 80)
      temp = temp + M(78, 58) * M(58, 80)
      temp = temp + M(78, 59) * M(59, 80)
      temp = temp + M(78, 62) * M(62, 80)
      temp = temp + M(78, 64) * M(64, 80)
      temp = temp + M(78, 68) * M(68, 80)
      temp = temp + M(78, 69) * M(69, 80)
      temp = temp + M(78, 70) * M(70, 80)
      temp = temp + M(78, 72) * M(72, 80)
      temp = temp + M(78, 73) * M(73, 80)
      temp = temp + M(78, 75) * M(75, 80)
      temp = temp + M(78, 76) * M(76, 80)
      temp = temp + M(78, 77) * M(77, 80)
      M(78, 80) = ( M(78, 80) - temp ) / M(78, 78)
C     Upper part.
      temp = M(78, 33) * M(33, 81)
      temp = temp + M(78, 37) * M(37, 81)
      temp = temp + M(78, 39) * M(39, 81)
      temp = temp + M(78, 40) * M(40, 81)
      temp = temp + M(78, 47) * M(47, 81)
      temp = temp + M(78, 48) * M(48, 81)
      temp = temp + M(78, 49) * M(49, 81)
      temp = temp + M(78, 50) * M(50, 81)
      temp = temp + M(78, 51) * M(51, 81)
      temp = temp + M(78, 52) * M(52, 81)
      temp = temp + M(78, 54) * M(54, 81)
      temp = temp + M(78, 55) * M(55, 81)
      temp = temp + M(78, 57) * M(57, 81)
      temp = temp + M(78, 58) * M(58, 81)
      temp = temp + M(78, 59) * M(59, 81)
      temp = temp + M(78, 62) * M(62, 81)
      temp = temp + M(78, 64) * M(64, 81)
      temp = temp + M(78, 68) * M(68, 81)
      temp = temp + M(78, 69) * M(69, 81)
      temp = temp + M(78, 70) * M(70, 81)
      temp = temp + M(78, 72) * M(72, 81)
      temp = temp + M(78, 73) * M(73, 81)
      temp = temp + M(78, 75) * M(75, 81)
      temp = temp + M(78, 76) * M(76, 81)
      temp = temp + M(78, 77) * M(77, 81)
      M(78, 81) = ( M(78, 81) - temp ) / M(78, 78)
C     Upper part.
      temp = M(78, 68) * M(68, 82)
      temp = temp + M(78, 69) * M(69, 82)
      temp = temp + M(78, 70) * M(70, 82)
      temp = temp + M(78, 72) * M(72, 82)
      temp = temp + M(78, 73) * M(73, 82)
      temp = temp + M(78, 75) * M(75, 82)
      temp = temp + M(78, 76) * M(76, 82)
      temp = temp + M(78, 77) * M(77, 82)
      M(78, 82) = ( M(78, 82) - temp ) / M(78, 78)

C     Lower part.
      temp = M(79, 42) * M(42, 79)
      temp = temp + M(79, 59) * M(59, 79)
      temp = temp + M(79, 73) * M(73, 79)
      temp = temp + M(79, 75) * M(75, 79)
      temp = temp + M(79, 76) * M(76, 79)
      temp = temp + M(79, 77) * M(77, 79)
      temp = temp + M(79, 78) * M(78, 79)
      M(79, 79) = M(79, 79) - temp
C     Lower part.
      temp = M(80, 42) * M(42, 79)
      temp = temp + M(80, 44) * M(44, 79)
      temp = temp + M(80, 59) * M(59, 79)
      temp = temp + M(80, 62) * M(62, 79)
      temp = temp + M(80, 64) * M(64, 79)
      temp = temp + M(80, 67) * M(67, 79)
      temp = temp + M(80, 68) * M(68, 79)
      temp = temp + M(80, 69) * M(69, 79)
      temp = temp + M(80, 70) * M(70, 79)
      temp = temp + M(80, 71) * M(71, 79)
      temp = temp + M(80, 72) * M(72, 79)
      temp = temp + M(80, 73) * M(73, 79)
      temp = temp + M(80, 74) * M(74, 79)
      temp = temp + M(80, 75) * M(75, 79)
      temp = temp + M(80, 76) * M(76, 79)
      temp = temp + M(80, 77) * M(77, 79)
      temp = temp + M(80, 78) * M(78, 79)
      M(80, 79) = M(80, 79) - temp
C     Lower part.
      temp = M(81, 42) * M(42, 79)
      temp = temp + M(81, 59) * M(59, 79)
      temp = temp + M(81, 60) * M(60, 79)
      temp = temp + M(81, 61) * M(61, 79)
      temp = temp + M(81, 62) * M(62, 79)
      temp = temp + M(81, 64) * M(64, 79)
      temp = temp + M(81, 65) * M(65, 79)
      temp = temp + M(81, 66) * M(66, 79)
      temp = temp + M(81, 68) * M(68, 79)
      temp = temp + M(81, 69) * M(69, 79)
      temp = temp + M(81, 70) * M(70, 79)
      temp = temp + M(81, 71) * M(71, 79)
      temp = temp + M(81, 72) * M(72, 79)
      temp = temp + M(81, 73) * M(73, 79)
      temp = temp + M(81, 74) * M(74, 79)
      temp = temp + M(81, 75) * M(75, 79)
      temp = temp + M(81, 76) * M(76, 79)
      temp = temp + M(81, 77) * M(77, 79)
      temp = temp + M(81, 78) * M(78, 79)
      M(81, 79) = M(81, 79) - temp
C     Lower part.
      temp = M(82, 42) * M(42, 79)
      temp = temp + M(82, 59) * M(59, 79)
      temp = temp + M(82, 68) * M(68, 79)
      temp = temp + M(82, 69) * M(69, 79)
      temp = temp + M(82, 70) * M(70, 79)
      temp = temp + M(82, 72) * M(72, 79)
      temp = temp + M(82, 73) * M(73, 79)
      temp = temp + M(82, 75) * M(75, 79)
      temp = temp + M(82, 76) * M(76, 79)
      temp = temp + M(82, 77) * M(77, 79)
      temp = temp + M(82, 78) * M(78, 79)
      M(82, 79) = M(82, 79) - temp
C     Upper part.
      temp = M(79, 42) * M(42, 80)
      temp = temp + M(79, 46) * M(46, 80)
      temp = temp + M(79, 52) * M(52, 80)
      temp = temp + M(79, 59) * M(59, 80)
      temp = temp + M(79, 73) * M(73, 80)
      temp = temp + M(79, 75) * M(75, 80)
      temp = temp + M(79, 76) * M(76, 80)
      temp = temp + M(79, 77) * M(77, 80)
      temp = temp + M(79, 78) * M(78, 80)
      M(79, 80) = ( M(79, 80) - temp ) / M(79, 79)
C     Upper part.
      temp = M(79, 46) * M(46, 81)
      temp = temp + M(79, 52) * M(52, 81)
      temp = temp + M(79, 59) * M(59, 81)
      temp = temp + M(79, 73) * M(73, 81)
      temp = temp + M(79, 75) * M(75, 81)
      temp = temp + M(79, 76) * M(76, 81)
      temp = temp + M(79, 77) * M(77, 81)
      temp = temp + M(79, 78) * M(78, 81)
      M(79, 81) = ( M(79, 81) - temp ) / M(79, 79)
C     Upper part.
      temp = M(79, 73) * M(73, 82)
      temp = temp + M(79, 75) * M(75, 82)
      temp = temp + M(79, 76) * M(76, 82)
      temp = temp + M(79, 77) * M(77, 82)
      temp = temp + M(79, 78) * M(78, 82)
      M(79, 82) = ( M(79, 82) - temp ) / M(79, 79)

C     Lower part.
      temp = M(80, 13) * M(13, 80)
      temp = temp + M(80, 17) * M(17, 80)
      temp = temp + M(80, 18) * M(18, 80)
      temp = temp + M(80, 24) * M(24, 80)
      temp = temp + M(80, 31) * M(31, 80)
      temp = temp + M(80, 32) * M(32, 80)
      temp = temp + M(80, 33) * M(33, 80)
      temp = temp + M(80, 34) * M(34, 80)
      temp = temp + M(80, 36) * M(36, 80)
      temp = temp + M(80, 37) * M(37, 80)
      temp = temp + M(80, 39) * M(39, 80)
      temp = temp + M(80, 40) * M(40, 80)
      temp = temp + M(80, 42) * M(42, 80)
      temp = temp + M(80, 44) * M(44, 80)
      temp = temp + M(80, 46) * M(46, 80)
      temp = temp + M(80, 51) * M(51, 80)
      temp = temp + M(80, 52) * M(52, 80)
      temp = temp + M(80, 54) * M(54, 80)
      temp = temp + M(80, 57) * M(57, 80)
      temp = temp + M(80, 58) * M(58, 80)
      temp = temp + M(80, 59) * M(59, 80)
      temp = temp + M(80, 62) * M(62, 80)
      temp = temp + M(80, 64) * M(64, 80)
      temp = temp + M(80, 67) * M(67, 80)
      temp = temp + M(80, 68) * M(68, 80)
      temp = temp + M(80, 69) * M(69, 80)
      temp = temp + M(80, 70) * M(70, 80)
      temp = temp + M(80, 71) * M(71, 80)
      temp = temp + M(80, 72) * M(72, 80)
      temp = temp + M(80, 73) * M(73, 80)
      temp = temp + M(80, 74) * M(74, 80)
      temp = temp + M(80, 75) * M(75, 80)
      temp = temp + M(80, 76) * M(76, 80)
      temp = temp + M(80, 77) * M(77, 80)
      temp = temp + M(80, 78) * M(78, 80)
      temp = temp + M(80, 79) * M(79, 80)
      M(80, 80) = M(80, 80) - temp
C     Lower part.
      temp = M(81, 17) * M(17, 80)
      temp = temp + M(81, 18) * M(18, 80)
      temp = temp + M(81, 24) * M(24, 80)
      temp = temp + M(81, 31) * M(31, 80)
      temp = temp + M(81, 33) * M(33, 80)
      temp = temp + M(81, 34) * M(34, 80)
      temp = temp + M(81, 36) * M(36, 80)
      temp = temp + M(81, 37) * M(37, 80)
      temp = temp + M(81, 39) * M(39, 80)
      temp = temp + M(81, 40) * M(40, 80)
      temp = temp + M(81, 42) * M(42, 80)
      temp = temp + M(81, 45) * M(45, 80)
      temp = temp + M(81, 46) * M(46, 80)
      temp = temp + M(81, 51) * M(51, 80)
      temp = temp + M(81, 52) * M(52, 80)
      temp = temp + M(81, 53) * M(53, 80)
      temp = temp + M(81, 54) * M(54, 80)
      temp = temp + M(81, 56) * M(56, 80)
      temp = temp + M(81, 57) * M(57, 80)
      temp = temp + M(81, 58) * M(58, 80)
      temp = temp + M(81, 59) * M(59, 80)
      temp = temp + M(81, 60) * M(60, 80)
      temp = temp + M(81, 61) * M(61, 80)
      temp = temp + M(81, 62) * M(62, 80)
      temp = temp + M(81, 64) * M(64, 80)
      temp = temp + M(81, 65) * M(65, 80)
      temp = temp + M(81, 66) * M(66, 80)
      temp = temp + M(81, 68) * M(68, 80)
      temp = temp + M(81, 69) * M(69, 80)
      temp = temp + M(81, 70) * M(70, 80)
      temp = temp + M(81, 71) * M(71, 80)
      temp = temp + M(81, 72) * M(72, 80)
      temp = temp + M(81, 73) * M(73, 80)
      temp = temp + M(81, 74) * M(74, 80)
      temp = temp + M(81, 75) * M(75, 80)
      temp = temp + M(81, 76) * M(76, 80)
      temp = temp + M(81, 77) * M(77, 80)
      temp = temp + M(81, 78) * M(78, 80)
      temp = temp + M(81, 79) * M(79, 80)
      M(81, 80) = M(81, 80) - temp
C     Lower part.
      temp = M(82, 36) * M(36, 80)
      temp = temp + M(82, 37) * M(37, 80)
      temp = temp + M(82, 39) * M(39, 80)
      temp = temp + M(82, 40) * M(40, 80)
      temp = temp + M(82, 42) * M(42, 80)
      temp = temp + M(82, 51) * M(51, 80)
      temp = temp + M(82, 52) * M(52, 80)
      temp = temp + M(82, 57) * M(57, 80)
      temp = temp + M(82, 58) * M(58, 80)
      temp = temp + M(82, 59) * M(59, 80)
      temp = temp + M(82, 68) * M(68, 80)
      temp = temp + M(82, 69) * M(69, 80)
      temp = temp + M(82, 70) * M(70, 80)
      temp = temp + M(82, 72) * M(72, 80)
      temp = temp + M(82, 73) * M(73, 80)
      temp = temp + M(82, 75) * M(75, 80)
      temp = temp + M(82, 76) * M(76, 80)
      temp = temp + M(82, 77) * M(77, 80)
      temp = temp + M(82, 78) * M(78, 80)
      temp = temp + M(82, 79) * M(79, 80)
      M(82, 80) = M(82, 80) - temp
C     Upper part.
      temp = M(80, 24) * M(24, 81)
      temp = temp + M(80, 33) * M(33, 81)
      temp = temp + M(80, 36) * M(36, 81)
      temp = temp + M(80, 37) * M(37, 81)
      temp = temp + M(80, 39) * M(39, 81)
      temp = temp + M(80, 40) * M(40, 81)
      temp = temp + M(80, 46) * M(46, 81)
      temp = temp + M(80, 47) * M(47, 81)
      temp = temp + M(80, 48) * M(48, 81)
      temp = temp + M(80, 49) * M(49, 81)
      temp = temp + M(80, 50) * M(50, 81)
      temp = temp + M(80, 51) * M(51, 81)
      temp = temp + M(80, 52) * M(52, 81)
      temp = temp + M(80, 54) * M(54, 81)
      temp = temp + M(80, 55) * M(55, 81)
      temp = temp + M(80, 57) * M(57, 81)
      temp = temp + M(80, 58) * M(58, 81)
      temp = temp + M(80, 59) * M(59, 81)
      temp = temp + M(80, 62) * M(62, 81)
      temp = temp + M(80, 64) * M(64, 81)
      temp = temp + M(80, 67) * M(67, 81)
      temp = temp + M(80, 68) * M(68, 81)
      temp = temp + M(80, 69) * M(69, 81)
      temp = temp + M(80, 70) * M(70, 81)
      temp = temp + M(80, 71) * M(71, 81)
      temp = temp + M(80, 72) * M(72, 81)
      temp = temp + M(80, 73) * M(73, 81)
      temp = temp + M(80, 74) * M(74, 81)
      temp = temp + M(80, 75) * M(75, 81)
      temp = temp + M(80, 76) * M(76, 81)
      temp = temp + M(80, 77) * M(77, 81)
      temp = temp + M(80, 78) * M(78, 81)
      temp = temp + M(80, 79) * M(79, 81)
      M(80, 81) = ( M(80, 81) - temp ) / M(80, 80)
C     Upper part.
      temp = M(80, 68) * M(68, 82)
      temp = temp + M(80, 69) * M(69, 82)
      temp = temp + M(80, 70) * M(70, 82)
      temp = temp + M(80, 71) * M(71, 82)
      temp = temp + M(80, 72) * M(72, 82)
      temp = temp + M(80, 73) * M(73, 82)
      temp = temp + M(80, 74) * M(74, 82)
      temp = temp + M(80, 75) * M(75, 82)
      temp = temp + M(80, 76) * M(76, 82)
      temp = temp + M(80, 77) * M(77, 82)
      temp = temp + M(80, 78) * M(78, 82)
      temp = temp + M(80, 79) * M(79, 82)
      M(80, 82) = ( M(80, 82) - temp ) / M(80, 80)

C     Lower part.
      temp = M(81, 24) * M(24, 81)
      temp = temp + M(81, 25) * M(25, 81)
      temp = temp + M(81, 33) * M(33, 81)
      temp = temp + M(81, 35) * M(35, 81)
      temp = temp + M(81, 36) * M(36, 81)
      temp = temp + M(81, 37) * M(37, 81)
      temp = temp + M(81, 39) * M(39, 81)
      temp = temp + M(81, 40) * M(40, 81)
      temp = temp + M(81, 45) * M(45, 81)
      temp = temp + M(81, 46) * M(46, 81)
      temp = temp + M(81, 47) * M(47, 81)
      temp = temp + M(81, 48) * M(48, 81)
      temp = temp + M(81, 49) * M(49, 81)
      temp = temp + M(81, 50) * M(50, 81)
      temp = temp + M(81, 51) * M(51, 81)
      temp = temp + M(81, 52) * M(52, 81)
      temp = temp + M(81, 53) * M(53, 81)
      temp = temp + M(81, 54) * M(54, 81)
      temp = temp + M(81, 55) * M(55, 81)
      temp = temp + M(81, 56) * M(56, 81)
      temp = temp + M(81, 57) * M(57, 81)
      temp = temp + M(81, 58) * M(58, 81)
      temp = temp + M(81, 59) * M(59, 81)
      temp = temp + M(81, 60) * M(60, 81)
      temp = temp + M(81, 61) * M(61, 81)
      temp = temp + M(81, 62) * M(62, 81)
      temp = temp + M(81, 64) * M(64, 81)
      temp = temp + M(81, 65) * M(65, 81)
      temp = temp + M(81, 66) * M(66, 81)
      temp = temp + M(81, 68) * M(68, 81)
      temp = temp + M(81, 69) * M(69, 81)
      temp = temp + M(81, 70) * M(70, 81)
      temp = temp + M(81, 71) * M(71, 81)
      temp = temp + M(81, 72) * M(72, 81)
      temp = temp + M(81, 73) * M(73, 81)
      temp = temp + M(81, 74) * M(74, 81)
      temp = temp + M(81, 75) * M(75, 81)
      temp = temp + M(81, 76) * M(76, 81)
      temp = temp + M(81, 77) * M(77, 81)
      temp = temp + M(81, 78) * M(78, 81)
      temp = temp + M(81, 79) * M(79, 81)
      temp = temp + M(81, 80) * M(80, 81)
      M(81, 81) = M(81, 81) - temp
C     Lower part.
      temp = M(82, 36) * M(36, 81)
      temp = temp + M(82, 37) * M(37, 81)
      temp = temp + M(82, 39) * M(39, 81)
      temp = temp + M(82, 40) * M(40, 81)
      temp = temp + M(82, 47) * M(47, 81)
      temp = temp + M(82, 48) * M(48, 81)
      temp = temp + M(82, 49) * M(49, 81)
      temp = temp + M(82, 51) * M(51, 81)
      temp = temp + M(82, 52) * M(52, 81)
      temp = temp + M(82, 55) * M(55, 81)
      temp = temp + M(82, 57) * M(57, 81)
      temp = temp + M(82, 58) * M(58, 81)
      temp = temp + M(82, 59) * M(59, 81)
      temp = temp + M(82, 68) * M(68, 81)
      temp = temp + M(82, 69) * M(69, 81)
      temp = temp + M(82, 70) * M(70, 81)
      temp = temp + M(82, 72) * M(72, 81)
      temp = temp + M(82, 73) * M(73, 81)
      temp = temp + M(82, 75) * M(75, 81)
      temp = temp + M(82, 76) * M(76, 81)
      temp = temp + M(82, 77) * M(77, 81)
      temp = temp + M(82, 78) * M(78, 81)
      temp = temp + M(82, 79) * M(79, 81)
      temp = temp + M(82, 80) * M(80, 81)
      M(82, 81) = M(82, 81) - temp
C     Upper part.
      temp = M(81, 68) * M(68, 82)
      temp = temp + M(81, 69) * M(69, 82)
      temp = temp + M(81, 70) * M(70, 82)
      temp = temp + M(81, 71) * M(71, 82)
      temp = temp + M(81, 72) * M(72, 82)
      temp = temp + M(81, 73) * M(73, 82)
      temp = temp + M(81, 74) * M(74, 82)
      temp = temp + M(81, 75) * M(75, 82)
      temp = temp + M(81, 76) * M(76, 82)
      temp = temp + M(81, 77) * M(77, 82)
      temp = temp + M(81, 78) * M(78, 82)
      temp = temp + M(81, 79) * M(79, 82)
      temp = temp + M(81, 80) * M(80, 82)
      M(81, 82) = ( M(81, 82) - temp ) / M(81, 81)

C     Lower part.
      temp = M(82, 68) * M(68, 82)
      temp = temp + M(82, 69) * M(69, 82)
      temp = temp + M(82, 70) * M(70, 82)
      temp = temp + M(82, 72) * M(72, 82)
      temp = temp + M(82, 73) * M(73, 82)
      temp = temp + M(82, 75) * M(75, 82)
      temp = temp + M(82, 76) * M(76, 82)
      temp = temp + M(82, 77) * M(77, 82)
      temp = temp + M(82, 78) * M(78, 82)
      temp = temp + M(82, 79) * M(79, 82)
      temp = temp + M(82, 80) * M(80, 82)
      temp = temp + M(82, 81) * M(81, 82)
      M(82, 82) = M(82, 82) - temp


      END
