C------------------------------------------------------------------------
C     Copyright (C) 2001-2008, ENPC - INRIA - EDF R&D
C
C     This file is part of the air quality modeling system Polyphemus.
C
C     Polyphemus is developed in the INRIA - ENPC joint project-team
C     CLIME and in the ENPC - EDF R&D joint laboratory CEREA.
C
C     Polyphemus is free software; you can redistribute i and/or modify
C     it under the terms of the GNU General Public License as published
C     by the Free Software Foundation; either version 2 of the License,
C     or (at your option) any later version.
C
C     Polyphemus is distributed in the hope that it will be useful, but
C     WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
C     General Public License for more details.
C
C     For more information, visit the Polyphemus web site:
C     http://cerea.enpc.fr/polyphemus/
C------------------------------------------------------------------------
 
      subroutine jacdchemdc(ns,nr,y,convers_factor,
     $                    convers_factor_jac,rk,JacC)
 
C------------------------------------------------------------------------
C
C     -- DESCRIPTION
C
C     This routine computes the Jacobian matrix for the gas-phase.
C     This routine is automatically generated by SPACK.
C     Mechanism: RACM2_SORGAM        
C     Species: _ciRACM2_SORGAM     
C
C------------------------------------------------------------------------
C
C     -- INPUT VARIABLES
C
C     Ns: chemical species number.
C     NR: reaction number.
C     Y: chemical concentrations.
C     RK: kinetic rates.
C     convers_factor: unity conversion factor of mug/m3 to molecules/cm3.
C     convers_factor_jac: Wmol(i)/Wmol(j) for JacC(i,j)
C
C     -- INPUT/OUTPUT VARIABLES
C
C     -- OUTPUT VARIABLES
C
C     JACC: Jacobian matrix.
C
C------------------------------------------------------------------------
C
C     -- REMARKS
C
C     The matrix JACC could be stored in a low-dimensional vector.
C
C------------------------------------------------------------------------
C
C     -- MODIFICATIONS
C
C------------------------------------------------------------------------
C
C     -- AUTHOR(S)
C
C     SPACK.
C
C------------------------------------------------------------------------
 
      implicit none
 
      integer i,j,nr,ns
      double precision dw(nr,ns),rk(nr),y(ns),JacC(ns,ns)
      double precision convers_factor(ns)
      double precision convers_factor_jac(ns,ns)
      double precision conc(ns)
 
      do j=1,ns
       do i=1,ns
        JacC(i,j)=0.d0
       enddo
      enddo
 
C     Conversion mug/m3 to molecules/cm3.
 
      do i = 1, ns
         conc(i) = y(i) * convers_factor(i)
      enddo
 
      call dratedc(ns,nr,rk,conc,dw)
 
      JacC( 47,121) = JacC( 47,121) + dw(  1,121)
      JacC(121,121) = JacC(121,121) - dw(  1,121)
      JacC(123,121) = JacC(123,121) + dw(  1,121)
      JacC(  3, 91) = JacC(  3, 91) + dw(  2, 91)
      JacC( 91, 91) = JacC( 91, 91) - dw(  2, 91)
      JacC( 47, 91) = JacC( 47, 91) + dw(  3, 91)
      JacC( 91, 91) = JacC( 91, 91) - dw(  3, 91)
      JacC( 24, 24) = JacC( 24, 24) - dw(  4, 24)
      JacC(118, 24) = JacC(118, 24) + dw(  4, 24)
      JacC(123, 24) = JacC(123, 24) + dw(  4, 24)
      JacC(101,101) = JacC(101,101) - dw(  5,101)
      JacC(118,101) = JacC(118,101) + dw(  5,101)
      JacC(121,101) = JacC(121,101) + dw(  5,101)
      JacC( 43, 43) = JacC( 43, 43) - dw(  6, 43)
      JacC(117, 43) = JacC(117, 43)+ 0.2000000000000000D+00*dw(  6, 43)
      JacC(118, 43) = JacC(118, 43)+ 0.2000000000000000D+00*dw(  6, 43)
      JacC(119, 43) = JacC(119, 43)+ 0.8000000000000000D+00*dw(  6, 43)
      JacC(121, 43) = JacC(121, 43)+ 0.8000000000000000D+00*dw(  6, 43)
      JacC(117,117) = JacC(117,117) - dw(  7,117)
      JacC(123,117) = JacC(123,117) + dw(  7,117)
      JacC( 47,117) = JacC( 47,117) + dw(  8,117)
      JacC(117,117) = JacC(117,117) - dw(  8,117)
      JacC(121,117) = JacC(121,117) + dw(  8,117)
      JacC( 51, 51) = JacC( 51, 51) - dw(  9, 51)
      JacC(118, 51) = JacC(118, 51)+ 0.2000000000000000D+01*dw(  9, 51)
      JacC(107,116) = JacC(107,116) + dw( 10,116)
      JacC(116,116) = JacC(116,116) - dw( 10,116)
      JacC(107,116) = JacC(107,116) + dw( 11,116)
      JacC(116,116) = JacC(116,116) - dw( 11,116)
      JacC(119,116) = JacC(119,116)+ 0.2000000000000000D+01*dw( 11,116)
      JacC( 94, 94) = JacC( 94, 94) - dw( 12, 94)
      JacC(107, 94) = JacC(107, 94) + dw( 12, 94)
      JacC(113, 94) = JacC(113, 94) + dw( 12, 94)
      JacC(119, 94) = JacC(119, 94) + dw( 12, 94)
      JacC(107,109) = JacC(107,109) + dw( 13,109)
      JacC(109,109) = JacC(109,109) - dw( 13,109)
      JacC(114,109) = JacC(114,109) + dw( 13,109)
      JacC(119,109) = JacC(119,109) + dw( 13,109)
      JacC( 73, 73) = JacC( 73, 73) - dw( 14, 73)
      JacC(113, 73) = JacC(113, 73) + dw( 14, 73)
      JacC(122, 73) = JacC(122, 73) + dw( 14, 73)
      JacC( 37, 37) = JacC( 37, 37) - dw( 15, 37)
      JacC(113, 37) = JacC(113, 37)+ 0.5000000000000000D+00*dw( 15, 37)
      JacC(114, 37) = JacC(114, 37)+ 0.5000000000000000D+00*dw( 15, 37)
      JacC(122, 37) = JacC(122, 37) + dw( 15, 37)
      JacC(111,111) = JacC(111,111) - dw( 16,111)
      JacC(114,111) = JacC(114,111) + dw( 16,111)
      JacC(122,111) = JacC(122,111) + dw( 16,111)
      JacC( 75, 75) = JacC( 75, 75) - dw( 17, 75)
      JacC(116, 75) = JacC(116, 75) + dw( 17, 75)
      JacC(119, 75) = JacC(119, 75) + dw( 17, 75)
      JacC(122, 75) = JacC(122, 75) + dw( 17, 75)
      JacC( 92, 92) = JacC( 92, 92) - dw( 18, 92)
      JacC(104, 92) = JacC(104, 92)+ 0.3300000000000000D+00*dw( 18, 92)
      JacC(107, 92) = JacC(107, 92)+ 0.6700000000000000D+00*dw( 18, 92)
      JacC(112, 92) = JacC(112, 92)+ 0.3400000000000000D+00*dw( 18, 92)
      JacC(116, 92) = JacC(116, 92)+ 0.6700000000000000D+00*dw( 18, 92)
      JacC(118, 92) = JacC(118, 92)+ 0.3400000000000000D+00*dw( 18, 92)
      JacC(119, 92) = JacC(119, 92)+ 0.6600000000000000D+00*dw( 18, 92)
      JacC(122, 92) = JacC(122, 92)+ 0.6700000000000000D+00*dw( 18, 92)
      JacC( 81, 81) = JacC( 81, 81) - dw( 19, 81)
      JacC( 83, 81) = JacC( 83, 81)+ 0.7000000000000000D+00*dw( 19, 81)
      JacC(104, 81) = JacC(104, 81)+ 0.3000000000000000D+00*dw( 19, 81)
      JacC(107, 81) = JacC(107, 81)+ 0.7000000000000000D+00*dw( 19, 81)
      JacC(113, 81) = JacC(113, 81)+ 0.3000000000000000D+00*dw( 19, 81)
      JacC( 83, 83) = JacC( 83, 83) - dw( 20, 83)
      JacC(107, 83) = JacC(107, 83)+ 0.1220000000000000D+01*dw( 20, 83)
      JacC(109, 83) = JacC(109, 83)+ 0.4340000000000000D+00*dw( 20, 83)
      JacC(111, 83) = JacC(111, 83)+ 0.2160000000000000D+00*dw( 20, 83)
      JacC(116, 83) = JacC(116, 83)+ 0.3500000000000000D+00*dw( 20, 83)
      JacC(119, 83) = JacC(119, 83)+ 0.1220000000000000D+01*dw( 20, 83)
      JacC(122, 83) = JacC(122, 83)+ 0.7840000000000000D+00*dw( 20, 83)
      JacC(102,102) = JacC(102,102) - dw( 21,102)
      JacC(107,102) = JacC(107,102)+ 0.2000000000000000D+01*dw( 21,102)
      JacC(119,102) = JacC(119,102)+ 0.2000000000000000D+01*dw( 21,102)
      JacC(102,102) = JacC(102,102) - dw( 22,102)
      JacC(107,102) = JacC(107,102)+ 0.2000000000000000D+01*dw( 22,102)
      JacC(102,102) = JacC(102,102) - dw( 23,102)
      JacC(107,102) = JacC(107,102)+ 0.2000000000000000D+01*dw( 23,102)
      JacC(116,102) = JacC(116,102) + dw( 23,102)
      JacC(100,100) = JacC(100,100) - dw( 24,100)
      JacC(107,100) = JacC(107,100) + dw( 24,100)
      JacC(119,100) = JacC(119,100) + dw( 24,100)
      JacC(122,100) = JacC(122,100) + dw( 24,100)
      JacC( 68, 68) = JacC( 68, 68) - dw( 25, 68)
      JacC(100, 68) = JacC(100, 68)+ 0.5000000000000000D+00*dw( 25, 68)
      JacC(102, 68) = JacC(102, 68)+ 0.5000000000000000D+00*dw( 25, 68)
      JacC(107, 68) = JacC(107, 68) + dw( 25, 68)
      JacC(112, 68) = JacC(112, 68)+ 0.2000000000000000D+01*dw( 25, 68)
      JacC(119, 68) = JacC(119, 68)+ 0.1500000000000000D+01*dw( 25, 68)
      JacC(122, 68) = JacC(122, 68)+ 0.5000000000000000D+00*dw( 25, 68)
      JacC( 65, 65) = JacC( 65, 65) - dw( 26, 65)
      JacC(100, 65) = JacC(100, 65)+ 0.5000000000000000D+00*dw( 26, 65)
      JacC(102, 65) = JacC(102, 65)+ 0.5000000000000000D+00*dw( 26, 65)
      JacC(107, 65) = JacC(107, 65) + dw( 26, 65)
      JacC(112, 65) = JacC(112, 65)+ 0.2000000000000000D+01*dw( 26, 65)
      JacC(119, 65) = JacC(119, 65)+ 0.1500000000000000D+01*dw( 26, 65)
      JacC(122, 65) = JacC(122, 65)+ 0.5000000000000000D+00*dw( 26, 65)
      JacC( 69, 69) = JacC( 69, 69) - dw( 27, 69)
      JacC( 87, 69) = JacC( 87, 69) + dw( 27, 69)
      JacC(107, 69) = JacC(107, 69) + dw( 27, 69)
      JacC(119, 69) = JacC(119, 69) + dw( 27, 69)
      JacC(122, 69) = JacC(122, 69) + dw( 27, 69)
      JacC( 56, 56) = JacC( 56, 56) - dw( 28, 56)
      JacC( 62, 56) = JacC( 62, 56) + dw( 28, 56)
      JacC(107, 56) = JacC(107, 56) + dw( 28, 56)
      JacC(119, 56) = JacC(119, 56) + dw( 28, 56)
      JacC( 40, 40) = JacC( 40, 40) - dw( 29, 40)
      JacC(116, 40) = JacC(116, 40) + dw( 29, 40)
      JacC(118, 40) = JacC(118, 40) + dw( 29, 40)
      JacC(119, 40) = JacC(119, 40) + dw( 29, 40)
      JacC(109,115) = JacC(109,115) + dw( 30,115)
      JacC(115,115) = JacC(115,115) - dw( 30,115)
      JacC(118,115) = JacC(118,115) + dw( 30,115)
      JacC(119,115) = JacC(119,115) + dw( 30,115)
      JacC( 70, 70) = JacC( 70, 70) - dw( 31, 70)
      JacC(113, 70) = JacC(113, 70) + dw( 31, 70)
      JacC(118, 70) = JacC(118, 70) + dw( 31, 70)
      JacC(108,108) = JacC(108,108) - dw( 32,108)
      JacC(109,108) = JacC(109,108)+ 0.2000000000000000D+00*dw( 32,108)
      JacC(111,108) = JacC(111,108)+ 0.8000000000000000D+00*dw( 32,108)
      JacC(119,108) = JacC(119,108) + dw( 32,108)
      JacC(121,108) = JacC(121,108) + dw( 32,108)
      JacC( 41, 41) = JacC( 41, 41) - dw( 33, 41)
      JacC(121, 41) = JacC(121, 41) + dw( 33, 41)
      JacC(122, 41) = JacC(122, 41) + dw( 33, 41)
      JacC( 41, 41) = JacC( 41, 41) - dw( 34, 41)
      JacC(113, 41) = JacC(113, 41) + dw( 34, 41)
      JacC(117, 41) = JacC(117, 41) + dw( 34, 41)
      JacC( 47, 47) = JacC( 47, 47) - dw( 35, 47)
      JacC( 91, 47) = JacC( 91, 47) + dw( 35, 47)
      JacC( 47, 47) = JacC( 47, 47) - dw( 36, 47)
      JacC( 47, 91) = JacC( 47, 91) - dw( 36, 91)
      JacC( 91, 47) = JacC( 91, 47) - dw( 36, 47)
      JacC( 91, 91) = JacC( 91, 91) - dw( 36, 91)
      JacC(  3,  3) = JacC(  3,  3) - dw( 37,  3)
      JacC( 47,  3) = JacC( 47,  3) + dw( 37,  3)
      JacC(  3,  3) = JacC(  3,  3) - dw( 38,  3)
      JacC( 47,  3) = JacC( 47,  3) + dw( 38,  3)
      JacC(  3,  3) = JacC(  3,  3) - dw( 39,  3)
      JacC(118,  3) = JacC(118,  3)+ 0.2000000000000000D+01*dw( 39,  3)
      JacC( 91, 91) = JacC( 91, 91) - dw( 40, 91)
      JacC( 91,118) = JacC( 91,118) - dw( 40,118)
      JacC(118, 91) = JacC(118, 91) - dw( 40, 91)
      JacC(118,118) = JacC(118,118) - dw( 40,118)
      JacC(119, 91) = JacC(119, 91) + dw( 40, 91)
      JacC(119,118) = JacC(119,118) + dw( 40,118)
      JacC( 91, 91) = JacC( 91, 91) - dw( 41, 91)
      JacC( 91,119) = JacC( 91,119) - dw( 41,119)
      JacC(118, 91) = JacC(118, 91) + dw( 41, 91)
      JacC(118,119) = JacC(118,119) + dw( 41,119)
      JacC(119, 91) = JacC(119, 91) - dw( 41, 91)
      JacC(119,119) = JacC(119,119) - dw( 41,119)
      JacC(118,118) = JacC(118,118) - dw( 42,118)
      JacC(118,119) = JacC(118,119) - dw( 42,119)
      JacC(119,118) = JacC(119,118) - dw( 42,118)
      JacC(119,119) = JacC(119,119) - dw( 42,119)
      JacC( 51, 51) = JacC( 51, 51) - dw( 43, 51)
      JacC( 51,118) = JacC( 51,118) - dw( 43,118)
      JacC(118, 51) = JacC(118, 51) - dw( 43, 51)
      JacC(118,118) = JacC(118,118) - dw( 43,118)
      JacC(119, 51) = JacC(119, 51) + dw( 43, 51)
      JacC(119,118) = JacC(119,118) + dw( 43,118)
      JacC( 51,119) = JacC( 51,119) + dw( 44,119)
      JacC( 51,119) = JacC( 51,119) + dw( 44,119)
      JacC(119,119) = JacC(119,119)- 0.2000000000000000D+01*dw( 44,119)
      JacC(119,119) = JacC(119,119)- 0.2000000000000000D+01*dw( 44,119)
      JacC( 51,119) = JacC( 51,119) + dw( 45,119)
      JacC( 51,119) = JacC( 51,119) + dw( 45,119)
      JacC(119,119) = JacC(119,119)- 0.2000000000000000D+01*dw( 45,119)
      JacC(119,119) = JacC(119,119)- 0.2000000000000000D+01*dw( 45,119)
      JacC( 47, 47) = JacC( 47, 47) - dw( 46, 47)
      JacC( 47,123) = JacC( 47,123) - dw( 46,123)
      JacC(121, 47) = JacC(121, 47) + dw( 46, 47)
      JacC(121,123) = JacC(121,123) + dw( 46,123)
      JacC(123, 47) = JacC(123, 47) - dw( 46, 47)
      JacC(123,123) = JacC(123,123) - dw( 46,123)
      JacC( 47, 47) = JacC( 47, 47) - dw( 47, 47)
      JacC( 47,121) = JacC( 47,121) - dw( 47,121)
      JacC(121, 47) = JacC(121, 47) - dw( 47, 47)
      JacC(121,121) = JacC(121,121) - dw( 47,121)
      JacC(123, 47) = JacC(123, 47) + dw( 47, 47)
      JacC(123,121) = JacC(123,121) + dw( 47,121)
      JacC( 47, 47) = JacC( 47, 47) - dw( 48, 47)
      JacC( 47,121) = JacC( 47,121) - dw( 48,121)
      JacC(117, 47) = JacC(117, 47) + dw( 48, 47)
      JacC(117,121) = JacC(117,121) + dw( 48,121)
      JacC(121, 47) = JacC(121, 47) - dw( 48, 47)
      JacC(121,121) = JacC(121,121) - dw( 48,121)
      JacC( 24,118) = JacC( 24,118) + dw( 49,118)
      JacC( 24,123) = JacC( 24,123) + dw( 49,123)
      JacC(118,118) = JacC(118,118) - dw( 49,118)
      JacC(118,123) = JacC(118,123) - dw( 49,123)
      JacC(123,118) = JacC(123,118) - dw( 49,118)
      JacC(123,123) = JacC(123,123) - dw( 49,123)
      JacC(101,118) = JacC(101,118) + dw( 50,118)
      JacC(101,121) = JacC(101,121) + dw( 50,121)
      JacC(118,118) = JacC(118,118) - dw( 50,118)
      JacC(118,121) = JacC(118,121) - dw( 50,121)
      JacC(121,118) = JacC(121,118) - dw( 50,118)
      JacC(121,121) = JacC(121,121) - dw( 50,121)
      JacC(117,118) = JacC(117,118) - dw( 51,118)
      JacC(117,117) = JacC(117,117) - dw( 51,117)
      JacC(118,118) = JacC(118,118) - dw( 51,118)
      JacC(118,117) = JacC(118,117) - dw( 51,117)
      JacC(119,118) = JacC(119,118) + dw( 51,118)
      JacC(119,117) = JacC(119,117) + dw( 51,117)
      JacC(121,118) = JacC(121,118) + dw( 51,118)
      JacC(121,117) = JacC(121,117) + dw( 51,117)
      JacC(118,119) = JacC(118,119) + dw( 52,119)
      JacC(118,123) = JacC(118,123) + dw( 52,123)
      JacC(119,119) = JacC(119,119) - dw( 52,119)
      JacC(119,123) = JacC(119,123) - dw( 52,123)
      JacC(121,119) = JacC(121,119) + dw( 52,119)
      JacC(121,123) = JacC(121,123) + dw( 52,123)
      JacC(123,119) = JacC(123,119) - dw( 52,119)
      JacC(123,123) = JacC(123,123) - dw( 52,123)
      JacC( 43,119) = JacC( 43,119) + dw( 53,119)
      JacC( 43,121) = JacC( 43,121) + dw( 53,121)
      JacC(119,119) = JacC(119,119) - dw( 53,119)
      JacC(119,121) = JacC(119,121) - dw( 53,121)
      JacC(121,119) = JacC(121,119) - dw( 53,119)
      JacC(121,121) = JacC(121,121) - dw( 53,121)
      JacC( 43, 43) = JacC( 43, 43) - dw( 54, 43)
      JacC(119, 43) = JacC(119, 43) + dw( 54, 43)
      JacC(121, 43) = JacC(121, 43) + dw( 54, 43)
      JacC(101,119) = JacC(101,119)+ 0.3000000000000000D+00*dw( 55,119)
      JacC(101,117) = JacC(101,117)+ 0.3000000000000000D+00*dw( 55,117)
      JacC(117,119) = JacC(117,119) - dw( 55,119)
      JacC(117,117) = JacC(117,117) - dw( 55,117)
      JacC(118,119) = JacC(118,119)+ 0.7000000000000000D+00*dw( 55,119)
      JacC(118,117) = JacC(118,117)+ 0.7000000000000000D+00*dw( 55,117)
      JacC(119,119) = JacC(119,119) - dw( 55,119)
      JacC(119,117) = JacC(119,117) - dw( 55,117)
      JacC(121,119) = JacC(121,119)+ 0.7000000000000000D+00*dw( 55,119)
      JacC(121,117) = JacC(121,117)+ 0.7000000000000000D+00*dw( 55,117)
      JacC( 24,118) = JacC( 24,118) - dw( 56,118)
      JacC( 24, 24) = JacC( 24, 24) - dw( 56, 24)
      JacC(118,118) = JacC(118,118) - dw( 56,118)
      JacC(118, 24) = JacC(118, 24) - dw( 56, 24)
      JacC(121,118) = JacC(121,118) + dw( 56,118)
      JacC(121, 24) = JacC(121, 24) + dw( 56, 24)
      JacC(101,118) = JacC(101,118) - dw( 57,118)
      JacC(101,101) = JacC(101,101) - dw( 57,101)
      JacC(117,118) = JacC(117,118) + dw( 57,118)
      JacC(117,101) = JacC(117,101) + dw( 57,101)
      JacC(118,118) = JacC(118,118) - dw( 57,118)
      JacC(118,101) = JacC(118,101) - dw( 57,101)
      JacC( 43,118) = JacC( 43,118) - dw( 58,118)
      JacC( 43, 43) = JacC( 43, 43) - dw( 58, 43)
      JacC(118,118) = JacC(118,118) - dw( 58,118)
      JacC(118, 43) = JacC(118, 43) - dw( 58, 43)
      JacC(121,118) = JacC(121,118) + dw( 58,118)
      JacC(121, 43) = JacC(121, 43) + dw( 58, 43)
      JacC( 91, 91) = JacC( 91, 91) - dw( 59, 91)
      JacC( 91,123) = JacC( 91,123) - dw( 59,123)
      JacC(121, 91) = JacC(121, 91) + dw( 59, 91)
      JacC(121,123) = JacC(121,123) + dw( 59,123)
      JacC(123, 91) = JacC(123, 91) - dw( 59, 91)
      JacC(123,123) = JacC(123,123) - dw( 59,123)
      JacC( 91, 91) = JacC( 91, 91) - dw( 60, 91)
      JacC( 91,121) = JacC( 91,121) - dw( 60,121)
      JacC(117, 91) = JacC(117, 91) + dw( 60, 91)
      JacC(117,121) = JacC(117,121) + dw( 60,121)
      JacC(121, 91) = JacC(121, 91) - dw( 60, 91)
      JacC(121,121) = JacC(121,121) - dw( 60,121)
      JacC(121,123) = JacC(121,123)+ 0.2000000000000000D+01*dw( 61,123)
      JacC(121,123) = JacC(121,123)+ 0.2000000000000000D+01*dw( 61,123)
      JacC(123,123) = JacC(123,123)- 0.2000000000000000D+01*dw( 61,123)
      JacC(123,123) = JacC(123,123)- 0.2000000000000000D+01*dw( 61,123)
      JacC(117,117) = JacC(117,117) - dw( 62,117)
      JacC(117,123) = JacC(117,123) - dw( 62,123)
      JacC(121,117) = JacC(121,117)+ 0.2000000000000000D+01*dw( 62,117)
      JacC(121,123) = JacC(121,123)+ 0.2000000000000000D+01*dw( 62,123)
      JacC(123,117) = JacC(123,117) - dw( 62,117)
      JacC(123,123) = JacC(123,123) - dw( 62,123)
      JacC(117,117) = JacC(117,117) - dw( 63,117)
      JacC(117,121) = JacC(117,121) - dw( 63,121)
      JacC(123,117) = JacC(123,117) + dw( 63,117)
      JacC(123,121) = JacC(123,121) + dw( 63,121)
      JacC( 18,117) = JacC( 18,117) + dw( 64,117)
      JacC( 18,121) = JacC( 18,121) + dw( 64,121)
      JacC(117,117) = JacC(117,117) - dw( 64,117)
      JacC(117,121) = JacC(117,121) - dw( 64,121)
      JacC(121,117) = JacC(121,117) - dw( 64,117)
      JacC(121,121) = JacC(121,121) - dw( 64,121)
      JacC( 18, 18) = JacC( 18, 18) - dw( 65, 18)
      JacC(117, 18) = JacC(117, 18) + dw( 65, 18)
      JacC(121, 18) = JacC(121, 18) + dw( 65, 18)
      JacC( 18, 18) = JacC( 18, 18) - dw( 66, 18)
      JacC(101, 18) = JacC(101, 18)+ 0.2000000000000000D+01*dw( 66, 18)
      JacC(117,117) = JacC(117,117)- 0.2000000000000000D+01*dw( 67,117)
      JacC(117,117) = JacC(117,117)- 0.2000000000000000D+01*dw( 67,117)
      JacC(121,117) = JacC(121,117)+ 0.2000000000000000D+01*dw( 67,117)
      JacC(121,117) = JacC(121,117)+ 0.2000000000000000D+01*dw( 67,117)
      JacC(118,118) = JacC(118,118) - dw( 68,118)
      JacC(119,118) = JacC(119,118) + dw( 68,118)
      JacC(  4,118) = JacC(  4,118) - dw( 69,118)
      JacC(  4,  4) = JacC(  4,  4) - dw( 69,  4)
      JacC(  5,118) = JacC(  5,118) + dw( 69,118)
      JacC(  5,  4) = JacC(  5,  4) + dw( 69,  4)
      JacC(118,118) = JacC(118,118) - dw( 69,118)
      JacC(118,  4) = JacC(118,  4) - dw( 69,  4)
      JacC(119,118) = JacC(119,118) + dw( 69,118)
      JacC(119,  4) = JacC(119,  4) + dw( 69,  4)
      JacC(107,107) = JacC(107,107) - dw( 70,107)
      JacC(107,118) = JacC(107,118) - dw( 70,118)
      JacC(118,107) = JacC(118,107) - dw( 70,107)
      JacC(118,118) = JacC(118,118) - dw( 70,118)
      JacC(119,107) = JacC(119,107) + dw( 70,107)
      JacC(119,118) = JacC(119,118) + dw( 70,118)
      JacC( 44, 44) = JacC( 44, 44) - dw( 71, 44)
      JacC( 44,118) = JacC( 44,118) - dw( 71,118)
      JacC(113, 44) = JacC(113, 44) + dw( 71, 44)
      JacC(113,118) = JacC(113,118) + dw( 71,118)
      JacC(118, 44) = JacC(118, 44) - dw( 71, 44)
      JacC(118,118) = JacC(118,118) - dw( 71,118)
      JacC( 39, 39) = JacC( 39, 39) - dw( 72, 39)
      JacC( 39,118) = JacC( 39,118) - dw( 72,118)
      JacC(114, 39) = JacC(114, 39) + dw( 72, 39)
      JacC(114,118) = JacC(114,118) + dw( 72,118)
      JacC(118, 39) = JacC(118, 39) - dw( 72, 39)
      JacC(118,118) = JacC(118,118) - dw( 72,118)
      JacC( 99, 99) = JacC( 99, 99) - dw( 73, 99)
      JacC( 99,118) = JacC( 99,118) - dw( 73,118)
      JacC(116, 99) = JacC(116, 99) + dw( 73, 99)
      JacC(116,118) = JacC(116,118) + dw( 73,118)
      JacC(118, 99) = JacC(118, 99) - dw( 73, 99)
      JacC(118,118) = JacC(118,118) - dw( 73,118)
      JacC(119, 99) = JacC(119, 99) + dw( 73, 99)
      JacC(119,118) = JacC(119,118) + dw( 73,118)
      JacC( 26, 26) = JacC( 26, 26) - dw( 74, 26)
      JacC( 26,118) = JacC( 26,118) - dw( 74,118)
      JacC( 94, 26) = JacC( 94, 26) + dw( 74, 26)
      JacC( 94,118) = JacC( 94,118) + dw( 74,118)
      JacC(118, 26) = JacC(118, 26) - dw( 74, 26)
      JacC(118,118) = JacC(118,118) - dw( 74,118)
      JacC(119, 26) = JacC(119, 26) + dw( 74, 26)
      JacC(119,118) = JacC(119,118) + dw( 74,118)
      JacC( 89, 89) = JacC( 89, 89) - dw( 75, 89)
      JacC( 89,118) = JacC( 89,118) - dw( 75,118)
      JacC( 94, 89) = JacC( 94, 89)+ 0.1840000000000000D+00*dw( 75, 89)
      JacC( 94,118) = JacC( 94,118)+ 0.1840000000000000D+00*dw( 75,118)
      JacC(109, 89) = JacC(109, 89)+ 0.7190000000000000D+00*dw( 75, 89)
      JacC(109,118) = JacC(109,118)+ 0.7190000000000000D+00*dw( 75,118)
      JacC(118, 89) = JacC(118, 89) - dw( 75, 89)
      JacC(118,118) = JacC(118,118) - dw( 75,118)
      JacC(119, 89) = JacC(119, 89) + dw( 75, 89)
      JacC(119,118) = JacC(119,118) + dw( 75,118)
      JacC(  6,  6) = JacC(  6,  6) - dw( 76,  6)
      JacC(  6,118) = JacC(  6,118) - dw( 76,118)
      JacC( 74,  6) = JacC( 74,  6)+ 0.3500000000000000D+00*dw( 76,  6)
      JacC( 74,118) = JacC( 74,118)+ 0.3500000000000000D+00*dw( 76,118)
      JacC(102,  6) = JacC(102,  6)+ 0.6500000000000000D+00*dw( 76,  6)
      JacC(102,118) = JacC(102,118)+ 0.6500000000000000D+00*dw( 76,118)
      JacC(107,  6) = JacC(107,  6)+ 0.3500000000000000D+00*dw( 76,  6)
      JacC(107,118) = JacC(107,118)+ 0.3500000000000000D+00*dw( 76,118)
      JacC(118,  6) = JacC(118,  6)- 0.3500000000000000D+00*dw( 76,  6)
      JacC(118,118) = JacC(118,118)- 0.3500000000000000D+00*dw( 76,118)
      JacC(119,  6) = JacC(119,  6)+ 0.3500000000000000D+00*dw( 76,  6)
      JacC(119,118) = JacC(119,118)+ 0.3500000000000000D+00*dw( 76,118)
      JacC(  8,  8) = JacC(  8,  8) - dw( 77,  8)
      JacC(  8,118) = JacC(  8,118) - dw( 77,118)
      JacC(110,  8) = JacC(110,  8) + dw( 77,  8)
      JacC(110,118) = JacC(110,118) + dw( 77,118)
      JacC(118,  8) = JacC(118,  8) - dw( 77,  8)
      JacC(118,118) = JacC(118,118) - dw( 77,118)
      JacC(  9,  9) = JacC(  9,  9) - dw( 78,  9)
      JacC(  9,118) = JacC(  9,118) - dw( 78,118)
      JacC( 76,  9) = JacC( 76,  9) + dw( 78,  9)
      JacC( 76,118) = JacC( 76,118) + dw( 78,118)
      JacC(118,  9) = JacC(118,  9) - dw( 78,  9)
      JacC(118,118) = JacC(118,118) - dw( 78,118)
      JacC( 10, 10) = JacC( 10, 10) - dw( 79, 10)
      JacC( 10,118) = JacC( 10,118) - dw( 79,118)
      JacC( 17, 10) = JacC( 17, 10)+ 0.4800000000000000D-01*dw( 79, 10)
      JacC( 17,118) = JacC( 17,118)+ 0.4800000000000000D-01*dw( 79,118)
      JacC( 75, 10) = JacC( 75, 10)+ 0.2400000000000000D-01*dw( 79, 10)
      JacC( 75,118) = JacC( 75,118)+ 0.2400000000000000D-01*dw( 79,118)
      JacC( 79, 10) = JacC( 79, 10)+ 0.9510000000000000D+00*dw( 79, 10)
      JacC( 79,118) = JacC( 79,118)+ 0.9510000000000000D+00*dw( 79,118)
      JacC(109, 10) = JacC(109, 10)+ 0.2500000000000000D-01*dw( 79, 10)
      JacC(109,118) = JacC(109,118)+ 0.2500000000000000D-01*dw( 79,118)
      JacC(118, 10) = JacC(118, 10) - dw( 79, 10)
      JacC(118,118) = JacC(118,118) - dw( 79,118)
      JacC(119, 10) = JacC(119, 10)+ 0.4900000000000000D-01*dw( 79, 10)
      JacC(119,118) = JacC(119,118)+ 0.4900000000000000D-01*dw( 79,118)
      JacC( 28, 28) = JacC( 28, 28) - dw( 80, 28)
      JacC( 28,118) = JacC( 28,118) - dw( 80,118)
      JacC( 98, 28) = JacC( 98, 28) + dw( 80, 28)
      JacC( 98,118) = JacC( 98,118) + dw( 80,118)
      JacC(118, 28) = JacC(118, 28) - dw( 80, 28)
      JacC(118,118) = JacC(118,118) - dw( 80,118)
      JacC( 38, 38) = JacC( 38, 38) - dw( 81, 38)
      JacC( 38,118) = JacC( 38,118) - dw( 81,118)
      JacC( 50, 38) = JacC( 50, 38)+ 0.8000000000000000D-02*dw( 81, 38)
      JacC( 50,118) = JacC( 50,118)+ 0.8000000000000000D-02*dw( 81,118)
      JacC( 71, 38) = JacC( 71, 38) + dw( 81, 38)
      JacC( 71,118) = JacC( 71,118) + dw( 81,118)
      JacC(118, 38) = JacC(118, 38) - dw( 81, 38)
      JacC(118,118) = JacC(118,118) - dw( 81,118)
      JacC( 50, 86) = JacC( 50, 86)+ 0.8000000000000000D-02*dw( 82, 86)
      JacC( 50,118) = JacC( 50,118)+ 0.8000000000000000D-02*dw( 82,118)
      JacC( 86, 86) = JacC( 86, 86) - dw( 82, 86)
      JacC( 86,118) = JacC( 86,118) - dw( 82,118)
      JacC( 87, 86) = JacC( 87, 86) + dw( 82, 86)
      JacC( 87,118) = JacC( 87,118) + dw( 82,118)
      JacC(118, 86) = JacC(118, 86) - dw( 82, 86)
      JacC(118,118) = JacC(118,118) - dw( 82,118)
      JacC( 25, 25) = JacC( 25, 25) - dw( 83, 25)
      JacC( 25,118) = JacC( 25,118) - dw( 83,118)
      JacC( 87, 25) = JacC( 87, 25) + dw( 83, 25)
      JacC( 87,118) = JacC( 87,118) + dw( 83,118)
      JacC(118, 25) = JacC(118, 25) - dw( 83, 25)
      JacC(118,118) = JacC(118,118) - dw( 83,118)
      JacC( 31, 31) = JacC( 31, 31) - dw( 84, 31)
      JacC( 31,118) = JacC( 31,118) - dw( 84,118)
      JacC( 80, 31) = JacC( 80, 31) + dw( 84, 31)
      JacC( 80,118) = JacC( 80,118) + dw( 84,118)
      JacC(118, 31) = JacC(118, 31) - dw( 84, 31)
      JacC(118,118) = JacC(118,118) - dw( 84,118)
      JacC( 21, 21) = JacC( 21, 21) - dw( 85, 21)
      JacC( 21,118) = JacC( 21,118) - dw( 85,118)
      JacC( 22, 21) = JacC( 22, 21)+ 0.6384000000000000D-02*dw( 85, 21)
      JacC( 22,118) = JacC( 22,118)+ 0.6384000000000000D-02*dw( 85,118)
      JacC( 23, 21) = JacC( 23, 21)+ 0.5494800000000000D-01*dw( 85, 21)
      JacC( 23,118) = JacC( 23,118)+ 0.5494800000000000D-01*dw( 85,118)
      JacC( 72, 21) = JacC( 72, 21) + dw( 85, 21)
      JacC( 72,118) = JacC( 72,118) + dw( 85,118)
      JacC(118, 21) = JacC(118, 21) - dw( 85, 21)
      JacC(118,118) = JacC(118,118) - dw( 85,118)
      JacC( 32, 32) = JacC( 32, 32) - dw( 86, 32)
      JacC( 32,118) = JacC( 32,118) - dw( 86,118)
      JacC( 33, 32) = JacC( 33, 32)+ 0.3720000000000000D-01*dw( 86, 32)
      JacC( 33,118) = JacC( 33,118)+ 0.3720000000000000D-01*dw( 86,118)
      JacC( 34, 32) = JacC( 34, 32)+ 0.5630000000000000D-01*dw( 86, 32)
      JacC( 34,118) = JacC( 34,118)+ 0.5630000000000000D-01*dw( 86,118)
      JacC( 85, 32) = JacC( 85, 32) + dw( 86, 32)
      JacC( 85,118) = JacC( 85,118) + dw( 86,118)
      JacC(118, 32) = JacC(118, 32) - dw( 86, 32)
      JacC(118,118) = JacC(118,118) - dw( 86,118)
      JacC( 30, 30) = JacC( 30, 30) - dw( 87, 30)
      JacC( 30,118) = JacC( 30,118) - dw( 87,118)
      JacC( 92, 30) = JacC( 92, 30) + dw( 87, 30)
      JacC( 92,118) = JacC( 92,118) + dw( 87,118)
      JacC( 19, 45) = JacC( 19, 45) + dw( 88, 45)
      JacC( 19,118) = JacC( 19,118) + dw( 88,118)
      JacC( 45, 45) = JacC( 45, 45) - dw( 88, 45)
      JacC( 45,118) = JacC( 45,118) - dw( 88,118)
      JacC( 93, 45) = JacC( 93, 45) + dw( 88, 45)
      JacC( 93,118) = JacC( 93,118) + dw( 88,118)
      JacC(118, 45) = JacC(118, 45) - dw( 88, 45)
      JacC(118,118) = JacC(118,118) - dw( 88,118)
      JacC( 35, 35) = JacC( 35, 35) - dw( 89, 35)
      JacC( 35,118) = JacC( 35,118) - dw( 89,118)
      JacC(104, 35) = JacC(104, 35) + dw( 89, 35)
      JacC(104,118) = JacC(104,118) + dw( 89,118)
      JacC(118, 35) = JacC(118, 35) - dw( 89, 35)
      JacC(118,118) = JacC(118,118) - dw( 89,118)
      JacC( 93, 93) = JacC( 93, 93) - dw( 90, 93)
      JacC( 93,118) = JacC( 93,118) - dw( 90,118)
      JacC(100, 93) = JacC(100, 93) + dw( 90, 93)
      JacC(100,118) = JacC(100,118) + dw( 90,118)
      JacC(118, 93) = JacC(118, 93) - dw( 90, 93)
      JacC(118,118) = JacC(118,118) - dw( 90,118)
      JacC(119, 93) = JacC(119, 93) + dw( 90, 93)
      JacC(119,118) = JacC(119,118) + dw( 90,118)
      JacC( 19, 19) = JacC( 19, 19) - dw( 91, 19)
      JacC( 19,118) = JacC( 19,118) - dw( 91,118)
      JacC(107, 19) = JacC(107, 19) + dw( 91, 19)
      JacC(107,118) = JacC(107,118) + dw( 91,118)
      JacC(116, 19) = JacC(116, 19) + dw( 91, 19)
      JacC(116,118) = JacC(116,118) + dw( 91,118)
      JacC(118, 19) = JacC(118, 19) - dw( 91, 19)
      JacC(118,118) = JacC(118,118) - dw( 91,118)
      JacC(121, 19) = JacC(121, 19) + dw( 91, 19)
      JacC(121,118) = JacC(121,118) + dw( 91,118)
      JacC( 29, 29) = JacC( 29, 29) - dw( 92, 29)
      JacC( 29,118) = JacC( 29,118) - dw( 92,118)
      JacC(109, 29) = JacC(109, 29) + dw( 92, 29)
      JacC(109,118) = JacC(109,118) + dw( 92,118)
      JacC(118, 29) = JacC(118, 29) - dw( 92, 29)
      JacC(118,118) = JacC(118,118) - dw( 92,118)
      JacC(119, 29) = JacC(119, 29) + dw( 92, 29)
      JacC(119,118) = JacC(119,118) + dw( 92,118)
      JacC(  7,  7) = JacC(  7,  7) - dw( 93,  7)
      JacC(  7,118) = JacC(  7,118) - dw( 93,118)
      JacC( 20,  7) = JacC( 20,  7)+ 0.5300000000000000D+00*dw( 93,  7)
      JacC( 20,118) = JacC( 20,118)+ 0.5300000000000000D+00*dw( 93,118)
      JacC( 48,  7) = JacC( 48,  7)+ 0.3900000000000000D-01*dw( 93,  7)
      JacC( 48,118) = JacC( 48,118)+ 0.3900000000000000D-01*dw( 93,118)
      JacC( 49,  7) = JacC( 49,  7)+ 0.1080000000000000D+00*dw( 93,  7)
      JacC( 49,118) = JacC( 49,118)+ 0.1080000000000000D+00*dw( 93,118)
      JacC( 77,  7) = JacC( 77,  7)+ 0.3520000000000000D+00*dw( 93,  7)
      JacC( 77,118) = JacC( 77,118)+ 0.3520000000000000D+00*dw( 93,118)
      JacC( 83,  7) = JacC( 83,  7)+ 0.1180000000000000D+00*dw( 93,  7)
      JacC( 83,118) = JacC( 83,118)+ 0.1180000000000000D+00*dw( 93,118)
      JacC(118,  7) = JacC(118,  7) - dw( 93,  7)
      JacC(118,118) = JacC(118,118) - dw( 93,118)
      JacC(119,  7) = JacC(119,  7)+ 0.6480000000000000D+00*dw( 93,  7)
      JacC(119,118) = JacC(119,118)+ 0.6480000000000000D+00*dw( 93,118)
      JacC( 11, 11) = JacC( 11, 11) - dw( 94, 11)
      JacC( 11,118) = JacC( 11,118) - dw( 94,118)
      JacC( 12, 11) = JacC( 12, 11)+ 0.8900000000000000D+00*dw( 94, 11)
      JacC( 12,118) = JacC( 12,118)+ 0.8900000000000000D+00*dw( 94,118)
      JacC( 48, 11) = JacC( 48, 11)+ 0.3900000000000000D-01*dw( 94, 11)
      JacC( 48,118) = JacC( 48,118)+ 0.3900000000000000D-01*dw( 94,118)
      JacC( 49, 11) = JacC( 49, 11)+ 0.1080000000000000D+00*dw( 94, 11)
      JacC( 49,118) = JacC( 49,118)+ 0.1080000000000000D+00*dw( 94,118)
      JacC( 53, 11) = JacC( 53, 11)+ 0.6000000000000000D-01*dw( 94, 11)
      JacC( 53,118) = JacC( 53,118)+ 0.6000000000000000D-01*dw( 94,118)
      JacC( 61, 11) = JacC( 61, 11)+ 0.5000000000000000D-01*dw( 94, 11)
      JacC( 61,118) = JacC( 61,118)+ 0.5000000000000000D-01*dw( 94,118)
      JacC(118, 11) = JacC(118, 11) - dw( 94, 11)
      JacC(118,118) = JacC(118,118) - dw( 94,118)
      JacC(119, 11) = JacC(119, 11)+ 0.5000000000000000D-01*dw( 94, 11)
      JacC(119,118) = JacC(119,118)+ 0.5000000000000000D-01*dw( 94,118)
      JacC( 53, 53) = JacC( 53, 53) - dw( 95, 53)
      JacC( 53,123) = JacC( 53,123) - dw( 95,123)
      JacC( 56, 53) = JacC( 56, 53) + dw( 95, 53)
      JacC( 56,123) = JacC( 56,123) + dw( 95,123)
      JacC(121, 53) = JacC(121, 53) + dw( 95, 53)
      JacC(121,123) = JacC(121,123) + dw( 95,123)
      JacC(123, 53) = JacC(123, 53) - dw( 95, 53)
      JacC(123,123) = JacC(123,123) - dw( 95,123)
      JacC( 12, 12) = JacC( 12, 12) - dw( 96, 12)
      JacC( 27, 12) = JacC( 27, 12)+ 0.2800000000000000D+00*dw( 96, 12)
      JacC( 52, 12) = JacC( 52, 12)+ 0.1500000000000000D+00*dw( 96, 12)
      JacC( 54, 12) = JacC( 54, 12)+ 0.2800000000000000D+00*dw( 96, 12)
      JacC( 61, 12) = JacC( 61, 12)+ 0.1000000000000000D-01*dw( 96, 12)
      JacC( 65, 12) = JacC( 65, 12)+ 0.2800000000000000D+00*dw( 96, 12)
      JacC(118, 12) = JacC(118, 12)+ 0.2800000000000000D+00*dw( 96, 12)
      JacC(119, 12) = JacC(119, 12)+ 0.2900000000000000D+00*dw( 96, 12)
      JacC( 52, 54) = JacC( 52, 54)+ 0.5000000000000000D+00*dw( 97, 54)
      JacC( 54, 54) = JacC( 54, 54) - dw( 97, 54)
      JacC( 61, 54) = JacC( 61, 54)+ 0.1000000000000000D-01*dw( 97, 54)
      JacC( 65, 54) = JacC( 65, 54)+ 0.4900000000000000D+00*dw( 97, 54)
      JacC(118, 54) = JacC(118, 54)+ 0.4900000000000000D+00*dw( 97, 54)
      JacC(119, 54) = JacC(119, 54)+ 0.1000000000000000D-01*dw( 97, 54)
      JacC( 54, 54) = JacC( 54, 54) - dw( 98, 54)
      JacC( 54,123) = JacC( 54,123) - dw( 98,123)
      JacC( 65, 54) = JacC( 65, 54)+ 0.9500000000000000D+00*dw( 98, 54)
      JacC( 65,123) = JacC( 65,123)+ 0.9500000000000000D+00*dw( 98,123)
      JacC(108, 54) = JacC(108, 54)+ 0.5000000000000000D-01*dw( 98, 54)
      JacC(108,123) = JacC(108,123)+ 0.5000000000000000D-01*dw( 98,123)
      JacC(119, 54) = JacC(119, 54)+ 0.9500000000000000D+00*dw( 98, 54)
      JacC(119,123) = JacC(119,123)+ 0.9500000000000000D+00*dw( 98,123)
      JacC(121, 54) = JacC(121, 54)+ 0.9500000000000000D+00*dw( 98, 54)
      JacC(121,123) = JacC(121,123)+ 0.9500000000000000D+00*dw( 98,123)
      JacC(123, 54) = JacC(123, 54) - dw( 98, 54)
      JacC(123,123) = JacC(123,123) - dw( 98,123)
      JacC( 52, 52) = JacC( 52, 52) - dw( 99, 52)
      JacC( 52,123) = JacC( 52,123) - dw( 99,123)
      JacC( 68, 52) = JacC( 68, 52)+ 0.9500000000000000D+00*dw( 99, 52)
      JacC( 68,123) = JacC( 68,123)+ 0.9500000000000000D+00*dw( 99,123)
      JacC(100, 52) = JacC(100, 52)+ 0.9500000000000000D+00*dw( 99, 52)
      JacC(100,123) = JacC(100,123)+ 0.9500000000000000D+00*dw( 99,123)
      JacC(108, 52) = JacC(108, 52)+ 0.5000000000000000D-01*dw( 99, 52)
      JacC(108,123) = JacC(108,123)+ 0.5000000000000000D-01*dw( 99,123)
      JacC(119, 52) = JacC(119, 52)+ 0.9500000000000000D+00*dw( 99, 52)
      JacC(119,123) = JacC(119,123)+ 0.9500000000000000D+00*dw( 99,123)
      JacC(121, 52) = JacC(121, 52)+ 0.9500000000000000D+00*dw( 99, 52)
      JacC(121,123) = JacC(121,123)+ 0.9500000000000000D+00*dw( 99,123)
      JacC(123, 52) = JacC(123, 52) - dw( 99, 52)
      JacC(123,123) = JacC(123,123) - dw( 99,123)
      JacC( 15, 15) = JacC( 15, 15) - dw(100, 15)
      JacC( 15,118) = JacC( 15,118) - dw(100,118)
      JacC( 16, 15) = JacC( 16, 15)+ 0.8900000000000000D+00*dw(100, 15)
      JacC( 16,118) = JacC( 16,118)+ 0.8900000000000000D+00*dw(100,118)
      JacC( 48, 15) = JacC( 48, 15)+ 0.3900000000000000D-01*dw(100, 15)
      JacC( 48,118) = JacC( 48,118)+ 0.3900000000000000D-01*dw(100,118)
      JacC( 49, 15) = JacC( 49, 15)+ 0.1080000000000000D+00*dw(100, 15)
      JacC( 49,118) = JacC( 49,118)+ 0.1080000000000000D+00*dw(100,118)
      JacC( 55, 15) = JacC( 55, 15)+ 0.6000000000000000D-01*dw(100, 15)
      JacC( 55,118) = JacC( 55,118)+ 0.6000000000000000D-01*dw(100,118)
      JacC( 61, 15) = JacC( 61, 15)+ 0.5000000000000000D-01*dw(100, 15)
      JacC( 61,118) = JacC( 61,118)+ 0.5000000000000000D-01*dw(100,118)
      JacC(118, 15) = JacC(118, 15) - dw(100, 15)
      JacC(118,118) = JacC(118,118) - dw(100,118)
      JacC(119, 15) = JacC(119, 15)+ 0.5000000000000000D-01*dw(100, 15)
      JacC(119,118) = JacC(119,118)+ 0.5000000000000000D-01*dw(100,118)
      JacC( 13, 13) = JacC( 13, 13) - dw(101, 13)
      JacC( 13,118) = JacC( 13,118) - dw(101,118)
      JacC( 14, 13) = JacC( 14, 13)+ 0.8900000000000000D+00*dw(101, 13)
      JacC( 14,118) = JacC( 14,118)+ 0.8900000000000000D+00*dw(101,118)
      JacC( 48, 13) = JacC( 48, 13)+ 0.3900000000000000D-01*dw(101, 13)
      JacC( 48,118) = JacC( 48,118)+ 0.3900000000000000D-01*dw(101,118)
      JacC( 49, 13) = JacC( 49, 13)+ 0.1080000000000000D+00*dw(101, 13)
      JacC( 49,118) = JacC( 49,118)+ 0.1080000000000000D+00*dw(101,118)
      JacC( 55, 13) = JacC( 55, 13)+ 0.6000000000000000D-01*dw(101, 13)
      JacC( 55,118) = JacC( 55,118)+ 0.6000000000000000D-01*dw(101,118)
      JacC( 61, 13) = JacC( 61, 13)+ 0.5000000000000000D-01*dw(101, 13)
      JacC( 61,118) = JacC( 61,118)+ 0.5000000000000000D-01*dw(101,118)
      JacC(118, 13) = JacC(118, 13) - dw(101, 13)
      JacC(118,118) = JacC(118,118) - dw(101,118)
      JacC(119, 13) = JacC(119, 13)+ 0.5000000000000000D-01*dw(101, 13)
      JacC(119,118) = JacC(119,118)+ 0.5000000000000000D-01*dw(101,118)
      JacC( 55, 55) = JacC( 55, 55) - dw(102, 55)
      JacC( 55,123) = JacC( 55,123) - dw(102,123)
      JacC( 56, 55) = JacC( 56, 55) + dw(102, 55)
      JacC( 56,123) = JacC( 56,123) + dw(102,123)
      JacC(121, 55) = JacC(121, 55) + dw(102, 55)
      JacC(121,123) = JacC(121,123) + dw(102,123)
      JacC(123, 55) = JacC(123, 55) - dw(102, 55)
      JacC(123,123) = JacC(123,123) - dw(102,123)
      JacC( 14, 14) = JacC( 14, 14) - dw(103, 14)
      JacC( 27, 14) = JacC( 27, 14)+ 0.8400000000000000D+00*dw(103, 14)
      JacC( 60, 14) = JacC( 60, 14)+ 0.3080000000000000D+00*dw(103, 14)
      JacC( 61, 14) = JacC( 61, 14)+ 0.1000000000000000D-01*dw(103, 14)
      JacC( 63, 14) = JacC( 63, 14)+ 0.1500000000000000D+00*dw(103, 14)
      JacC( 65, 14) = JacC( 65, 14)+ 0.2240000000000000D+00*dw(103, 14)
      JacC(118, 14) = JacC(118, 14)+ 0.3080000000000000D+00*dw(103, 14)
      JacC(119, 14) = JacC(119, 14)+ 0.3080000000000000D+00*dw(103, 14)
      JacC( 16, 16) = JacC( 16, 16) - dw(104, 16)
      JacC( 27, 16) = JacC( 27, 16)+ 0.8400000000000000D+00*dw(104, 16)
      JacC( 61, 16) = JacC( 61, 16)+ 0.1000000000000000D-01*dw(104, 16)
      JacC( 63, 16) = JacC( 63, 16)+ 0.1500000000000000D+00*dw(104, 16)
      JacC( 64, 16) = JacC( 64, 16)+ 0.3080000000000000D+00*dw(104, 16)
      JacC( 65, 16) = JacC( 65, 16)+ 0.2240000000000000D+00*dw(104, 16)
      JacC(118, 16) = JacC(118, 16)+ 0.3080000000000000D+00*dw(104, 16)
      JacC(119, 16) = JacC(119, 16)+ 0.3080000000000000D+00*dw(104, 16)
      JacC( 60, 60) = JacC( 60, 60) - dw(105, 60)
      JacC( 61, 60) = JacC( 61, 60)+ 0.1000000000000000D-01*dw(105, 60)
      JacC( 63, 60) = JacC( 63, 60)+ 0.5000000000000000D+00*dw(105, 60)
      JacC( 65, 60) = JacC( 65, 60)+ 0.4900000000000000D+00*dw(105, 60)
      JacC(118, 60) = JacC(118, 60)+ 0.4900000000000000D+00*dw(105, 60)
      JacC(119, 60) = JacC(119, 60)+ 0.1000000000000000D-01*dw(105, 60)
      JacC( 61, 64) = JacC( 61, 64)+ 0.1000000000000000D-01*dw(106, 64)
      JacC( 63, 64) = JacC( 63, 64)+ 0.5000000000000000D+00*dw(106, 64)
      JacC( 64, 64) = JacC( 64, 64) - dw(106, 64)
      JacC( 65, 64) = JacC( 65, 64)+ 0.4900000000000000D+00*dw(106, 64)
      JacC(118, 64) = JacC(118, 64)+ 0.4900000000000000D+00*dw(106, 64)
      JacC(119, 64) = JacC(119, 64)+ 0.1000000000000000D-01*dw(106, 64)
      JacC( 60, 60) = JacC( 60, 60) - dw(107, 60)
      JacC( 60,123) = JacC( 60,123) - dw(107,123)
      JacC( 65, 60) = JacC( 65, 60)+ 0.9500000000000000D+00*dw(107, 60)
      JacC( 65,123) = JacC( 65,123)+ 0.9500000000000000D+00*dw(107,123)
      JacC(108, 60) = JacC(108, 60)+ 0.5000000000000000D-01*dw(107, 60)
      JacC(108,123) = JacC(108,123)+ 0.5000000000000000D-01*dw(107,123)
      JacC(119, 60) = JacC(119, 60)+ 0.9500000000000000D+00*dw(107, 60)
      JacC(119,123) = JacC(119,123)+ 0.9500000000000000D+00*dw(107,123)
      JacC(121, 60) = JacC(121, 60)+ 0.9500000000000000D+00*dw(107, 60)
      JacC(121,123) = JacC(121,123)+ 0.9500000000000000D+00*dw(107,123)
      JacC(123, 60) = JacC(123, 60) - dw(107, 60)
      JacC(123,123) = JacC(123,123) - dw(107,123)
      JacC( 63, 63) = JacC( 63, 63) - dw(108, 63)
      JacC( 63,123) = JacC( 63,123) - dw(108,123)
      JacC( 68, 63) = JacC( 68, 63)+ 0.9500000000000000D+00*dw(108, 63)
      JacC( 68,123) = JacC( 68,123)+ 0.9500000000000000D+00*dw(108,123)
      JacC( 69, 63) = JacC( 69, 63)+ 0.1950000000000000D+01*dw(108, 63)
      JacC( 69,123) = JacC( 69,123)+ 0.1950000000000000D+01*dw(108,123)
      JacC(100, 63) = JacC(100, 63)+ 0.9500000000000000D+00*dw(108, 63)
      JacC(100,123) = JacC(100,123)+ 0.9500000000000000D+00*dw(108,123)
      JacC(108, 63) = JacC(108, 63)+ 0.5000000000000000D-01*dw(108, 63)
      JacC(108,123) = JacC(108,123)+ 0.5000000000000000D-01*dw(108,123)
      JacC(119, 63) = JacC(119, 63)+ 0.9500000000000000D+00*dw(108, 63)
      JacC(119,123) = JacC(119,123)+ 0.9500000000000000D+00*dw(108,123)
      JacC(121, 63) = JacC(121, 63)+ 0.9500000000000000D+00*dw(108, 63)
      JacC(121,123) = JacC(121,123)+ 0.9500000000000000D+00*dw(108,123)
      JacC(123, 63) = JacC(123, 63) - dw(108, 63)
      JacC(123,123) = JacC(123,123) - dw(108,123)
      JacC( 48, 56) = JacC( 48, 56)+ 0.3900000000000000D-01*dw(109, 56)
      JacC( 48,118) = JacC( 48,118)+ 0.3900000000000000D-01*dw(109,118)
      JacC( 49, 56) = JacC( 49, 56)+ 0.1080000000000000D+00*dw(109, 56)
      JacC( 49,118) = JacC( 49,118)+ 0.1080000000000000D+00*dw(109,118)
      JacC( 56, 56) = JacC( 56, 56) - dw(109, 56)
      JacC( 56,118) = JacC( 56,118) - dw(109,118)
      JacC( 57, 56) = JacC( 57, 56) + dw(109, 56)
      JacC( 57,118) = JacC( 57,118) + dw(109,118)
      JacC(118, 56) = JacC(118, 56) - dw(109, 56)
      JacC(118,118) = JacC(118,118) - dw(109,118)
      JacC( 57, 57) = JacC( 57, 57) - dw(110, 57)
      JacC( 57,123) = JacC( 57,123) - dw(110,123)
      JacC( 58, 57) = JacC( 58, 57) + dw(110, 57)
      JacC( 58,123) = JacC( 58,123) + dw(110,123)
      JacC(121, 57) = JacC(121, 57) + dw(110, 57)
      JacC(121,123) = JacC(121,123) + dw(110,123)
      JacC(123, 57) = JacC(123, 57) - dw(110, 57)
      JacC(123,123) = JacC(123,123) - dw(110,123)
      JacC( 58, 58) = JacC( 58, 58) - dw(111, 58)
      JacC( 58,123) = JacC( 58,123) - dw(111,123)
      JacC( 59, 58) = JacC( 59, 58) + dw(111, 58)
      JacC( 59,123) = JacC( 59,123) + dw(111,123)
      JacC(121, 58) = JacC(121, 58) + dw(111, 58)
      JacC(121,123) = JacC(121,123) + dw(111,123)
      JacC(123, 58) = JacC(123, 58) - dw(111, 58)
      JacC(123,123) = JacC(123,123) - dw(111,123)
      JacC( 59, 59) = JacC( 59, 59) - dw(112, 59)
      JacC( 59,121) = JacC( 59,121) - dw(112,121)
      JacC(108, 59) = JacC(108, 59) + dw(112, 59)
      JacC(108,121) = JacC(108,121) + dw(112,121)
      JacC(121, 59) = JacC(121, 59) - dw(112, 59)
      JacC(121,121) = JacC(121,121) - dw(112,121)
      JacC( 20, 20) = JacC( 20, 20) - dw(113, 20)
      JacC( 20,118) = JacC( 20,118) - dw(113,118)
      JacC( 36, 20) = JacC( 36, 20)+ 0.7300000000000000D+00*dw(113, 20)
      JacC( 36,118) = JacC( 36,118)+ 0.7300000000000000D+00*dw(113,118)
      JacC( 48, 20) = JacC( 48, 20)+ 0.3900000000000000D-01*dw(113, 20)
      JacC( 48,118) = JacC( 48,118)+ 0.3900000000000000D-01*dw(113,118)
      JacC( 49, 20) = JacC( 49, 20)+ 0.1080000000000000D+00*dw(113, 20)
      JacC( 49,118) = JacC( 49,118)+ 0.1080000000000000D+00*dw(113,118)
      JacC( 62, 20) = JacC( 62, 20)+ 0.7000000000000001D-01*dw(113, 20)
      JacC( 62,118) = JacC( 62,118)+ 0.7000000000000001D-01*dw(113,118)
      JacC( 97, 20) = JacC( 97, 20)+ 0.2000000000000000D+00*dw(113, 20)
      JacC( 97,118) = JacC( 97,118)+ 0.2000000000000000D+00*dw(113,118)
      JacC(118, 20) = JacC(118, 20) - dw(113, 20)
      JacC(118,118) = JacC(118,118) - dw(113,118)
      JacC(119, 20) = JacC(119, 20)+ 0.7300000000000000D+00*dw(113, 20)
      JacC(119,118) = JacC(119,118)+ 0.7300000000000000D+00*dw(113,118)
      JacC( 36, 61) = JacC( 36, 61)+ 0.7300000000000000D+00*dw(114, 61)
      JacC( 36,118) = JacC( 36,118)+ 0.7300000000000000D+00*dw(114,118)
      JacC( 48, 61) = JacC( 48, 61)+ 0.3900000000000000D-01*dw(114, 61)
      JacC( 48,118) = JacC( 48,118)+ 0.3900000000000000D-01*dw(114,118)
      JacC( 49, 61) = JacC( 49, 61)+ 0.1080000000000000D+00*dw(114, 61)
      JacC( 49,118) = JacC( 49,118)+ 0.1080000000000000D+00*dw(114,118)
      JacC( 61, 61) = JacC( 61, 61) - dw(114, 61)
      JacC( 61,118) = JacC( 61,118) - dw(114,118)
      JacC( 62, 61) = JacC( 62, 61)+ 0.7000000000000001D-01*dw(114, 61)
      JacC( 62,118) = JacC( 62,118)+ 0.7000000000000001D-01*dw(114,118)
      JacC( 97, 61) = JacC( 97, 61)+ 0.2000000000000000D+00*dw(114, 61)
      JacC( 97,118) = JacC( 97,118)+ 0.2000000000000000D+00*dw(114,118)
      JacC(118, 61) = JacC(118, 61) - dw(114, 61)
      JacC(118,118) = JacC(118,118) - dw(114,118)
      JacC(119, 61) = JacC(119, 61)+ 0.7300000000000000D+00*dw(114, 61)
      JacC(119,118) = JacC(119,118)+ 0.7300000000000000D+00*dw(114,118)
      JacC( 36, 36) = JacC( 36, 36) - dw(115, 36)
      JacC( 36,118) = JacC( 36,118) - dw(115,118)
      JacC( 96, 36) = JacC( 96, 36) + dw(115, 36)
      JacC( 96,118) = JacC( 96,118) + dw(115,118)
      JacC(118, 36) = JacC(118, 36) - dw(115, 36)
      JacC(118,118) = JacC(118,118) - dw(115,118)
      JacC( 36, 36) = JacC( 36, 36) - dw(116, 36)
      JacC( 36,117) = JacC( 36,117) - dw(116,117)
      JacC( 96, 36) = JacC( 96, 36) + dw(116, 36)
      JacC( 96,117) = JacC( 96,117) + dw(116,117)
      JacC(101, 36) = JacC(101, 36) + dw(116, 36)
      JacC(101,117) = JacC(101,117) + dw(116,117)
      JacC(117, 36) = JacC(117, 36) - dw(116, 36)
      JacC(117,117) = JacC(117,117) - dw(116,117)
      JacC( 91, 96) = JacC( 91, 96) - dw(117, 96)
      JacC( 91, 91) = JacC( 91, 91) - dw(117, 91)
      JacC( 95, 96) = JacC( 95, 96) + dw(117, 96)
      JacC( 95, 91) = JacC( 95, 91) + dw(117, 91)
      JacC( 96, 96) = JacC( 96, 96) - dw(117, 96)
      JacC( 96, 91) = JacC( 96, 91) - dw(117, 91)
      JacC( 96, 96) = JacC( 96, 96) - dw(118, 96)
      JacC( 96,121) = JacC( 96,121) - dw(118,121)
      JacC(108, 96) = JacC(108, 96) + dw(118, 96)
      JacC(108,121) = JacC(108,121) + dw(118,121)
      JacC(121, 96) = JacC(121, 96) - dw(118, 96)
      JacC(121,121) = JacC(121,121) - dw(118,121)
      JacC( 95, 95) = JacC( 95, 95) - dw(119, 95)
      JacC( 95,123) = JacC( 95,123) - dw(119,123)
      JacC( 96, 95) = JacC( 96, 95) + dw(119, 95)
      JacC( 96,123) = JacC( 96,123) + dw(119,123)
      JacC(121, 95) = JacC(121, 95) + dw(119, 95)
      JacC(121,123) = JacC(121,123) + dw(119,123)
      JacC(123, 95) = JacC(123, 95) - dw(119, 95)
      JacC(123,123) = JacC(123,123) - dw(119,123)
      JacC( 95, 95) = JacC( 95, 95) - dw(120, 95)
      JacC( 95,113) = JacC( 95,113) - dw(120,113)
      JacC( 96, 95) = JacC( 96, 95) + dw(120, 95)
      JacC( 96,113) = JacC( 96,113) + dw(120,113)
      JacC(113, 95) = JacC(113, 95) - dw(120, 95)
      JacC(113,113) = JacC(113,113) - dw(120,113)
      JacC(116, 95) = JacC(116, 95) + dw(120, 95)
      JacC(116,113) = JacC(116,113) + dw(120,113)
      JacC(119, 95) = JacC(119, 95) + dw(120, 95)
      JacC(119,113) = JacC(119,113) + dw(120,113)
      JacC( 95, 95) = JacC( 95, 95) - dw(121, 95)
      JacC( 95,122) = JacC( 95,122) - dw(121,122)
      JacC( 96, 95) = JacC( 96, 95) + dw(121, 95)
      JacC( 96,122) = JacC( 96,122) + dw(121,122)
      JacC(113, 95) = JacC(113, 95) + dw(121, 95)
      JacC(113,122) = JacC(113,122) + dw(121,122)
      JacC(119, 95) = JacC(119, 95) + dw(121, 95)
      JacC(119,122) = JacC(119,122) + dw(121,122)
      JacC(122, 95) = JacC(122, 95) - dw(121, 95)
      JacC(122,122) = JacC(122,122) - dw(121,122)
      JacC( 95, 95) = JacC( 95, 95) - dw(122, 95)
      JacC( 95,119) = JacC( 95,119) - dw(122,119)
      JacC(115, 95) = JacC(115, 95) + dw(122, 95)
      JacC(115,119) = JacC(115,119) + dw(122,119)
      JacC(119, 95) = JacC(119, 95) - dw(122, 95)
      JacC(119,119) = JacC(119,119) - dw(122,119)
      JacC( 95, 95) = JacC( 95, 95) - dw(123, 95)
      JacC( 95,117) = JacC( 95,117) - dw(123,117)
      JacC( 96, 95) = JacC( 96, 95) + dw(123, 95)
      JacC( 96,117) = JacC( 96,117) + dw(123,117)
      JacC(117, 95) = JacC(117, 95) - dw(123, 95)
      JacC(117,117) = JacC(117,117) - dw(123,117)
      JacC(121, 95) = JacC(121, 95) + dw(123, 95)
      JacC(121,117) = JacC(121,117) + dw(123,117)
      JacC(107,116) = JacC(107,116) + dw(124,116)
      JacC(107,118) = JacC(107,118) + dw(124,118)
      JacC(116,116) = JacC(116,116) - dw(124,116)
      JacC(116,118) = JacC(116,118) - dw(124,118)
      JacC(118,116) = JacC(118,116) - dw(124,116)
      JacC(118,118) = JacC(118,118) - dw(124,118)
      JacC(119,116) = JacC(119,116) + dw(124,116)
      JacC(119,118) = JacC(119,118) + dw(124,118)
      JacC( 94, 94) = JacC( 94, 94) - dw(125, 94)
      JacC( 94,118) = JacC( 94,118) - dw(125,118)
      JacC(118, 94) = JacC(118, 94) - dw(125, 94)
      JacC(118,118) = JacC(118,118) - dw(125,118)
      JacC(122, 94) = JacC(122, 94) + dw(125, 94)
      JacC(122,118) = JacC(122,118) + dw(125,118)
      JacC(109,109) = JacC(109,109) - dw(126,109)
      JacC(109,118) = JacC(109,118) - dw(126,118)
      JacC(118,109) = JacC(118,109) - dw(126,109)
      JacC(118,118) = JacC(118,118) - dw(126,118)
      JacC(120,109) = JacC(120,109) + dw(126,109)
      JacC(120,118) = JacC(120,118) + dw(126,118)
      JacC( 73, 73) = JacC( 73, 73) - dw(127, 73)
      JacC( 73,118) = JacC( 73,118) - dw(127,118)
      JacC( 78, 73) = JacC( 78, 73) + dw(127, 73)
      JacC( 78,118) = JacC( 78,118) + dw(127,118)
      JacC(118, 73) = JacC(118, 73) - dw(127, 73)
      JacC(118,118) = JacC(118,118) - dw(127,118)
      JacC( 37, 37) = JacC( 37, 37) - dw(128, 37)
      JacC( 37,118) = JacC( 37,118) - dw(128,118)
      JacC( 67, 37) = JacC( 67, 37) + dw(128, 37)
      JacC( 67,118) = JacC( 67,118) + dw(128,118)
      JacC(118, 37) = JacC(118, 37) - dw(128, 37)
      JacC(118,118) = JacC(118,118) - dw(128,118)
      JacC(105,111) = JacC(105,111) + dw(129,111)
      JacC(105,118) = JacC(105,118) + dw(129,118)
      JacC(111,111) = JacC(111,111) - dw(129,111)
      JacC(111,118) = JacC(111,118) - dw(129,118)
      JacC(118,111) = JacC(118,111) - dw(129,111)
      JacC(118,118) = JacC(118,118) - dw(129,118)
      JacC( 75, 75) = JacC( 75, 75) - dw(130, 75)
      JacC( 75,118) = JacC( 75,118) - dw(130,118)
      JacC(100, 75) = JacC(100, 75) + dw(130, 75)
      JacC(100,118) = JacC(100,118) + dw(130,118)
      JacC(118, 75) = JacC(118, 75) - dw(130, 75)
      JacC(118,118) = JacC(118,118) - dw(130,118)
      JacC(119, 75) = JacC(119, 75) + dw(130, 75)
      JacC(119,118) = JacC(119,118) + dw(130,118)
      JacC(102,102) = JacC(102,102) - dw(131,102)
      JacC(102,118) = JacC(102,118) - dw(131,118)
      JacC(107,102) = JacC(107,102)+ 0.2000000000000000D+01*dw(131,102)
      JacC(107,118) = JacC(107,118)+ 0.2000000000000000D+01*dw(131,118)
      JacC(118,102) = JacC(118,102) - dw(131,102)
      JacC(118,118) = JacC(118,118) - dw(131,118)
      JacC(119,102) = JacC(119,102) + dw(131,102)
      JacC(119,118) = JacC(119,118) + dw(131,118)
      JacC(100,100) = JacC(100,100) - dw(132,100)
      JacC(100,118) = JacC(100,118) - dw(132,118)
      JacC(107,100) = JacC(107,100) + dw(132,100)
      JacC(107,118) = JacC(107,118) + dw(132,118)
      JacC(118,100) = JacC(118,100) - dw(132,100)
      JacC(118,118) = JacC(118,118) - dw(132,118)
      JacC(122,100) = JacC(122,100) + dw(132,100)
      JacC(122,118) = JacC(122,118) + dw(132,118)
      JacC( 92, 92) = JacC( 92, 92) - dw(133, 92)
      JacC( 92,118) = JacC( 92,118) - dw(133,118)
      JacC(104, 92) = JacC(104, 92) + dw(133, 92)
      JacC(104,118) = JacC(104,118) + dw(133,118)
      JacC(118, 92) = JacC(118, 92) - dw(133, 92)
      JacC(118,118) = JacC(118,118) - dw(133,118)
      JacC( 81, 81) = JacC( 81, 81) - dw(134, 81)
      JacC( 81,118) = JacC( 81,118) - dw(134,118)
      JacC( 82, 81) = JacC( 82, 81) + dw(134, 81)
      JacC( 82,118) = JacC( 82,118) + dw(134,118)
      JacC(118, 81) = JacC(118, 81) - dw(134, 81)
      JacC(118,118) = JacC(118,118) - dw(134,118)
      JacC( 83, 83) = JacC( 83, 83) - dw(135, 83)
      JacC( 83,118) = JacC( 83,118) - dw(135,118)
      JacC( 84, 83) = JacC( 84, 83)+ 0.6870000000000001D+00*dw(135, 83)
      JacC( 84,118) = JacC( 84,118)+ 0.6870000000000001D+00*dw(135,118)
      JacC(118, 83) = JacC(118, 83) - dw(135, 83)
      JacC(118,118) = JacC(118,118) - dw(135,118)
      JacC(122, 83) = JacC(122, 83)+ 0.3130000000000000D+00*dw(135, 83)
      JacC(122,118) = JacC(122,118)+ 0.3130000000000000D+00*dw(135,118)
      JacC( 27, 27) = JacC( 27, 27) - dw(136, 27)
      JacC( 27,118) = JacC( 27,118) - dw(136,118)
      JacC(107, 27) = JacC(107, 27) + dw(136, 27)
      JacC(107,118) = JacC(107,118) + dw(136,118)
      JacC(109, 27) = JacC(109, 27) + dw(136, 27)
      JacC(109,118) = JacC(109,118) + dw(136,118)
      JacC(112, 27) = JacC(112, 27) + dw(136, 27)
      JacC(112,118) = JacC(112,118) + dw(136,118)
      JacC(118, 27) = JacC(118, 27) - dw(136, 27)
      JacC(118,118) = JacC(118,118) - dw(136,118)
      JacC(119, 27) = JacC(119, 27) + dw(136, 27)
      JacC(119,118) = JacC(119,118) + dw(136,118)
      JacC( 65, 65) = JacC( 65, 65) - dw(137, 65)
      JacC( 65,118) = JacC( 65,118) - dw(137,118)
      JacC(109, 65) = JacC(109, 65) + dw(137, 65)
      JacC(109,118) = JacC(109,118) + dw(137,118)
      JacC(112, 65) = JacC(112, 65) + dw(137, 65)
      JacC(112,118) = JacC(112,118) + dw(137,118)
      JacC(118, 65) = JacC(118, 65) - dw(137, 65)
      JacC(118,118) = JacC(118,118) - dw(137,118)
      JacC(122, 65) = JacC(122, 65) + dw(137, 65)
      JacC(122,118) = JacC(122,118) + dw(137,118)
      JacC( 68, 68) = JacC( 68, 68) - dw(138, 68)
      JacC( 68,118) = JacC( 68,118) - dw(138,118)
      JacC(109, 68) = JacC(109, 68) + dw(138, 68)
      JacC(109,118) = JacC(109,118) + dw(138,118)
      JacC(112, 68) = JacC(112, 68) + dw(138, 68)
      JacC(112,118) = JacC(112,118) + dw(138,118)
      JacC(118, 68) = JacC(118, 68) - dw(138, 68)
      JacC(118,118) = JacC(118,118) - dw(138,118)
      JacC(122, 68) = JacC(122, 68) + dw(138, 68)
      JacC(122,118) = JacC(122,118) + dw(138,118)
      JacC( 69, 69) = JacC( 69, 69) - dw(139, 69)
      JacC( 69,118) = JacC( 69,118) - dw(139,118)
      JacC(107, 69) = JacC(107, 69) + dw(139, 69)
      JacC(107,118) = JacC(107,118) + dw(139,118)
      JacC(118, 69) = JacC(118, 69) - dw(139, 69)
      JacC(118,118) = JacC(118,118) - dw(139,118)
      JacC(122, 69) = JacC(122, 69) + dw(139, 69)
      JacC(122,118) = JacC(122,118) + dw(139,118)
      JacC( 40, 40) = JacC( 40, 40) - dw(140, 40)
      JacC( 40,118) = JacC( 40,118) - dw(140,118)
      JacC(113, 40) = JacC(113, 40)+ 0.6500000000000000D+00*dw(140, 40)
      JacC(113,118) = JacC(113,118)+ 0.6500000000000000D+00*dw(140,118)
      JacC(116, 40) = JacC(116, 40)+ 0.3500000000000000D+00*dw(140, 40)
      JacC(116,118) = JacC(116,118)+ 0.3500000000000000D+00*dw(140,118)
      JacC(118, 40) = JacC(118, 40)- 0.6500000000000000D+00*dw(140, 40)
      JacC(118,118) = JacC(118,118)- 0.6500000000000000D+00*dw(140,118)
      JacC(109,115) = JacC(109,115)+ 0.8000000000000000D-01*dw(141,115)
      JacC(109,118) = JacC(109,118)+ 0.8000000000000000D-01*dw(141,118)
      JacC(110,115) = JacC(110,115)+ 0.4400000000000000D+00*dw(141,115)
      JacC(110,118) = JacC(110,118)+ 0.4400000000000000D+00*dw(141,118)
      JacC(111,115) = JacC(111,115)+ 0.4100000000000000D+00*dw(141,115)
      JacC(111,118) = JacC(111,118)+ 0.4100000000000000D+00*dw(141,118)
      JacC(112,115) = JacC(112,115)+ 0.7000000000000001D-01*dw(141,115)
      JacC(112,118) = JacC(112,118)+ 0.7000000000000001D-01*dw(141,118)
      JacC(115,115) = JacC(115,115) - dw(141,115)
      JacC(115,118) = JacC(115,118) - dw(141,118)
      JacC(118,115) = JacC(118,115)- 0.5100000000000000D+00*dw(141,115)
      JacC(118,118) = JacC(118,118)- 0.5100000000000000D+00*dw(141,118)
      JacC( 70, 70) = JacC( 70, 70) - dw(142, 70)
      JacC( 70,118) = JacC( 70,118) - dw(142,118)
      JacC(112, 70) = JacC(112, 70)+ 0.3500000000000000D+00*dw(142, 70)
      JacC(112,118) = JacC(112,118)+ 0.3500000000000000D+00*dw(142,118)
      JacC(116, 70) = JacC(116, 70)+ 0.3500000000000000D+00*dw(142, 70)
      JacC(116,118) = JacC(116,118)+ 0.3500000000000000D+00*dw(142,118)
      JacC(118, 70) = JacC(118, 70)- 0.6500000000000000D+00*dw(142, 70)
      JacC(118,118) = JacC(118,118)- 0.6500000000000000D+00*dw(142,118)
      JacC(122, 70) = JacC(122, 70)+ 0.6500000000000000D+00*dw(142, 70)
      JacC(122,118) = JacC(122,118)+ 0.6500000000000000D+00*dw(142,118)
      JacC( 41, 41) = JacC( 41, 41) - dw(143, 41)
      JacC( 41,118) = JacC( 41,118) - dw(143,118)
      JacC(112, 41) = JacC(112, 41) + dw(143, 41)
      JacC(112,118) = JacC(112,118) + dw(143,118)
      JacC(116, 41) = JacC(116, 41) + dw(143, 41)
      JacC(116,118) = JacC(116,118) + dw(143,118)
      JacC(117, 41) = JacC(117, 41) + dw(143, 41)
      JacC(117,118) = JacC(117,118) + dw(143,118)
      JacC(118, 41) = JacC(118, 41) - dw(143, 41)
      JacC(118,118) = JacC(118,118) - dw(143,118)
      JacC( 42, 42) = JacC( 42, 42) - dw(144, 42)
      JacC( 42,118) = JacC( 42,118) - dw(144,118)
      JacC(112, 42) = JacC(112, 42) + dw(144, 42)
      JacC(112,118) = JacC(112,118) + dw(144,118)
      JacC(116, 42) = JacC(116, 42) + dw(144, 42)
      JacC(116,118) = JacC(116,118) + dw(144,118)
      JacC(117, 42) = JacC(117, 42) + dw(144, 42)
      JacC(117,118) = JacC(117,118) + dw(144,118)
      JacC(118, 42) = JacC(118, 42) - dw(144, 42)
      JacC(118,118) = JacC(118,118) - dw(144,118)
      JacC( 46, 46) = JacC( 46, 46) - dw(145, 46)
      JacC( 46,118) = JacC( 46,118) - dw(145,118)
      JacC( 93, 46) = JacC( 93, 46) + dw(145, 46)
      JacC( 93,118) = JacC( 93,118) + dw(145,118)
      JacC(118, 46) = JacC(118, 46) - dw(145, 46)
      JacC(118,118) = JacC(118,118) - dw(145,118)
      JacC(121, 46) = JacC(121, 46) + dw(145, 46)
      JacC(121,118) = JacC(121,118) + dw(145,118)
      JacC(108,108) = JacC(108,108) - dw(146,108)
      JacC(108,118) = JacC(108,118) - dw(146,118)
      JacC(110,108) = JacC(110,108) + dw(146,108)
      JacC(110,118) = JacC(110,118) + dw(146,118)
      JacC(118,108) = JacC(118,108) - dw(146,108)
      JacC(118,118) = JacC(118,118) - dw(146,118)
      JacC(121,108) = JacC(121,108) + dw(146,108)
      JacC(121,118) = JacC(121,118) + dw(146,118)
      JacC( 74, 74) = JacC( 74, 74) - dw(147, 74)
      JacC( 74,118) = JacC( 74,118) - dw(147,118)
      JacC(118, 74) = JacC(118, 74) - dw(147, 74)
      JacC(118,118) = JacC(118,118) - dw(147,118)
      JacC(119, 74) = JacC(119, 74) + dw(147, 74)
      JacC(119,118) = JacC(119,118) + dw(147,118)
      JacC(103,106) = JacC(103,106)+ 0.3600000000000000D+00*dw(148,106)
      JacC(103,118) = JacC(103,118)+ 0.3600000000000000D+00*dw(148,118)
      JacC(106,106) = JacC(106,106) - dw(148,106)
      JacC(106,118) = JacC(106,118) - dw(148,118)
      JacC(113,106) = JacC(113,106)+ 0.6400000000000000D+00*dw(148,106)
      JacC(113,118) = JacC(113,118)+ 0.6400000000000000D+00*dw(148,118)
      JacC(118,106) = JacC(118,106) - dw(148,106)
      JacC(118,118) = JacC(118,118) - dw(148,118)
      JacC(101,116) = JacC(101,116) + dw(149,116)
      JacC(101,117) = JacC(101,117) + dw(149,117)
      JacC(107,116) = JacC(107,116) + dw(149,116)
      JacC(107,117) = JacC(107,117) + dw(149,117)
      JacC(116,116) = JacC(116,116) - dw(149,116)
      JacC(116,117) = JacC(116,117) - dw(149,117)
      JacC(117,116) = JacC(117,116) - dw(149,116)
      JacC(117,117) = JacC(117,117) - dw(149,117)
      JacC(119,116) = JacC(119,116) + dw(149,116)
      JacC(119,117) = JacC(119,117) + dw(149,117)
      JacC( 94, 94) = JacC( 94, 94) - dw(150, 94)
      JacC( 94,117) = JacC( 94,117) - dw(150,117)
      JacC(101, 94) = JacC(101, 94) + dw(150, 94)
      JacC(101,117) = JacC(101,117) + dw(150,117)
      JacC(117, 94) = JacC(117, 94) - dw(150, 94)
      JacC(117,117) = JacC(117,117) - dw(150,117)
      JacC(122, 94) = JacC(122, 94) + dw(150, 94)
      JacC(122,117) = JacC(122,117) + dw(150,117)
      JacC(101,109) = JacC(101,109) + dw(151,109)
      JacC(101,117) = JacC(101,117) + dw(151,117)
      JacC(109,109) = JacC(109,109) - dw(151,109)
      JacC(109,117) = JacC(109,117) - dw(151,117)
      JacC(117,109) = JacC(117,109) - dw(151,109)
      JacC(117,117) = JacC(117,117) - dw(151,117)
      JacC(120,109) = JacC(120,109) + dw(151,109)
      JacC(120,117) = JacC(120,117) + dw(151,117)
      JacC(101,102) = JacC(101,102) + dw(152,102)
      JacC(101,117) = JacC(101,117) + dw(152,117)
      JacC(102,102) = JacC(102,102) - dw(152,102)
      JacC(102,117) = JacC(102,117) - dw(152,117)
      JacC(107,102) = JacC(107,102)+ 0.2000000000000000D+01*dw(152,102)
      JacC(107,117) = JacC(107,117)+ 0.2000000000000000D+01*dw(152,117)
      JacC(117,102) = JacC(117,102) - dw(152,102)
      JacC(117,117) = JacC(117,117) - dw(152,117)
      JacC(119,102) = JacC(119,102) + dw(152,102)
      JacC(119,117) = JacC(119,117) + dw(152,117)
      JacC(100,100) = JacC(100,100) - dw(153,100)
      JacC(100,117) = JacC(100,117) - dw(153,117)
      JacC(101,100) = JacC(101,100) + dw(153,100)
      JacC(101,117) = JacC(101,117) + dw(153,117)
      JacC(107,100) = JacC(107,100) + dw(153,100)
      JacC(107,117) = JacC(107,117) + dw(153,117)
      JacC(117,100) = JacC(117,100) - dw(153,100)
      JacC(117,117) = JacC(117,117) - dw(153,117)
      JacC(122,100) = JacC(122,100) + dw(153,100)
      JacC(122,117) = JacC(122,117) + dw(153,117)
      JacC( 27, 27) = JacC( 27, 27) - dw(154, 27)
      JacC( 27,117) = JacC( 27,117) - dw(154,117)
      JacC(101, 27) = JacC(101, 27)+ 0.5000000000000000D+00*dw(154, 27)
      JacC(101,117) = JacC(101,117)+ 0.5000000000000000D+00*dw(154,117)
      JacC(102, 27) = JacC(102, 27) + dw(154, 27)
      JacC(102,117) = JacC(102,117) + dw(154,117)
      JacC(107, 27) = JacC(107, 27)+ 0.1500000000000000D+01*dw(154, 27)
      JacC(107,117) = JacC(107,117)+ 0.1500000000000000D+01*dw(154,117)
      JacC(117, 27) = JacC(117, 27) - dw(154, 27)
      JacC(117,117) = JacC(117,117) - dw(154,117)
      JacC(118, 27) = JacC(118, 27)+ 0.5000000000000000D+00*dw(154, 27)
      JacC(118,117) = JacC(118,117)+ 0.5000000000000000D+00*dw(154,117)
      JacC(119, 27) = JacC(119, 27)+ 0.1500000000000000D+01*dw(154, 27)
      JacC(119,117) = JacC(119,117)+ 0.1500000000000000D+01*dw(154,117)
      JacC(121, 27) = JacC(121, 27)+ 0.5000000000000000D+00*dw(154, 27)
      JacC(121,117) = JacC(121,117)+ 0.5000000000000000D+00*dw(154,117)
      JacC( 20, 20) = JacC( 20, 20) - dw(155, 20)
      JacC( 20,117) = JacC( 20,117) - dw(155,117)
      JacC( 48, 20) = JacC( 48, 20)+ 0.3900000000000000D-01*dw(155, 20)
      JacC( 48,117) = JacC( 48,117)+ 0.3900000000000000D-01*dw(155,117)
      JacC( 49, 20) = JacC( 49, 20)+ 0.1080000000000000D+00*dw(155, 20)
      JacC( 49,117) = JacC( 49,117)+ 0.1080000000000000D+00*dw(155,117)
      JacC( 62, 20) = JacC( 62, 20)+ 0.4000000000000000D+00*dw(155, 20)
      JacC( 62,117) = JacC( 62,117)+ 0.4000000000000000D+00*dw(155,117)
      JacC( 66, 20) = JacC( 66, 20)+ 0.5000000000000000D+00*dw(155, 20)
      JacC( 66,117) = JacC( 66,117)+ 0.5000000000000000D+00*dw(155,117)
      JacC( 97, 20) = JacC( 97, 20)+ 0.1000000000000000D+00*dw(155, 20)
      JacC( 97,117) = JacC( 97,117)+ 0.1000000000000000D+00*dw(155,117)
      JacC(101, 20) = JacC(101, 20)+ 0.5000000000000000D+00*dw(155, 20)
      JacC(101,117) = JacC(101,117)+ 0.5000000000000000D+00*dw(155,117)
      JacC(117, 20) = JacC(117, 20) - dw(155, 20)
      JacC(117,117) = JacC(117,117) - dw(155,117)
      JacC( 48, 61) = JacC( 48, 61)+ 0.3900000000000000D-01*dw(156, 61)
      JacC( 48,117) = JacC( 48,117)+ 0.3900000000000000D-01*dw(156,117)
      JacC( 49, 61) = JacC( 49, 61)+ 0.1080000000000000D+00*dw(156, 61)
      JacC( 49,117) = JacC( 49,117)+ 0.1080000000000000D+00*dw(156,117)
      JacC( 61, 61) = JacC( 61, 61) - dw(156, 61)
      JacC( 61,117) = JacC( 61,117) - dw(156,117)
      JacC( 62, 61) = JacC( 62, 61)+ 0.4000000000000000D+00*dw(156, 61)
      JacC( 62,117) = JacC( 62,117)+ 0.4000000000000000D+00*dw(156,117)
      JacC( 66, 61) = JacC( 66, 61)+ 0.5000000000000000D+00*dw(156, 61)
      JacC( 66,117) = JacC( 66,117)+ 0.5000000000000000D+00*dw(156,117)
      JacC( 97, 61) = JacC( 97, 61)+ 0.1000000000000000D+00*dw(156, 61)
      JacC( 97,117) = JacC( 97,117)+ 0.1000000000000000D+00*dw(156,117)
      JacC(101, 61) = JacC(101, 61)+ 0.5000000000000000D+00*dw(156, 61)
      JacC(101,117) = JacC(101,117)+ 0.5000000000000000D+00*dw(156,117)
      JacC(117, 61) = JacC(117, 61) - dw(156, 61)
      JacC(117,117) = JacC(117,117) - dw(156,117)
      JacC( 66, 66) = JacC( 66, 66) - dw(157, 66)
      JacC( 66,123) = JacC( 66,123) - dw(157,123)
      JacC(102, 66) = JacC(102, 66) + dw(157, 66)
      JacC(102,123) = JacC(102,123) + dw(157,123)
      JacC(115, 66) = JacC(115, 66) + dw(157, 66)
      JacC(115,123) = JacC(115,123) + dw(157,123)
      JacC(121, 66) = JacC(121, 66)+ 0.2000000000000000D+01*dw(157, 66)
      JacC(121,123) = JacC(121,123)+ 0.2000000000000000D+01*dw(157,123)
      JacC(123, 66) = JacC(123, 66) - dw(157, 66)
      JacC(123,123) = JacC(123,123) - dw(157,123)
      JacC( 66, 66) = JacC( 66, 66) - dw(158, 66)
      JacC( 66,117) = JacC( 66,117) - dw(158,117)
      JacC(102, 66) = JacC(102, 66) + dw(158, 66)
      JacC(102,117) = JacC(102,117) + dw(158,117)
      JacC(115, 66) = JacC(115, 66) + dw(158, 66)
      JacC(115,117) = JacC(115,117) + dw(158,117)
      JacC(117, 66) = JacC(117, 66) - dw(158, 66)
      JacC(117,117) = JacC(117,117) - dw(158,117)
      JacC(121, 66) = JacC(121, 66)+ 0.2000000000000000D+01*dw(158, 66)
      JacC(121,117) = JacC(121,117)+ 0.2000000000000000D+01*dw(158,117)
      JacC( 66, 66) = JacC( 66, 66) - dw(159, 66)
      JacC( 66,113) = JacC( 66,113) - dw(159,113)
      JacC(102, 66) = JacC(102, 66)+ 0.7000000000000000D+00*dw(159, 66)
      JacC(102,113) = JacC(102,113)+ 0.7000000000000000D+00*dw(159,113)
      JacC(108, 66) = JacC(108, 66)+ 0.3000000000000000D+00*dw(159, 66)
      JacC(108,113) = JacC(108,113)+ 0.3000000000000000D+00*dw(159,113)
      JacC(113, 66) = JacC(113, 66) - dw(159, 66)
      JacC(113,113) = JacC(113,113) - dw(159,113)
      JacC(115, 66) = JacC(115, 66)+ 0.7000000000000000D+00*dw(159, 66)
      JacC(115,113) = JacC(115,113)+ 0.7000000000000000D+00*dw(159,113)
      JacC(116, 66) = JacC(116, 66) + dw(159, 66)
      JacC(116,113) = JacC(116,113) + dw(159,113)
      JacC(119, 66) = JacC(119, 66) + dw(159, 66)
      JacC(119,113) = JacC(119,113) + dw(159,113)
      JacC(121, 66) = JacC(121, 66)+ 0.7000000000000000D+00*dw(159, 66)
      JacC(121,113) = JacC(121,113)+ 0.7000000000000000D+00*dw(159,113)
      JacC( 66, 66) = JacC( 66, 66) - dw(160, 66)
      JacC( 66,122) = JacC( 66,122) - dw(160,122)
      JacC(102, 66) = JacC(102, 66)+ 0.7000000000000000D+00*dw(160, 66)
      JacC(102,122) = JacC(102,122)+ 0.7000000000000000D+00*dw(160,122)
      JacC(108, 66) = JacC(108, 66)+ 0.3000000000000000D+00*dw(160, 66)
      JacC(108,122) = JacC(108,122)+ 0.3000000000000000D+00*dw(160,122)
      JacC(113, 66) = JacC(113, 66) + dw(160, 66)
      JacC(113,122) = JacC(113,122) + dw(160,122)
      JacC(115, 66) = JacC(115, 66)+ 0.7000000000000000D+00*dw(160, 66)
      JacC(115,122) = JacC(115,122)+ 0.7000000000000000D+00*dw(160,122)
      JacC(119, 66) = JacC(119, 66) + dw(160, 66)
      JacC(119,122) = JacC(119,122) + dw(160,122)
      JacC(121, 66) = JacC(121, 66)+ 0.7000000000000000D+00*dw(160, 66)
      JacC(121,122) = JacC(121,122)+ 0.7000000000000000D+00*dw(160,122)
      JacC(122, 66) = JacC(122, 66) - dw(160, 66)
      JacC(122,122) = JacC(122,122) - dw(160,122)
      JacC( 66, 66) = JacC( 66, 66) - dw(161, 66)
      JacC( 66,119) = JacC( 66,119) - dw(161,119)
      JacC(115, 66) = JacC(115, 66) + dw(161, 66)
      JacC(115,119) = JacC(115,119) + dw(161,119)
      JacC(119, 66) = JacC(119, 66) - dw(161, 66)
      JacC(119,119) = JacC(119,119) - dw(161,119)
      JacC( 28, 28) = JacC( 28, 28) - dw(162, 28)
      JacC( 28,117) = JacC( 28,117) - dw(162,117)
      JacC( 88, 28) = JacC( 88, 28)+ 0.2000000000000000D+00*dw(162, 28)
      JacC( 88,117) = JacC( 88,117)+ 0.2000000000000000D+00*dw(162,117)
      JacC( 90, 28) = JacC( 90, 28)+ 0.8000000000000000D+00*dw(162, 28)
      JacC( 90,117) = JacC( 90,117)+ 0.8000000000000000D+00*dw(162,117)
      JacC(117, 28) = JacC(117, 28) - dw(162, 28)
      JacC(117,117) = JacC(117,117) - dw(162,117)
      JacC( 38, 38) = JacC( 38, 38) - dw(163, 38)
      JacC( 38,117) = JacC( 38,117) - dw(163,117)
      JacC( 50, 38) = JacC( 50, 38)+ 0.8000000000000000D-02*dw(163, 38)
      JacC( 50,117) = JacC( 50,117)+ 0.8000000000000000D-02*dw(163,117)
      JacC( 88, 38) = JacC( 88, 38)+ 0.5700000000000000D+00*dw(163, 38)
      JacC( 88,117) = JacC( 88,117)+ 0.5700000000000000D+00*dw(163,117)
      JacC( 90, 38) = JacC( 90, 38)+ 0.4300000000000000D+00*dw(163, 38)
      JacC( 90,117) = JacC( 90,117)+ 0.4300000000000000D+00*dw(163,117)
      JacC(117, 38) = JacC(117, 38) - dw(163, 38)
      JacC(117,117) = JacC(117,117) - dw(163,117)
      JacC( 50, 86) = JacC( 50, 86)+ 0.8000000000000000D-02*dw(164, 86)
      JacC( 50,117) = JacC( 50,117)+ 0.8000000000000000D-02*dw(164,117)
      JacC( 86, 86) = JacC( 86, 86) - dw(164, 86)
      JacC( 86,117) = JacC( 86,117) - dw(164,117)
      JacC( 88, 86) = JacC( 88, 86)+ 0.8900000000000000D+00*dw(164, 86)
      JacC( 88,117) = JacC( 88,117)+ 0.8900000000000000D+00*dw(164,117)
      JacC( 90, 86) = JacC( 90, 86)+ 0.1100000000000000D+00*dw(164, 86)
      JacC( 90,117) = JacC( 90,117)+ 0.1100000000000000D+00*dw(164,117)
      JacC(117, 86) = JacC(117, 86) - dw(164, 86)
      JacC(117,117) = JacC(117,117) - dw(164,117)
      JacC( 25, 25) = JacC( 25, 25) - dw(165, 25)
      JacC( 25,117) = JacC( 25,117) - dw(165,117)
      JacC( 88, 25) = JacC( 88, 25)+ 0.1000000000000000D+00*dw(165, 25)
      JacC( 88,117) = JacC( 88,117)+ 0.1000000000000000D+00*dw(165,117)
      JacC( 90, 25) = JacC( 90, 25)+ 0.9000000000000000D+00*dw(165, 25)
      JacC( 90,117) = JacC( 90,117)+ 0.9000000000000000D+00*dw(165,117)
      JacC( 92, 25) = JacC( 92, 25)+ 0.9000000000000000D+00*dw(165, 25)
      JacC( 92,117) = JacC( 92,117)+ 0.9000000000000000D+00*dw(165,117)
      JacC(117, 25) = JacC(117, 25) - dw(165, 25)
      JacC(117,117) = JacC(117,117) - dw(165,117)
      JacC( 31, 31) = JacC( 31, 31) - dw(166, 31)
      JacC( 31,117) = JacC( 31,117) - dw(166,117)
      JacC( 45, 31) = JacC( 45, 31) + dw(166, 31)
      JacC( 45,117) = JacC( 45,117) + dw(166,117)
      JacC(117, 31) = JacC(117, 31) - dw(166, 31)
      JacC(117,117) = JacC(117,117) - dw(166,117)
      JacC( 92, 92) = JacC( 92, 92) - dw(167, 92)
      JacC( 92,117) = JacC( 92,117) - dw(167,117)
      JacC(101, 92) = JacC(101, 92)+ 0.5000000000000000D+00*dw(167, 92)
      JacC(101,117) = JacC(101,117)+ 0.5000000000000000D+00*dw(167,117)
      JacC(104, 92) = JacC(104, 92)+ 0.5000000000000000D+00*dw(167, 92)
      JacC(104,117) = JacC(104,117)+ 0.5000000000000000D+00*dw(167,117)
      JacC(107, 92) = JacC(107, 92)+ 0.5000000000000000D+00*dw(167, 92)
      JacC(107,117) = JacC(107,117)+ 0.5000000000000000D+00*dw(167,117)
      JacC(108, 92) = JacC(108, 92)+ 0.5000000000000000D+00*dw(167, 92)
      JacC(108,117) = JacC(108,117)+ 0.5000000000000000D+00*dw(167,117)
      JacC(112, 92) = JacC(112, 92)+ 0.5000000000000000D+00*dw(167, 92)
      JacC(112,117) = JacC(112,117)+ 0.5000000000000000D+00*dw(167,117)
      JacC(117, 92) = JacC(117, 92) - dw(167, 92)
      JacC(117,117) = JacC(117,117) - dw(167,117)
      JacC(119, 92) = JacC(119, 92)+ 0.5000000000000000D+00*dw(167, 92)
      JacC(119,117) = JacC(119,117)+ 0.5000000000000000D+00*dw(167,117)
      JacC( 83, 83) = JacC( 83, 83) - dw(168, 83)
      JacC( 83,117) = JacC( 83,117) - dw(168,117)
      JacC(107, 83) = JacC(107, 83)+ 0.6680000000000000D+00*dw(168, 83)
      JacC(107,117) = JacC(107,117)+ 0.6680000000000000D+00*dw(168,117)
      JacC(108, 83) = JacC(108, 83) + dw(168, 83)
      JacC(108,117) = JacC(108,117) + dw(168,117)
      JacC(109, 83) = JacC(109, 83)+ 0.3320000000000000D+00*dw(168, 83)
      JacC(109,117) = JacC(109,117)+ 0.3320000000000000D+00*dw(168,117)
      JacC(112, 83) = JacC(112, 83) + dw(168, 83)
      JacC(112,117) = JacC(112,117) + dw(168,117)
      JacC(116, 83) = JacC(116, 83)+ 0.3320000000000000D+00*dw(168, 83)
      JacC(116,117) = JacC(116,117)+ 0.3320000000000000D+00*dw(168,117)
      JacC(117, 83) = JacC(117, 83) - dw(168, 83)
      JacC(117,117) = JacC(117,117) - dw(168,117)
      JacC(119, 83) = JacC(119, 83) + dw(168, 83)
      JacC(119,117) = JacC(119,117) + dw(168,117)
      JacC( 21, 21) = JacC( 21, 21) - dw(169, 21)
      JacC( 21,117) = JacC( 21,117) - dw(169,117)
      JacC( 88, 21) = JacC( 88, 21)+ 0.9000000000000000D+00*dw(169, 21)
      JacC( 88,117) = JacC( 88,117)+ 0.9000000000000000D+00*dw(169,117)
      JacC( 90, 21) = JacC( 90, 21)+ 0.1000000000000000D+00*dw(169, 21)
      JacC( 90,117) = JacC( 90,117)+ 0.1000000000000000D+00*dw(169,117)
      JacC(117, 21) = JacC(117, 21) - dw(169, 21)
      JacC(117,117) = JacC(117,117) - dw(169,117)
      JacC( 32, 32) = JacC( 32, 32) - dw(170, 32)
      JacC( 32,117) = JacC( 32,117) - dw(170,117)
      JacC( 88, 32) = JacC( 88, 32)+ 0.8700000000000000D+00*dw(170, 32)
      JacC( 88,117) = JacC( 88,117)+ 0.8700000000000000D+00*dw(170,117)
      JacC( 90, 32) = JacC( 90, 32)+ 0.1300000000000000D+00*dw(170, 32)
      JacC( 90,117) = JacC( 90,117)+ 0.1300000000000000D+00*dw(170,117)
      JacC(117, 32) = JacC(117, 32) - dw(170, 32)
      JacC(117,117) = JacC(117,117) - dw(170,117)
      JacC( 46, 46) = JacC( 46, 46) - dw(171, 46)
      JacC( 46,117) = JacC( 46,117) - dw(171,117)
      JacC(104, 46) = JacC(104, 46) + dw(171, 46)
      JacC(104,117) = JacC(104,117) + dw(171,117)
      JacC(117, 46) = JacC(117, 46) - dw(171, 46)
      JacC(117,117) = JacC(117,117) - dw(171,117)
      JacC(121, 46) = JacC(121, 46) + dw(171, 46)
      JacC(121,117) = JacC(121,117) + dw(171,117)
      JacC( 28, 28) = JacC( 28, 28) - dw(172, 28)
      JacC( 28, 91) = JacC( 28, 91) - dw(172, 91)
      JacC( 74, 28) = JacC( 74, 28)+ 0.3700000000000000D+00*dw(172, 28)
      JacC( 74, 91) = JacC( 74, 91)+ 0.3700000000000000D+00*dw(172, 91)
      JacC( 91, 28) = JacC( 91, 28) - dw(172, 28)
      JacC( 91, 91) = JacC( 91, 91) - dw(172, 91)
      JacC(107, 28) = JacC(107, 28)+ 0.4300000000000000D+00*dw(172, 28)
      JacC(107, 91) = JacC(107, 91)+ 0.4300000000000000D+00*dw(172, 91)
      JacC(116, 28) = JacC(116, 28) + dw(172, 28)
      JacC(116, 91) = JacC(116, 91) + dw(172, 91)
      JacC(118, 28) = JacC(118, 28)+ 0.1200000000000000D+00*dw(172, 28)
      JacC(118, 91) = JacC(118, 91)+ 0.1200000000000000D+00*dw(172, 91)
      JacC(119, 28) = JacC(119, 28)+ 0.2600000000000000D+00*dw(172, 28)
      JacC(119, 91) = JacC(119, 91)+ 0.2600000000000000D+00*dw(172, 91)
      JacC( 38, 38) = JacC( 38, 38) - dw(173, 38)
      JacC( 38, 91) = JacC( 38, 91) - dw(173, 91)
      JacC( 39, 38) = JacC( 39, 38)+ 0.3000000000000000D-01*dw(173, 38)
      JacC( 39, 91) = JacC( 39, 91)+ 0.3000000000000000D-01*dw(173, 91)
      JacC( 44, 38) = JacC( 44, 38)+ 0.6000000000000000D-01*dw(173, 38)
      JacC( 44, 91) = JacC( 44, 91)+ 0.6000000000000000D-01*dw(173, 91)
      JacC( 50, 38) = JacC( 50, 38)+ 0.8000000000000000D-02*dw(173, 38)
      JacC( 50, 91) = JacC( 50, 91)+ 0.8000000000000000D-02*dw(173, 91)
      JacC( 51, 38) = JacC( 51, 38)+ 0.6000000000000000D-02*dw(173, 38)
      JacC( 51, 91) = JacC( 51, 91)+ 0.6000000000000000D-02*dw(173, 91)
      JacC( 74, 38) = JacC( 74, 38)+ 0.1400000000000000D+00*dw(173, 38)
      JacC( 74, 91) = JacC( 74, 91)+ 0.1400000000000000D+00*dw(173, 91)
      JacC( 91, 38) = JacC( 91, 38) - dw(173, 38)
      JacC( 91, 91) = JacC( 91, 91) - dw(173, 91)
      JacC(105, 38) = JacC(105, 38)+ 0.3000000000000000D-01*dw(173, 38)
      JacC(105, 91) = JacC(105, 91)+ 0.3000000000000000D-01*dw(173, 91)
      JacC(106, 38) = JacC(106, 38)+ 0.1000000000000000D+00*dw(173, 38)
      JacC(106, 91) = JacC(106, 91)+ 0.1000000000000000D+00*dw(173, 91)
      JacC(107, 38) = JacC(107, 38)+ 0.3700000000000000D+00*dw(173, 38)
      JacC(107, 91) = JacC(107, 91)+ 0.3700000000000000D+00*dw(173, 91)
      JacC(109, 38) = JacC(109, 38)+ 0.4400000000000000D+00*dw(173, 38)
      JacC(109, 91) = JacC(109, 91)+ 0.4400000000000000D+00*dw(173, 91)
      JacC(111, 38) = JacC(111, 38)+ 0.3000000000000000D-01*dw(173, 38)
      JacC(111, 91) = JacC(111, 91)+ 0.3000000000000000D-01*dw(173, 91)
      JacC(113, 38) = JacC(113, 38)+ 0.1900000000000000D+00*dw(173, 38)
      JacC(113, 91) = JacC(113, 91)+ 0.1900000000000000D+00*dw(173, 91)
      JacC(114, 38) = JacC(114, 38)+ 0.1000000000000000D+00*dw(173, 38)
      JacC(114, 91) = JacC(114, 91)+ 0.1000000000000000D+00*dw(173, 91)
      JacC(116, 38) = JacC(116, 38)+ 0.6400000000000000D+00*dw(173, 38)
      JacC(116, 91) = JacC(116, 91)+ 0.6400000000000000D+00*dw(173, 91)
      JacC(118, 38) = JacC(118, 38)+ 0.4000000000000000D+00*dw(173, 38)
      JacC(118, 91) = JacC(118, 91)+ 0.4000000000000000D+00*dw(173, 91)
      JacC(119, 38) = JacC(119, 38)+ 0.2500000000000000D+00*dw(173, 38)
      JacC(119, 91) = JacC(119, 91)+ 0.2500000000000000D+00*dw(173, 91)
      JacC( 39, 86) = JacC( 39, 86)+ 0.6000000000000000D-01*dw(174, 86)
      JacC( 39, 91) = JacC( 39, 91)+ 0.6000000000000000D-01*dw(174, 91)
      JacC( 44, 86) = JacC( 44, 86)+ 0.7000000000000001D-01*dw(174, 86)
      JacC( 44, 91) = JacC( 44, 91)+ 0.7000000000000001D-01*dw(174, 91)
      JacC( 50, 86) = JacC( 50, 86)+ 0.8000000000000000D-02*dw(174, 86)
      JacC( 50, 91) = JacC( 50, 91)+ 0.8000000000000000D-02*dw(174, 91)
      JacC( 51, 86) = JacC( 51, 86)+ 0.1100000000000000D-01*dw(174, 86)
      JacC( 51, 91) = JacC( 51, 91)+ 0.1100000000000000D-01*dw(174, 91)
      JacC( 86, 86) = JacC( 86, 86) - dw(174, 86)
      JacC( 86, 91) = JacC( 86, 91) - dw(174, 91)
      JacC( 91, 86) = JacC( 91, 86) - dw(174, 86)
      JacC( 91, 91) = JacC( 91, 91) - dw(174, 91)
      JacC(105, 86) = JacC(105, 86)+ 0.1200000000000000D+00*dw(174, 86)
      JacC(105, 91) = JacC(105, 91)+ 0.1200000000000000D+00*dw(174, 91)
      JacC(106, 86) = JacC(106, 86)+ 0.1400000000000000D+00*dw(174, 86)
      JacC(106, 91) = JacC(106, 91)+ 0.1400000000000000D+00*dw(174, 91)
      JacC(107, 86) = JacC(107, 86)+ 0.3000000000000000D+00*dw(174, 86)
      JacC(107, 91) = JacC(107, 91)+ 0.3000000000000000D+00*dw(174, 91)
      JacC(109, 86) = JacC(109, 86)+ 0.9900000000000000D+00*dw(174, 86)
      JacC(109, 91) = JacC(109, 91)+ 0.9900000000000000D+00*dw(174, 91)
      JacC(111, 86) = JacC(111, 86)+ 0.1600000000000000D+00*dw(174, 86)
      JacC(111, 91) = JacC(111, 91)+ 0.1600000000000000D+00*dw(174, 91)
      JacC(113, 86) = JacC(113, 86)+ 0.2300000000000000D+00*dw(174, 86)
      JacC(113, 91) = JacC(113, 91)+ 0.2300000000000000D+00*dw(174, 91)
      JacC(114, 86) = JacC(114, 86)+ 0.1800000000000000D+00*dw(174, 86)
      JacC(114, 91) = JacC(114, 91)+ 0.1800000000000000D+00*dw(174, 91)
      JacC(116, 86) = JacC(116, 86)+ 0.2000000000000000D-01*dw(174, 86)
      JacC(116, 91) = JacC(116, 91)+ 0.2000000000000000D-01*dw(174, 91)
      JacC(118, 86) = JacC(118, 86)+ 0.6300000000000000D+00*dw(174, 86)
      JacC(118, 91) = JacC(118, 91)+ 0.6300000000000000D+00*dw(174, 91)
      JacC(119, 86) = JacC(119, 86)+ 0.2200000000000000D+00*dw(174, 86)
      JacC(119, 91) = JacC(119, 91)+ 0.2200000000000000D+00*dw(174, 91)
      JacC( 25, 25) = JacC( 25, 25) - dw(175, 25)
      JacC( 25, 91) = JacC( 25, 91) - dw(175, 91)
      JacC( 38, 25) = JacC( 38, 25)+ 0.3500000000000000D+00*dw(175, 25)
      JacC( 38, 91) = JacC( 38, 91)+ 0.3500000000000000D+00*dw(175, 91)
      JacC( 47, 25) = JacC( 47, 25)+ 0.9000000000000000D-01*dw(175, 25)
      JacC( 47, 91) = JacC( 47, 91)+ 0.9000000000000000D-01*dw(175, 91)
      JacC( 51, 25) = JacC( 51, 25)+ 0.1000000000000000D-02*dw(175, 25)
      JacC( 51, 91) = JacC( 51, 91)+ 0.1000000000000000D-02*dw(175, 91)
      JacC( 74, 25) = JacC( 74, 25)+ 0.1500000000000000D+00*dw(175, 25)
      JacC( 74, 91) = JacC( 74, 91)+ 0.1500000000000000D+00*dw(175, 91)
      JacC( 91, 25) = JacC( 91, 25) - dw(175, 25)
      JacC( 91, 91) = JacC( 91, 91) - dw(175, 91)
      JacC( 92, 25) = JacC( 92, 25)+ 0.3900000000000000D+00*dw(175, 25)
      JacC( 92, 91) = JacC( 92, 91)+ 0.3900000000000000D+00*dw(175, 91)
      JacC(105, 25) = JacC(105, 25)+ 0.2000000000000000D-01*dw(175, 25)
      JacC(105, 91) = JacC(105, 91)+ 0.2000000000000000D-01*dw(175, 91)
      JacC(107, 25) = JacC(107, 25)+ 0.3600000000000000D+00*dw(175, 25)
      JacC(107, 91) = JacC(107, 91)+ 0.3600000000000000D+00*dw(175, 91)
      JacC(112, 25) = JacC(112, 25)+ 0.1300000000000000D+00*dw(175, 25)
      JacC(112, 91) = JacC(112, 91)+ 0.1300000000000000D+00*dw(175, 91)
      JacC(113, 25) = JacC(113, 25)+ 0.3000000000000000D-01*dw(175, 25)
      JacC(113, 91) = JacC(113, 91)+ 0.3000000000000000D-01*dw(175, 91)
      JacC(116, 25) = JacC(116, 25)+ 0.9000000000000000D+00*dw(175, 25)
      JacC(116, 91) = JacC(116, 91)+ 0.9000000000000000D+00*dw(175, 91)
      JacC(118, 25) = JacC(118, 25)+ 0.2800000000000000D+00*dw(175, 25)
      JacC(118, 91) = JacC(118, 91)+ 0.2800000000000000D+00*dw(175, 91)
      JacC(119, 25) = JacC(119, 25)+ 0.3000000000000000D+00*dw(175, 25)
      JacC(119, 91) = JacC(119, 91)+ 0.3000000000000000D+00*dw(175, 91)
      JacC(122, 25) = JacC(122, 25)+ 0.1500000000000000D+00*dw(175, 25)
      JacC(122, 91) = JacC(122, 91)+ 0.1500000000000000D+00*dw(175, 91)
      JacC( 31, 31) = JacC( 31, 31) - dw(176, 31)
      JacC( 31, 91) = JacC( 31, 91) - dw(176, 91)
      JacC( 51, 31) = JacC( 51, 31)+ 0.9000000000000000D-01*dw(176, 31)
      JacC( 51, 91) = JacC( 51, 91)+ 0.9000000000000000D-01*dw(176, 91)
      JacC( 74, 31) = JacC( 74, 31)+ 0.2800000000000000D+00*dw(176, 31)
      JacC( 74, 91) = JacC( 74, 91)+ 0.2800000000000000D+00*dw(176, 91)
      JacC( 81, 31) = JacC( 81, 31)+ 0.1890000000000000D+00*dw(176, 31)
      JacC( 81, 91) = JacC( 81, 91)+ 0.1890000000000000D+00*dw(176, 91)
      JacC( 91, 31) = JacC( 91, 31) - dw(176, 31)
      JacC( 91, 91) = JacC( 91, 91) - dw(176, 91)
      JacC( 92, 31) = JacC( 92, 31)+ 0.4610000000000000D+00*dw(176, 31)
      JacC( 92, 91) = JacC( 92, 91)+ 0.4610000000000000D+00*dw(176, 91)
      JacC(104, 31) = JacC(104, 31)+ 0.1000000000000000D+00*dw(176, 31)
      JacC(104, 91) = JacC(104, 91)+ 0.1000000000000000D+00*dw(176, 91)
      JacC(107, 31) = JacC(107, 31)+ 0.1400000000000000D+00*dw(176, 31)
      JacC(107, 91) = JacC(107, 91)+ 0.1400000000000000D+00*dw(176, 91)
      JacC(113, 31) = JacC(113, 31)+ 0.8000000000000000D-01*dw(176, 31)
      JacC(113, 91) = JacC(113, 91)+ 0.8000000000000000D-01*dw(176, 91)
      JacC(116, 31) = JacC(116, 31)+ 0.5800000000000000D+00*dw(176, 31)
      JacC(116, 91) = JacC(116, 91)+ 0.5800000000000000D+00*dw(176, 91)
      JacC(118, 31) = JacC(118, 31)+ 0.2500000000000000D+00*dw(176, 31)
      JacC(118, 91) = JacC(118, 91)+ 0.2500000000000000D+00*dw(176, 91)
      JacC(119, 31) = JacC(119, 31)+ 0.2500000000000000D+00*dw(176, 31)
      JacC(119, 91) = JacC(119, 91)+ 0.2500000000000000D+00*dw(176, 91)
      JacC(122, 31) = JacC(122, 31)+ 0.1000000000000000D+00*dw(176, 31)
      JacC(122, 91) = JacC(122, 91)+ 0.1000000000000000D+00*dw(176, 91)
      JacC( 74, 92) = JacC( 74, 92)+ 0.4500000000000000D+00*dw(177, 92)
      JacC( 74, 91) = JacC( 74, 91)+ 0.4500000000000000D+00*dw(177, 91)
      JacC( 91, 92) = JacC( 91, 92) - dw(177, 92)
      JacC( 91, 91) = JacC( 91, 91) - dw(177, 91)
      JacC( 92, 92) = JacC( 92, 92) - dw(177, 92)
      JacC( 92, 91) = JacC( 92, 91) - dw(177, 91)
      JacC(100, 92) = JacC(100, 92)+ 0.9000000000000000D+00*dw(177, 92)
      JacC(100, 91) = JacC(100, 91)+ 0.9000000000000000D+00*dw(177, 91)
      JacC(107, 92) = JacC(107, 92)+ 0.2200000000000000D+00*dw(177, 92)
      JacC(107, 91) = JacC(107, 91)+ 0.2200000000000000D+00*dw(177, 91)
      JacC(118, 92) = JacC(118, 92)+ 0.1900000000000000D+00*dw(177, 92)
      JacC(118, 91) = JacC(118, 91)+ 0.1900000000000000D+00*dw(177, 91)
      JacC(119, 92) = JacC(119, 92)+ 0.3200000000000000D+00*dw(177, 92)
      JacC(119, 91) = JacC(119, 91)+ 0.3200000000000000D+00*dw(177, 91)
      JacC(122, 92) = JacC(122, 92)+ 0.1000000000000000D+00*dw(177, 92)
      JacC(122, 91) = JacC(122, 91)+ 0.1000000000000000D+00*dw(177, 91)
      JacC( 74, 81) = JacC( 74, 81)+ 0.6700000000000000D+00*dw(178, 81)
      JacC( 74, 91) = JacC( 74, 91)+ 0.6700000000000000D+00*dw(178, 91)
      JacC( 81, 81) = JacC( 81, 81) - dw(178, 81)
      JacC( 81, 91) = JacC( 81, 91) - dw(178, 91)
      JacC( 91, 81) = JacC( 91, 81) - dw(178, 81)
      JacC( 91, 91) = JacC( 91, 91) - dw(178, 91)
      JacC(100, 81) = JacC(100, 81)+ 0.9500000000000000D+00*dw(178, 81)
      JacC(100, 91) = JacC(100, 91)+ 0.9500000000000000D+00*dw(178, 91)
      JacC(107, 81) = JacC(107, 81)+ 0.1100000000000000D+00*dw(178, 81)
      JacC(107, 91) = JacC(107, 91)+ 0.1100000000000000D+00*dw(178, 91)
      JacC(112, 81) = JacC(112, 81)+ 0.5000000000000000D-01*dw(178, 81)
      JacC(112, 91) = JacC(112, 91)+ 0.5000000000000000D-01*dw(178, 91)
      JacC(116, 81) = JacC(116, 81)+ 0.1000000000000000D+00*dw(178, 81)
      JacC(116, 91) = JacC(116, 91)+ 0.1000000000000000D+00*dw(178, 91)
      JacC(118, 81) = JacC(118, 81)+ 0.1600000000000000D+00*dw(178, 81)
      JacC(118, 91) = JacC(118, 91)+ 0.1600000000000000D+00*dw(178, 91)
      JacC(119, 81) = JacC(119, 81)+ 0.1100000000000000D+00*dw(178, 81)
      JacC(119, 91) = JacC(119, 91)+ 0.1100000000000000D+00*dw(178, 91)
      JacC(122, 81) = JacC(122, 81)+ 0.5000000000000000D-01*dw(178, 81)
      JacC(122, 91) = JacC(122, 91)+ 0.5000000000000000D-01*dw(178, 91)
      JacC( 74, 83) = JacC( 74, 83)+ 0.4400000000000000D-01*dw(179, 83)
      JacC( 74, 91) = JacC( 74, 91)+ 0.4400000000000000D-01*dw(179, 91)
      JacC( 83, 83) = JacC( 83, 83) - dw(179, 83)
      JacC( 83, 91) = JacC( 83, 91) - dw(179, 91)
      JacC( 91, 83) = JacC( 91, 83) - dw(179, 83)
      JacC( 91, 91) = JacC( 91, 91) - dw(179, 91)
      JacC(100, 83) = JacC(100, 83)+ 0.6530000000000000D+00*dw(179, 83)
      JacC(100, 91) = JacC(100, 91)+ 0.6530000000000000D+00*dw(179, 91)
      JacC(102, 83) = JacC(102, 83)+ 0.3100000000000000D-01*dw(179, 83)
      JacC(102, 91) = JacC(102, 91)+ 0.3100000000000000D-01*dw(179, 91)
      JacC(107, 83) = JacC(107, 83)+ 0.2430000000000000D+00*dw(179, 83)
      JacC(107, 91) = JacC(107, 91)+ 0.2430000000000000D+00*dw(179, 91)
      JacC(109, 83) = JacC(109, 83)+ 0.6200000000000000D-01*dw(179, 83)
      JacC(109, 91) = JacC(109, 91)+ 0.6200000000000000D-01*dw(179, 91)
      JacC(111, 83) = JacC(111, 83)+ 0.2780000000000000D+00*dw(179, 83)
      JacC(111, 91) = JacC(111, 91)+ 0.2780000000000000D+00*dw(179, 91)
      JacC(112, 83) = JacC(112, 83)+ 0.1000000000000000D+00*dw(179, 83)
      JacC(112, 91) = JacC(112, 91)+ 0.1000000000000000D+00*dw(179, 91)
      JacC(113, 83) = JacC(113, 83)+ 0.1680000000000000D+00*dw(179, 83)
      JacC(113, 91) = JacC(113, 91)+ 0.1680000000000000D+00*dw(179, 91)
      JacC(116, 83) = JacC(116, 83)+ 0.2180000000000000D+00*dw(179, 83)
      JacC(116, 91) = JacC(116, 91)+ 0.2180000000000000D+00*dw(179, 91)
      JacC(118, 83) = JacC(118, 83)+ 0.4760000000000000D+00*dw(179, 83)
      JacC(118, 91) = JacC(118, 91)+ 0.4760000000000000D+00*dw(179, 91)
      JacC(119, 83) = JacC(119, 83)+ 0.7199999999999999D-01*dw(179, 83)
      JacC(119, 91) = JacC(119, 91)+ 0.7199999999999999D-01*dw(179, 91)
      JacC(122, 83) = JacC(122, 83)+ 0.2370000000000000D+00*dw(179, 83)
      JacC(122, 91) = JacC(122, 91)+ 0.2370000000000000D+00*dw(179, 91)
      JacC( 21, 21) = JacC( 21, 21) - dw(180, 21)
      JacC( 21, 91) = JacC( 21, 91) - dw(180, 91)
      JacC( 22, 21) = JacC( 22, 21)+ 0.2160000000000000D-01*dw(180, 21)
      JacC( 22, 91) = JacC( 22, 91)+ 0.2160000000000000D-01*dw(180, 91)
      JacC( 23, 21) = JacC( 23, 21)+ 0.1860000000000000D+00*dw(180, 21)
      JacC( 23, 91) = JacC( 23, 91)+ 0.1860000000000000D+00*dw(180, 91)
      JacC( 51, 21) = JacC( 51, 21)+ 0.2000000000000000D-01*dw(180, 21)
      JacC( 51, 91) = JacC( 51, 91)+ 0.2000000000000000D-01*dw(180, 91)
      JacC( 91, 21) = JacC( 91, 21) - dw(180, 21)
      JacC( 91, 91) = JacC( 91, 91) - dw(180, 91)
      JacC(105, 21) = JacC(105, 21)+ 0.4200000000000000D+00*dw(180, 21)
      JacC(105, 91) = JacC(105, 91)+ 0.4200000000000000D+00*dw(180, 91)
      JacC(107, 21) = JacC(107, 21)+ 0.1400000000000000D+00*dw(180, 21)
      JacC(107, 91) = JacC(107, 91)+ 0.1400000000000000D+00*dw(180, 91)
      JacC(109, 21) = JacC(109, 21)+ 0.6500000000000000D+00*dw(180, 21)
      JacC(109, 91) = JacC(109, 91)+ 0.6500000000000000D+00*dw(180, 91)
      JacC(111, 21) = JacC(111, 21)+ 0.5300000000000000D+00*dw(180, 21)
      JacC(111, 91) = JacC(111, 91)+ 0.5300000000000000D+00*dw(180, 91)
      JacC(114, 21) = JacC(114, 21)+ 0.2000000000000000D+00*dw(180, 21)
      JacC(114, 91) = JacC(114, 91)+ 0.2000000000000000D+00*dw(180, 91)
      JacC(118, 21) = JacC(118, 21)+ 0.8500000000000000D+00*dw(180, 21)
      JacC(118, 91) = JacC(118, 91)+ 0.8500000000000000D+00*dw(180, 91)
      JacC(119, 21) = JacC(119, 21)+ 0.1000000000000000D+00*dw(180, 21)
      JacC(119, 91) = JacC(119, 91)+ 0.1000000000000000D+00*dw(180, 91)
      JacC( 32, 32) = JacC( 32, 32) - dw(181, 32)
      JacC( 32, 91) = JacC( 32, 91) - dw(181, 91)
      JacC( 33, 32) = JacC( 33, 32)+ 0.1260000000000000D+00*dw(181, 32)
      JacC( 33, 91) = JacC( 33, 91)+ 0.1260000000000000D+00*dw(181, 91)
      JacC( 34, 32) = JacC( 34, 32)+ 0.1910000000000000D+00*dw(181, 32)
      JacC( 34, 91) = JacC( 34, 91)+ 0.1910000000000000D+00*dw(181, 91)
      JacC( 38, 32) = JacC( 38, 32)+ 0.4600000000000000D+00*dw(181, 32)
      JacC( 38, 91) = JacC( 38, 91)+ 0.4600000000000000D+00*dw(181, 91)
      JacC( 51, 32) = JacC( 51, 32)+ 0.2000000000000000D-01*dw(181, 32)
      JacC( 51, 91) = JacC( 51, 91)+ 0.2000000000000000D-01*dw(181, 91)
      JacC( 74, 32) = JacC( 74, 32)+ 0.1000000000000000D-01*dw(181, 32)
      JacC( 74, 91) = JacC( 74, 91)+ 0.1000000000000000D-01*dw(181, 91)
      JacC( 91, 32) = JacC( 91, 32) - dw(181, 32)
      JacC( 91, 91) = JacC( 91, 91) - dw(181, 91)
      JacC( 92, 32) = JacC( 92, 32)+ 0.7900000000000000D+00*dw(181, 32)
      JacC( 92, 91) = JacC( 92, 91)+ 0.7900000000000000D+00*dw(181, 91)
      JacC(105, 32) = JacC(105, 32)+ 0.4200000000000000D+00*dw(181, 32)
      JacC(105, 91) = JacC(105, 91)+ 0.4200000000000000D+00*dw(181, 91)
      JacC(106, 32) = JacC(106, 32)+ 0.7000000000000001D-01*dw(181, 32)
      JacC(106, 91) = JacC(106, 91)+ 0.7000000000000001D-01*dw(181, 91)
      JacC(107, 32) = JacC(107, 32)+ 0.1400000000000000D+00*dw(181, 32)
      JacC(107, 91) = JacC(107, 91)+ 0.1400000000000000D+00*dw(181, 91)
      JacC(114, 32) = JacC(114, 32)+ 0.1600000000000000D+00*dw(181, 32)
      JacC(114, 91) = JacC(114, 91)+ 0.1600000000000000D+00*dw(181, 91)
      JacC(116, 32) = JacC(116, 32)+ 0.4000000000000000D-01*dw(181, 32)
      JacC(116, 91) = JacC(116, 91)+ 0.4000000000000000D-01*dw(181, 91)
      JacC(118, 32) = JacC(118, 32)+ 0.8500000000000000D+00*dw(181, 32)
      JacC(118, 91) = JacC(118, 91)+ 0.8500000000000000D+00*dw(181, 91)
      JacC(119, 32) = JacC(119, 32)+ 0.1000000000000000D+00*dw(181, 32)
      JacC(119, 91) = JacC(119, 91)+ 0.1000000000000000D+00*dw(181, 91)
      JacC( 27, 27) = JacC( 27, 27) - dw(182, 27)
      JacC( 27, 91) = JacC( 27, 91) - dw(182, 91)
      JacC( 91, 27) = JacC( 91, 27) - dw(182, 27)
      JacC( 91, 91) = JacC( 91, 91) - dw(182, 91)
      JacC(102, 27) = JacC(102, 27) + dw(182, 27)
      JacC(102, 91) = JacC(102, 91) + dw(182, 91)
      JacC(107, 27) = JacC(107, 27)+ 0.1500000000000000D+01*dw(182, 27)
      JacC(107, 91) = JacC(107, 91)+ 0.1500000000000000D+01*dw(182, 91)
      JacC(118, 27) = JacC(118, 27)+ 0.5000000000000000D+00*dw(182, 27)
      JacC(118, 91) = JacC(118, 91)+ 0.5000000000000000D+00*dw(182, 91)
      JacC(119, 27) = JacC(119, 27)+ 0.1500000000000000D+01*dw(182, 27)
      JacC(119, 91) = JacC(119, 91)+ 0.1500000000000000D+01*dw(182, 91)
      JacC( 69, 69) = JacC( 69, 69) - dw(183, 69)
      JacC( 69, 91) = JacC( 69, 91) - dw(183, 91)
      JacC( 70, 69) = JacC( 70, 69)+ 0.1100000000000000D+00*dw(183, 69)
      JacC( 70, 91) = JacC( 70, 91)+ 0.1100000000000000D+00*dw(183, 91)
      JacC( 74, 69) = JacC( 74, 69)+ 0.2500000000000000D+00*dw(183, 69)
      JacC( 74, 91) = JacC( 74, 91)+ 0.2500000000000000D+00*dw(183, 91)
      JacC( 91, 69) = JacC( 91, 69) - dw(183, 69)
      JacC( 91, 91) = JacC( 91, 91) - dw(183, 91)
      JacC(100, 69) = JacC(100, 69)+ 0.2480000000000000D+01*dw(183, 69)
      JacC(100, 91) = JacC(100, 91)+ 0.2480000000000000D+01*dw(183, 91)
      JacC(106, 69) = JacC(106, 69)+ 0.2500000000000000D+00*dw(183, 69)
      JacC(106, 91) = JacC(106, 91)+ 0.2500000000000000D+00*dw(183, 91)
      JacC(107, 69) = JacC(107, 69)+ 0.1500000000000000D+01*dw(183, 69)
      JacC(107, 91) = JacC(107, 91)+ 0.1500000000000000D+01*dw(183, 91)
      JacC(118, 69) = JacC(118, 69)+ 0.5000000000000000D+00*dw(183, 69)
      JacC(118, 91) = JacC(118, 91)+ 0.5000000000000000D+00*dw(183, 91)
      JacC(119, 69) = JacC(119, 69) + dw(183, 69)
      JacC(119, 91) = JacC(119, 91) + dw(183, 91)
      JacC( 62, 62) = JacC( 62, 62) - dw(184, 62)
      JacC( 62,121) = JacC( 62,121) - dw(184,121)
      JacC(108, 62) = JacC(108, 62) + dw(184, 62)
      JacC(108,121) = JacC(108,121) + dw(184,121)
      JacC(121, 62) = JacC(121, 62) - dw(184, 62)
      JacC(121,121) = JacC(121,121) - dw(184,121)
      JacC( 41,122) = JacC( 41,122) + dw(185,122)
      JacC( 41,121) = JacC( 41,121) + dw(185,121)
      JacC(121,122) = JacC(121,122) - dw(185,122)
      JacC(121,121) = JacC(121,121) - dw(185,121)
      JacC(122,122) = JacC(122,122) - dw(185,122)
      JacC(122,121) = JacC(122,121) - dw(185,121)
      JacC( 42,120) = JacC( 42,120) + dw(186,120)
      JacC( 42,121) = JacC( 42,121) + dw(186,121)
      JacC(120,120) = JacC(120,120) - dw(186,120)
      JacC(120,121) = JacC(120,121) - dw(186,121)
      JacC(121,120) = JacC(121,120) - dw(186,120)
      JacC(121,121) = JacC(121,121) - dw(186,121)
      JacC( 41, 41) = JacC( 41, 41) - dw(187, 41)
      JacC(121, 41) = JacC(121, 41) + dw(187, 41)
      JacC(122, 41) = JacC(122, 41) + dw(187, 41)
      JacC( 42, 42) = JacC( 42, 42) - dw(188, 42)
      JacC(120, 42) = JacC(120, 42) + dw(188, 42)
      JacC(121, 42) = JacC(121, 42) + dw(188, 42)
      JacC( 46,104) = JacC( 46,104) + dw(189,104)
      JacC( 46,121) = JacC( 46,121) + dw(189,121)
      JacC(104,104) = JacC(104,104) - dw(189,104)
      JacC(104,121) = JacC(104,121) - dw(189,121)
      JacC(121,104) = JacC(121,104) - dw(189,104)
      JacC(121,121) = JacC(121,121) - dw(189,121)
      JacC( 46, 46) = JacC( 46, 46) - dw(190, 46)
      JacC(104, 46) = JacC(104, 46) + dw(190, 46)
      JacC(121, 46) = JacC(121, 46) + dw(190, 46)
      JacC(113,113) = JacC(113,113) - dw(191,113)
      JacC(113,123) = JacC(113,123) - dw(191,123)
      JacC(116,113) = JacC(116,113) + dw(191,113)
      JacC(116,123) = JacC(116,123) + dw(191,123)
      JacC(119,113) = JacC(119,113) + dw(191,113)
      JacC(119,123) = JacC(119,123) + dw(191,123)
      JacC(121,113) = JacC(121,113) + dw(191,113)
      JacC(121,123) = JacC(121,123) + dw(191,123)
      JacC(123,113) = JacC(123,113) - dw(191,113)
      JacC(123,123) = JacC(123,123) - dw(191,123)
      JacC( 94,114) = JacC( 94,114) + dw(192,114)
      JacC( 94,123) = JacC( 94,123) + dw(192,123)
      JacC(114,114) = JacC(114,114) - dw(192,114)
      JacC(114,123) = JacC(114,123) - dw(192,123)
      JacC(119,114) = JacC(119,114) + dw(192,114)
      JacC(119,123) = JacC(119,123) + dw(192,123)
      JacC(121,114) = JacC(121,114) + dw(192,114)
      JacC(121,123) = JacC(121,123) + dw(192,123)
      JacC(123,114) = JacC(123,114) - dw(192,114)
      JacC(123,123) = JacC(123,123) - dw(192,123)
      JacC( 73,110) = JacC( 73,110)+ 0.6230000000000000D+00*dw(193,110)
      JacC( 73,123) = JacC( 73,123)+ 0.6230000000000000D+00*dw(193,123)
      JacC(102,110) = JacC(102,110)+ 0.6300000000000000D-01*dw(193,110)
      JacC(102,123) = JacC(102,123)+ 0.6300000000000000D-01*dw(193,123)
      JacC(108,110) = JacC(108,110)+ 0.5900000000000000D-01*dw(193,110)
      JacC(108,123) = JacC(108,123)+ 0.5900000000000000D-01*dw(193,123)
      JacC(109,110) = JacC(109,110)+ 0.2330000000000000D+00*dw(193,110)
      JacC(109,123) = JacC(109,123)+ 0.2330000000000000D+00*dw(193,123)
      JacC(110,110) = JacC(110,110) - dw(193,110)
      JacC(110,123) = JacC(110,123) - dw(193,123)
      JacC(112,110) = JacC(112,110)+ 0.4800000000000000D-01*dw(193,110)
      JacC(112,123) = JacC(112,123)+ 0.4800000000000000D-01*dw(193,123)
      JacC(113,110) = JacC(113,110)+ 0.1500000000000000D+00*dw(193,110)
      JacC(113,123) = JacC(113,123)+ 0.1500000000000000D+00*dw(193,123)
      JacC(114,110) = JacC(114,110)+ 0.4800000000000000D-01*dw(193,110)
      JacC(114,123) = JacC(114,123)+ 0.4800000000000000D-01*dw(193,123)
      JacC(116,110) = JacC(116,110)+ 0.4700000000000000D-01*dw(193,110)
      JacC(116,123) = JacC(116,123)+ 0.4700000000000000D-01*dw(193,123)
      JacC(119,110) = JacC(119,110)+ 0.7420000000000000D+00*dw(193,110)
      JacC(119,123) = JacC(119,123)+ 0.7420000000000000D+00*dw(193,123)
      JacC(121,110) = JacC(121,110)+ 0.9409999999999999D+00*dw(193,110)
      JacC(121,123) = JacC(121,123)+ 0.9409999999999999D+00*dw(193,123)
      JacC(123,110) = JacC(123,110) - dw(193,110)
      JacC(123,123) = JacC(123,123) - dw(193,123)
      JacC( 37, 76) = JacC( 37, 76)+ 0.1220000000000000D+00*dw(194, 76)
      JacC( 37,123) = JacC( 37,123)+ 0.1220000000000000D+00*dw(194,123)
      JacC( 73, 76) = JacC( 73, 76)+ 0.1000000000000000D+00*dw(194, 76)
      JacC( 73,123) = JacC( 73,123)+ 0.1000000000000000D+00*dw(194,123)
      JacC( 76, 76) = JacC( 76, 76) - dw(194, 76)
      JacC( 76,123) = JacC( 76,123) - dw(194,123)
      JacC(108, 76) = JacC(108, 76)+ 0.1240000000000000D+00*dw(194, 76)
      JacC(108,123) = JacC(108,123)+ 0.1240000000000000D+00*dw(194,123)
      JacC(109, 76) = JacC(109, 76)+ 0.2110000000000000D+00*dw(194, 76)
      JacC(109,123) = JacC(109,123)+ 0.2110000000000000D+00*dw(194,123)
      JacC(111, 76) = JacC(111, 76)+ 0.5000000000000000D+00*dw(194, 76)
      JacC(111,123) = JacC(111,123)+ 0.5000000000000000D+00*dw(194,123)
      JacC(112, 76) = JacC(112, 76)+ 0.3340000000000000D+00*dw(194, 76)
      JacC(112,123) = JacC(112,123)+ 0.3340000000000000D+00*dw(194,123)
      JacC(113, 76) = JacC(113, 76)+ 0.3100000000000000D-01*dw(194, 76)
      JacC(113,123) = JacC(113,123)+ 0.3100000000000000D-01*dw(194,123)
      JacC(114, 76) = JacC(114, 76)+ 0.2450000000000000D+00*dw(194, 76)
      JacC(114,123) = JacC(114,123)+ 0.2450000000000000D+00*dw(194,123)
      JacC(116, 76) = JacC(116, 76)+ 0.2100000000000000D-01*dw(194, 76)
      JacC(116,123) = JacC(116,123)+ 0.2100000000000000D-01*dw(194,123)
      JacC(119, 76) = JacC(119, 76)+ 0.5990000000000000D+00*dw(194, 76)
      JacC(119,123) = JacC(119,123)+ 0.5990000000000000D+00*dw(194,123)
      JacC(121, 76) = JacC(121, 76)+ 0.8760000000000000D+00*dw(194, 76)
      JacC(121,123) = JacC(121,123)+ 0.8760000000000000D+00*dw(194,123)
      JacC(123, 76) = JacC(123, 76) - dw(194, 76)
      JacC(123,123) = JacC(123,123) - dw(194,123)
      JacC( 79, 79) = JacC( 79, 79) - dw(195, 79)
      JacC( 79,123) = JacC( 79,123) - dw(195,123)
      JacC(108, 79) = JacC(108, 79)+ 0.2610000000000000D+00*dw(195, 79)
      JacC(108,123) = JacC(108,123)+ 0.2610000000000000D+00*dw(195,123)
      JacC(109, 79) = JacC(109, 79)+ 0.1500000000000000D+00*dw(195, 79)
      JacC(109,123) = JacC(109,123)+ 0.1500000000000000D+00*dw(195,123)
      JacC(111, 79) = JacC(111, 79)+ 0.6420000000000000D+00*dw(195, 79)
      JacC(111,123) = JacC(111,123)+ 0.6420000000000000D+00*dw(195,123)
      JacC(112, 79) = JacC(112, 79)+ 0.4160000000000000D+00*dw(195, 79)
      JacC(112,123) = JacC(112,123)+ 0.4160000000000000D+00*dw(195,123)
      JacC(114, 79) = JacC(114, 79)+ 0.1330000000000000D+00*dw(195, 79)
      JacC(114,123) = JacC(114,123)+ 0.1330000000000000D+00*dw(195,123)
      JacC(119, 79) = JacC(119, 79)+ 0.6060000000000000D+00*dw(195, 79)
      JacC(119,123) = JacC(119,123)+ 0.6060000000000000D+00*dw(195,123)
      JacC(121, 79) = JacC(121, 79)+ 0.7390000000000000D+00*dw(195, 79)
      JacC(121,123) = JacC(121,123)+ 0.7390000000000000D+00*dw(195,123)
      JacC(123, 79) = JacC(123, 79) - dw(195, 79)
      JacC(123,123) = JacC(123,123) - dw(195,123)
      JacC( 98, 98) = JacC( 98, 98) - dw(196, 98)
      JacC( 98,123) = JacC( 98,123) - dw(196,123)
      JacC(109, 98) = JacC(109, 98)+ 0.2000000000000000D+00*dw(196, 98)
      JacC(109,123) = JacC(109,123)+ 0.2000000000000000D+00*dw(196,123)
      JacC(116, 98) = JacC(116, 98)+ 0.1600000000000000D+01*dw(196, 98)
      JacC(116,123) = JacC(116,123)+ 0.1600000000000000D+01*dw(196,123)
      JacC(119, 98) = JacC(119, 98) + dw(196, 98)
      JacC(119,123) = JacC(119,123) + dw(196,123)
      JacC(121, 98) = JacC(121, 98) + dw(196, 98)
      JacC(121,123) = JacC(121,123) + dw(196,123)
      JacC(123, 98) = JacC(123, 98) - dw(196, 98)
      JacC(123,123) = JacC(123,123) - dw(196,123)
      JacC( 71, 71) = JacC( 71, 71) - dw(197, 71)
      JacC( 71,123) = JacC( 71,123) - dw(197,123)
      JacC(109, 71) = JacC(109, 71)+ 0.9399999999999999D+00*dw(197, 71)
      JacC(109,123) = JacC(109,123)+ 0.9399999999999999D+00*dw(197,123)
      JacC(111, 71) = JacC(111, 71)+ 0.6000000000000000D-01*dw(197, 71)
      JacC(111,123) = JacC(111,123)+ 0.6000000000000000D-01*dw(197,123)
      JacC(116, 71) = JacC(116, 71) + dw(197, 71)
      JacC(116,123) = JacC(116,123) + dw(197,123)
      JacC(119, 71) = JacC(119, 71) + dw(197, 71)
      JacC(119,123) = JacC(119,123) + dw(197,123)
      JacC(121, 71) = JacC(121, 71) + dw(197, 71)
      JacC(121,123) = JacC(121,123) + dw(197,123)
      JacC(123, 71) = JacC(123, 71) - dw(197, 71)
      JacC(123,123) = JacC(123,123) - dw(197,123)
      JacC( 87, 87) = JacC( 87, 87) - dw(198, 87)
      JacC( 87,123) = JacC( 87,123) - dw(198,123)
      JacC(109, 87) = JacC(109, 87)+ 0.1710000000000000D+01*dw(198, 87)
      JacC(109,123) = JacC(109,123)+ 0.1710000000000000D+01*dw(198,123)
      JacC(111, 87) = JacC(111, 87)+ 0.2900000000000000D+00*dw(198, 87)
      JacC(111,123) = JacC(111,123)+ 0.2900000000000000D+00*dw(198,123)
      JacC(119, 87) = JacC(119, 87) + dw(198, 87)
      JacC(119,123) = JacC(119,123) + dw(198,123)
      JacC(121, 87) = JacC(121, 87) + dw(198, 87)
      JacC(121,123) = JacC(121,123) + dw(198,123)
      JacC(123, 87) = JacC(123, 87) - dw(198, 87)
      JacC(123,123) = JacC(123,123) - dw(198,123)
      JacC( 45, 80) = JacC( 45, 80)+ 0.4600000000000000D-01*dw(199, 80)
      JacC( 45,123) = JacC( 45,123)+ 0.4600000000000000D-01*dw(199,123)
      JacC( 80, 80) = JacC( 80, 80) - dw(199, 80)
      JacC( 80,123) = JacC( 80,123) - dw(199,123)
      JacC( 81, 80) = JacC( 81, 80)+ 0.5820000000000000D+00*dw(199, 80)
      JacC( 81,123) = JacC( 81,123)+ 0.5820000000000000D+00*dw(199,123)
      JacC( 92, 80) = JacC( 92, 80)+ 0.4180000000000000D+00*dw(199, 80)
      JacC( 92,123) = JacC( 92,123)+ 0.4180000000000000D+00*dw(199,123)
      JacC(116, 80) = JacC(116, 80) + dw(199, 80)
      JacC(116,123) = JacC(116,123) + dw(199,123)
      JacC(119, 80) = JacC(119, 80)+ 0.9540000000000000D+00*dw(199, 80)
      JacC(119,123) = JacC(119,123)+ 0.9540000000000000D+00*dw(199,123)
      JacC(121, 80) = JacC(121, 80)+ 0.9540000000000000D+00*dw(199, 80)
      JacC(121,123) = JacC(121,123)+ 0.9540000000000000D+00*dw(199,123)
      JacC(123, 80) = JacC(123, 80) - dw(199, 80)
      JacC(123,123) = JacC(123,123) - dw(199,123)
      JacC( 93,104) = JacC( 93,104)+ 0.2500000000000000D+00*dw(200,104)
      JacC( 93,123) = JacC( 93,123)+ 0.2500000000000000D+00*dw(200,123)
      JacC(100,104) = JacC(100,104)+ 0.5000000000000000D+00*dw(200,104)
      JacC(100,123) = JacC(100,123)+ 0.5000000000000000D+00*dw(200,123)
      JacC(104,104) = JacC(104,104) - dw(200,104)
      JacC(104,123) = JacC(104,123) - dw(200,123)
      JacC(107,104) = JacC(107,104)+ 0.2500000000000000D+00*dw(200,104)
      JacC(107,123) = JacC(107,123)+ 0.2500000000000000D+00*dw(200,123)
      JacC(116,104) = JacC(116,104)+ 0.7500000000000000D+00*dw(200,104)
      JacC(116,123) = JacC(116,123)+ 0.7500000000000000D+00*dw(200,123)
      JacC(119,104) = JacC(119,104)+ 0.7500000000000000D+00*dw(200,104)
      JacC(119,123) = JacC(119,123)+ 0.7500000000000000D+00*dw(200,123)
      JacC(121,104) = JacC(121,104) + dw(200,104)
      JacC(121,123) = JacC(121,123) + dw(200,123)
      JacC(122,104) = JacC(122,104)+ 0.2500000000000000D+00*dw(200,104)
      JacC(122,123) = JacC(122,123)+ 0.2500000000000000D+00*dw(200,123)
      JacC(123,104) = JacC(123,104) - dw(200,104)
      JacC(123,123) = JacC(123,123) - dw(200,123)
      JacC( 82, 82) = JacC( 82, 82) - dw(201, 82)
      JacC( 82,123) = JacC( 82,123) - dw(201,123)
      JacC(100, 82) = JacC(100, 82)+ 0.3000000000000000D+00*dw(201, 82)
      JacC(100,123) = JacC(100,123)+ 0.3000000000000000D+00*dw(201,123)
      JacC(109, 82) = JacC(109, 82)+ 0.7000000000000000D+00*dw(201, 82)
      JacC(109,123) = JacC(109,123)+ 0.7000000000000000D+00*dw(201,123)
      JacC(112, 82) = JacC(112, 82)+ 0.7000000000000000D+00*dw(201, 82)
      JacC(112,123) = JacC(112,123)+ 0.7000000000000000D+00*dw(201,123)
      JacC(116, 82) = JacC(116, 82)+ 0.3000000000000000D+00*dw(201, 82)
      JacC(116,123) = JacC(116,123)+ 0.3000000000000000D+00*dw(201,123)
      JacC(119, 82) = JacC(119, 82)+ 0.3000000000000000D+00*dw(201, 82)
      JacC(119,123) = JacC(119,123)+ 0.3000000000000000D+00*dw(201,123)
      JacC(121, 82) = JacC(121, 82) + dw(201, 82)
      JacC(121,123) = JacC(121,123) + dw(201,123)
      JacC(122, 82) = JacC(122, 82)+ 0.7000000000000000D+00*dw(201, 82)
      JacC(122,123) = JacC(122,123)+ 0.7000000000000000D+00*dw(201,123)
      JacC(123, 82) = JacC(123, 82) - dw(201, 82)
      JacC(123,123) = JacC(123,123) - dw(201,123)
      JacC( 67, 67) = JacC( 67, 67) - dw(202, 67)
      JacC( 67,123) = JacC( 67,123) - dw(202,123)
      JacC( 68, 67) = JacC( 68, 67)+ 0.6700000000000000D+00*dw(202, 67)
      JacC( 68,123) = JacC( 68,123)+ 0.6700000000000000D+00*dw(202,123)
      JacC(116, 67) = JacC(116, 67)+ 0.3300000000000000D+00*dw(202, 67)
      JacC(116,123) = JacC(116,123)+ 0.3300000000000000D+00*dw(202,123)
      JacC(119, 67) = JacC(119, 67)+ 0.6700000000000000D+00*dw(202, 67)
      JacC(119,123) = JacC(119,123)+ 0.6700000000000000D+00*dw(202,123)
      JacC(121, 67) = JacC(121, 67) + dw(202, 67)
      JacC(121,123) = JacC(121,123) + dw(202,123)
      JacC(123, 67) = JacC(123, 67) - dw(202, 67)
      JacC(123,123) = JacC(123,123) - dw(202,123)
      JacC( 84, 84) = JacC( 84, 84) - dw(203, 84)
      JacC( 84,123) = JacC( 84,123) - dw(203,123)
      JacC(100, 84) = JacC(100, 84)+ 0.2100000000000000D+00*dw(203, 84)
      JacC(100,123) = JacC(100,123)+ 0.2100000000000000D+00*dw(203,123)
      JacC(102, 84) = JacC(102, 84)+ 0.1800000000000000D+00*dw(203, 84)
      JacC(102,123) = JacC(102,123)+ 0.1800000000000000D+00*dw(203,123)
      JacC(107, 84) = JacC(107, 84)+ 0.6100000000000000D+00*dw(203, 84)
      JacC(107,123) = JacC(107,123)+ 0.6100000000000000D+00*dw(203,123)
      JacC(109, 84) = JacC(109, 84)+ 0.2700000000000000D+00*dw(203, 84)
      JacC(109,123) = JacC(109,123)+ 0.2700000000000000D+00*dw(203,123)
      JacC(111, 84) = JacC(111, 84)+ 0.7000000000000000D+00*dw(203, 84)
      JacC(111,123) = JacC(111,123)+ 0.7000000000000000D+00*dw(203,123)
      JacC(116, 84) = JacC(116, 84)+ 0.3000000000000000D-01*dw(203, 84)
      JacC(116,123) = JacC(116,123)+ 0.3000000000000000D-01*dw(203,123)
      JacC(119, 84) = JacC(119, 84) + dw(203, 84)
      JacC(119,123) = JacC(119,123) + dw(203,123)
      JacC(121, 84) = JacC(121, 84) + dw(203, 84)
      JacC(121,123) = JacC(121,123) + dw(203,123)
      JacC(123, 84) = JacC(123, 84) - dw(203, 84)
      JacC(123,123) = JacC(123,123) - dw(203,123)
      JacC( 72, 72) = JacC( 72, 72) - dw(204, 72)
      JacC( 72,123) = JacC( 72,123) - dw(204,123)
      JacC( 73, 72) = JacC( 73, 72)+ 0.1100000000000000D+00*dw(204, 72)
      JacC( 73,123) = JacC( 73,123)+ 0.1100000000000000D+00*dw(204,123)
      JacC( 74, 72) = JacC( 74, 72)+ 0.7000000000000001D-01*dw(204, 72)
      JacC( 74,123) = JacC( 74,123)+ 0.7000000000000001D-01*dw(204,123)
      JacC(108, 72) = JacC(108, 72)+ 0.1800000000000000D+00*dw(204, 72)
      JacC(108,123) = JacC(108,123)+ 0.1800000000000000D+00*dw(204,123)
      JacC(109, 72) = JacC(109, 72)+ 0.4300000000000000D+00*dw(204, 72)
      JacC(109,123) = JacC(109,123)+ 0.4300000000000000D+00*dw(204,123)
      JacC(111, 72) = JacC(111, 72)+ 0.4400000000000000D+00*dw(204, 72)
      JacC(111,123) = JacC(111,123)+ 0.4400000000000000D+00*dw(204,123)
      JacC(116, 72) = JacC(116, 72)+ 0.2300000000000000D+00*dw(204, 72)
      JacC(116,123) = JacC(116,123)+ 0.2300000000000000D+00*dw(204,123)
      JacC(119, 72) = JacC(119, 72)+ 0.8200000000000000D+00*dw(204, 72)
      JacC(119,123) = JacC(119,123)+ 0.8200000000000000D+00*dw(204,123)
      JacC(121, 72) = JacC(121, 72)+ 0.8200000000000000D+00*dw(204, 72)
      JacC(121,123) = JacC(121,123)+ 0.8200000000000000D+00*dw(204,123)
      JacC(123, 72) = JacC(123, 72) - dw(204, 72)
      JacC(123,123) = JacC(123,123) - dw(204,123)
      JacC( 73, 85) = JacC( 73, 85)+ 0.3000000000000000D-01*dw(205, 85)
      JacC( 73,123) = JacC( 73,123)+ 0.3000000000000000D-01*dw(205,123)
      JacC( 85, 85) = JacC( 85, 85) - dw(205, 85)
      JacC( 85,123) = JacC( 85,123) - dw(205,123)
      JacC( 92, 85) = JacC( 92, 85)+ 0.2500000000000000D+00*dw(205, 85)
      JacC( 92,123) = JacC( 92,123)+ 0.2500000000000000D+00*dw(205,123)
      JacC(108, 85) = JacC(108, 85)+ 0.1000000000000000D+00*dw(205, 85)
      JacC(108,123) = JacC(108,123)+ 0.1000000000000000D+00*dw(205,123)
      JacC(111, 85) = JacC(111, 85)+ 0.2500000000000000D+00*dw(205, 85)
      JacC(111,123) = JacC(111,123)+ 0.2500000000000000D+00*dw(205,123)
      JacC(119, 85) = JacC(119, 85)+ 0.9000000000000000D+00*dw(205, 85)
      JacC(119,123) = JacC(119,123)+ 0.9000000000000000D+00*dw(205,123)
      JacC(121, 85) = JacC(121, 85)+ 0.9000000000000000D+00*dw(205, 85)
      JacC(121,123) = JacC(121,123)+ 0.9000000000000000D+00*dw(205,123)
      JacC(123, 85) = JacC(123, 85) - dw(205, 85)
      JacC(123,123) = JacC(123,123) - dw(205,123)
      JacC( 77, 77) = JacC( 77, 77) - dw(206, 77)
      JacC( 77,123) = JacC( 77,123) - dw(206,123)
      JacC( 83, 77) = JacC( 83, 77)+ 0.4590000000000000D+00*dw(206, 77)
      JacC( 83,123) = JacC( 83,123)+ 0.4590000000000000D+00*dw(206,123)
      JacC( 86, 77) = JacC( 86, 77)+ 0.4590000000000000D+00*dw(206, 77)
      JacC( 86,123) = JacC( 86,123)+ 0.4590000000000000D+00*dw(206,123)
      JacC(102, 77) = JacC(102, 77)+ 0.9180000000000000D+00*dw(206, 77)
      JacC(102,123) = JacC(102,123)+ 0.9180000000000000D+00*dw(206,123)
      JacC(108, 77) = JacC(108, 77)+ 0.8200000000000000D-01*dw(206, 77)
      JacC(108,123) = JacC(108,123)+ 0.8200000000000000D-01*dw(206,123)
      JacC(119, 77) = JacC(119, 77)+ 0.9180000000000000D+00*dw(206, 77)
      JacC(119,123) = JacC(119,123)+ 0.9180000000000000D+00*dw(206,123)
      JacC(121, 77) = JacC(121, 77)+ 0.9180000000000000D+00*dw(206, 77)
      JacC(121,123) = JacC(121,123)+ 0.9180000000000000D+00*dw(206,123)
      JacC(123, 77) = JacC(123, 77) - dw(206, 77)
      JacC(123,123) = JacC(123,123) - dw(206,123)
      JacC( 64, 64) = JacC( 64, 64) - dw(207, 64)
      JacC( 64,123) = JacC( 64,123) - dw(207,123)
      JacC( 65, 64) = JacC( 65, 64)+ 0.7300000000000000D-01*dw(207, 64)
      JacC( 65,123) = JacC( 65,123)+ 0.7300000000000000D-01*dw(207,123)
      JacC( 68, 64) = JacC( 68, 64)+ 0.7000000000000000D+00*dw(207, 64)
      JacC( 68,123) = JacC( 68,123)+ 0.7000000000000000D+00*dw(207,123)
      JacC( 69, 64) = JacC( 69, 64)+ 0.1770000000000000D+00*dw(207, 64)
      JacC( 69,123) = JacC( 69,123)+ 0.1770000000000000D+00*dw(207,123)
      JacC(100, 64) = JacC(100, 64)+ 0.6000000000000000D+00*dw(207, 64)
      JacC(100,123) = JacC(100,123)+ 0.6000000000000000D+00*dw(207,123)
      JacC(102, 64) = JacC(102, 64)+ 0.3500000000000000D+00*dw(207, 64)
      JacC(102,123) = JacC(102,123)+ 0.3500000000000000D+00*dw(207,123)
      JacC(108, 64) = JacC(108, 64)+ 0.5000000000000000D-01*dw(207, 64)
      JacC(108,123) = JacC(108,123)+ 0.5000000000000000D-01*dw(207,123)
      JacC(119, 64) = JacC(119, 64)+ 0.9500000000000000D+00*dw(207, 64)
      JacC(119,123) = JacC(119,123)+ 0.9500000000000000D+00*dw(207,123)
      JacC(121, 64) = JacC(121, 64)+ 0.9500000000000000D+00*dw(207, 64)
      JacC(121,123) = JacC(121,123)+ 0.9500000000000000D+00*dw(207,123)
      JacC(123, 64) = JacC(123, 64) - dw(207, 64)
      JacC(123,123) = JacC(123,123) - dw(207,123)
      JacC( 75, 97) = JacC( 75, 97)+ 0.3200000000000000D+00*dw(208, 97)
      JacC( 75,123) = JacC( 75,123)+ 0.3200000000000000D+00*dw(208,123)
      JacC( 97, 97) = JacC( 97, 97) - dw(208, 97)
      JacC( 97,123) = JacC( 97,123) - dw(208,123)
      JacC(102, 97) = JacC(102, 97)+ 0.6800000000000000D+00*dw(208, 97)
      JacC(102,123) = JacC(102,123)+ 0.6800000000000000D+00*dw(208,123)
      JacC(115, 97) = JacC(115, 97)+ 0.6800000000000000D+00*dw(208, 97)
      JacC(115,123) = JacC(115,123)+ 0.6800000000000000D+00*dw(208,123)
      JacC(119, 97) = JacC(119, 97) + dw(208, 97)
      JacC(119,123) = JacC(119,123) + dw(208,123)
      JacC(121, 97) = JacC(121, 97) + dw(208, 97)
      JacC(121,123) = JacC(121,123) + dw(208,123)
      JacC(123, 97) = JacC(123, 97) - dw(208, 97)
      JacC(123,123) = JacC(123,123) - dw(208,123)
      JacC(113,122) = JacC(113,122) + dw(209,122)
      JacC(113,123) = JacC(113,123) + dw(209,123)
      JacC(121,122) = JacC(121,122) + dw(209,122)
      JacC(121,123) = JacC(121,123) + dw(209,123)
      JacC(122,122) = JacC(122,122) - dw(209,122)
      JacC(122,123) = JacC(122,123) - dw(209,123)
      JacC(123,122) = JacC(123,122) - dw(209,122)
      JacC(123,123) = JacC(123,123) - dw(209,123)
      JacC(114,120) = JacC(114,120) + dw(210,120)
      JacC(114,123) = JacC(114,123) + dw(210,123)
      JacC(120,120) = JacC(120,120) - dw(210,120)
      JacC(120,123) = JacC(120,123) - dw(210,123)
      JacC(121,120) = JacC(121,120) + dw(210,120)
      JacC(121,123) = JacC(121,123) + dw(210,123)
      JacC(123,120) = JacC(123,120) - dw(210,120)
      JacC(123,123) = JacC(123,123) - dw(210,123)
      JacC(100,105) = JacC(100,105)+ 0.5400000000000000D+00*dw(211,105)
      JacC(100,123) = JacC(100,123)+ 0.5400000000000000D+00*dw(211,123)
      JacC(105,105) = JacC(105,105) - dw(211,105)
      JacC(105,123) = JacC(105,123) - dw(211,123)
      JacC(109,105) = JacC(109,105)+ 0.4600000000000000D+00*dw(211,105)
      JacC(109,123) = JacC(109,123)+ 0.4600000000000000D+00*dw(211,123)
      JacC(112,105) = JacC(112,105)+ 0.1600000000000000D+00*dw(211,105)
      JacC(112,123) = JacC(112,123)+ 0.1600000000000000D+00*dw(211,123)
      JacC(119,105) = JacC(119,105)+ 0.7700000000000000D+00*dw(211,105)
      JacC(119,123) = JacC(119,123)+ 0.7700000000000000D+00*dw(211,123)
      JacC(121,105) = JacC(121,105) + dw(211,105)
      JacC(121,123) = JacC(121,123) + dw(211,123)
      JacC(122,105) = JacC(122,105)+ 0.2300000000000000D+00*dw(211,105)
      JacC(122,123) = JacC(122,123)+ 0.2300000000000000D+00*dw(211,123)
      JacC(123,105) = JacC(123,105) - dw(211,105)
      JacC(123,123) = JacC(123,123) - dw(211,123)
      JacC( 78, 78) = JacC( 78, 78) - dw(212, 78)
      JacC( 78,123) = JacC( 78,123) - dw(212,123)
      JacC(116, 78) = JacC(116, 78) + dw(212, 78)
      JacC(116,123) = JacC(116,123) + dw(212,123)
      JacC(121, 78) = JacC(121, 78) + dw(212, 78)
      JacC(121,123) = JacC(121,123) + dw(212,123)
      JacC(122, 78) = JacC(122, 78) + dw(212, 78)
      JacC(122,123) = JacC(122,123) + dw(212,123)
      JacC(123, 78) = JacC(123, 78) - dw(212, 78)
      JacC(123,123) = JacC(123,123) - dw(212,123)
      JacC( 90, 90) = JacC( 90, 90) - dw(213, 90)
      JacC( 90,123) = JacC( 90,123) - dw(213,123)
      JacC(108, 90) = JacC(108, 90) + dw(213, 90)
      JacC(108,123) = JacC(108,123) + dw(213,123)
      JacC(119, 90) = JacC(119, 90) + dw(213, 90)
      JacC(119,123) = JacC(119,123) + dw(213,123)
      JacC(121, 90) = JacC(121, 90) + dw(213, 90)
      JacC(121,123) = JacC(121,123) + dw(213,123)
      JacC(123, 90) = JacC(123, 90) - dw(213, 90)
      JacC(123,123) = JacC(123,123) - dw(213,123)
      JacC( 88, 88) = JacC( 88, 88) - dw(214, 88)
      JacC( 88,123) = JacC( 88,123) - dw(214,123)
      JacC(109, 88) = JacC(109, 88)+ 0.1240000000000000D+01*dw(214, 88)
      JacC(109,123) = JacC(109,123)+ 0.1240000000000000D+01*dw(214,123)
      JacC(111, 88) = JacC(111, 88)+ 0.4640000000000000D+00*dw(214, 88)
      JacC(111,123) = JacC(111,123)+ 0.4640000000000000D+00*dw(214,123)
      JacC(116, 88) = JacC(116, 88)+ 0.2870000000000000D+00*dw(214, 88)
      JacC(116,123) = JacC(116,123)+ 0.2870000000000000D+00*dw(214,123)
      JacC(121, 88) = JacC(121, 88)+ 0.2000000000000000D+01*dw(214, 88)
      JacC(121,123) = JacC(121,123)+ 0.2000000000000000D+01*dw(214,123)
      JacC(123, 88) = JacC(123, 88) - dw(214, 88)
      JacC(123,123) = JacC(123,123) - dw(214,123)
      JacC( 40,113) = JacC( 40,113) + dw(215,113)
      JacC( 40,119) = JacC( 40,119) + dw(215,119)
      JacC(113,113) = JacC(113,113) - dw(215,113)
      JacC(113,119) = JacC(113,119) - dw(215,119)
      JacC(119,113) = JacC(119,113) - dw(215,113)
      JacC(119,119) = JacC(119,119) - dw(215,119)
      JacC(114,114) = JacC(114,114) - dw(216,114)
      JacC(114,119) = JacC(114,119) - dw(216,119)
      JacC(115,114) = JacC(115,114) + dw(216,114)
      JacC(115,119) = JacC(115,119) + dw(216,119)
      JacC(119,114) = JacC(119,114) - dw(216,114)
      JacC(119,119) = JacC(119,119) - dw(216,119)
      JacC(110,110) = JacC(110,110) - dw(217,110)
      JacC(110,119) = JacC(110,119) - dw(217,119)
      JacC(115,110) = JacC(115,110) + dw(217,110)
      JacC(115,119) = JacC(115,119) + dw(217,119)
      JacC(119,110) = JacC(119,110) - dw(217,110)
      JacC(119,119) = JacC(119,119) - dw(217,119)
      JacC( 76, 76) = JacC( 76, 76) - dw(218, 76)
      JacC( 76,119) = JacC( 76,119) - dw(218,119)
      JacC(115, 76) = JacC(115, 76) + dw(218, 76)
      JacC(115,119) = JacC(115,119) + dw(218,119)
      JacC(119, 76) = JacC(119, 76) - dw(218, 76)
      JacC(119,119) = JacC(119,119) - dw(218,119)
      JacC( 79, 79) = JacC( 79, 79) - dw(219, 79)
      JacC( 79,119) = JacC( 79,119) - dw(219,119)
      JacC(115, 79) = JacC(115, 79) + dw(219, 79)
      JacC(115,119) = JacC(115,119) + dw(219,119)
      JacC(119, 79) = JacC(119, 79) - dw(219, 79)
      JacC(119,119) = JacC(119,119) - dw(219,119)
      JacC( 98, 98) = JacC( 98, 98) - dw(220, 98)
      JacC( 98,119) = JacC( 98,119) - dw(220,119)
      JacC(115, 98) = JacC(115, 98) + dw(220, 98)
      JacC(115,119) = JacC(115,119) + dw(220,119)
      JacC(119, 98) = JacC(119, 98) - dw(220, 98)
      JacC(119,119) = JacC(119,119) - dw(220,119)
      JacC( 71, 71) = JacC( 71, 71) - dw(221, 71)
      JacC( 71,119) = JacC( 71,119) - dw(221,119)
      JacC(115, 71) = JacC(115, 71) + dw(221, 71)
      JacC(115,119) = JacC(115,119) + dw(221,119)
      JacC(119, 71) = JacC(119, 71) - dw(221, 71)
      JacC(119,119) = JacC(119,119) - dw(221,119)
      JacC( 87, 87) = JacC( 87, 87) - dw(222, 87)
      JacC( 87,119) = JacC( 87,119) - dw(222,119)
      JacC(115, 87) = JacC(115, 87) + dw(222, 87)
      JacC(115,119) = JacC(115,119) + dw(222,119)
      JacC(119, 87) = JacC(119, 87) - dw(222, 87)
      JacC(119,119) = JacC(119,119) - dw(222,119)
      JacC( 30, 80) = JacC( 30, 80) + dw(223, 80)
      JacC( 30,119) = JacC( 30,119) + dw(223,119)
      JacC( 80, 80) = JacC( 80, 80) - dw(223, 80)
      JacC( 80,119) = JacC( 80,119) - dw(223,119)
      JacC(119, 80) = JacC(119, 80) - dw(223, 80)
      JacC(119,119) = JacC(119,119) - dw(223,119)
      JacC( 35,104) = JacC( 35,104) + dw(224,104)
      JacC( 35,119) = JacC( 35,119) + dw(224,119)
      JacC(104,104) = JacC(104,104) - dw(224,104)
      JacC(104,119) = JacC(104,119) - dw(224,119)
      JacC(119,104) = JacC(119,104) - dw(224,104)
      JacC(119,119) = JacC(119,119) - dw(224,119)
      JacC( 82, 82) = JacC( 82, 82) - dw(225, 82)
      JacC( 82,119) = JacC( 82,119) - dw(225,119)
      JacC(115, 82) = JacC(115, 82) + dw(225, 82)
      JacC(115,119) = JacC(115,119) + dw(225,119)
      JacC(119, 82) = JacC(119, 82) - dw(225, 82)
      JacC(119,119) = JacC(119,119) - dw(225,119)
      JacC( 84, 84) = JacC( 84, 84) - dw(226, 84)
      JacC( 84,119) = JacC( 84,119) - dw(226,119)
      JacC(115, 84) = JacC(115, 84) + dw(226, 84)
      JacC(115,119) = JacC(115,119) + dw(226,119)
      JacC(119, 84) = JacC(119, 84) - dw(226, 84)
      JacC(119,119) = JacC(119,119) - dw(226,119)
      JacC( 72, 72) = JacC( 72, 72) - dw(227, 72)
      JacC( 72,119) = JacC( 72,119) - dw(227,119)
      JacC(115, 72) = JacC(115, 72) + dw(227, 72)
      JacC(115,119) = JacC(115,119) + dw(227,119)
      JacC(119, 72) = JacC(119, 72) - dw(227, 72)
      JacC(119,119) = JacC(119,119) - dw(227,119)
      JacC( 85, 85) = JacC( 85, 85) - dw(228, 85)
      JacC( 85,119) = JacC( 85,119) - dw(228,119)
      JacC(115, 85) = JacC(115, 85) + dw(228, 85)
      JacC(115,119) = JacC(115,119) + dw(228,119)
      JacC(119, 85) = JacC(119, 85) - dw(228, 85)
      JacC(119,119) = JacC(119,119) - dw(228,119)
      JacC( 77, 77) = JacC( 77, 77) - dw(229, 77)
      JacC( 77,119) = JacC( 77,119) - dw(229,119)
      JacC(115, 77) = JacC(115, 77) + dw(229, 77)
      JacC(115,119) = JacC(115,119) + dw(229,119)
      JacC(119, 77) = JacC(119, 77) - dw(229, 77)
      JacC(119,119) = JacC(119,119) - dw(229,119)
      JacC( 54, 54) = JacC( 54, 54) - dw(230, 54)
      JacC( 54,119) = JacC( 54,119) - dw(230,119)
      JacC(115, 54) = JacC(115, 54) + dw(230, 54)
      JacC(115,119) = JacC(115,119) + dw(230,119)
      JacC(119, 54) = JacC(119, 54) - dw(230, 54)
      JacC(119,119) = JacC(119,119) - dw(230,119)
      JacC( 60, 60) = JacC( 60, 60) - dw(231, 60)
      JacC( 60,119) = JacC( 60,119) - dw(231,119)
      JacC(115, 60) = JacC(115, 60) + dw(231, 60)
      JacC(115,119) = JacC(115,119) + dw(231,119)
      JacC(119, 60) = JacC(119, 60) - dw(231, 60)
      JacC(119,119) = JacC(119,119) - dw(231,119)
      JacC( 64, 64) = JacC( 64, 64) - dw(232, 64)
      JacC( 64,119) = JacC( 64,119) - dw(232,119)
      JacC(115, 64) = JacC(115, 64) + dw(232, 64)
      JacC(115,119) = JacC(115,119) + dw(232,119)
      JacC(119, 64) = JacC(119, 64) - dw(232, 64)
      JacC(119,119) = JacC(119,119) - dw(232,119)
      JacC( 97, 97) = JacC( 97, 97) - dw(233, 97)
      JacC( 97,119) = JacC( 97,119) - dw(233,119)
      JacC(115, 97) = JacC(115, 97) + dw(233, 97)
      JacC(115,119) = JacC(115,119) + dw(233,119)
      JacC(119, 97) = JacC(119, 97) - dw(233, 97)
      JacC(119,119) = JacC(119,119) - dw(233,119)
      JacC( 61, 62) = JacC( 61, 62) + dw(234, 62)
      JacC( 61,119) = JacC( 61,119) + dw(234,119)
      JacC( 62, 62) = JacC( 62, 62) - dw(234, 62)
      JacC( 62,119) = JacC( 62,119) - dw(234,119)
      JacC(119, 62) = JacC(119, 62) - dw(234, 62)
      JacC(119,119) = JacC(119,119) - dw(234,119)
      JacC( 70,122) = JacC( 70,122)+ 0.4000000000000000D+00*dw(235,122)
      JacC( 70,119) = JacC( 70,119)+ 0.4000000000000000D+00*dw(235,119)
      JacC(106,122) = JacC(106,122)+ 0.2000000000000000D+00*dw(235,122)
      JacC(106,119) = JacC(106,119)+ 0.2000000000000000D+00*dw(235,119)
      JacC(113,122) = JacC(113,122)+ 0.4000000000000000D+00*dw(235,122)
      JacC(113,119) = JacC(113,119)+ 0.4000000000000000D+00*dw(235,119)
      JacC(118,122) = JacC(118,122)+ 0.4000000000000000D+00*dw(235,122)
      JacC(118,119) = JacC(118,119)+ 0.4000000000000000D+00*dw(235,119)
      JacC(119,122) = JacC(119,122) - dw(235,122)
      JacC(119,119) = JacC(119,119) - dw(235,119)
      JacC(122,122) = JacC(122,122) - dw(235,122)
      JacC(122,119) = JacC(122,119) - dw(235,119)
      JacC( 70,120) = JacC( 70,120)+ 0.4000000000000000D+00*dw(236,120)
      JacC( 70,119) = JacC( 70,119)+ 0.4000000000000000D+00*dw(236,119)
      JacC(106,120) = JacC(106,120)+ 0.2000000000000000D+00*dw(236,120)
      JacC(106,119) = JacC(106,119)+ 0.2000000000000000D+00*dw(236,119)
      JacC(114,120) = JacC(114,120)+ 0.4000000000000000D+00*dw(236,120)
      JacC(114,119) = JacC(114,119)+ 0.4000000000000000D+00*dw(236,119)
      JacC(118,120) = JacC(118,120)+ 0.4000000000000000D+00*dw(236,120)
      JacC(118,119) = JacC(118,119)+ 0.4000000000000000D+00*dw(236,119)
      JacC(119,120) = JacC(119,120) - dw(236,120)
      JacC(119,119) = JacC(119,119) - dw(236,119)
      JacC(120,120) = JacC(120,120) - dw(236,120)
      JacC(120,119) = JacC(120,119) - dw(236,119)
      JacC( 78, 78) = JacC( 78, 78) - dw(237, 78)
      JacC( 78,119) = JacC( 78,119) - dw(237,119)
      JacC(115, 78) = JacC(115, 78)+ 0.3300000000000000D+00*dw(237, 78)
      JacC(115,119) = JacC(115,119)+ 0.3300000000000000D+00*dw(237,119)
      JacC(116, 78) = JacC(116, 78)+ 0.6700000000000000D+00*dw(237, 78)
      JacC(116,119) = JacC(116,119)+ 0.6700000000000000D+00*dw(237,119)
      JacC(118, 78) = JacC(118, 78)+ 0.6700000000000000D+00*dw(237, 78)
      JacC(118,119) = JacC(118,119)+ 0.6700000000000000D+00*dw(237,119)
      JacC(119, 78) = JacC(119, 78) - dw(237, 78)
      JacC(119,119) = JacC(119,119) - dw(237,119)
      JacC(122, 78) = JacC(122, 78)+ 0.6700000000000000D+00*dw(237, 78)
      JacC(122,119) = JacC(122,119)+ 0.6700000000000000D+00*dw(237,119)
      JacC( 67, 67) = JacC( 67, 67) - dw(238, 67)
      JacC( 67,119) = JacC( 67,119) - dw(238,119)
      JacC(115, 67) = JacC(115, 67) + dw(238, 67)
      JacC(115,119) = JacC(115,119) + dw(238,119)
      JacC(119, 67) = JacC(119, 67) - dw(238, 67)
      JacC(119,119) = JacC(119,119) - dw(238,119)
      JacC(105,105) = JacC(105,105) - dw(239,105)
      JacC(105,119) = JacC(105,119) - dw(239,119)
      JacC(115,105) = JacC(115,105) + dw(239,105)
      JacC(115,119) = JacC(115,119) + dw(239,119)
      JacC(119,105) = JacC(119,105) - dw(239,105)
      JacC(119,119) = JacC(119,119) - dw(239,119)
      JacC( 90, 90) = JacC( 90, 90) - dw(240, 90)
      JacC( 90,119) = JacC( 90,119) - dw(240,119)
      JacC(108, 90) = JacC(108, 90) + dw(240, 90)
      JacC(108,119) = JacC(108,119) + dw(240,119)
      JacC(119, 90) = JacC(119, 90) - dw(240, 90)
      JacC(119,119) = JacC(119,119) - dw(240,119)
      JacC( 88, 88) = JacC( 88, 88) - dw(241, 88)
      JacC( 88,119) = JacC( 88,119) - dw(241,119)
      JacC(108, 88) = JacC(108, 88) + dw(241, 88)
      JacC(108,119) = JacC(108,119) + dw(241,119)
      JacC(119, 88) = JacC(119, 88) - dw(241, 88)
      JacC(119,119) = JacC(119,119) - dw(241,119)
      JacC( 99,113) = JacC( 99,113)+ 0.6300000000000000D+00*dw(242,113)
      JacC( 99,113) = JacC( 99,113)+ 0.6300000000000000D+00*dw(242,113)
      JacC(113,113) = JacC(113,113)- 0.2000000000000000D+01*dw(242,113)
      JacC(113,113) = JacC(113,113)- 0.2000000000000000D+01*dw(242,113)
      JacC(116,113) = JacC(116,113)+ 0.1370000000000000D+01*dw(242,113)
      JacC(116,113) = JacC(116,113)+ 0.1370000000000000D+01*dw(242,113)
      JacC(119,113) = JacC(119,113)+ 0.7400000000000000D+00*dw(242,113)
      JacC(119,113) = JacC(119,113)+ 0.7400000000000000D+00*dw(242,113)
      JacC( 26,114) = JacC( 26,114)+ 0.2500000000000000D+00*dw(243,114)
      JacC( 26,113) = JacC( 26,113)+ 0.2500000000000000D+00*dw(243,113)
      JacC( 94,114) = JacC( 94,114)+ 0.7500000000000000D+00*dw(243,114)
      JacC( 94,113) = JacC( 94,113)+ 0.7500000000000000D+00*dw(243,113)
      JacC( 99,114) = JacC( 99,114)+ 0.2500000000000000D+00*dw(243,114)
      JacC( 99,113) = JacC( 99,113)+ 0.2500000000000000D+00*dw(243,113)
      JacC(113,114) = JacC(113,114) - dw(243,114)
      JacC(113,113) = JacC(113,113) - dw(243,113)
      JacC(114,114) = JacC(114,114) - dw(243,114)
      JacC(114,113) = JacC(114,113) - dw(243,113)
      JacC(116,114) = JacC(116,114)+ 0.7500000000000000D+00*dw(243,114)
      JacC(116,113) = JacC(116,113)+ 0.7500000000000000D+00*dw(243,113)
      JacC(119,114) = JacC(119,114) + dw(243,114)
      JacC(119,113) = JacC(119,113) + dw(243,113)
      JacC( 89,110) = JacC( 89,110)+ 0.2500000000000000D+00*dw(244,110)
      JacC( 89,113) = JacC( 89,113)+ 0.2500000000000000D+00*dw(244,113)
      JacC( 99,110) = JacC( 99,110)+ 0.2500000000000000D+00*dw(244,110)
      JacC( 99,113) = JacC( 99,113)+ 0.2500000000000000D+00*dw(244,113)
      JacC(102,110) = JacC(102,110)+ 0.5000000000000000D-01*dw(244,110)
      JacC(102,113) = JacC(102,113)+ 0.5000000000000000D-01*dw(244,113)
      JacC(109,110) = JacC(109,110)+ 0.1980000000000000D+00*dw(244,110)
      JacC(109,113) = JacC(109,113)+ 0.1980000000000000D+00*dw(244,113)
      JacC(110,110) = JacC(110,110) - dw(244,110)
      JacC(110,113) = JacC(110,113) - dw(244,113)
      JacC(111,110) = JacC(111,110)+ 0.4970000000000000D+00*dw(244,110)
      JacC(111,113) = JacC(111,113)+ 0.4970000000000000D+00*dw(244,113)
      JacC(112,110) = JacC(112,110)+ 0.2600000000000000D-01*dw(244,110)
      JacC(112,113) = JacC(112,113)+ 0.2600000000000000D-01*dw(244,113)
      JacC(113,110) = JacC(113,110)- 0.9200000000000000D+00*dw(244,110)
      JacC(113,113) = JacC(113,113)- 0.9200000000000000D+00*dw(244,113)
      JacC(114,110) = JacC(114,110)+ 0.2600000000000000D-01*dw(244,110)
      JacC(114,113) = JacC(114,113)+ 0.2600000000000000D-01*dw(244,113)
      JacC(116,110) = JacC(116,110)+ 0.8270000000000000D+00*dw(244,110)
      JacC(116,113) = JacC(116,113)+ 0.8270000000000000D+00*dw(244,113)
      JacC(119,110) = JacC(119,110)+ 0.8940000000000000D+00*dw(244,110)
      JacC(119,113) = JacC(119,113)+ 0.8940000000000000D+00*dw(244,113)
      JacC( 76, 76) = JacC( 76, 76) - dw(245, 76)
      JacC( 76,113) = JacC( 76,113) - dw(245,113)
      JacC( 89, 76) = JacC( 89, 76)+ 0.2500000000000000D+00*dw(245, 76)
      JacC( 89,113) = JacC( 89,113)+ 0.2500000000000000D+00*dw(245,113)
      JacC( 99, 76) = JacC( 99, 76)+ 0.2500000000000000D+00*dw(245, 76)
      JacC( 99,113) = JacC( 99,113)+ 0.2500000000000000D+00*dw(245,113)
      JacC(109, 76) = JacC(109, 76)+ 0.2510000000000000D+00*dw(245, 76)
      JacC(109,113) = JacC(109,113)+ 0.2510000000000000D+00*dw(245,113)
      JacC(111, 76) = JacC(111, 76)+ 0.6180000000000000D+00*dw(245, 76)
      JacC(111,113) = JacC(111,113)+ 0.6180000000000000D+00*dw(245,113)
      JacC(112, 76) = JacC(112, 76)+ 0.1910000000000000D+00*dw(245, 76)
      JacC(112,113) = JacC(112,113)+ 0.1910000000000000D+00*dw(245,113)
      JacC(113, 76) = JacC(113, 76)- 0.9820000000000000D+00*dw(245, 76)
      JacC(113,113) = JacC(113,113)- 0.9820000000000000D+00*dw(245,113)
      JacC(114, 76) = JacC(114, 76)+ 0.1400000000000000D+00*dw(245, 76)
      JacC(114,113) = JacC(114,113)+ 0.1400000000000000D+00*dw(245,113)
      JacC(116, 76) = JacC(116, 76)+ 0.7770000000000000D+00*dw(245, 76)
      JacC(116,113) = JacC(116,113)+ 0.7770000000000000D+00*dw(245,113)
      JacC(119, 76) = JacC(119, 76)+ 0.8420000000000000D+00*dw(245, 76)
      JacC(119,113) = JacC(119,113)+ 0.8420000000000000D+00*dw(245,113)
      JacC( 79, 79) = JacC( 79, 79) - dw(246, 79)
      JacC( 79,113) = JacC( 79,113) - dw(246,113)
      JacC( 89, 79) = JacC( 89, 79)+ 0.2500000000000000D+00*dw(246, 79)
      JacC( 89,113) = JacC( 89,113)+ 0.2500000000000000D+00*dw(246,113)
      JacC( 99, 79) = JacC( 99, 79)+ 0.2500000000000000D+00*dw(246, 79)
      JacC( 99,113) = JacC( 99,113)+ 0.2500000000000000D+00*dw(246,113)
      JacC(109, 79) = JacC(109, 79)+ 0.1970000000000000D+00*dw(246, 79)
      JacC(109,113) = JacC(109,113)+ 0.1970000000000000D+00*dw(246,113)
      JacC(111, 79) = JacC(111, 79)+ 0.6520000000000000D+00*dw(246, 79)
      JacC(111,113) = JacC(111,113)+ 0.6520000000000000D+00*dw(246,113)
      JacC(112, 79) = JacC(112, 79)+ 0.2810000000000000D+00*dw(246, 79)
      JacC(112,113) = JacC(112,113)+ 0.2810000000000000D+00*dw(246,113)
      JacC(113, 79) = JacC(113, 79) - dw(246, 79)
      JacC(113,113) = JacC(113,113) - dw(246,113)
      JacC(114, 79) = JacC(114, 79)+ 0.9000000000000000D-01*dw(246, 79)
      JacC(114,113) = JacC(114,113)+ 0.9000000000000000D-01*dw(246,113)
      JacC(116, 79) = JacC(116, 79)+ 0.7500000000000000D+00*dw(246, 79)
      JacC(116,113) = JacC(116,113)+ 0.7500000000000000D+00*dw(246,113)
      JacC(119, 79) = JacC(119, 79)+ 0.9100000000000000D+00*dw(246, 79)
      JacC(119,113) = JacC(119,113)+ 0.9100000000000000D+00*dw(246,113)
      JacC( 29, 98) = JacC( 29, 98)+ 0.2500000000000000D+00*dw(247, 98)
      JacC( 29,113) = JacC( 29,113)+ 0.2500000000000000D+00*dw(247,113)
      JacC( 98, 98) = JacC( 98, 98) - dw(247, 98)
      JacC( 98,113) = JacC( 98,113) - dw(247,113)
      JacC( 99, 98) = JacC( 99, 98)+ 0.2500000000000000D+00*dw(247, 98)
      JacC( 99,113) = JacC( 99,113)+ 0.2500000000000000D+00*dw(247,113)
      JacC(109, 98) = JacC(109, 98)+ 0.1500000000000000D+00*dw(247, 98)
      JacC(109,113) = JacC(109,113)+ 0.1500000000000000D+00*dw(247,113)
      JacC(113, 98) = JacC(113, 98) - dw(247, 98)
      JacC(113,113) = JacC(113,113) - dw(247,113)
      JacC(116, 98) = JacC(116, 98)+ 0.1950000000000000D+01*dw(247, 98)
      JacC(116,113) = JacC(116,113)+ 0.1950000000000000D+01*dw(247,113)
      JacC(119, 98) = JacC(119, 98) + dw(247, 98)
      JacC(119,113) = JacC(119,113) + dw(247,113)
      JacC( 71, 71) = JacC( 71, 71) - dw(248, 71)
      JacC( 71,113) = JacC( 71,113) - dw(248,113)
      JacC( 89, 71) = JacC( 89, 71)+ 0.2500000000000000D+00*dw(248, 71)
      JacC( 89,113) = JacC( 89,113)+ 0.2500000000000000D+00*dw(248,113)
      JacC( 99, 71) = JacC( 99, 71)+ 0.2500000000000000D+00*dw(248, 71)
      JacC( 99,113) = JacC( 99,113)+ 0.2500000000000000D+00*dw(248,113)
      JacC(109, 71) = JacC(109, 71)+ 0.7050000000000000D+00*dw(248, 71)
      JacC(109,113) = JacC(109,113)+ 0.7050000000000000D+00*dw(248,113)
      JacC(111, 71) = JacC(111, 71)+ 0.4500000000000000D-01*dw(248, 71)
      JacC(111,113) = JacC(111,113)+ 0.4500000000000000D-01*dw(248,113)
      JacC(113, 71) = JacC(113, 71) - dw(248, 71)
      JacC(113,113) = JacC(113,113) - dw(248,113)
      JacC(116, 71) = JacC(116, 71)+ 0.1500000000000000D+01*dw(248, 71)
      JacC(116,113) = JacC(116,113)+ 0.1500000000000000D+01*dw(248,113)
      JacC(119, 71) = JacC(119, 71) + dw(248, 71)
      JacC(119,113) = JacC(119,113) + dw(248,113)
      JacC( 87, 87) = JacC( 87, 87) - dw(249, 87)
      JacC( 87,113) = JacC( 87,113) - dw(249,113)
      JacC( 89, 87) = JacC( 89, 87)+ 0.2500000000000000D+00*dw(249, 87)
      JacC( 89,113) = JacC( 89,113)+ 0.2500000000000000D+00*dw(249,113)
      JacC( 99, 87) = JacC( 99, 87)+ 0.2500000000000000D+00*dw(249, 87)
      JacC( 99,113) = JacC( 99,113)+ 0.2500000000000000D+00*dw(249,113)
      JacC(109, 87) = JacC(109, 87)+ 0.1280000000000000D+01*dw(249, 87)
      JacC(109,113) = JacC(109,113)+ 0.1280000000000000D+01*dw(249,113)
      JacC(111, 87) = JacC(111, 87)+ 0.2180000000000000D+00*dw(249, 87)
      JacC(111,113) = JacC(111,113)+ 0.2180000000000000D+00*dw(249,113)
      JacC(113, 87) = JacC(113, 87) - dw(249, 87)
      JacC(113,113) = JacC(113,113) - dw(249,113)
      JacC(116, 87) = JacC(116, 87)+ 0.7500000000000000D+00*dw(249, 87)
      JacC(116,113) = JacC(116,113)+ 0.7500000000000000D+00*dw(249,113)
      JacC(119, 87) = JacC(119, 87) + dw(249, 87)
      JacC(119,113) = JacC(119,113) + dw(249,113)
      JacC( 80, 80) = JacC( 80, 80) - dw(250, 80)
      JacC( 80,113) = JacC( 80,113) - dw(250,113)
      JacC( 81, 80) = JacC( 81, 80)+ 0.3050000000000000D+00*dw(250, 80)
      JacC( 81,113) = JacC( 81,113)+ 0.3050000000000000D+00*dw(250,113)
      JacC( 89, 80) = JacC( 89, 80)+ 0.2500000000000000D+00*dw(250, 80)
      JacC( 89,113) = JacC( 89,113)+ 0.2500000000000000D+00*dw(250,113)
      JacC( 92, 80) = JacC( 92, 80)+ 0.2190000000000000D+00*dw(250, 80)
      JacC( 92,113) = JacC( 92,113)+ 0.2190000000000000D+00*dw(250,113)
      JacC( 99, 80) = JacC( 99, 80)+ 0.2500000000000000D+00*dw(250, 80)
      JacC( 99,113) = JacC( 99,113)+ 0.2500000000000000D+00*dw(250,113)
      JacC(113, 80) = JacC(113, 80) - dw(250, 80)
      JacC(113,113) = JacC(113,113) - dw(250,113)
      JacC(116, 80) = JacC(116, 80)+ 0.1540000000000000D+01*dw(250, 80)
      JacC(116,113) = JacC(116,113)+ 0.1540000000000000D+01*dw(250,113)
      JacC(119, 80) = JacC(119, 80) + dw(250, 80)
      JacC(119,113) = JacC(119,113) + dw(250,113)
      JacC( 89,104) = JacC( 89,104)+ 0.2500000000000000D+00*dw(251,104)
      JacC( 89,113) = JacC( 89,113)+ 0.2500000000000000D+00*dw(251,113)
      JacC( 93,104) = JacC( 93,104)+ 0.1670000000000000D+00*dw(251,104)
      JacC( 93,113) = JacC( 93,113)+ 0.1670000000000000D+00*dw(251,113)
      JacC( 99,104) = JacC( 99,104)+ 0.2500000000000000D+00*dw(251,104)
      JacC( 99,113) = JacC( 99,113)+ 0.2500000000000000D+00*dw(251,113)
      JacC(100,104) = JacC(100,104)+ 0.3330000000000000D+00*dw(251,104)
      JacC(100,113) = JacC(100,113)+ 0.3330000000000000D+00*dw(251,113)
      JacC(104,104) = JacC(104,104) - dw(251,104)
      JacC(104,113) = JacC(104,113) - dw(251,113)
      JacC(106,104) = JacC(106,104)+ 0.4200000000000000D-01*dw(251,104)
      JacC(106,113) = JacC(106,113)+ 0.4200000000000000D-01*dw(251,113)
      JacC(107,104) = JacC(107,104)+ 0.1670000000000000D+00*dw(251,104)
      JacC(107,113) = JacC(107,113)+ 0.1670000000000000D+00*dw(251,113)
      JacC(113,104) = JacC(113,104) - dw(251,104)
      JacC(113,113) = JacC(113,113) - dw(251,113)
      JacC(116,104) = JacC(116,104)+ 0.1500000000000000D+01*dw(251,104)
      JacC(116,113) = JacC(116,113)+ 0.1500000000000000D+01*dw(251,113)
      JacC(119,104) = JacC(119,104) + dw(251,104)
      JacC(119,113) = JacC(119,113) + dw(251,113)
      JacC(122,104) = JacC(122,104)+ 0.1670000000000000D+00*dw(251,104)
      JacC(122,113) = JacC(122,113)+ 0.1670000000000000D+00*dw(251,113)
      JacC( 82, 82) = JacC( 82, 82) - dw(252, 82)
      JacC( 82,113) = JacC( 82,113) - dw(252,113)
      JacC( 89, 82) = JacC( 89, 82)+ 0.2500000000000000D+00*dw(252, 82)
      JacC( 89,113) = JacC( 89,113)+ 0.2500000000000000D+00*dw(252,113)
      JacC( 99, 82) = JacC( 99, 82)+ 0.2500000000000000D+00*dw(252, 82)
      JacC( 99,113) = JacC( 99,113)+ 0.2500000000000000D+00*dw(252,113)
      JacC(100, 82) = JacC(100, 82)+ 0.5000000000000000D+00*dw(252, 82)
      JacC(100,113) = JacC(100,113)+ 0.5000000000000000D+00*dw(252,113)
      JacC(106, 82) = JacC(106, 82)+ 0.2920000000000000D+00*dw(252, 82)
      JacC(106,113) = JacC(106,113)+ 0.2920000000000000D+00*dw(252,113)
      JacC(109, 82) = JacC(109, 82)+ 0.1750000000000000D+01*dw(252, 82)
      JacC(109,113) = JacC(109,113)+ 0.1750000000000000D+01*dw(252,113)
      JacC(112, 82) = JacC(112, 82)+ 0.1160000000000000D+01*dw(252, 82)
      JacC(112,113) = JacC(112,113)+ 0.1160000000000000D+01*dw(252,113)
      JacC(113, 82) = JacC(113, 82) - dw(252, 82)
      JacC(113,113) = JacC(113,113) - dw(252,113)
      JacC(116, 82) = JacC(116, 82)+ 0.1500000000000000D+01*dw(252, 82)
      JacC(116,113) = JacC(116,113)+ 0.1500000000000000D+01*dw(252,113)
      JacC(119, 82) = JacC(119, 82) + dw(252, 82)
      JacC(119,113) = JacC(119,113) + dw(252,113)
      JacC(122, 82) = JacC(122, 82)+ 0.1160000000000000D+01*dw(252, 82)
      JacC(122,113) = JacC(122,113)+ 0.1160000000000000D+01*dw(252,113)
      JacC( 84, 84) = JacC( 84, 84) - dw(253, 84)
      JacC( 84,113) = JacC( 84,113) - dw(253,113)
      JacC( 89, 84) = JacC( 89, 84)+ 0.2500000000000000D+00*dw(253, 84)
      JacC( 89,113) = JacC( 89,113)+ 0.2500000000000000D+00*dw(253,113)
      JacC( 99, 84) = JacC( 99, 84)+ 0.2500000000000000D+00*dw(253, 84)
      JacC( 99,113) = JacC( 99,113)+ 0.2500000000000000D+00*dw(253,113)
      JacC(100, 84) = JacC(100, 84)+ 0.1050000000000000D+00*dw(253, 84)
      JacC(100,113) = JacC(100,113)+ 0.1050000000000000D+00*dw(253,113)
      JacC(102, 84) = JacC(102, 84)+ 0.1350000000000000D+00*dw(253, 84)
      JacC(102,113) = JacC(102,113)+ 0.1350000000000000D+00*dw(253,113)
      JacC(107, 84) = JacC(107, 84)+ 0.3050000000000000D+00*dw(253, 84)
      JacC(107,113) = JacC(107,113)+ 0.3050000000000000D+00*dw(253,113)
      JacC(109, 84) = JacC(109, 84)+ 0.2030000000000000D+00*dw(253, 84)
      JacC(109,113) = JacC(109,113)+ 0.2030000000000000D+00*dw(253,113)
      JacC(111, 84) = JacC(111, 84)+ 0.5250000000000000D+00*dw(253, 84)
      JacC(111,113) = JacC(111,113)+ 0.5250000000000000D+00*dw(253,113)
      JacC(113, 84) = JacC(113, 84) - dw(253, 84)
      JacC(113,113) = JacC(113,113) - dw(253,113)
      JacC(116, 84) = JacC(116, 84)+ 0.7730000000000000D+00*dw(253, 84)
      JacC(116,113) = JacC(116,113)+ 0.7730000000000000D+00*dw(253,113)
      JacC(119, 84) = JacC(119, 84) + dw(253, 84)
      JacC(119,113) = JacC(119,113) + dw(253,113)
      JacC( 72, 72) = JacC( 72, 72) - dw(254, 72)
      JacC( 72,113) = JacC( 72,113) - dw(254,113)
      JacC( 89, 72) = JacC( 89, 72)+ 0.2500000000000000D+00*dw(254, 72)
      JacC( 89,113) = JacC( 89,113)+ 0.2500000000000000D+00*dw(254,113)
      JacC( 99, 72) = JacC( 99, 72)+ 0.2500000000000000D+00*dw(254, 72)
      JacC( 99,113) = JacC( 99,113)+ 0.2500000000000000D+00*dw(254,113)
      JacC(109, 72) = JacC(109, 72)+ 0.7500000000000000D+00*dw(254, 72)
      JacC(109,113) = JacC(109,113)+ 0.7500000000000000D+00*dw(254,113)
      JacC(111, 72) = JacC(111, 72)+ 0.7500000000000000D+00*dw(254, 72)
      JacC(111,113) = JacC(111,113)+ 0.7500000000000000D+00*dw(254,113)
      JacC(113, 72) = JacC(113, 72) - dw(254, 72)
      JacC(113,113) = JacC(113,113) - dw(254,113)
      JacC(116, 72) = JacC(116, 72)+ 0.7500000000000000D+00*dw(254, 72)
      JacC(116,113) = JacC(116,113)+ 0.7500000000000000D+00*dw(254,113)
      JacC(119, 72) = JacC(119, 72) + dw(254, 72)
      JacC(119,113) = JacC(119,113) + dw(254,113)
      JacC( 85, 85) = JacC( 85, 85) - dw(255, 85)
      JacC( 85,113) = JacC( 85,113) - dw(255,113)
      JacC( 86, 85) = JacC( 86, 85)+ 0.1920000000000000D+00*dw(255, 85)
      JacC( 86,113) = JacC( 86,113)+ 0.1920000000000000D+00*dw(255,113)
      JacC( 89, 85) = JacC( 89, 85)+ 0.2500000000000000D+00*dw(255, 85)
      JacC( 89,113) = JacC( 89,113)+ 0.2500000000000000D+00*dw(255,113)
      JacC( 92, 85) = JacC( 92, 85)+ 0.3080000000000000D+00*dw(255, 85)
      JacC( 92,113) = JacC( 92,113)+ 0.3080000000000000D+00*dw(255,113)
      JacC( 99, 85) = JacC( 99, 85)+ 0.2500000000000000D+00*dw(255, 85)
      JacC( 99,113) = JacC( 99,113)+ 0.2500000000000000D+00*dw(255,113)
      JacC(113, 85) = JacC(113, 85) - dw(255, 85)
      JacC(113,113) = JacC(113,113) - dw(255,113)
      JacC(116, 85) = JacC(116, 85)+ 0.1040000000000000D+01*dw(255, 85)
      JacC(116,113) = JacC(116,113)+ 0.1040000000000000D+01*dw(255,113)
      JacC(119, 85) = JacC(119, 85) + dw(255, 85)
      JacC(119,113) = JacC(119,113) + dw(255,113)
      JacC( 77, 77) = JacC( 77, 77) - dw(256, 77)
      JacC( 77,113) = JacC( 77,113) - dw(256,113)
      JacC( 83, 77) = JacC( 83, 77)+ 0.7000000000000000D+00*dw(256, 77)
      JacC( 83,113) = JacC( 83,113)+ 0.7000000000000000D+00*dw(256,113)
      JacC( 86, 77) = JacC( 86, 77)+ 0.3000000000000000D+00*dw(256, 77)
      JacC( 86,113) = JacC( 86,113)+ 0.3000000000000000D+00*dw(256,113)
      JacC(102, 77) = JacC(102, 77)+ 0.6000000000000000D+00*dw(256, 77)
      JacC(102,113) = JacC(102,113)+ 0.6000000000000000D+00*dw(256,113)
      JacC(113, 77) = JacC(113, 77) - dw(256, 77)
      JacC(113,113) = JacC(113,113) - dw(256,113)
      JacC(116, 77) = JacC(116, 77) + dw(256, 77)
      JacC(116,113) = JacC(116,113) + dw(256,113)
      JacC(119, 77) = JacC(119, 77)+ 0.2600000000000000D+01*dw(256, 77)
      JacC(119,113) = JacC(119,113)+ 0.2600000000000000D+01*dw(256,113)
      JacC( 54, 54) = JacC( 54, 54) - dw(257, 54)
      JacC( 54,113) = JacC( 54,113) - dw(257,113)
      JacC( 65, 54) = JacC( 65, 54) + dw(257, 54)
      JacC( 65,113) = JacC( 65,113) + dw(257,113)
      JacC(102, 54) = JacC(102, 54)+ 0.2710000000000000D+00*dw(257, 54)
      JacC(102,113) = JacC(102,113)+ 0.2710000000000000D+00*dw(257,113)
      JacC(113, 54) = JacC(113, 54) - dw(257, 54)
      JacC(113,113) = JacC(113,113) - dw(257,113)
      JacC(116, 54) = JacC(116, 54) + dw(257, 54)
      JacC(116,113) = JacC(116,113) + dw(257,113)
      JacC(119, 54) = JacC(119, 54)+ 0.2000000000000000D+01*dw(257, 54)
      JacC(119,113) = JacC(119,113)+ 0.2000000000000000D+01*dw(257,113)
      JacC( 53, 53) = JacC( 53, 53) - dw(258, 53)
      JacC( 53,113) = JacC( 53,113) - dw(258,113)
      JacC( 56, 53) = JacC( 56, 53) + dw(258, 53)
      JacC( 56,113) = JacC( 56,113) + dw(258,113)
      JacC(113, 53) = JacC(113, 53) - dw(258, 53)
      JacC(113,113) = JacC(113,113) - dw(258,113)
      JacC(116, 53) = JacC(116, 53) + dw(258, 53)
      JacC(116,113) = JacC(116,113) + dw(258,113)
      JacC(119, 53) = JacC(119, 53) + dw(258, 53)
      JacC(119,113) = JacC(119,113) + dw(258,113)
      JacC( 52, 52) = JacC( 52, 52) - dw(259, 52)
      JacC( 52,113) = JacC( 52,113) - dw(259,113)
      JacC( 68, 52) = JacC( 68, 52) + dw(259, 52)
      JacC( 68,113) = JacC( 68,113) + dw(259,113)
      JacC(100, 52) = JacC(100, 52) + dw(259, 52)
      JacC(100,113) = JacC(100,113) + dw(259,113)
      JacC(113, 52) = JacC(113, 52) - dw(259, 52)
      JacC(113,113) = JacC(113,113) - dw(259,113)
      JacC(116, 52) = JacC(116, 52) + dw(259, 52)
      JacC(116,113) = JacC(116,113) + dw(259,113)
      JacC(119, 52) = JacC(119, 52)+ 0.2000000000000000D+01*dw(259, 52)
      JacC(119,113) = JacC(119,113)+ 0.2000000000000000D+01*dw(259,113)
      JacC( 64, 64) = JacC( 64, 64) - dw(260, 64)
      JacC( 64,113) = JacC( 64,113) - dw(260,113)
      JacC( 65, 64) = JacC( 65, 64)+ 0.7700000000000000D-01*dw(260, 64)
      JacC( 65,113) = JacC( 65,113)+ 0.7700000000000000D-01*dw(260,113)
      JacC( 68, 64) = JacC( 68, 64)+ 0.7370000000000000D+00*dw(260, 64)
      JacC( 68,113) = JacC( 68,113)+ 0.7370000000000000D+00*dw(260,113)
      JacC( 69, 64) = JacC( 69, 64)+ 0.1860000000000000D+00*dw(260, 64)
      JacC( 69,113) = JacC( 69,113)+ 0.1860000000000000D+00*dw(260,113)
      JacC(100, 64) = JacC(100, 64)+ 0.6320000000000000D+00*dw(260, 64)
      JacC(100,113) = JacC(100,113)+ 0.6320000000000000D+00*dw(260,113)
      JacC(102, 64) = JacC(102, 64)+ 0.3680000000000000D+00*dw(260, 64)
      JacC(102,113) = JacC(102,113)+ 0.3680000000000000D+00*dw(260,113)
      JacC(113, 64) = JacC(113, 64) - dw(260, 64)
      JacC(113,113) = JacC(113,113) - dw(260,113)
      JacC(116, 64) = JacC(116, 64) + dw(260, 64)
      JacC(116,113) = JacC(116,113) + dw(260,113)
      JacC(119, 64) = JacC(119, 64)+ 0.2000000000000000D+01*dw(260, 64)
      JacC(119,113) = JacC(119,113)+ 0.2000000000000000D+01*dw(260,113)
      JacC( 55, 55) = JacC( 55, 55) - dw(261, 55)
      JacC( 55,113) = JacC( 55,113) - dw(261,113)
      JacC( 56, 55) = JacC( 56, 55) + dw(261, 55)
      JacC( 56,113) = JacC( 56,113) + dw(261,113)
      JacC(113, 55) = JacC(113, 55) - dw(261, 55)
      JacC(113,113) = JacC(113,113) - dw(261,113)
      JacC(116, 55) = JacC(116, 55) + dw(261, 55)
      JacC(116,113) = JacC(116,113) + dw(261,113)
      JacC(119, 55) = JacC(119, 55) + dw(261, 55)
      JacC(119,113) = JacC(119,113) + dw(261,113)
      JacC( 60, 60) = JacC( 60, 60) - dw(262, 60)
      JacC( 60,113) = JacC( 60,113) - dw(262,113)
      JacC( 65, 60) = JacC( 65, 60) + dw(262, 60)
      JacC( 65,113) = JacC( 65,113) + dw(262,113)
      JacC(113, 60) = JacC(113, 60) - dw(262, 60)
      JacC(113,113) = JacC(113,113) - dw(262,113)
      JacC(116, 60) = JacC(116, 60) + dw(262, 60)
      JacC(116,113) = JacC(116,113) + dw(262,113)
      JacC(119, 60) = JacC(119, 60)+ 0.2000000000000000D+01*dw(262, 60)
      JacC(119,113) = JacC(119,113)+ 0.2000000000000000D+01*dw(262,113)
      JacC( 63, 63) = JacC( 63, 63) - dw(263, 63)
      JacC( 63,113) = JacC( 63,113) - dw(263,113)
      JacC( 68, 63) = JacC( 68, 63) + dw(263, 63)
      JacC( 68,113) = JacC( 68,113) + dw(263,113)
      JacC( 69, 63) = JacC( 69, 63)+ 0.2050000000000000D+01*dw(263, 63)
      JacC( 69,113) = JacC( 69,113)+ 0.2050000000000000D+01*dw(263,113)
      JacC(100, 63) = JacC(100, 63) + dw(263, 63)
      JacC(100,113) = JacC(100,113) + dw(263,113)
      JacC(113, 63) = JacC(113, 63) - dw(263, 63)
      JacC(113,113) = JacC(113,113) - dw(263,113)
      JacC(116, 63) = JacC(116, 63) + dw(263, 63)
      JacC(116,113) = JacC(116,113) + dw(263,113)
      JacC(119, 63) = JacC(119, 63)+ 0.2000000000000000D+01*dw(263, 63)
      JacC(119,113) = JacC(119,113)+ 0.2000000000000000D+01*dw(263,113)
      JacC( 57, 57) = JacC( 57, 57) - dw(264, 57)
      JacC( 57,113) = JacC( 57,113) - dw(264,113)
      JacC( 58, 57) = JacC( 58, 57) + dw(264, 57)
      JacC( 58,113) = JacC( 58,113) + dw(264,113)
      JacC(113, 57) = JacC(113, 57) - dw(264, 57)
      JacC(113,113) = JacC(113,113) - dw(264,113)
      JacC(116, 57) = JacC(116, 57) + dw(264, 57)
      JacC(116,113) = JacC(116,113) + dw(264,113)
      JacC(119, 57) = JacC(119, 57) + dw(264, 57)
      JacC(119,113) = JacC(119,113) + dw(264,113)
      JacC( 58, 58) = JacC( 58, 58) - dw(265, 58)
      JacC( 58,113) = JacC( 58,113) - dw(265,113)
      JacC( 59, 58) = JacC( 59, 58) + dw(265, 58)
      JacC( 59,113) = JacC( 59,113) + dw(265,113)
      JacC(113, 58) = JacC(113, 58) - dw(265, 58)
      JacC(113,113) = JacC(113,113) - dw(265,113)
      JacC(116, 58) = JacC(116, 58) + dw(265, 58)
      JacC(116,113) = JacC(116,113) + dw(265,113)
      JacC(119, 58) = JacC(119, 58) + dw(265, 58)
      JacC(119,113) = JacC(119,113) + dw(265,113)
      JacC( 75, 97) = JacC( 75, 97)+ 0.3200000000000000D+00*dw(266, 97)
      JacC( 75,113) = JacC( 75,113)+ 0.3200000000000000D+00*dw(266,113)
      JacC( 97, 97) = JacC( 97, 97) - dw(266, 97)
      JacC( 97,113) = JacC( 97,113) - dw(266,113)
      JacC(102, 97) = JacC(102, 97)+ 0.6800000000000000D+00*dw(266, 97)
      JacC(102,113) = JacC(102,113)+ 0.6800000000000000D+00*dw(266,113)
      JacC(113, 97) = JacC(113, 97) - dw(266, 97)
      JacC(113,113) = JacC(113,113) - dw(266,113)
      JacC(115, 97) = JacC(115, 97)+ 0.6800000000000000D+00*dw(266, 97)
      JacC(115,113) = JacC(115,113)+ 0.6800000000000000D+00*dw(266,113)
      JacC(116, 97) = JacC(116, 97) + dw(266, 97)
      JacC(116,113) = JacC(116,113) + dw(266,113)
      JacC(119, 97) = JacC(119, 97)+ 0.2000000000000000D+01*dw(266, 97)
      JacC(119,113) = JacC(119,113)+ 0.2000000000000000D+01*dw(266,113)
      JacC(106,122) = JacC(106,122)+ 0.1000000000000000D+00*dw(267,122)
      JacC(106,113) = JacC(106,113)+ 0.1000000000000000D+00*dw(267,113)
      JacC(113,122) = JacC(113,122)- 0.9999999999999998D-01*dw(267,122)
      JacC(113,113) = JacC(113,113)- 0.9999999999999998D-01*dw(267,113)
      JacC(116,122) = JacC(116,122) + dw(267,122)
      JacC(116,113) = JacC(116,113) + dw(267,113)
      JacC(119,122) = JacC(119,122)+ 0.9000000000000000D+00*dw(267,122)
      JacC(119,113) = JacC(119,113)+ 0.9000000000000000D+00*dw(267,113)
      JacC(122,122) = JacC(122,122) - dw(267,122)
      JacC(122,113) = JacC(122,113) - dw(267,113)
      JacC(106,120) = JacC(106,120)+ 0.1000000000000000D+00*dw(268,120)
      JacC(106,113) = JacC(106,113)+ 0.1000000000000000D+00*dw(268,113)
      JacC(113,120) = JacC(113,120)- 0.9999999999999998D-01*dw(268,120)
      JacC(113,113) = JacC(113,113)- 0.9999999999999998D-01*dw(268,113)
      JacC(116,120) = JacC(116,120) + dw(268,120)
      JacC(116,113) = JacC(116,113) + dw(268,113)
      JacC(119,120) = JacC(119,120)+ 0.9000000000000000D+00*dw(268,120)
      JacC(119,113) = JacC(119,113)+ 0.9000000000000000D+00*dw(268,113)
      JacC(120,120) = JacC(120,120) - dw(268,120)
      JacC(120,113) = JacC(120,113) - dw(268,113)
      JacC( 78, 78) = JacC( 78, 78) - dw(269, 78)
      JacC( 78,113) = JacC( 78,113) - dw(269,113)
      JacC( 89, 78) = JacC( 89, 78)+ 0.2500000000000000D+00*dw(269, 78)
      JacC( 89,113) = JacC( 89,113)+ 0.2500000000000000D+00*dw(269,113)
      JacC( 99, 78) = JacC( 99, 78)+ 0.2500000000000000D+00*dw(269, 78)
      JacC( 99,113) = JacC( 99,113)+ 0.2500000000000000D+00*dw(269,113)
      JacC(106, 78) = JacC(106, 78)+ 0.1250000000000000D+00*dw(269, 78)
      JacC(106,113) = JacC(106,113)+ 0.1250000000000000D+00*dw(269,113)
      JacC(113, 78) = JacC(113, 78) - dw(269, 78)
      JacC(113,113) = JacC(113,113) - dw(269,113)
      JacC(116, 78) = JacC(116, 78)+ 0.1500000000000000D+01*dw(269, 78)
      JacC(116,113) = JacC(116,113)+ 0.1500000000000000D+01*dw(269,113)
      JacC(119, 78) = JacC(119, 78)+ 0.5000000000000000D+00*dw(269, 78)
      JacC(119,113) = JacC(119,113)+ 0.5000000000000000D+00*dw(269,113)
      JacC(122, 78) = JacC(122, 78)+ 0.5000000000000000D+00*dw(269, 78)
      JacC(122,113) = JacC(122,113)+ 0.5000000000000000D+00*dw(269,113)
      JacC( 67, 67) = JacC( 67, 67) - dw(270, 67)
      JacC( 67,113) = JacC( 67,113) - dw(270,113)
      JacC( 68, 67) = JacC( 68, 67)+ 0.3340000000000000D+00*dw(270, 67)
      JacC( 68,113) = JacC( 68,113)+ 0.3340000000000000D+00*dw(270,113)
      JacC( 89, 67) = JacC( 89, 67)+ 0.2500000000000000D+00*dw(270, 67)
      JacC( 89,113) = JacC( 89,113)+ 0.2500000000000000D+00*dw(270,113)
      JacC( 99, 67) = JacC( 99, 67)+ 0.2500000000000000D+00*dw(270, 67)
      JacC( 99,113) = JacC( 99,113)+ 0.2500000000000000D+00*dw(270,113)
      JacC(113, 67) = JacC(113, 67) - dw(270, 67)
      JacC(113,113) = JacC(113,113) - dw(270,113)
      JacC(116, 67) = JacC(116, 67) + dw(270, 67)
      JacC(116,113) = JacC(116,113) + dw(270,113)
      JacC(119, 67) = JacC(119, 67)+ 0.8340000000000000D+00*dw(270, 67)
      JacC(119,113) = JacC(119,113)+ 0.8340000000000000D+00*dw(270,113)
      JacC( 68,105) = JacC( 68,105)+ 0.5000000000000000D+00*dw(271,105)
      JacC( 68,113) = JacC( 68,113)+ 0.5000000000000000D+00*dw(271,113)
      JacC( 89,105) = JacC( 89,105)+ 0.2500000000000000D+00*dw(271,105)
      JacC( 89,113) = JacC( 89,113)+ 0.2500000000000000D+00*dw(271,113)
      JacC( 99,105) = JacC( 99,105)+ 0.2500000000000000D+00*dw(271,105)
      JacC( 99,113) = JacC( 99,113)+ 0.2500000000000000D+00*dw(271,113)
      JacC(105,105) = JacC(105,105) - dw(271,105)
      JacC(105,113) = JacC(105,113) - dw(271,113)
      JacC(113,105) = JacC(113,105) - dw(271,105)
      JacC(113,113) = JacC(113,113) - dw(271,113)
      JacC(116,105) = JacC(116,105)+ 0.7500000000000000D+00*dw(271,105)
      JacC(116,113) = JacC(116,113)+ 0.7500000000000000D+00*dw(271,113)
      JacC(119,105) = JacC(119,105) + dw(271,105)
      JacC(119,113) = JacC(119,113) + dw(271,113)
      JacC( 90, 90) = JacC( 90, 90) - dw(272, 90)
      JacC( 90,113) = JacC( 90,113) - dw(272,113)
      JacC(108, 90) = JacC(108, 90) + dw(272, 90)
      JacC(108,113) = JacC(108,113) + dw(272,113)
      JacC(113, 90) = JacC(113, 90) - dw(272, 90)
      JacC(113,113) = JacC(113,113) - dw(272,113)
      JacC(116, 90) = JacC(116, 90) + dw(272, 90)
      JacC(116,113) = JacC(116,113) + dw(272,113)
      JacC(119, 90) = JacC(119, 90)+ 0.2000000000000000D+01*dw(272, 90)
      JacC(119,113) = JacC(119,113)+ 0.2000000000000000D+01*dw(272,113)
      JacC( 88, 88) = JacC( 88, 88) - dw(273, 88)
      JacC( 88,113) = JacC( 88,113) - dw(273,113)
      JacC( 89, 88) = JacC( 89, 88)+ 0.2500000000000000D+00*dw(273, 88)
      JacC( 89,113) = JacC( 89,113)+ 0.2500000000000000D+00*dw(273,113)
      JacC( 99, 88) = JacC( 99, 88)+ 0.2500000000000000D+00*dw(273, 88)
      JacC( 99,113) = JacC( 99,113)+ 0.2500000000000000D+00*dw(273,113)
      JacC(108, 88) = JacC(108, 88)+ 0.5000000000000000D+00*dw(273, 88)
      JacC(108,113) = JacC(108,113)+ 0.5000000000000000D+00*dw(273,113)
      JacC(109, 88) = JacC(109, 88)+ 0.9300000000000000D+00*dw(273, 88)
      JacC(109,113) = JacC(109,113)+ 0.9300000000000000D+00*dw(273,113)
      JacC(111, 88) = JacC(111, 88)+ 0.3480000000000000D+00*dw(273, 88)
      JacC(111,113) = JacC(111,113)+ 0.3480000000000000D+00*dw(273,113)
      JacC(113, 88) = JacC(113, 88) - dw(273, 88)
      JacC(113,113) = JacC(113,113) - dw(273,113)
      JacC(116, 88) = JacC(116, 88)+ 0.9650000000000000D+00*dw(273, 88)
      JacC(116,113) = JacC(116,113)+ 0.9650000000000000D+00*dw(273,113)
      JacC(119, 88) = JacC(119, 88)+ 0.5000000000000000D+00*dw(273, 88)
      JacC(119,113) = JacC(119,113)+ 0.5000000000000000D+00*dw(273,113)
      JacC(121, 88) = JacC(121, 88)+ 0.5000000000000000D+00*dw(273, 88)
      JacC(121,113) = JacC(121,113)+ 0.5000000000000000D+00*dw(273,113)
      JacC( 94,114) = JacC( 94,114) + dw(274,114)
      JacC( 94,122) = JacC( 94,122) + dw(274,122)
      JacC(106,114) = JacC(106,114)+ 0.5000000000000000D+00*dw(274,114)
      JacC(106,122) = JacC(106,122)+ 0.5000000000000000D+00*dw(274,122)
      JacC(113,114) = JacC(113,114)+ 0.5000000000000000D+00*dw(274,114)
      JacC(113,122) = JacC(113,122)+ 0.5000000000000000D+00*dw(274,122)
      JacC(114,114) = JacC(114,114) - dw(274,114)
      JacC(114,122) = JacC(114,122) - dw(274,122)
      JacC(119,114) = JacC(119,114)+ 0.5000000000000000D+00*dw(274,114)
      JacC(119,122) = JacC(119,122)+ 0.5000000000000000D+00*dw(274,122)
      JacC(122,114) = JacC(122,114) - dw(274,114)
      JacC(122,122) = JacC(122,122) - dw(274,122)
      JacC(102,110) = JacC(102,110)+ 0.6700000000000000D-01*dw(275,110)
      JacC(102,122) = JacC(102,122)+ 0.6700000000000000D-01*dw(275,122)
      JacC(106,110) = JacC(106,110)+ 0.5000000000000000D+00*dw(275,110)
      JacC(106,122) = JacC(106,122)+ 0.5000000000000000D+00*dw(275,122)
      JacC(109,110) = JacC(109,110)+ 0.2730000000000000D+00*dw(275,110)
      JacC(109,122) = JacC(109,122)+ 0.2730000000000000D+00*dw(275,122)
      JacC(110,110) = JacC(110,110) - dw(275,110)
      JacC(110,122) = JacC(110,122) - dw(275,122)
      JacC(111,110) = JacC(111,110)+ 0.6620000000000000D+00*dw(275,110)
      JacC(111,122) = JacC(111,122)+ 0.6620000000000000D+00*dw(275,122)
      JacC(112,110) = JacC(112,110)+ 0.2600000000000000D-01*dw(275,110)
      JacC(112,122) = JacC(112,122)+ 0.2600000000000000D-01*dw(275,122)
      JacC(113,110) = JacC(113,110)+ 0.5800000000000000D+00*dw(275,110)
      JacC(113,122) = JacC(113,122)+ 0.5800000000000000D+00*dw(275,122)
      JacC(114,110) = JacC(114,110)+ 0.2600000000000000D-01*dw(275,110)
      JacC(114,122) = JacC(114,122)+ 0.2600000000000000D-01*dw(275,122)
      JacC(116,110) = JacC(116,110)+ 0.1300000000000000D+00*dw(275,110)
      JacC(116,122) = JacC(116,122)+ 0.1300000000000000D+00*dw(275,122)
      JacC(119,110) = JacC(119,110)+ 0.3940000000000000D+00*dw(275,110)
      JacC(119,122) = JacC(119,122)+ 0.3940000000000000D+00*dw(275,122)
      JacC(122,110) = JacC(122,110) - dw(275,110)
      JacC(122,122) = JacC(122,122) - dw(275,122)
      JacC( 76, 76) = JacC( 76, 76) - dw(276, 76)
      JacC( 76,122) = JacC( 76,122) - dw(276,122)
      JacC(106, 76) = JacC(106, 76)+ 0.5000000000000000D+00*dw(276, 76)
      JacC(106,122) = JacC(106,122)+ 0.5000000000000000D+00*dw(276,122)
      JacC(109, 76) = JacC(109, 76)+ 0.3810000000000000D+00*dw(276, 76)
      JacC(109,122) = JacC(109,122)+ 0.3810000000000000D+00*dw(276,122)
      JacC(111, 76) = JacC(111, 76)+ 0.8240000000000000D+00*dw(276, 76)
      JacC(111,122) = JacC(111,122)+ 0.8240000000000000D+00*dw(276,122)
      JacC(112, 76) = JacC(112, 76)+ 0.1910000000000000D+00*dw(276, 76)
      JacC(112,122) = JacC(112,122)+ 0.1910000000000000D+00*dw(276,122)
      JacC(113, 76) = JacC(113, 76)+ 0.5180000000000000D+00*dw(276, 76)
      JacC(113,122) = JacC(113,122)+ 0.5180000000000000D+00*dw(276,122)
      JacC(114, 76) = JacC(114, 76)+ 0.1400000000000000D+00*dw(276, 76)
      JacC(114,122) = JacC(114,122)+ 0.1400000000000000D+00*dw(276,122)
      JacC(116, 76) = JacC(116, 76)+ 0.4200000000000000D-01*dw(276, 76)
      JacC(116,122) = JacC(116,122)+ 0.4200000000000000D-01*dw(276,122)
      JacC(119, 76) = JacC(119, 76)+ 0.3420000000000000D+00*dw(276, 76)
      JacC(119,122) = JacC(119,122)+ 0.3420000000000000D+00*dw(276,122)
      JacC(122, 76) = JacC(122, 76) - dw(276, 76)
      JacC(122,122) = JacC(122,122) - dw(276,122)
      JacC( 79, 79) = JacC( 79, 79) - dw(277, 79)
      JacC( 79,122) = JacC( 79,122) - dw(277,122)
      JacC(106, 79) = JacC(106, 79)+ 0.4950000000000000D+00*dw(277, 79)
      JacC(106,122) = JacC(106,122)+ 0.4950000000000000D+00*dw(277,122)
      JacC(109, 79) = JacC(109, 79)+ 0.2170000000000000D+00*dw(277, 79)
      JacC(109,122) = JacC(109,122)+ 0.2170000000000000D+00*dw(277,122)
      JacC(111, 79) = JacC(111, 79)+ 0.6420000000000000D+00*dw(277, 79)
      JacC(111,122) = JacC(111,122)+ 0.6420000000000000D+00*dw(277,122)
      JacC(112, 79) = JacC(112, 79)+ 0.2080000000000000D+00*dw(277, 79)
      JacC(112,122) = JacC(112,122)+ 0.2080000000000000D+00*dw(277,122)
      JacC(113, 79) = JacC(113, 79)+ 0.5000000000000000D+00*dw(277, 79)
      JacC(113,122) = JacC(113,122)+ 0.5000000000000000D+00*dw(277,122)
      JacC(114, 79) = JacC(114, 79)+ 0.6700000000000000D-01*dw(277, 79)
      JacC(114,122) = JacC(114,122)+ 0.6700000000000000D-01*dw(277,122)
      JacC(119, 79) = JacC(119, 79)+ 0.3030000000000000D+00*dw(277, 79)
      JacC(119,122) = JacC(119,122)+ 0.3030000000000000D+00*dw(277,122)
      JacC(122, 79) = JacC(122, 79) - dw(277, 79)
      JacC(122,122) = JacC(122,122) - dw(277,122)
      JacC( 98, 98) = JacC( 98, 98) - dw(278, 98)
      JacC( 98,122) = JacC( 98,122) - dw(278,122)
      JacC(106, 98) = JacC(106, 98)+ 0.5000000000000000D+00*dw(278, 98)
      JacC(106,122) = JacC(106,122)+ 0.5000000000000000D+00*dw(278,122)
      JacC(109, 98) = JacC(109, 98)+ 0.2000000000000000D+00*dw(278, 98)
      JacC(109,122) = JacC(109,122)+ 0.2000000000000000D+00*dw(278,122)
      JacC(113, 98) = JacC(113, 98)+ 0.5000000000000000D+00*dw(278, 98)
      JacC(113,122) = JacC(113,122)+ 0.5000000000000000D+00*dw(278,122)
      JacC(116, 98) = JacC(116, 98)+ 0.1600000000000000D+01*dw(278, 98)
      JacC(116,122) = JacC(116,122)+ 0.1600000000000000D+01*dw(278,122)
      JacC(119, 98) = JacC(119, 98)+ 0.5000000000000000D+00*dw(278, 98)
      JacC(119,122) = JacC(119,122)+ 0.5000000000000000D+00*dw(278,122)
      JacC(122, 98) = JacC(122, 98) - dw(278, 98)
      JacC(122,122) = JacC(122,122) - dw(278,122)
      JacC( 71, 71) = JacC( 71, 71) - dw(279, 71)
      JacC( 71,122) = JacC( 71,122) - dw(279,122)
      JacC(106, 71) = JacC(106, 71)+ 0.5000000000000000D+00*dw(279, 71)
      JacC(106,122) = JacC(106,122)+ 0.5000000000000000D+00*dw(279,122)
      JacC(109, 71) = JacC(109, 71)+ 0.9399999999999999D+00*dw(279, 71)
      JacC(109,122) = JacC(109,122)+ 0.9399999999999999D+00*dw(279,122)
      JacC(111, 71) = JacC(111, 71)+ 0.6000000000000000D-01*dw(279, 71)
      JacC(111,122) = JacC(111,122)+ 0.6000000000000000D-01*dw(279,122)
      JacC(113, 71) = JacC(113, 71)+ 0.5000000000000000D+00*dw(279, 71)
      JacC(113,122) = JacC(113,122)+ 0.5000000000000000D+00*dw(279,122)
      JacC(116, 71) = JacC(116, 71) + dw(279, 71)
      JacC(116,122) = JacC(116,122) + dw(279,122)
      JacC(119, 71) = JacC(119, 71)+ 0.5000000000000000D+00*dw(279, 71)
      JacC(119,122) = JacC(119,122)+ 0.5000000000000000D+00*dw(279,122)
      JacC(122, 71) = JacC(122, 71) - dw(279, 71)
      JacC(122,122) = JacC(122,122) - dw(279,122)
      JacC( 87, 87) = JacC( 87, 87) - dw(280, 87)
      JacC( 87,122) = JacC( 87,122) - dw(280,122)
      JacC(106, 87) = JacC(106, 87)+ 0.5000000000000000D+00*dw(280, 87)
      JacC(106,122) = JacC(106,122)+ 0.5000000000000000D+00*dw(280,122)
      JacC(109, 87) = JacC(109, 87)+ 0.1710000000000000D+01*dw(280, 87)
      JacC(109,122) = JacC(109,122)+ 0.1710000000000000D+01*dw(280,122)
      JacC(111, 87) = JacC(111, 87)+ 0.2900000000000000D+00*dw(280, 87)
      JacC(111,122) = JacC(111,122)+ 0.2900000000000000D+00*dw(280,122)
      JacC(113, 87) = JacC(113, 87)+ 0.5000000000000000D+00*dw(280, 87)
      JacC(113,122) = JacC(113,122)+ 0.5000000000000000D+00*dw(280,122)
      JacC(119, 87) = JacC(119, 87)+ 0.5000000000000000D+00*dw(280, 87)
      JacC(119,122) = JacC(119,122)+ 0.5000000000000000D+00*dw(280,122)
      JacC(122, 87) = JacC(122, 87) - dw(280, 87)
      JacC(122,122) = JacC(122,122) - dw(280,122)
      JacC( 80, 80) = JacC( 80, 80) - dw(281, 80)
      JacC( 80,122) = JacC( 80,122) - dw(281,122)
      JacC( 81, 80) = JacC( 81, 80)+ 0.3050000000000000D+00*dw(281, 80)
      JacC( 81,122) = JacC( 81,122)+ 0.3050000000000000D+00*dw(281,122)
      JacC( 92, 80) = JacC( 92, 80)+ 0.2190000000000000D+00*dw(281, 80)
      JacC( 92,122) = JacC( 92,122)+ 0.2190000000000000D+00*dw(281,122)
      JacC(106, 80) = JacC(106, 80)+ 0.5000000000000000D+00*dw(281, 80)
      JacC(106,122) = JacC(106,122)+ 0.5000000000000000D+00*dw(281,122)
      JacC(113, 80) = JacC(113, 80)+ 0.5000000000000000D+00*dw(281, 80)
      JacC(113,122) = JacC(113,122)+ 0.5000000000000000D+00*dw(281,122)
      JacC(116, 80) = JacC(116, 80)+ 0.1048000000000000D+01*dw(281, 80)
      JacC(116,122) = JacC(116,122)+ 0.1048000000000000D+01*dw(281,122)
      JacC(119, 80) = JacC(119, 80)+ 0.5000000000000000D+00*dw(281, 80)
      JacC(119,122) = JacC(119,122)+ 0.5000000000000000D+00*dw(281,122)
      JacC(122, 80) = JacC(122, 80) - dw(281, 80)
      JacC(122,122) = JacC(122,122) - dw(281,122)
      JacC( 93,104) = JacC( 93,104)+ 0.1670000000000000D+00*dw(282,104)
      JacC( 93,122) = JacC( 93,122)+ 0.1670000000000000D+00*dw(282,122)
      JacC(100,104) = JacC(100,104)+ 0.3300000000000000D+00*dw(282,104)
      JacC(100,122) = JacC(100,122)+ 0.3300000000000000D+00*dw(282,122)
      JacC(104,104) = JacC(104,104) - dw(282,104)
      JacC(104,122) = JacC(104,122) - dw(282,122)
      JacC(106,104) = JacC(106,104)+ 0.5830000000000000D+00*dw(282,104)
      JacC(106,122) = JacC(106,122)+ 0.5830000000000000D+00*dw(282,122)
      JacC(107,104) = JacC(107,104)+ 0.1670000000000000D+00*dw(282,104)
      JacC(107,122) = JacC(107,122)+ 0.1670000000000000D+00*dw(282,122)
      JacC(113,104) = JacC(113,104)+ 0.5000000000000000D+00*dw(282,104)
      JacC(113,122) = JacC(113,122)+ 0.5000000000000000D+00*dw(282,122)
      JacC(116,104) = JacC(116,104) + dw(282,104)
      JacC(116,122) = JacC(116,122) + dw(282,122)
      JacC(119,104) = JacC(119,104)+ 0.5000000000000000D+00*dw(282,104)
      JacC(119,122) = JacC(119,122)+ 0.5000000000000000D+00*dw(282,122)
      JacC(122,104) = JacC(122,104)- 0.8330000000000000D+00*dw(282,104)
      JacC(122,122) = JacC(122,122)- 0.8330000000000000D+00*dw(282,122)
      JacC( 82, 82) = JacC( 82, 82) - dw(283, 82)
      JacC( 82,122) = JacC( 82,122) - dw(283,122)
      JacC(100, 82) = JacC(100, 82)+ 0.5000000000000000D+00*dw(283, 82)
      JacC(100,122) = JacC(100,122)+ 0.5000000000000000D+00*dw(283,122)
      JacC(106, 82) = JacC(106, 82)+ 0.1083000000000000D+01*dw(283, 82)
      JacC(106,122) = JacC(106,122)+ 0.1083000000000000D+01*dw(283,122)
      JacC(109, 82) = JacC(109, 82)+ 0.2300000000000000D+01*dw(283, 82)
      JacC(109,122) = JacC(109,122)+ 0.2300000000000000D+01*dw(283,122)
      JacC(112, 82) = JacC(112, 82)+ 0.1160000000000000D+01*dw(283, 82)
      JacC(112,122) = JacC(112,122)+ 0.1160000000000000D+01*dw(283,122)
      JacC(113, 82) = JacC(113, 82)+ 0.5000000000000000D+00*dw(283, 82)
      JacC(113,122) = JacC(113,122)+ 0.5000000000000000D+00*dw(283,122)
      JacC(116, 82) = JacC(116, 82) + dw(283, 82)
      JacC(116,122) = JacC(116,122) + dw(283,122)
      JacC(119, 82) = JacC(119, 82)+ 0.5000000000000000D+00*dw(283, 82)
      JacC(119,122) = JacC(119,122)+ 0.5000000000000000D+00*dw(283,122)
      JacC(122, 82) = JacC(122, 82)+ 0.1599999999999999D+00*dw(283, 82)
      JacC(122,122) = JacC(122,122)+ 0.1599999999999999D+00*dw(283,122)
      JacC( 84, 84) = JacC( 84, 84) - dw(284, 84)
      JacC( 84,122) = JacC( 84,122) - dw(284,122)
      JacC(100, 84) = JacC(100, 84)+ 0.1050000000000000D+00*dw(284, 84)
      JacC(100,122) = JacC(100,122)+ 0.1050000000000000D+00*dw(284,122)
      JacC(102, 84) = JacC(102, 84)+ 0.1800000000000000D+00*dw(284, 84)
      JacC(102,122) = JacC(102,122)+ 0.1800000000000000D+00*dw(284,122)
      JacC(106, 84) = JacC(106, 84)+ 0.5000000000000000D+00*dw(284, 84)
      JacC(106,122) = JacC(106,122)+ 0.5000000000000000D+00*dw(284,122)
      JacC(107, 84) = JacC(107, 84)+ 0.5000000000000000D+00*dw(284, 84)
      JacC(107,122) = JacC(107,122)+ 0.5000000000000000D+00*dw(284,122)
      JacC(109, 84) = JacC(109, 84)+ 0.2700000000000000D+00*dw(284, 84)
      JacC(109,122) = JacC(109,122)+ 0.2700000000000000D+00*dw(284,122)
      JacC(111, 84) = JacC(111, 84)+ 0.7000000000000000D+00*dw(284, 84)
      JacC(111,122) = JacC(111,122)+ 0.7000000000000000D+00*dw(284,122)
      JacC(113, 84) = JacC(113, 84)+ 0.5000000000000000D+00*dw(284, 84)
      JacC(113,122) = JacC(113,122)+ 0.5000000000000000D+00*dw(284,122)
      JacC(116, 84) = JacC(116, 84)+ 0.3000000000000000D-01*dw(284, 84)
      JacC(116,122) = JacC(116,122)+ 0.3000000000000000D-01*dw(284,122)
      JacC(119, 84) = JacC(119, 84)+ 0.5000000000000000D+00*dw(284, 84)
      JacC(119,122) = JacC(119,122)+ 0.5000000000000000D+00*dw(284,122)
      JacC(122, 84) = JacC(122, 84) - dw(284, 84)
      JacC(122,122) = JacC(122,122) - dw(284,122)
      JacC( 72, 72) = JacC( 72, 72) - dw(285, 72)
      JacC( 72,122) = JacC( 72,122) - dw(285,122)
      JacC(106, 72) = JacC(106, 72) + dw(285, 72)
      JacC(106,122) = JacC(106,122) + dw(285,122)
      JacC(109, 72) = JacC(109, 72) + dw(285, 72)
      JacC(109,122) = JacC(109,122) + dw(285,122)
      JacC(111, 72) = JacC(111, 72) + dw(285, 72)
      JacC(111,122) = JacC(111,122) + dw(285,122)
      JacC(113, 72) = JacC(113, 72)+ 0.5000000000000000D+00*dw(285, 72)
      JacC(113,122) = JacC(113,122)+ 0.5000000000000000D+00*dw(285,122)
      JacC(119, 72) = JacC(119, 72)+ 0.5000000000000000D+00*dw(285, 72)
      JacC(119,122) = JacC(119,122)+ 0.5000000000000000D+00*dw(285,122)
      JacC(122, 72) = JacC(122, 72) - dw(285, 72)
      JacC(122,122) = JacC(122,122) - dw(285,122)
      JacC( 85, 85) = JacC( 85, 85) - dw(286, 85)
      JacC( 85,122) = JacC( 85,122) - dw(286,122)
      JacC( 86, 85) = JacC( 86, 85)+ 0.1920000000000000D+00*dw(286, 85)
      JacC( 86,122) = JacC( 86,122)+ 0.1920000000000000D+00*dw(286,122)
      JacC( 92, 85) = JacC( 92, 85)+ 0.3080000000000000D+00*dw(286, 85)
      JacC( 92,122) = JacC( 92,122)+ 0.3080000000000000D+00*dw(286,122)
      JacC(106, 85) = JacC(106, 85)+ 0.5000000000000000D+00*dw(286, 85)
      JacC(106,122) = JacC(106,122)+ 0.5000000000000000D+00*dw(286,122)
      JacC(113, 85) = JacC(113, 85)+ 0.5000000000000000D+00*dw(286, 85)
      JacC(113,122) = JacC(113,122)+ 0.5000000000000000D+00*dw(286,122)
      JacC(116, 85) = JacC(116, 85)+ 0.3850000000000000D+00*dw(286, 85)
      JacC(116,122) = JacC(116,122)+ 0.3850000000000000D+00*dw(286,122)
      JacC(119, 85) = JacC(119, 85)+ 0.5000000000000000D+00*dw(286, 85)
      JacC(119,122) = JacC(119,122)+ 0.5000000000000000D+00*dw(286,122)
      JacC(122, 85) = JacC(122, 85) - dw(286, 85)
      JacC(122,122) = JacC(122,122) - dw(286,122)
      JacC( 77, 77) = JacC( 77, 77) - dw(287, 77)
      JacC( 77,122) = JacC( 77,122) - dw(287,122)
      JacC( 83, 77) = JacC( 83, 77)+ 0.7000000000000000D+00*dw(287, 77)
      JacC( 83,122) = JacC( 83,122)+ 0.7000000000000000D+00*dw(287,122)
      JacC( 86, 77) = JacC( 86, 77)+ 0.3000000000000000D+00*dw(287, 77)
      JacC( 86,122) = JacC( 86,122)+ 0.3000000000000000D+00*dw(287,122)
      JacC(102, 77) = JacC(102, 77)+ 0.6000000000000000D+00*dw(287, 77)
      JacC(102,122) = JacC(102,122)+ 0.6000000000000000D+00*dw(287,122)
      JacC(113, 77) = JacC(113, 77) + dw(287, 77)
      JacC(113,122) = JacC(113,122) + dw(287,122)
      JacC(119, 77) = JacC(119, 77)+ 0.6000000000000000D+00*dw(287, 77)
      JacC(119,122) = JacC(119,122)+ 0.6000000000000000D+00*dw(287,122)
      JacC(122, 77) = JacC(122, 77) - dw(287, 77)
      JacC(122,122) = JacC(122,122) - dw(287,122)
      JacC( 54, 54) = JacC( 54, 54) - dw(288, 54)
      JacC( 54,122) = JacC( 54,122) - dw(288,122)
      JacC( 65, 54) = JacC( 65, 54) + dw(288, 54)
      JacC( 65,122) = JacC( 65,122) + dw(288,122)
      JacC(113, 54) = JacC(113, 54) + dw(288, 54)
      JacC(113,122) = JacC(113,122) + dw(288,122)
      JacC(119, 54) = JacC(119, 54) + dw(288, 54)
      JacC(119,122) = JacC(119,122) + dw(288,122)
      JacC(122, 54) = JacC(122, 54) - dw(288, 54)
      JacC(122,122) = JacC(122,122) - dw(288,122)
      JacC( 53, 53) = JacC( 53, 53) - dw(289, 53)
      JacC( 53,122) = JacC( 53,122) - dw(289,122)
      JacC( 56, 53) = JacC( 56, 53) + dw(289, 53)
      JacC( 56,122) = JacC( 56,122) + dw(289,122)
      JacC(113, 53) = JacC(113, 53) + dw(289, 53)
      JacC(113,122) = JacC(113,122) + dw(289,122)
      JacC(122, 53) = JacC(122, 53) - dw(289, 53)
      JacC(122,122) = JacC(122,122) - dw(289,122)
      JacC( 52, 52) = JacC( 52, 52) - dw(290, 52)
      JacC( 52,122) = JacC( 52,122) - dw(290,122)
      JacC( 68, 52) = JacC( 68, 52) + dw(290, 52)
      JacC( 68,122) = JacC( 68,122) + dw(290,122)
      JacC(100, 52) = JacC(100, 52) + dw(290, 52)
      JacC(100,122) = JacC(100,122) + dw(290,122)
      JacC(113, 52) = JacC(113, 52) + dw(290, 52)
      JacC(113,122) = JacC(113,122) + dw(290,122)
      JacC(119, 52) = JacC(119, 52) + dw(290, 52)
      JacC(119,122) = JacC(119,122) + dw(290,122)
      JacC(122, 52) = JacC(122, 52) - dw(290, 52)
      JacC(122,122) = JacC(122,122) - dw(290,122)
      JacC( 63, 63) = JacC( 63, 63) - dw(291, 63)
      JacC( 63,122) = JacC( 63,122) - dw(291,122)
      JacC( 68, 63) = JacC( 68, 63) + dw(291, 63)
      JacC( 68,122) = JacC( 68,122) + dw(291,122)
      JacC( 69, 63) = JacC( 69, 63)+ 0.2050000000000000D+01*dw(291, 63)
      JacC( 69,122) = JacC( 69,122)+ 0.2050000000000000D+01*dw(291,122)
      JacC(100, 63) = JacC(100, 63) + dw(291, 63)
      JacC(100,122) = JacC(100,122) + dw(291,122)
      JacC(113, 63) = JacC(113, 63) + dw(291, 63)
      JacC(113,122) = JacC(113,122) + dw(291,122)
      JacC(119, 63) = JacC(119, 63) + dw(291, 63)
      JacC(119,122) = JacC(119,122) + dw(291,122)
      JacC(122, 63) = JacC(122, 63) - dw(291, 63)
      JacC(122,122) = JacC(122,122) - dw(291,122)
      JacC( 57, 57) = JacC( 57, 57) - dw(292, 57)
      JacC( 57,122) = JacC( 57,122) - dw(292,122)
      JacC( 58, 57) = JacC( 58, 57) + dw(292, 57)
      JacC( 58,122) = JacC( 58,122) + dw(292,122)
      JacC(113, 57) = JacC(113, 57) + dw(292, 57)
      JacC(113,122) = JacC(113,122) + dw(292,122)
      JacC(122, 57) = JacC(122, 57) - dw(292, 57)
      JacC(122,122) = JacC(122,122) - dw(292,122)
      JacC( 58, 58) = JacC( 58, 58) - dw(293, 58)
      JacC( 58,122) = JacC( 58,122) - dw(293,122)
      JacC( 59, 58) = JacC( 59, 58) + dw(293, 58)
      JacC( 59,122) = JacC( 59,122) + dw(293,122)
      JacC(113, 58) = JacC(113, 58) + dw(293, 58)
      JacC(113,122) = JacC(113,122) + dw(293,122)
      JacC(122, 58) = JacC(122, 58) - dw(293, 58)
      JacC(122,122) = JacC(122,122) - dw(293,122)
      JacC( 64, 64) = JacC( 64, 64) - dw(294, 64)
      JacC( 64,122) = JacC( 64,122) - dw(294,122)
      JacC( 65, 64) = JacC( 65, 64)+ 0.7700000000000000D-01*dw(294, 64)
      JacC( 65,122) = JacC( 65,122)+ 0.7700000000000000D-01*dw(294,122)
      JacC( 68, 64) = JacC( 68, 64)+ 0.7370000000000000D+00*dw(294, 64)
      JacC( 68,122) = JacC( 68,122)+ 0.7370000000000000D+00*dw(294,122)
      JacC( 69, 64) = JacC( 69, 64)+ 0.1860000000000000D+00*dw(294, 64)
      JacC( 69,122) = JacC( 69,122)+ 0.1860000000000000D+00*dw(294,122)
      JacC(100, 64) = JacC(100, 64)+ 0.6320000000000000D+00*dw(294, 64)
      JacC(100,122) = JacC(100,122)+ 0.6320000000000000D+00*dw(294,122)
      JacC(102, 64) = JacC(102, 64)+ 0.3680000000000000D+00*dw(294, 64)
      JacC(102,122) = JacC(102,122)+ 0.3680000000000000D+00*dw(294,122)
      JacC(113, 64) = JacC(113, 64) + dw(294, 64)
      JacC(113,122) = JacC(113,122) + dw(294,122)
      JacC(119, 64) = JacC(119, 64) + dw(294, 64)
      JacC(119,122) = JacC(119,122) + dw(294,122)
      JacC(122, 64) = JacC(122, 64) - dw(294, 64)
      JacC(122,122) = JacC(122,122) - dw(294,122)
      JacC( 55, 55) = JacC( 55, 55) - dw(295, 55)
      JacC( 55,122) = JacC( 55,122) - dw(295,122)
      JacC( 56, 55) = JacC( 56, 55) + dw(295, 55)
      JacC( 56,122) = JacC( 56,122) + dw(295,122)
      JacC(113, 55) = JacC(113, 55) + dw(295, 55)
      JacC(113,122) = JacC(113,122) + dw(295,122)
      JacC(122, 55) = JacC(122, 55) - dw(295, 55)
      JacC(122,122) = JacC(122,122) - dw(295,122)
      JacC( 60, 60) = JacC( 60, 60) - dw(296, 60)
      JacC( 60,122) = JacC( 60,122) - dw(296,122)
      JacC( 65, 60) = JacC( 65, 60) + dw(296, 60)
      JacC( 65,122) = JacC( 65,122) + dw(296,122)
      JacC(113, 60) = JacC(113, 60) + dw(296, 60)
      JacC(113,122) = JacC(113,122) + dw(296,122)
      JacC(119, 60) = JacC(119, 60) + dw(296, 60)
      JacC(119,122) = JacC(119,122) + dw(296,122)
      JacC(122, 60) = JacC(122, 60) - dw(296, 60)
      JacC(122,122) = JacC(122,122) - dw(296,122)
      JacC( 75, 97) = JacC( 75, 97)+ 0.3200000000000000D+00*dw(297, 97)
      JacC( 75,122) = JacC( 75,122)+ 0.3200000000000000D+00*dw(297,122)
      JacC( 97, 97) = JacC( 97, 97) - dw(297, 97)
      JacC( 97,122) = JacC( 97,122) - dw(297,122)
      JacC(102, 97) = JacC(102, 97)+ 0.6800000000000000D+00*dw(297, 97)
      JacC(102,122) = JacC(102,122)+ 0.6800000000000000D+00*dw(297,122)
      JacC(113, 97) = JacC(113, 97) + dw(297, 97)
      JacC(113,122) = JacC(113,122) + dw(297,122)
      JacC(115, 97) = JacC(115, 97)+ 0.6800000000000000D+00*dw(297, 97)
      JacC(115,122) = JacC(115,122)+ 0.6800000000000000D+00*dw(297,122)
      JacC(119, 97) = JacC(119, 97)+ 0.2000000000000000D+01*dw(297, 97)
      JacC(119,122) = JacC(119,122)+ 0.2000000000000000D+01*dw(297,122)
      JacC(122, 97) = JacC(122, 97) - dw(297, 97)
      JacC(122,122) = JacC(122,122) - dw(297,122)
      JacC(113,122) = JacC(113,122)+ 0.2000000000000000D+01*dw(298,122)
      JacC(113,122) = JacC(113,122)+ 0.2000000000000000D+01*dw(298,122)
      JacC(122,122) = JacC(122,122)- 0.2000000000000000D+01*dw(298,122)
      JacC(122,122) = JacC(122,122)- 0.2000000000000000D+01*dw(298,122)
      JacC(114,120) = JacC(114,120)+ 0.2000000000000000D+01*dw(299,120)
      JacC(114,120) = JacC(114,120)+ 0.2000000000000000D+01*dw(299,120)
      JacC(120,120) = JacC(120,120)- 0.2000000000000000D+01*dw(299,120)
      JacC(120,120) = JacC(120,120)- 0.2000000000000000D+01*dw(299,120)
      JacC( 68,105) = JacC( 68,105)+ 0.5000000000000000D+00*dw(300,105)
      JacC( 68,122) = JacC( 68,122)+ 0.5000000000000000D+00*dw(300,122)
      JacC(105,105) = JacC(105,105) - dw(300,105)
      JacC(105,122) = JacC(105,122) - dw(300,122)
      JacC(106,105) = JacC(106,105)+ 0.5000000000000000D+00*dw(300,105)
      JacC(106,122) = JacC(106,122)+ 0.5000000000000000D+00*dw(300,122)
      JacC(113,105) = JacC(113,105)+ 0.5000000000000000D+00*dw(300,105)
      JacC(113,122) = JacC(113,122)+ 0.5000000000000000D+00*dw(300,122)
      JacC(119,105) = JacC(119,105)+ 0.5000000000000000D+00*dw(300,105)
      JacC(119,122) = JacC(119,122)+ 0.5000000000000000D+00*dw(300,122)
      JacC(122,105) = JacC(122,105) - dw(300,105)
      JacC(122,122) = JacC(122,122) - dw(300,122)
      JacC( 78, 78) = JacC( 78, 78) - dw(301, 78)
      JacC( 78,122) = JacC( 78,122) - dw(301,122)
      JacC(106, 78) = JacC(106, 78)+ 0.7500000000000000D+00*dw(301, 78)
      JacC(106,122) = JacC(106,122)+ 0.7500000000000000D+00*dw(301,122)
      JacC(113, 78) = JacC(113, 78)+ 0.5000000000000000D+00*dw(301, 78)
      JacC(113,122) = JacC(113,122)+ 0.5000000000000000D+00*dw(301,122)
      JacC(116, 78) = JacC(116, 78) + dw(301, 78)
      JacC(116,122) = JacC(116,122) + dw(301,122)
      JacC(122, 78) = JacC(122, 78)- 0.5000000000000000D+00*dw(301, 78)
      JacC(122,122) = JacC(122,122)- 0.5000000000000000D+00*dw(301,122)
      JacC( 67, 67) = JacC( 67, 67) - dw(302, 67)
      JacC( 67,122) = JacC( 67,122) - dw(302,122)
      JacC( 68, 67) = JacC( 68, 67)+ 0.3340000000000000D+00*dw(302, 67)
      JacC( 68,122) = JacC( 68,122)+ 0.3340000000000000D+00*dw(302,122)
      JacC(106, 67) = JacC(106, 67)+ 0.5000000000000000D+00*dw(302, 67)
      JacC(106,122) = JacC(106,122)+ 0.5000000000000000D+00*dw(302,122)
      JacC(113, 67) = JacC(113, 67)+ 0.5000000000000000D+00*dw(302, 67)
      JacC(113,122) = JacC(113,122)+ 0.5000000000000000D+00*dw(302,122)
      JacC(116, 67) = JacC(116, 67)+ 0.3300000000000000D+00*dw(302, 67)
      JacC(116,122) = JacC(116,122)+ 0.3300000000000000D+00*dw(302,122)
      JacC(119, 67) = JacC(119, 67)+ 0.3300000000000000D+00*dw(302, 67)
      JacC(119,122) = JacC(119,122)+ 0.3300000000000000D+00*dw(302,122)
      JacC(122, 67) = JacC(122, 67) - dw(302, 67)
      JacC(122,122) = JacC(122,122) - dw(302,122)
      JacC( 90, 90) = JacC( 90, 90) - dw(303, 90)
      JacC( 90,122) = JacC( 90,122) - dw(303,122)
      JacC(108, 90) = JacC(108, 90) + dw(303, 90)
      JacC(108,122) = JacC(108,122) + dw(303,122)
      JacC(113, 90) = JacC(113, 90) + dw(303, 90)
      JacC(113,122) = JacC(113,122) + dw(303,122)
      JacC(119, 90) = JacC(119, 90) + dw(303, 90)
      JacC(119,122) = JacC(119,122) + dw(303,122)
      JacC(122, 90) = JacC(122, 90) - dw(303, 90)
      JacC(122,122) = JacC(122,122) - dw(303,122)
      JacC( 88, 88) = JacC( 88, 88) - dw(304, 88)
      JacC( 88,122) = JacC( 88,122) - dw(304,122)
      JacC(106, 88) = JacC(106, 88)+ 0.5000000000000000D+00*dw(304, 88)
      JacC(106,122) = JacC(106,122)+ 0.5000000000000000D+00*dw(304,122)
      JacC(109, 88) = JacC(109, 88)+ 0.1240000000000000D+01*dw(304, 88)
      JacC(109,122) = JacC(109,122)+ 0.1240000000000000D+01*dw(304,122)
      JacC(111, 88) = JacC(111, 88)+ 0.4640000000000000D+00*dw(304, 88)
      JacC(111,122) = JacC(111,122)+ 0.4640000000000000D+00*dw(304,122)
      JacC(113, 88) = JacC(113, 88)+ 0.5000000000000000D+00*dw(304, 88)
      JacC(113,122) = JacC(113,122)+ 0.5000000000000000D+00*dw(304,122)
      JacC(116, 88) = JacC(116, 88)+ 0.2870000000000000D+00*dw(304, 88)
      JacC(116,122) = JacC(116,122)+ 0.2870000000000000D+00*dw(304,122)
      JacC(121, 88) = JacC(121, 88) + dw(304, 88)
      JacC(121,122) = JacC(121,122) + dw(304,122)
      JacC(122, 88) = JacC(122, 88) - dw(304, 88)
      JacC(122,122) = JacC(122,122) - dw(304,122)
      JacC( 90, 90) = JacC( 90, 90)- 0.2000000000000000D+01*dw(305, 90)
      JacC( 90, 90) = JacC( 90, 90)- 0.2000000000000000D+01*dw(305, 90)
      JacC(108, 90) = JacC(108, 90)+ 0.2000000000000000D+01*dw(305, 90)
      JacC(108, 90) = JacC(108, 90)+ 0.2000000000000000D+01*dw(305, 90)
      JacC(119, 90) = JacC(119, 90) + dw(305, 90)
      JacC(119, 90) = JacC(119, 90) + dw(305, 90)
      JacC( 88, 90) = JacC( 88, 90) - dw(306, 90)
      JacC( 88, 88) = JacC( 88, 88) - dw(306, 88)
      JacC( 90, 90) = JacC( 90, 90) - dw(306, 90)
      JacC( 90, 88) = JacC( 90, 88) - dw(306, 88)
      JacC(108, 90) = JacC(108, 90)+ 0.1500000000000000D+01*dw(306, 90)
      JacC(108, 88) = JacC(108, 88)+ 0.1500000000000000D+01*dw(306, 88)
      JacC(109, 90) = JacC(109, 90)+ 0.6400000000000000D+00*dw(306, 90)
      JacC(109, 88) = JacC(109, 88)+ 0.6400000000000000D+00*dw(306, 88)
      JacC(111, 90) = JacC(111, 90)+ 0.1490000000000000D+00*dw(306, 90)
      JacC(111, 88) = JacC(111, 88)+ 0.1490000000000000D+00*dw(306, 88)
      JacC(116, 90) = JacC(116, 90)+ 0.2020000000000000D+00*dw(306, 90)
      JacC(116, 88) = JacC(116, 88)+ 0.2020000000000000D+00*dw(306, 88)
      JacC(119, 90) = JacC(119, 90)+ 0.5000000000000000D+00*dw(306, 90)
      JacC(119, 88) = JacC(119, 88)+ 0.5000000000000000D+00*dw(306, 88)
      JacC(121, 90) = JacC(121, 90)+ 0.5000000000000000D+00*dw(306, 90)
      JacC(121, 88) = JacC(121, 88)+ 0.5000000000000000D+00*dw(306, 88)
      JacC( 88, 88) = JacC( 88, 88)- 0.2000000000000000D+01*dw(307, 88)
      JacC( 88, 88) = JacC( 88, 88)- 0.2000000000000000D+01*dw(307, 88)
      JacC(108, 88) = JacC(108, 88) + dw(307, 88)
      JacC(108, 88) = JacC(108, 88) + dw(307, 88)
      JacC(109, 88) = JacC(109, 88)+ 0.1210000000000000D+01*dw(307, 88)
      JacC(109, 88) = JacC(109, 88)+ 0.1210000000000000D+01*dw(307, 88)
      JacC(111, 88) = JacC(111, 88)+ 0.2850000000000000D+00*dw(307, 88)
      JacC(111, 88) = JacC(111, 88)+ 0.2850000000000000D+00*dw(307, 88)
      JacC(116, 88) = JacC(116, 88)+ 0.5040000000000000D+00*dw(307, 88)
      JacC(116, 88) = JacC(116, 88)+ 0.5040000000000000D+00*dw(307, 88)
      JacC(121, 88) = JacC(121, 88) + dw(307, 88)
      JacC(121, 88) = JacC(121, 88) + dw(307, 88)
      JacC(113,113) = JacC(113,113) - dw(308,113)
      JacC(113,117) = JacC(113,117) - dw(308,117)
      JacC(116,113) = JacC(116,113) + dw(308,113)
      JacC(116,117) = JacC(116,117) + dw(308,117)
      JacC(117,113) = JacC(117,113) - dw(308,113)
      JacC(117,117) = JacC(117,117) - dw(308,117)
      JacC(119,113) = JacC(119,113) + dw(308,113)
      JacC(119,117) = JacC(119,117) + dw(308,117)
      JacC(121,113) = JacC(121,113) + dw(308,113)
      JacC(121,117) = JacC(121,117) + dw(308,117)
      JacC( 94,114) = JacC( 94,114) + dw(309,114)
      JacC( 94,117) = JacC( 94,117) + dw(309,117)
      JacC(114,114) = JacC(114,114) - dw(309,114)
      JacC(114,117) = JacC(114,117) - dw(309,117)
      JacC(117,114) = JacC(117,114) - dw(309,114)
      JacC(117,117) = JacC(117,117) - dw(309,117)
      JacC(119,114) = JacC(119,114) + dw(309,114)
      JacC(119,117) = JacC(119,117) + dw(309,117)
      JacC(121,114) = JacC(121,114) + dw(309,114)
      JacC(121,117) = JacC(121,117) + dw(309,117)
      JacC(102,110) = JacC(102,110)+ 0.6700000000000000D-01*dw(310,110)
      JacC(102,117) = JacC(102,117)+ 0.6700000000000000D-01*dw(310,117)
      JacC(109,110) = JacC(109,110)+ 0.2480000000000000D+00*dw(310,110)
      JacC(109,117) = JacC(109,117)+ 0.2480000000000000D+00*dw(310,117)
      JacC(110,110) = JacC(110,110) - dw(310,110)
      JacC(110,117) = JacC(110,117) - dw(310,117)
      JacC(111,110) = JacC(111,110)+ 0.6620000000000000D+00*dw(310,110)
      JacC(111,117) = JacC(111,117)+ 0.6620000000000000D+00*dw(310,117)
      JacC(112,110) = JacC(112,110)+ 0.5100000000000000D-01*dw(310,110)
      JacC(112,117) = JacC(112,117)+ 0.5100000000000000D-01*dw(310,117)
      JacC(113,110) = JacC(113,110)+ 0.1590000000000000D+00*dw(310,110)
      JacC(113,117) = JacC(113,117)+ 0.1590000000000000D+00*dw(310,117)
      JacC(114,110) = JacC(114,110)+ 0.5100000000000000D-01*dw(310,110)
      JacC(114,117) = JacC(114,117)+ 0.5100000000000000D-01*dw(310,117)
      JacC(116,110) = JacC(116,110)+ 0.5000000000000000D-01*dw(310,110)
      JacC(116,117) = JacC(116,117)+ 0.5000000000000000D-01*dw(310,117)
      JacC(117,110) = JacC(117,110) - dw(310,110)
      JacC(117,117) = JacC(117,117) - dw(310,117)
      JacC(119,110) = JacC(119,110)+ 0.7890000000000000D+00*dw(310,110)
      JacC(119,117) = JacC(119,117)+ 0.7890000000000000D+00*dw(310,117)
      JacC(121,110) = JacC(121,110) + dw(310,110)
      JacC(121,117) = JacC(121,117) + dw(310,117)
      JacC( 76, 76) = JacC( 76, 76) - dw(311, 76)
      JacC( 76,117) = JacC( 76,117) - dw(311,117)
      JacC(109, 76) = JacC(109, 76)+ 0.2410000000000000D+00*dw(311, 76)
      JacC(109,117) = JacC(109,117)+ 0.2410000000000000D+00*dw(311,117)
      JacC(111, 76) = JacC(111, 76)+ 0.8240000000000000D+00*dw(311, 76)
      JacC(111,117) = JacC(111,117)+ 0.8240000000000000D+00*dw(311,117)
      JacC(112, 76) = JacC(112, 76)+ 0.3810000000000000D+00*dw(311, 76)
      JacC(112,117) = JacC(112,117)+ 0.3810000000000000D+00*dw(311,117)
      JacC(113, 76) = JacC(113, 76)+ 0.3500000000000000D-01*dw(311, 76)
      JacC(113,117) = JacC(113,117)+ 0.3500000000000000D-01*dw(311,117)
      JacC(114, 76) = JacC(114, 76)+ 0.2800000000000000D+00*dw(311, 76)
      JacC(114,117) = JacC(114,117)+ 0.2800000000000000D+00*dw(311,117)
      JacC(116, 76) = JacC(116, 76)+ 0.2400000000000000D-01*dw(311, 76)
      JacC(116,117) = JacC(116,117)+ 0.2400000000000000D-01*dw(311,117)
      JacC(117, 76) = JacC(117, 76) - dw(311, 76)
      JacC(117,117) = JacC(117,117) - dw(311,117)
      JacC(119, 76) = JacC(119, 76)+ 0.6840000000000001D+00*dw(311, 76)
      JacC(119,117) = JacC(119,117)+ 0.6840000000000001D+00*dw(311,117)
      JacC(121, 76) = JacC(121, 76) + dw(311, 76)
      JacC(121,117) = JacC(121,117) + dw(311,117)
      JacC( 79, 79) = JacC( 79, 79) - dw(312, 79)
      JacC( 79,117) = JacC( 79,117) - dw(312,117)
      JacC(109, 79) = JacC(109, 79)+ 0.2030000000000000D+00*dw(312, 79)
      JacC(109,117) = JacC(109,117)+ 0.2030000000000000D+00*dw(312,117)
      JacC(111, 79) = JacC(111, 79)+ 0.8690000000000000D+00*dw(312, 79)
      JacC(111,117) = JacC(111,117)+ 0.8690000000000000D+00*dw(312,117)
      JacC(112, 79) = JacC(112, 79)+ 0.5629999999999999D+00*dw(312, 79)
      JacC(112,117) = JacC(112,117)+ 0.5629999999999999D+00*dw(312,117)
      JacC(114, 79) = JacC(114, 79)+ 0.1800000000000000D+00*dw(312, 79)
      JacC(114,117) = JacC(114,117)+ 0.1800000000000000D+00*dw(312,117)
      JacC(117, 79) = JacC(117, 79) - dw(312, 79)
      JacC(117,117) = JacC(117,117) - dw(312,117)
      JacC(119, 79) = JacC(119, 79)+ 0.8200000000000000D+00*dw(312, 79)
      JacC(119,117) = JacC(119,117)+ 0.8200000000000000D+00*dw(312,117)
      JacC(121, 79) = JacC(121, 79) + dw(312, 79)
      JacC(121,117) = JacC(121,117) + dw(312,117)
      JacC( 98, 98) = JacC( 98, 98) - dw(313, 98)
      JacC( 98,117) = JacC( 98,117) - dw(313,117)
      JacC(109, 98) = JacC(109, 98)+ 0.2000000000000000D+00*dw(313, 98)
      JacC(109,117) = JacC(109,117)+ 0.2000000000000000D+00*dw(313,117)
      JacC(116, 98) = JacC(116, 98)+ 0.1600000000000000D+01*dw(313, 98)
      JacC(116,117) = JacC(116,117)+ 0.1600000000000000D+01*dw(313,117)
      JacC(117, 98) = JacC(117, 98) - dw(313, 98)
      JacC(117,117) = JacC(117,117) - dw(313,117)
      JacC(119, 98) = JacC(119, 98) + dw(313, 98)
      JacC(119,117) = JacC(119,117) + dw(313,117)
      JacC(121, 98) = JacC(121, 98) + dw(313, 98)
      JacC(121,117) = JacC(121,117) + dw(313,117)
      JacC( 71, 71) = JacC( 71, 71) - dw(314, 71)
      JacC( 71,117) = JacC( 71,117) - dw(314,117)
      JacC(109, 71) = JacC(109, 71)+ 0.9399999999999999D+00*dw(314, 71)
      JacC(109,117) = JacC(109,117)+ 0.9399999999999999D+00*dw(314,117)
      JacC(111, 71) = JacC(111, 71)+ 0.6000000000000000D-01*dw(314, 71)
      JacC(111,117) = JacC(111,117)+ 0.6000000000000000D-01*dw(314,117)
      JacC(116, 71) = JacC(116, 71) + dw(314, 71)
      JacC(116,117) = JacC(116,117) + dw(314,117)
      JacC(117, 71) = JacC(117, 71) - dw(314, 71)
      JacC(117,117) = JacC(117,117) - dw(314,117)
      JacC(119, 71) = JacC(119, 71) + dw(314, 71)
      JacC(119,117) = JacC(119,117) + dw(314,117)
      JacC(121, 71) = JacC(121, 71) + dw(314, 71)
      JacC(121,117) = JacC(121,117) + dw(314,117)
      JacC( 87, 87) = JacC( 87, 87) - dw(315, 87)
      JacC( 87,117) = JacC( 87,117) - dw(315,117)
      JacC(109, 87) = JacC(109, 87)+ 0.1710000000000000D+01*dw(315, 87)
      JacC(109,117) = JacC(109,117)+ 0.1710000000000000D+01*dw(315,117)
      JacC(111, 87) = JacC(111, 87)+ 0.2900000000000000D+00*dw(315, 87)
      JacC(111,117) = JacC(111,117)+ 0.2900000000000000D+00*dw(315,117)
      JacC(117, 87) = JacC(117, 87) - dw(315, 87)
      JacC(117,117) = JacC(117,117) - dw(315,117)
      JacC(119, 87) = JacC(119, 87) + dw(315, 87)
      JacC(119,117) = JacC(119,117) + dw(315,117)
      JacC(121, 87) = JacC(121, 87) + dw(315, 87)
      JacC(121,117) = JacC(121,117) + dw(315,117)
      JacC( 80, 80) = JacC( 80, 80) - dw(316, 80)
      JacC( 80,117) = JacC( 80,117) - dw(316,117)
      JacC( 81, 80) = JacC( 81, 80)+ 0.6100000000000000D+00*dw(316, 80)
      JacC( 81,117) = JacC( 81,117)+ 0.6100000000000000D+00*dw(316,117)
      JacC( 92, 80) = JacC( 92, 80)+ 0.4380000000000000D+00*dw(316, 80)
      JacC( 92,117) = JacC( 92,117)+ 0.4380000000000000D+00*dw(316,117)
      JacC(116, 80) = JacC(116, 80)+ 0.1050000000000000D+01*dw(316, 80)
      JacC(116,117) = JacC(116,117)+ 0.1050000000000000D+01*dw(316,117)
      JacC(117, 80) = JacC(117, 80) - dw(316, 80)
      JacC(117,117) = JacC(117,117) - dw(316,117)
      JacC(119, 80) = JacC(119, 80) + dw(316, 80)
      JacC(119,117) = JacC(119,117) + dw(316,117)
      JacC(121, 80) = JacC(121, 80) + dw(316, 80)
      JacC(121,117) = JacC(121,117) + dw(316,117)
      JacC( 72, 72) = JacC( 72, 72) - dw(317, 72)
      JacC( 72,117) = JacC( 72,117) - dw(317,117)
      JacC(109, 72) = JacC(109, 72) + dw(317, 72)
      JacC(109,117) = JacC(109,117) + dw(317,117)
      JacC(111, 72) = JacC(111, 72) + dw(317, 72)
      JacC(111,117) = JacC(111,117) + dw(317,117)
      JacC(117, 72) = JacC(117, 72) - dw(317, 72)
      JacC(117,117) = JacC(117,117) - dw(317,117)
      JacC(119, 72) = JacC(119, 72) + dw(317, 72)
      JacC(119,117) = JacC(119,117) + dw(317,117)
      JacC(121, 72) = JacC(121, 72) + dw(317, 72)
      JacC(121,117) = JacC(121,117) + dw(317,117)
      JacC( 85, 85) = JacC( 85, 85) - dw(318, 85)
      JacC( 85,117) = JacC( 85,117) - dw(318,117)
      JacC( 86, 85) = JacC( 86, 85)+ 0.3850000000000000D+00*dw(318, 85)
      JacC( 86,117) = JacC( 86,117)+ 0.3850000000000000D+00*dw(318,117)
      JacC( 92, 85) = JacC( 92, 85)+ 0.6150000000000000D+00*dw(318, 85)
      JacC( 92,117) = JacC( 92,117)+ 0.6150000000000000D+00*dw(318,117)
      JacC(116, 85) = JacC(116, 85)+ 0.3850000000000000D+00*dw(318, 85)
      JacC(116,117) = JacC(116,117)+ 0.3850000000000000D+00*dw(318,117)
      JacC(117, 85) = JacC(117, 85) - dw(318, 85)
      JacC(117,117) = JacC(117,117) - dw(318,117)
      JacC(119, 85) = JacC(119, 85) + dw(318, 85)
      JacC(119,117) = JacC(119,117) + dw(318,117)
      JacC(121, 85) = JacC(121, 85) + dw(318, 85)
      JacC(121,117) = JacC(121,117) + dw(318,117)
      JacC( 77, 77) = JacC( 77, 77) - dw(319, 77)
      JacC( 77,117) = JacC( 77,117) - dw(319,117)
      JacC( 83, 77) = JacC( 83, 77)+ 0.5000000000000000D+00*dw(319, 77)
      JacC( 83,117) = JacC( 83,117)+ 0.5000000000000000D+00*dw(319,117)
      JacC( 86, 77) = JacC( 86, 77)+ 0.5000000000000000D+00*dw(319, 77)
      JacC( 86,117) = JacC( 86,117)+ 0.5000000000000000D+00*dw(319,117)
      JacC(102, 77) = JacC(102, 77) + dw(319, 77)
      JacC(102,117) = JacC(102,117) + dw(319,117)
      JacC(117, 77) = JacC(117, 77) - dw(319, 77)
      JacC(117,117) = JacC(117,117) - dw(319,117)
      JacC(119, 77) = JacC(119, 77) + dw(319, 77)
      JacC(119,117) = JacC(119,117) + dw(319,117)
      JacC(121, 77) = JacC(121, 77) + dw(319, 77)
      JacC(121,117) = JacC(121,117) + dw(319,117)
      JacC( 64, 64) = JacC( 64, 64) - dw(320, 64)
      JacC( 64,117) = JacC( 64,117) - dw(320,117)
      JacC( 65, 64) = JacC( 65, 64)+ 0.7700000000000000D-01*dw(320, 64)
      JacC( 65,117) = JacC( 65,117)+ 0.7700000000000000D-01*dw(320,117)
      JacC( 68, 64) = JacC( 68, 64)+ 0.7370000000000000D+00*dw(320, 64)
      JacC( 68,117) = JacC( 68,117)+ 0.7370000000000000D+00*dw(320,117)
      JacC( 69, 64) = JacC( 69, 64)+ 0.1860000000000000D+00*dw(320, 64)
      JacC( 69,117) = JacC( 69,117)+ 0.1860000000000000D+00*dw(320,117)
      JacC(100, 64) = JacC(100, 64)+ 0.6320000000000000D+00*dw(320, 64)
      JacC(100,117) = JacC(100,117)+ 0.6320000000000000D+00*dw(320,117)
      JacC(102, 64) = JacC(102, 64)+ 0.3680000000000000D+00*dw(320, 64)
      JacC(102,117) = JacC(102,117)+ 0.3680000000000000D+00*dw(320,117)
      JacC(117, 64) = JacC(117, 64) - dw(320, 64)
      JacC(117,117) = JacC(117,117) - dw(320,117)
      JacC(119, 64) = JacC(119, 64) + dw(320, 64)
      JacC(119,117) = JacC(119,117) + dw(320,117)
      JacC(121, 64) = JacC(121, 64) + dw(320, 64)
      JacC(121,117) = JacC(121,117) + dw(320,117)
      JacC( 75, 97) = JacC( 75, 97)+ 0.3200000000000000D+00*dw(321, 97)
      JacC( 75,117) = JacC( 75,117)+ 0.3200000000000000D+00*dw(321,117)
      JacC( 97, 97) = JacC( 97, 97) - dw(321, 97)
      JacC( 97,117) = JacC( 97,117) - dw(321,117)
      JacC(102, 97) = JacC(102, 97)+ 0.6800000000000000D+00*dw(321, 97)
      JacC(102,117) = JacC(102,117)+ 0.6800000000000000D+00*dw(321,117)
      JacC(115, 97) = JacC(115, 97)+ 0.6800000000000000D+00*dw(321, 97)
      JacC(115,117) = JacC(115,117)+ 0.6800000000000000D+00*dw(321,117)
      JacC(117, 97) = JacC(117, 97) - dw(321, 97)
      JacC(117,117) = JacC(117,117) - dw(321,117)
      JacC(119, 97) = JacC(119, 97) + dw(321, 97)
      JacC(119,117) = JacC(119,117) + dw(321,117)
      JacC(121, 97) = JacC(121, 97) + dw(321, 97)
      JacC(121,117) = JacC(121,117) + dw(321,117)
      JacC(113,122) = JacC(113,122) + dw(322,122)
      JacC(113,117) = JacC(113,117) + dw(322,117)
      JacC(117,122) = JacC(117,122) - dw(322,122)
      JacC(117,117) = JacC(117,117) - dw(322,117)
      JacC(121,122) = JacC(121,122) + dw(322,122)
      JacC(121,117) = JacC(121,117) + dw(322,117)
      JacC(122,122) = JacC(122,122) - dw(322,122)
      JacC(122,117) = JacC(122,117) - dw(322,117)
      JacC(114,120) = JacC(114,120) + dw(323,120)
      JacC(114,117) = JacC(114,117) + dw(323,117)
      JacC(117,120) = JacC(117,120) - dw(323,120)
      JacC(117,117) = JacC(117,117) - dw(323,117)
      JacC(120,120) = JacC(120,120) - dw(323,120)
      JacC(120,117) = JacC(120,117) - dw(323,117)
      JacC(121,120) = JacC(121,120) + dw(323,120)
      JacC(121,117) = JacC(121,117) + dw(323,117)
      JacC( 67, 67) = JacC( 67, 67) - dw(324, 67)
      JacC( 67,117) = JacC( 67,117) - dw(324,117)
      JacC( 68, 67) = JacC( 68, 67)+ 0.6700000000000000D+00*dw(324, 67)
      JacC( 68,117) = JacC( 68,117)+ 0.6700000000000000D+00*dw(324,117)
      JacC(116, 67) = JacC(116, 67)+ 0.3300000000000000D+00*dw(324, 67)
      JacC(116,117) = JacC(116,117)+ 0.3300000000000000D+00*dw(324,117)
      JacC(117, 67) = JacC(117, 67) - dw(324, 67)
      JacC(117,117) = JacC(117,117) - dw(324,117)
      JacC(119, 67) = JacC(119, 67)+ 0.6700000000000000D+00*dw(324, 67)
      JacC(119,117) = JacC(119,117)+ 0.6700000000000000D+00*dw(324,117)
      JacC(121, 67) = JacC(121, 67) + dw(324, 67)
      JacC(121,117) = JacC(121,117) + dw(324,117)
      JacC( 68,105) = JacC( 68,105) + dw(325,105)
      JacC( 68,117) = JacC( 68,117) + dw(325,117)
      JacC(105,105) = JacC(105,105) - dw(325,105)
      JacC(105,117) = JacC(105,117) - dw(325,117)
      JacC(117,105) = JacC(117,105) - dw(325,105)
      JacC(117,117) = JacC(117,117) - dw(325,117)
      JacC(119,105) = JacC(119,105) + dw(325,105)
      JacC(119,117) = JacC(119,117) + dw(325,117)
      JacC(121,105) = JacC(121,105) + dw(325,105)
      JacC(121,117) = JacC(121,117) + dw(325,117)
      JacC( 78, 78) = JacC( 78, 78) - dw(326, 78)
      JacC( 78,117) = JacC( 78,117) - dw(326,117)
      JacC(116, 78) = JacC(116, 78) + dw(326, 78)
      JacC(116,117) = JacC(116,117) + dw(326,117)
      JacC(117, 78) = JacC(117, 78) - dw(326, 78)
      JacC(117,117) = JacC(117,117) - dw(326,117)
      JacC(121, 78) = JacC(121, 78) + dw(326, 78)
      JacC(121,117) = JacC(121,117) + dw(326,117)
      JacC(122, 78) = JacC(122, 78) + dw(326, 78)
      JacC(122,117) = JacC(122,117) + dw(326,117)
      JacC( 90, 90) = JacC( 90, 90) - dw(327, 90)
      JacC( 90,117) = JacC( 90,117) - dw(327,117)
      JacC(108, 90) = JacC(108, 90) + dw(327, 90)
      JacC(108,117) = JacC(108,117) + dw(327,117)
      JacC(117, 90) = JacC(117, 90) - dw(327, 90)
      JacC(117,117) = JacC(117,117) - dw(327,117)
      JacC(119, 90) = JacC(119, 90) + dw(327, 90)
      JacC(119,117) = JacC(119,117) + dw(327,117)
      JacC(121, 90) = JacC(121, 90) + dw(327, 90)
      JacC(121,117) = JacC(121,117) + dw(327,117)
      JacC( 88, 88) = JacC( 88, 88) - dw(328, 88)
      JacC( 88,117) = JacC( 88,117) - dw(328,117)
      JacC(109, 88) = JacC(109, 88)+ 0.1240000000000000D+01*dw(328, 88)
      JacC(109,117) = JacC(109,117)+ 0.1240000000000000D+01*dw(328,117)
      JacC(111, 88) = JacC(111, 88)+ 0.4640000000000000D+00*dw(328, 88)
      JacC(111,117) = JacC(111,117)+ 0.4640000000000000D+00*dw(328,117)
      JacC(116, 88) = JacC(116, 88)+ 0.2870000000000000D+00*dw(328, 88)
      JacC(116,117) = JacC(116,117)+ 0.2870000000000000D+00*dw(328,117)
      JacC(117, 88) = JacC(117, 88) - dw(328, 88)
      JacC(117,117) = JacC(117,117) - dw(328,117)
      JacC(121, 88) = JacC(121, 88)+ 0.2000000000000000D+01*dw(328, 88)
      JacC(121,117) = JacC(121,117)+ 0.2000000000000000D+01*dw(328,117)
      JacC( 82, 82) = JacC( 82, 82) - dw(329, 82)
      JacC( 82,117) = JacC( 82,117) - dw(329,117)
      JacC(100, 82) = JacC(100, 82) + dw(329, 82)
      JacC(100,117) = JacC(100,117) + dw(329,117)
      JacC(109, 82) = JacC(109, 82)+ 0.7000000000000000D+00*dw(329, 82)
      JacC(109,117) = JacC(109,117)+ 0.7000000000000000D+00*dw(329,117)
      JacC(112, 82) = JacC(112, 82)+ 0.2300000000000000D+01*dw(329, 82)
      JacC(112,117) = JacC(112,117)+ 0.2300000000000000D+01*dw(329,117)
      JacC(116, 82) = JacC(116, 82)+ 0.3000000000000000D+00*dw(329, 82)
      JacC(116,117) = JacC(116,117)+ 0.3000000000000000D+00*dw(329,117)
      JacC(117, 82) = JacC(117, 82) - dw(329, 82)
      JacC(117,117) = JacC(117,117) - dw(329,117)
      JacC(119, 82) = JacC(119, 82) + dw(329, 82)
      JacC(119,117) = JacC(119,117) + dw(329,117)
      JacC(121, 82) = JacC(121, 82) + dw(329, 82)
      JacC(121,117) = JacC(121,117) + dw(329,117)
      JacC(122, 82) = JacC(122, 82)+ 0.2300000000000000D+01*dw(329, 82)
      JacC(122,117) = JacC(122,117)+ 0.2300000000000000D+01*dw(329,117)
      JacC( 93,104) = JacC( 93,104)+ 0.3300000000000000D+00*dw(330,104)
      JacC( 93,117) = JacC( 93,117)+ 0.3300000000000000D+00*dw(330,117)
      JacC(100,104) = JacC(100,104)+ 0.6670000000000000D+00*dw(330,104)
      JacC(100,117) = JacC(100,117)+ 0.6670000000000000D+00*dw(330,117)
      JacC(104,104) = JacC(104,104) - dw(330,104)
      JacC(104,117) = JacC(104,117) - dw(330,117)
      JacC(107,104) = JacC(107,104)+ 0.3300000000000000D+00*dw(330,104)
      JacC(107,117) = JacC(107,117)+ 0.3300000000000000D+00*dw(330,117)
      JacC(116,104) = JacC(116,104) + dw(330,104)
      JacC(116,117) = JacC(116,117) + dw(330,117)
      JacC(117,104) = JacC(117,104) - dw(330,104)
      JacC(117,117) = JacC(117,117) - dw(330,117)
      JacC(119,104) = JacC(119,104) + dw(330,104)
      JacC(119,117) = JacC(119,117) + dw(330,117)
      JacC(121,104) = JacC(121,104) + dw(330,104)
      JacC(121,117) = JacC(121,117) + dw(330,117)
      JacC(122,104) = JacC(122,104)+ 0.3300000000000000D+00*dw(330,104)
      JacC(122,117) = JacC(122,117)+ 0.3300000000000000D+00*dw(330,117)
      JacC( 53, 53) = JacC( 53, 53) - dw(331, 53)
      JacC( 53,117) = JacC( 53,117) - dw(331,117)
      JacC( 56, 53) = JacC( 56, 53) + dw(331, 53)
      JacC( 56,117) = JacC( 56,117) + dw(331,117)
      JacC(117, 53) = JacC(117, 53) - dw(331, 53)
      JacC(117,117) = JacC(117,117) - dw(331,117)
      JacC(121, 53) = JacC(121, 53) + dw(331, 53)
      JacC(121,117) = JacC(121,117) + dw(331,117)
      JacC( 54, 54) = JacC( 54, 54) - dw(332, 54)
      JacC( 54,117) = JacC( 54,117) - dw(332,117)
      JacC( 65, 54) = JacC( 65, 54) + dw(332, 54)
      JacC( 65,117) = JacC( 65,117) + dw(332,117)
      JacC(117, 54) = JacC(117, 54) - dw(332, 54)
      JacC(117,117) = JacC(117,117) - dw(332,117)
      JacC(119, 54) = JacC(119, 54) + dw(332, 54)
      JacC(119,117) = JacC(119,117) + dw(332,117)
      JacC(121, 54) = JacC(121, 54) + dw(332, 54)
      JacC(121,117) = JacC(121,117) + dw(332,117)
      JacC( 52, 52) = JacC( 52, 52) - dw(333, 52)
      JacC( 52,117) = JacC( 52,117) - dw(333,117)
      JacC( 68, 52) = JacC( 68, 52) + dw(333, 52)
      JacC( 68,117) = JacC( 68,117) + dw(333,117)
      JacC(100, 52) = JacC(100, 52) + dw(333, 52)
      JacC(100,117) = JacC(100,117) + dw(333,117)
      JacC(117, 52) = JacC(117, 52) - dw(333, 52)
      JacC(117,117) = JacC(117,117) - dw(333,117)
      JacC(119, 52) = JacC(119, 52) + dw(333, 52)
      JacC(119,117) = JacC(119,117) + dw(333,117)
      JacC(121, 52) = JacC(121, 52) + dw(333, 52)
      JacC(121,117) = JacC(121,117) + dw(333,117)
      JacC( 55, 55) = JacC( 55, 55) - dw(334, 55)
      JacC( 55,117) = JacC( 55,117) - dw(334,117)
      JacC( 56, 55) = JacC( 56, 55) + dw(334, 55)
      JacC( 56,117) = JacC( 56,117) + dw(334,117)
      JacC(117, 55) = JacC(117, 55) - dw(334, 55)
      JacC(117,117) = JacC(117,117) - dw(334,117)
      JacC(121, 55) = JacC(121, 55) + dw(334, 55)
      JacC(121,117) = JacC(121,117) + dw(334,117)
      JacC( 60, 60) = JacC( 60, 60) - dw(335, 60)
      JacC( 60,117) = JacC( 60,117) - dw(335,117)
      JacC( 65, 60) = JacC( 65, 60) + dw(335, 60)
      JacC( 65,117) = JacC( 65,117) + dw(335,117)
      JacC(117, 60) = JacC(117, 60) - dw(335, 60)
      JacC(117,117) = JacC(117,117) - dw(335,117)
      JacC(119, 60) = JacC(119, 60) + dw(335, 60)
      JacC(119,117) = JacC(119,117) + dw(335,117)
      JacC(121, 60) = JacC(121, 60) + dw(335, 60)
      JacC(121,117) = JacC(121,117) + dw(335,117)
      JacC( 63, 63) = JacC( 63, 63) - dw(336, 63)
      JacC( 63,117) = JacC( 63,117) - dw(336,117)
      JacC( 68, 63) = JacC( 68, 63) + dw(336, 63)
      JacC( 68,117) = JacC( 68,117) + dw(336,117)
      JacC( 69, 63) = JacC( 69, 63)+ 0.2050000000000000D+01*dw(336, 63)
      JacC( 69,117) = JacC( 69,117)+ 0.2050000000000000D+01*dw(336,117)
      JacC(100, 63) = JacC(100, 63) + dw(336, 63)
      JacC(100,117) = JacC(100,117) + dw(336,117)
      JacC(117, 63) = JacC(117, 63) - dw(336, 63)
      JacC(117,117) = JacC(117,117) - dw(336,117)
      JacC(119, 63) = JacC(119, 63) + dw(336, 63)
      JacC(119,117) = JacC(119,117) + dw(336,117)
      JacC(121, 63) = JacC(121, 63) + dw(336, 63)
      JacC(121,117) = JacC(121,117) + dw(336,117)
      JacC( 57, 57) = JacC( 57, 57) - dw(337, 57)
      JacC( 57,117) = JacC( 57,117) - dw(337,117)
      JacC( 58, 57) = JacC( 58, 57) + dw(337, 57)
      JacC( 58,117) = JacC( 58,117) + dw(337,117)
      JacC(117, 57) = JacC(117, 57) - dw(337, 57)
      JacC(117,117) = JacC(117,117) - dw(337,117)
      JacC(121, 57) = JacC(121, 57) + dw(337, 57)
      JacC(121,117) = JacC(121,117) + dw(337,117)
      JacC( 58, 58) = JacC( 58, 58) - dw(338, 58)
      JacC( 58,117) = JacC( 58,117) - dw(338,117)
      JacC( 59, 58) = JacC( 59, 58) + dw(338, 58)
      JacC( 59,117) = JacC( 59,117) + dw(338,117)
      JacC(117, 58) = JacC(117, 58) - dw(338, 58)
      JacC(117,117) = JacC(117,117) - dw(338,117)
      JacC(121, 58) = JacC(121, 58) + dw(338, 58)
      JacC(121,117) = JacC(121,117) + dw(338,117)
      JacC( 84, 84) = JacC( 84, 84) - dw(339, 84)
      JacC( 84,117) = JacC( 84,117) - dw(339,117)
      JacC(100, 84) = JacC(100, 84)+ 0.2100000000000000D+00*dw(339, 84)
      JacC(100,117) = JacC(100,117)+ 0.2100000000000000D+00*dw(339,117)
      JacC(102, 84) = JacC(102, 84)+ 0.1800000000000000D+00*dw(339, 84)
      JacC(102,117) = JacC(102,117)+ 0.1800000000000000D+00*dw(339,117)
      JacC(107, 84) = JacC(107, 84)+ 0.6100000000000000D+00*dw(339, 84)
      JacC(107,117) = JacC(107,117)+ 0.6100000000000000D+00*dw(339,117)
      JacC(109, 84) = JacC(109, 84)+ 0.2700000000000000D+00*dw(339, 84)
      JacC(109,117) = JacC(109,117)+ 0.2700000000000000D+00*dw(339,117)
      JacC(111, 84) = JacC(111, 84)+ 0.7000000000000000D+00*dw(339, 84)
      JacC(111,117) = JacC(111,117)+ 0.7000000000000000D+00*dw(339,117)
      JacC(116, 84) = JacC(116, 84)+ 0.3000000000000000D-01*dw(339, 84)
      JacC(116,117) = JacC(116,117)+ 0.3000000000000000D-01*dw(339,117)
      JacC(117, 84) = JacC(117, 84) - dw(339, 84)
      JacC(117,117) = JacC(117,117) - dw(339,117)
      JacC(119, 84) = JacC(119, 84) + dw(339, 84)
      JacC(119,117) = JacC(119,117) + dw(339,117)
      JacC(121, 84) = JacC(121, 84) + dw(339, 84)
      JacC(121,117) = JacC(121,117) + dw(339,117)
      JacC(112,112) = JacC(112,112) - dw(340,112)
      JacC(112,119) = JacC(112,119) - dw(340,119)
      JacC(115,112) = JacC(115,112) + dw(340,112)
      JacC(115,119) = JacC(115,119) + dw(340,119)
      JacC(119,112) = JacC(119,112) - dw(340,112)
      JacC(119,119) = JacC(119,119) - dw(340,119)
      JacC(112,112) = JacC(112,112) - dw(341,112)
      JacC(112,113) = JacC(112,113) - dw(341,113)
      JacC(113,112) = JacC(113,112) - dw(341,112)
      JacC(113,113) = JacC(113,113) - dw(341,113)
      JacC(116,112) = JacC(116,112) + dw(341,112)
      JacC(116,113) = JacC(116,113) + dw(341,113)
      JacC(119,112) = JacC(119,112) + dw(341,112)
      JacC(119,113) = JacC(119,113) + dw(341,113)
      JacC(112,112) = JacC(112,112) - dw(342,112)
      JacC(112,122) = JacC(112,122) - dw(342,122)
      JacC(113,112) = JacC(113,112) + dw(342,112)
      JacC(113,122) = JacC(113,122) + dw(342,122)
      JacC(122,112) = JacC(122,112) - dw(342,112)
      JacC(122,122) = JacC(122,122) - dw(342,122)
      JacC(112,112) = JacC(112,112)- 0.2000000000000000D+01*dw(343,112)
      JacC(112,112) = JacC(112,112)- 0.2000000000000000D+01*dw(343,112)
      JacC(112,112) = JacC(112,112) - dw(344,112)
      JacC(112,123) = JacC(112,123) - dw(344,123)
      JacC(121,112) = JacC(121,112) + dw(344,112)
      JacC(121,123) = JacC(121,123) + dw(344,123)
      JacC(123,112) = JacC(123,112) - dw(344,112)
      JacC(123,123) = JacC(123,123) - dw(344,123)
      JacC(112,112) = JacC(112,112) - dw(345,112)
      JacC(112,117) = JacC(112,117) - dw(345,117)
      JacC(117,112) = JacC(117,112) - dw(345,112)
      JacC(117,117) = JacC(117,117) - dw(345,117)
      JacC(121,112) = JacC(121,112) + dw(345,112)
      JacC(121,117) = JacC(121,117) + dw(345,117)
      JacC(102,103) = JacC(102,103) + dw(346,103)
      JacC(102,123) = JacC(102,123) + dw(346,123)
      JacC(103,103) = JacC(103,103) - dw(346,103)
      JacC(103,123) = JacC(103,123) - dw(346,123)
      JacC(119,103) = JacC(119,103) + dw(346,103)
      JacC(119,123) = JacC(119,123) + dw(346,123)
      JacC(121,103) = JacC(121,103) + dw(346,103)
      JacC(121,123) = JacC(121,123) + dw(346,123)
      JacC(123,103) = JacC(123,103) - dw(346,103)
      JacC(123,123) = JacC(123,123) - dw(346,123)
      JacC(103,103) = JacC(103,103) - dw(347,103)
      JacC(103,119) = JacC(103,119) - dw(347,119)
      JacC(115,103) = JacC(115,103) + dw(347,103)
      JacC(115,119) = JacC(115,119) + dw(347,119)
      JacC(119,103) = JacC(119,103) - dw(347,103)
      JacC(119,119) = JacC(119,119) - dw(347,119)
      JacC(102,103) = JacC(102,103) + dw(348,103)
      JacC(102,113) = JacC(102,113) + dw(348,113)
      JacC(103,103) = JacC(103,103) - dw(348,103)
      JacC(103,113) = JacC(103,113) - dw(348,113)
      JacC(113,103) = JacC(113,103) - dw(348,103)
      JacC(113,113) = JacC(113,113) - dw(348,113)
      JacC(116,103) = JacC(116,103) + dw(348,103)
      JacC(116,113) = JacC(116,113) + dw(348,113)
      JacC(119,103) = JacC(119,103) + dw(348,103)
      JacC(119,113) = JacC(119,113) + dw(348,113)
      JacC(102,103) = JacC(102,103) + dw(349,103)
      JacC(102,122) = JacC(102,122) + dw(349,122)
      JacC(103,103) = JacC(103,103) - dw(349,103)
      JacC(103,122) = JacC(103,122) - dw(349,122)
      JacC(113,103) = JacC(113,103) + dw(349,103)
      JacC(113,122) = JacC(113,122) + dw(349,122)
      JacC(122,103) = JacC(122,103) - dw(349,103)
      JacC(122,122) = JacC(122,122) - dw(349,122)
      JacC(102,103) = JacC(102,103) + dw(350,103)
      JacC(102,117) = JacC(102,117) + dw(350,117)
      JacC(103,103) = JacC(103,103) - dw(350,103)
      JacC(103,117) = JacC(103,117) - dw(350,117)
      JacC(117,103) = JacC(117,103) - dw(350,103)
      JacC(117,117) = JacC(117,117) - dw(350,117)
      JacC(119,103) = JacC(119,103) + dw(350,103)
      JacC(119,117) = JacC(119,117) + dw(350,117)
      JacC(121,103) = JacC(121,103) + dw(350,103)
      JacC(121,117) = JacC(121,117) + dw(350,117)
      JacC(113,120) = JacC(113,120) + dw(351,120)
      JacC(113,122) = JacC(113,122) + dw(351,122)
      JacC(114,120) = JacC(114,120) + dw(351,120)
      JacC(114,122) = JacC(114,122) + dw(351,122)
      JacC(120,120) = JacC(120,120) - dw(351,120)
      JacC(120,122) = JacC(120,122) - dw(351,122)
      JacC(122,120) = JacC(122,120) - dw(351,120)
      JacC(122,122) = JacC(122,122) - dw(351,122)
      JacC( 51,119) = JacC( 51,119)+ 0.5000000000000000D+00*dw(352,119)
      JacC(119,119) = JacC(119,119) - dw(352,119)
      JacC( 24,121) = JacC( 24,121)+ 0.5000000000000000D+00*dw(353,121)
      JacC(101,121) = JacC(101,121)+ 0.5000000000000000D+00*dw(353,121)
      JacC(121,121) = JacC(121,121) - dw(353,121)
      JacC(101,117) = JacC(101,117) + dw(354,117)
      JacC(117,117) = JacC(117,117) - dw(354,117)
      JacC( 18, 18) = JacC( 18, 18) - dw(355, 18)
      JacC(101, 18) = JacC(101, 18)+ 0.2000000000000000D+01*dw(355, 18)
 
      do j = 1, ns
         do i = 1, ns
            JacC(i,j) = JacC(i,j) * convers_factor_jac(i,j)
         enddo
      enddo
 
 
      RETURN
      END
 
